@@ -1,4 +1,3 @@
-/* $Id: functions.c,v 1.20 2001/06/22 19:06:04 amai Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -41,21 +40,22 @@
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
-#include <LTconfig.h>
+#include "mwm.h"
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
 #include <ctype.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#include <stdio.h>
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
 #endif
+#ifdef HAVE_LIMITS_H
+#include <limits.h>
+#endif
 #ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
@@ -63,13 +63,8 @@
 #include <process.h>
 #endif
 
-#include <Xm/Xm.h>
-#include <Xm/MwmUtil.h>
 #include <Xm/MessageB.h>
 
-#include "mwm.h"
-
-
 /*
  * this only works if what you're assigning to/comparing with is an int
  */
@@ -82,8 +77,8 @@
 
 extern int menuFromFrameOrWindowOrTitlebar;
 extern Bool DoHandlePageing;
+extern XtAppContext app;
 extern volatile int alarmed;
-extern Bool debugging;
 
 extern char **g_argv;
 
@@ -96,7 +91,7 @@ extern char **g_argv;
  * It is public domain, no strings attached. No guarantees either.
  */
 static int
-match_pattern(const char *pattern, const char *string)
+match_pattern(char *pattern, char *string)
 {
     if (string == NULL)
     {
@@ -365,8 +360,8 @@ circulate(ScreenInfo *scr, MwmWindow *tmp_win, char *action, Bool Direction)
 	    if (action && (strlen(action) > 0) &&
 		!(match_pattern(action, t->name)) &&
 		!(match_pattern(action, t->icon_label)) &&
-		t->classhint.res_name &&
-		!(match_pattern(action, t->classhint.res_name)))
+		t->class.res_name &&
+		!(match_pattern(action, t->class.res_name)))
 		found = False;
 	    if ((found) && (Direction == DOWN) && (t->focus_sequence > best))
 	    {
@@ -421,12 +416,6 @@ maximize(ScreenInfo *scr, MwmWindow *tmp_win, int val1, int val2,
 {
     int new_width, new_height, new_x, new_y;
 
-    /* First make sure that window is de-iconified */
-    if (tmp_win->flags & ICONIFIED)
-    {
-	    if (val1 <= 0)
-		ICON_DeIconify(scr, tmp_win);
-    }
     if (tmp_win->flags & MAXIMIZED)
     {
 	tmp_win->flags &= ~MAXIMIZED;
@@ -584,8 +573,8 @@ restart(ScreenInfo *scr)
 		      XmNwidth, &wd, XmNheight, &ht, NULL);
 
 	XtVaSetValues(XtParent(restart_mb),
-		      XmNx, (scr->d_width - wd) / 2 - scr->frame_border_width,
-		      XmNy, (scr->d_height - ht) / 2 - scr->frame_border_width,
+		      XmNx, (scr->d_width - wd) / 2 - Mwm.frame_border_width,
+		      XmNy, (scr->d_height - ht) / 2 - Mwm.frame_border_width,
 		      NULL);
     }
 
@@ -651,8 +640,8 @@ quit(ScreenInfo *scr)
 	XtVaGetValues(quit_mb, XmNwidth, &wd, XmNheight, &ht, NULL);
 
 	XtVaSetValues(XtParent(quit_mb),
-		      XmNx, (scr->d_width - wd) / 2 - scr->frame_border_width,
-		      XmNy, (scr->d_height - ht) / 2 - scr->frame_border_width,
+		      XmNx, (scr->d_width - wd) / 2 - Mwm.frame_border_width,
+		      XmNy, (scr->d_height - ht) / 2 - Mwm.frame_border_width,
 		      NULL);
     }
 
@@ -740,8 +729,8 @@ set_behavior(ScreenInfo *scr)
 		      XmNwidth, &wd, XmNheight, &ht, NULL);
 
 	XtVaSetValues(XtParent(toggle_mb),
-		      XmNx, (scr->d_width - wd) / 2 - scr->frame_border_width,
-		      XmNy, (scr->d_height - ht) / 2 - scr->frame_border_width,
+		      XmNx, (scr->d_width - wd) / 2 - Mwm.frame_border_width,
+		      XmNy, (scr->d_height - ht) / 2 - Mwm.frame_border_width,
 		      NULL);
     }
 
@@ -880,14 +869,14 @@ win_list(ScreenInfo *scr, int val1, int val2)
 	if (mi->func != F_TITLE)
 	{
 	    if (mi->item != NULL)
-		XtFree(mi->item);
+		free(mi->item);
 	    if (mi->item2 != NULL)
-		XtFree(mi->item2);
+		free(mi->item2);
 	}
-	XtFree((char *)mi);
+	free(mi);
 	mi = tmp;
     }
-    XtFree((char *)mr);
+    free(mr);
 }
 
 /*
@@ -907,32 +896,6 @@ ExplicitMoveFocus(ScreenInfo *scr, MwmWindow *win, XEvent *event)
     }
 }
 
-/***********************************************************************
- *
- *  Procedure:
- *	(Un)normalize a window.
- *
- ***********************************************************************/
-static void
-normalize(ScreenInfo *scr, MwmWindow *tmp_win, int val1, int val2,
-	 int val1_unit, int val2_unit)
-{
-   /* Deiconify if iconified */
-   if (tmp_win->flags & ICONIFIED)
-   {
-      if (val1 <= 0)
-         ICON_DeIconify(scr, tmp_win);
-   } else
-      /* DeMaximize if maximized */
-      if (tmp_win->flags & MAXIMIZED) {
-         /* Taken from maximize() */
-         tmp_win->flags &= ~MAXIMIZED;
-         DEC_ConfigureDecorations(scr, tmp_win, tmp_win->orig_x, tmp_win->orig_y,
-               tmp_win->orig_wd, tmp_win->orig_ht, True);
-         DEC_DrawDecorations(scr, tmp_win, True, True, True, None);
-      }
-}
-
 /*
  * execute a mwm built in function
  */
@@ -948,17 +911,6 @@ FUNC_Execute(ScreenInfo *scr, int func, char *action, Window in_w,
     int warp_x = 0, warp_y = 0;
     Pixel TextColor, BackColor;
     Pixmap BackPixmap;
-    static int prev_screen = -1;
-    int scrno;
-
-    if (debugging) {
-       fprintf(stderr,
-             "FUNC_Execute: func %d %s context %s menu %s (%s)\n",
-             func, _MwmPrintF(func),
-             _MwmPrintC(context), 
-             menu ? menu->name : "(none)",
-             action);
-    }
 
     /* Defer Execution may wish to alter this value */
     w = in_w;
@@ -1032,7 +984,6 @@ FUNC_Execute(ScreenInfo *scr, int func, char *action, Window in_w,
 
     case F_EXEC:
 	{
-#ifndef __EMX__
 	    char *shell;
 
 	    if ((shell = getenv(MWM_SHELL_NAME)) == NULL)
@@ -1042,8 +993,6 @@ FUNC_Execute(ScreenInfo *scr, int func, char *action, Window in_w,
 		    shell = DEFAULT_SHELL;
 		}
 	    }
-#endif
-
 	    XGrabPointer(dpy, scr->root_win, True,
 			 ButtonPressMask | ButtonReleaseMask,
 			 GrabModeAsync, GrabModeAsync,
@@ -1053,60 +1002,11 @@ FUNC_Execute(ScreenInfo *scr, int func, char *action, Window in_w,
 #ifndef __EMX__
 	    if (!fork())
 	    {
-		char *disp_scr;
-		char *p_colon, *p_rdot;
-
-		/*
-		 * Make the child run on proper screen rather than on one
-		 * default for this instance of window manager. 
-		 */
-		disp_scr=(char *)malloc(strlen(DisplayString(dpy))+12);
-		strcpy(disp_scr, DisplayString(dpy));
-		p_colon = strrchr(disp_scr, ':');
-		if (p_colon == NULL)
-		    exit(102); 			/* erroneous display string */
-
-		p_rdot = strrchr(p_colon, '.');
-		if (p_rdot == NULL) {
-		    p_rdot = disp_scr + strlen(disp_scr);
-		}
-		sprintf(p_rdot, ".%lu", scr->screen);
-		if (SetEnvironment("DISPLAY", disp_scr) == -1)
-		    exit(104);
-
 		if (execl(shell, shell, "-c", action, (char *)0) == -1)
 		    exit(100);
 	    }
 #else
-         {
-          int childpid;
-          char *disp_scr;
-          char *p_colon, *p_rdot;
-
-		/*
-		 * Make the child run on proper screen rather than on one
-		 * default for this instance of window manager. 
-		 */
-		disp_scr=(char *)malloc(strlen(DisplayString(dpy))+12);
-		strcpy(disp_scr, DisplayString(dpy));
-		p_colon = strrchr(disp_scr, ':');
-		if (p_colon == NULL)
-		    exit(102); 			/* erroneous display string */
-
-		p_rdot = strrchr(p_colon, '.');
-		if (p_rdot == NULL) {
-		    p_rdot = disp_scr + strlen(disp_scr);
-		}
-		sprintf(p_rdot, ".%lu", scr->screen);
-		if (SetEnvironment("DISPLAY", disp_scr) == -1)
-		    exit(104);
-
-          /* FIXME: this shouldn't be an unconditional call to cmd.exe.
-                    Instead we should figure out which shell to call
-                    according to the XFree86 OS/2 standard! */
-	    childpid = spawnl(P_NOWAIT, "cmd.exe", "cmd.exe", "/C",
-                     action,(char *)0);
-         }
+	    spawnl(P_NOWAIT,"cmd.exe","cmd.exe","/C",action,(char *)0);
 #endif
 	    XUngrabPointer(dpy, CurrentTime);
 	    XSync(dpy, 0);
@@ -1165,14 +1065,11 @@ FUNC_Execute(ScreenInfo *scr, int func, char *action, Window in_w,
 	break;
 
     case F_MAXIMIZE:
-	if (tmp_win == NULL) {
-           fprintf(stderr, "Could not maximize - tmp_win is 0\n");
+	if (tmp_win == NULL)
 	    break;
-        }
 
 	if (function_allowed(func, tmp_win) == 0)
 	{
-           fprintf(stderr, "Could not maximize - op not allowed\n");
 	    XBell(dpy, scr->screen);
 	    break;
 	}
@@ -1254,15 +1151,11 @@ FUNC_Execute(ScreenInfo *scr, int func, char *action, Window in_w,
 	break;
 
     case F_NORMALIZE:
-	if (tmp_win == NULL)
-	    break;
-	normalize(scr, tmp_win, val1, val2, val1_unit, val2_unit);
+	fprintf(stderr, "NORMALIZE NOT SUPPORTED YET\n");
 	break;
 
     case F_NORM_AND_RAISE:
-	normalize(scr, tmp_win, val1, val2, val1_unit, val2_unit);
-	if (tmp_win)
-	    WIN_Raise(scr, MISC_RootOfTree(tmp_win));
+	fprintf(stderr, "NORM_AND_RAISE NOT SUPPORTED YET\n");
 	break;
 
     case F_PACK_ICONS:
@@ -1422,58 +1315,7 @@ FUNC_Execute(ScreenInfo *scr, int func, char *action, Window in_w,
 	break;
 
     case F_SCREEN:
-	{
-	    if (prev_screen == -1)
-                prev_screen = scr->screen;
-
-	    if (strcmp(action, "next") == 0)
-	        scrno = scr->screen + 1;
-	    else if (strcmp(action, "prev") == 0)
-	        scrno = scr->screen - 1;
-	    else if (strcmp(action, "back") == 0)
-	        scrno = prev_screen;
-	    else
-	        scrno = atoi(action);
-
-	    /* A.R. This assumes we have all our screens managed.
-	     * FIXME: Skip unmanaged screens if any...
-	     */
-	    scrno %= Mwm.number_of_screens;
-	    if (scrno < 0)
-	        scrno += Mwm.number_of_screens;
-
-	    if (scrno == scr->screen)
-		    break;
-	    prev_screen = scr->screen;
-
-	    /* FIXME: 
-	     * Without this call to MISC_Ungrab() f.screen does not 
-	     * work when called from a menu. That's because upper functions
-	     * from menus.c grab the pointer and we are not able to warp to
-	     * another root window.
-	     *     "Note you cannot use XWarpPointer to move the pointer
-	     *      outside the confine_to window of an active grab."
-	     *
-	     * MISC_Ungrab() here does much more things than we really 
-	     * need. IMHO, the design of update_menu() and friends should
-	     * better be changed to restore from all those settings
-	     * actual for the menu only, before FUNC_Exec() is invoked.
-	     * For now, MISC_Ungrab() is called here.
-	     * 
-	     * 		Andrei Rezvov <rezvov@niisi.msk.ru>
-	     */
-	    MISC_Ungrab(scr);
-
-	    XQueryPointer(dpy, scr->root_win/*eventp->root*/, 
-		          &JunkRoot, &JunkChild,
-		          &x, &y, &JunkX, &JunkY, &JunkMask);
-	    XWarpPointer(dpy, None, Mwm.screen_info[scrno]->root_win, 
-		          0, 0, 0, 0, x, y);
-
-	    XSetInputFocus(dpy, PointerRoot, RevertToParent, CurrentTime);
-
-	    XFlush(dpy);
-	}
+	fprintf(stderr, "SCREEN NOT SUPPORTED YET\n");
 	break;
 
     case F_SEND_MSG:
