@@ -12,8 +12,7 @@
  ***********************************************************************/
 
 #include "mwm.h"
-
-#include <stdio.h>
+#include <XmI/XmXpm.h>
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -23,15 +22,6 @@
 #include <fcntl.h>
 #endif
 
-#include <X11/extensions/shape.h>
-
-#if XmVERSION >= 2
-#include <Xm/XpmP.h>
-#else
-#include <XmI/XmXpm.h>
-#endif
-
-
 #define def_bitmap_width 50
 #define def_bitmap_height 50
 static unsigned char def_bitmap_bits[] =
@@ -143,7 +133,7 @@ find_icon_file(char *icon, char *pathlist, int type)
 	    pathlist = dir_end + 1;
     }
     /* Hmm, couldn't find the file.  Return NULL */
-    XtFree(path);
+    free(path);
     return NULL;
 }
 
@@ -225,7 +215,7 @@ get_bitmap_file(ScreenInfo *scr, MwmWindow *tmp_win)
 	tmp_win->icon_p_height = 0;
     }
 
-    XtFree(path);
+    free(path);
 }
 
 /*
@@ -235,11 +225,7 @@ static void
 get_xpm_file(ScreenInfo *scr, MwmWindow *tmp_win)
 {
     XWindowAttributes root_attr;
-#if XmVERSION >= 2
-    XpmAttributes xpm_attributes;
-#else
     _LtXpmAttributes xpm_attributes;
-#endif
     XImage *im, *imshape;
     GC gc;
     char *path = NULL;
@@ -251,20 +237,12 @@ get_xpm_file(ScreenInfo *scr, MwmWindow *tmp_win)
     XGetWindowAttributes(dpy, scr->root_win, &root_attr);
     xpm_attributes.colormap = root_attr.colormap;
     xpm_attributes.closeness = 40000;	/* Allow for "similar" colors */
-#if XmVERSION >= 2
-    xpm_attributes.valuemask = XpmSize | XpmReturnPixels | XpmColormap |
-	XpmCloseness;
-#else
     xpm_attributes.valuemask = _LtXpmSize | _LtXpmReturnPixels | _LtXpmColormap |
 	_LtXpmCloseness;
-#endif
 
 #ifdef NONSTANDARD_CONVERTERS
-#if XmVERSION >= 2
-    if (XpmReadFileToImage(dpy, path, &im, &imshape, &xpm_attributes) == XpmSuccess)
-#else
-    if (_LtXpmReadFileToImage(dpy, path, &im, &imshape, &xpm_attributes) == _LtXpmSuccess)
-#endif
+    if (_LtXpmReadFileToImage(dpy, path, &im, &imshape, &xpm_attributes) ==
+	_LtXpmSuccess)
     {
 
 	tmp_win->icon_pixmap = XCreatePixmap(dpy, scr->root_win,
@@ -302,7 +280,7 @@ get_xpm_file(ScreenInfo *scr, MwmWindow *tmp_win)
     }
 #endif
 
-    XtFree(path);
+    free(path);
 }
 
 /*
