@@ -25,7 +25,7 @@
 /**    OR PERFORMANCE OF THIS SOFTWARE.                                     **/
 /*****************************************************************************/
 /****************************************************************************
- * This module is based on Twm, but has been significantly modified 
+ * This module is based on Twm, but has been siginificantly modified 
  * by Rob Nation 
  ****************************************************************************/
 /***********************************************************************
@@ -33,20 +33,18 @@
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
-
-#include <LTconfig.h>
-
-#include <stdio.h>
-#include <string.h>
-#include <ctype.h>
-
-#include <Xm/Xm.h>
-#include <Xm/MwmUtil.h>
-
 #include "mwm.h"
 
-#include <X11/keysym.h>
-
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
+#ifdef TIME_WITH_SYS_TIME
+#include <time.h>
+#endif
+#endif
+#include <X11/Xfuncs.h>
 
 static int menu_on = 0;
 static MenuRoot *ActiveMenu = NULL;	/* the active menu */
@@ -151,20 +149,8 @@ function_allowed(MwmWindow *tmp, MenuItem *mi)
     if (mi->func == F_RESIZE && tmp && !(tmp->functions & MWM_FUNC_RESIZE))
 	return False;
 
-    /* Cannot iconify if the window is already iconified or the window
-       does not allow minimize */
-    if ((mi->func == F_ICONIFY && tmp) &&
-          ((tmp->flags & ICONIFIED) ||
-           !(tmp->functions & MWM_FUNC_MINIMIZE)))
-	return False;
-    
-    /* Cannot resize if iconified */
-    if (mi->func == F_RESIZE && tmp && (tmp->flags & ICONIFIED))
-        return False;
-
-    /* Can only normalize if iconified or maximized */
-    if (mi->func == F_NORMALIZE && tmp &&
-        !(tmp->flags & ICONIFIED) && !(tmp->flags & MAXIMIZED))
+    if (mi->func == F_ICONIFY && tmp && !(tmp->flags & ICONIFIED) &&
+	!(tmp->functions & MWM_FUNC_MINIMIZE))
 	return False;
 
     if (mi->func == F_MAXIMIZE && tmp && !(tmp->functions & MWM_FUNC_MAXIMIZE))
@@ -235,10 +221,9 @@ paint_entry(ScreenInfo *scr, MwmWindow *tmp, MenuRoot * mr, MenuItem *mi)
 
     if (function_allowed(tmp, mi))
 	currentGC = scr->components[MWM_MENU].normal_GC;
-    else {
     /* MLM: FIXME: SHOULD GRAY OUT ITEM */
-	currentGC = scr->components[MWM_MENU].grayed_GC;
-    }
+    else
+	currentGC = scr->components[MWM_MENU].normal_GC;
 
     if (*mi->item)
 	XDrawString(dpy, mr->w, currentGC, mi->x, text_y,
@@ -328,7 +313,7 @@ find_entry(ScreenInfo *scr, MwmWindow *tmp)
 
     /* if we weren't on the active item, change the active item and turn it
      * on */
-    if ((mi != ActiveItem) && (mi != NULL) && function_allowed(tmp, mi))
+    if ((mi != ActiveItem) && (mi != NULL))
     {
 	mi->state = 1;
 	paint_entry(scr, tmp, ActiveMenu, mi);
@@ -679,19 +664,18 @@ MENU_FindHotKey(MenuItem *it, KeySym key)
  * create a new menu root
  */
 MenuRoot *
-MENU_Create(const char *name)
+MENU_Create(char *name)
 {
     MenuRoot *tmp;
 
-    tmp  = (MenuRoot *) XtMalloc(sizeof(MenuRoot));
-    tmp->name   = XtNewString(name);
-    tmp->first  = NULL;
-    tmp->last   = NULL;
-    tmp->items  = 0;
-    tmp->width  = 0;
+    tmp = (MenuRoot *) XtMalloc(sizeof(MenuRoot));
+    tmp->name = name;
+    tmp->first = NULL;
+    tmp->last = NULL;
+    tmp->items = 0;
+    tmp->width = 0;
     tmp->width2 = 0;
-    tmp->w      = None;
-
+    tmp->w = None;
     return (tmp);
 }
 
@@ -732,7 +716,7 @@ MENU_Remove(ScreenInfo *scr, MenuRoot * menu)
 	if (menu == scr->popups[i])
 	{
 	    if (scr->num_popups != (i + 1))
-		memmove(&scr->popups[i], &scr->popups[i + 1], 
+		bcopy(&scr->popups[i + 1], &scr->popups[i],
 		      (scr->num_popups - i - 1) * sizeof(MenuRoot *));
 	    scr->num_popups--;
 	}
@@ -784,17 +768,12 @@ MENU_AddItem(ScreenInfo *scr, MenuRoot * menu, char *item, char *item2,
 
     if (func == F_POPUP)
     {
-	int i;
+	unsigned i;
 
 	if (action != (char *)0)
 	{
 	    for (i = 0; i < scr->num_popups; i++)
-#if 0
-  /* amai: it seems we don't ever use this catch!?! */
 		if (strcasecmp(scr->popups[i]->name, action) == 0)
-#else
-		if (strcmp(scr->popups[i]->name, action) == 0)
-#endif
 		{
 		    tmp->menu = scr->popups[i];
 		    break;
@@ -901,7 +880,7 @@ MENU_Realize(ScreenInfo *scr, MenuRoot * mr)
 			  CopyFromParent, (unsigned int)InputOutput,
 			  (Visual *)CopyFromParent,
 			  valuemask, &attributes);
-    XSaveContext(dpy, mr->w, MenuContext, (XPointer)mr);
+    XSaveContext(dpy, mr->w, MenuContext, (_Xconst char *)mr);
 }
 
 /*
@@ -1212,7 +1191,7 @@ MENU_DestroyMenus(ScreenInfo *scr)
  * reset the menuing system
  */
 void
-MENU_Reset(void)
+MENU_Reset()
 {
     ActiveItem = NULL;
     ActiveMenu = NULL;
@@ -1281,14 +1260,14 @@ MENU_BuildWindowMenu(ScreenInfo *scr, MwmWindow *win)
     else
     {
 	mr = (MenuRoot *) XtMalloc(sizeof(MenuRoot));
-	memcpy(mr, def, sizeof(MenuRoot));
+	bcopy(def, mr, sizeof(MenuRoot));
 	mr->first = mr->last = NULL;
     }
 
     for (mi = def->last; mi != NULL; mi = mi->prev)
     {
 	tmp = (MenuItem *)XtMalloc(sizeof(MenuItem));
-	memcpy(tmp, mi, sizeof(MenuItem));
+	bcopy(mi, tmp, sizeof(MenuItem));
 	if (mr->first == NULL)
 	{
 	    mr->first = tmp;
