@@ -12,8 +12,6 @@
 
 #include "mwm.h"
 
-#include <stdio.h>
-
 extern int menuFromFrameOrWindowOrTitlebar;
 extern int Stashed_X, Stashed_Y;
 Bool NeedToResizeToo;
@@ -31,7 +29,7 @@ display_position(ScreenInfo *scr, MwmWindow *tmp_win, int x, int y, int Init)
 
     ssw = XTextWidth(scr->components[MWM_FEEDBACK].font,
 		     " +8888 x +8888 ", 15);
-    sprintf(str, " %+-4d %+-4d ", x, y);
+    (void)sprintf(str, " %+-4d %+-4d ", x, y);
     if (Init)
     {
 	XClearWindow(dpy, scr->size_win);
