@@ -35,11 +35,6 @@
 
 #include "mwm.h"
 
-#include <Xm/XmosP.h>
-#if XmVERSION >= 2
-#include <XmI/XmI.h>
-#endif
-
 /****************************************************************************
  * The root window is surrounded by four windows which are InputOnly.  This
  * means you can see 'through' them, but they eat the input that happens
