@@ -1,6 +1,6 @@
 /**
  *
- * $Id: resources.c,v 1.14 2001/06/22 19:06:04 amai Exp $
+ * $Id: resources.c,v 1.8 1999/02/02 18:22:35 gritton Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -22,18 +22,10 @@
  *
  **/
 
-#include <LTconfig.h>
-
-#include <stdio.h>
-
-#include <Xm/Xm.h>
-#include <Xm/MwmUtil.h>
 #include "mwm.h"
-
-#include <Xm/XmP.h>
-#include <Xm/XmStrDefs.h>
-
 #include "mwmstrings.h"
+#include <Xm/Xm.h>
+#include <Xm/XmStrDefs.h>
 
 /*
  * mwm strings
@@ -245,6 +237,16 @@ static XtResource mwm_resources[] =
 	sizeof(String), Offset(bitmap_directory),
 	XmRString, (XtPointer)MWM_ICONDIR
     },
+    {
+	XmNbuttonBindings, XmCButtonBindings, XmRString,
+	sizeof(String), Offset(button_bindings),
+	XmRString, (XtPointer)DEFAULT_BUTTON_BINDING_NAME
+    },
+    {
+	XmNcleanText, XmCCleanText, XmRBoolean,
+	sizeof(Boolean), Offset(clean_text),
+	XmRImmediate, (XtPointer)False
+    },
     {
 	XmNclientAutoPlace, XmCClientAutoPlace, XmRBoolean,
 	sizeof(Boolean), Offset(client_auto_place),
@@ -285,46 +287,126 @@ static XtResource mwm_resources[] =
 	sizeof(Boolean), Offset(enforce_key_focus),
 	XmRImmediate, (XtPointer)True
     },
+    {
+	XmNfadeNormalIcon, XmCFadeNormalIcon, XmRBoolean,
+	sizeof(Boolean), Offset(fade_normal_icon),
+	XmRImmediate, (XtPointer)False
+    },
+    {
+	XmNfeedbackGeometry, XmCFeedbackGeometry, XmRString,
+	sizeof(Geometry), Offset(feedback_geometry),
+	XmRCallProc, (XtPointer)NULL
+    },
 #if 0
     {
 	XmNfreezeOnConfig, XmCFreezeOnConfig, XmRBoolean,
     },
 #endif
+    {
+	XmNframeBorderWidth, XmCFrameBorderWidth, XmRDimension,
+	sizeof(Dimension), Offset(frame_border_width),
+	XmRCallProc, (XtPointer)_WmDefaultBorderWidth
+    },
     {
 	XmNiconAutoPlace, XmCIconAutoPlace, XmRBoolean,
 	sizeof(Boolean), Offset(icon_auto_place),
 	XmRImmediate, (XtPointer)True
     },
+    {
+	XmNiconBoxGeometry, XmCIconBoxGeometry, XmRString,
+	sizeof(String), Offset(icon_box_geometry),
+	XmRCallProc, (XtPointer)NULL
+    },
+    {
+	XmNiconBoxName, XmCIconBoxName, XmRString,
+	sizeof(String), Offset(icon_box_name),
+	XmRImmediate, (XtPointer)"iconbox"
+    },
+    {
+	XmNiconBoxSBDisplayPolicy, XmCIconBoxSBDisplayPolicy, XmRString,
+	sizeof(String), Offset(icon_box_sb_display_policy),
+	XmRImmediate, (XtPointer)"all"
+    },
 #if 0
     {
 	XmNiconBoxScheme, XmCIconBoxScheme,
     },
 #endif
+    {
+	XmNiconBoxTitle, XmCIconBoxTitle, XmRXmString,
+	sizeof(XmString), Offset(icon_box_title),
+	XmRString, (XtPointer)"Icons"
+    },
     {
 	XmNiconClick, XmCIconClick, XmRBoolean,
 	sizeof(Boolean), Offset(icon_click),
 	XmRImmediate, (XtPointer)True
     },
+    {
+	XmNiconDecoration, XmCIconDecoration, XmRWmIDecor,
+	sizeof(long), Offset(icon_decoration),
+	XmRString, (XtPointer)"activelabel label image"
+    },
+    {
+	XmNiconImageMaximum, XmCIconImageMaximum, XmRWmSize,
+	sizeof(Size), Offset(icon_image_maximum),
+	XmRString, (XtPointer)"50x50"
+    },
+    {
+	XmNiconImageMinimum, XmCIconImageMinimum, XmRWmSize,
+	sizeof(Size), Offset(icon_image_minimum),
+	XmRString, (XtPointer)"16x16"
+    },
+    {
+	XmNiconPlacement, XmCIconPlacement, XmRWmIPlace,
+	sizeof(unsigned char), Offset(icon_placement),
+	XmRString, (XtPointer)"left bottom"
+    },
+    {
+	XmNiconPlacementMargin, XmCIconPlacementMargin, XmRDimension,
+	sizeof(Dimension), Offset(icon_placement_margin),
+	XmRImmediate, (XtPointer)1
+    },
     {
 	XmNinteractivePlacement, XmCInteractivePlacement, XmRBoolean,
 	sizeof(Boolean), Offset(interactive_placement),
 	XmRImmediate, (XtPointer)False
     },
+    {
+	XmNkeyBindings, XmCKeyBindings, XmRString,
+	sizeof(String), Offset(key_bindings),
+	XmRImmediate, (XtPointer)DEFAULT_KEY_BINDING_NAME
+    },
     {
 	XmNkeyboardFocusPolicy, XmCKeyboardFocusPolicy, XmRWmKFocus,
 	sizeof(unsigned char), Offset(keyboard_focus_policy),
 	XmRString, (XtPointer)"explicit"
     },
+    {
+	XmNlimitResize, XmCLimitResize, XmRBoolean,
+	sizeof(Boolean), Offset(limit_resize),
+	XmRImmediate, (XtPointer)True
+    },
     {
 	XmNlowerOnIconify, XmCLowerOnIconify, XmRBoolean,
 	sizeof(Boolean), Offset(lower_on_iconify),
 	XmRImmediate, (XtPointer)True
     },
+    {
+	XmNmaximumMaximumSize, XmCMaximumMaximumSize, XmRWmSize,
+	sizeof(String), Offset(maximum_maximum_size),
+	XmRCallProc, (XtPointer)NULL
+    },
     {
 	XmNmoveThreshold, XmCMoveThreshold, XmRDimension,
 	sizeof(Dimension), Offset(move_threshold),
 	XmRImmediate, (XtPointer)4
     },
+    {
+	XmNmoveOpaque, XmCMoveOpaque, XmRBoolean,
+	sizeof(Boolean), Offset(move_opaque),
+	XmRImmediate, (XtPointer)False
+    },
     {
 	XmNmultiScreen, XmCMultiScreen, XmRBoolean,
 	sizeof(Boolean), Offset(multi_screen),
@@ -360,6 +442,16 @@ static XtResource mwm_resources[] =
 	sizeof(Boolean), Offset(raise_key_focus),
 	XmRImmediate, (XtPointer)False
     },
+    {
+	XmNresizeBorderWidth, XmCFrameBorderWidth, XmRDimension,
+	sizeof(Dimension), Offset(resize_border_width),
+	XmRCallProc, (XtPointer)_WmDefaultResizeBorderWidth
+    },
+    {
+	XmNresizeCursors, XmCResizeCursors, XmRBoolean,
+	sizeof(Boolean), Offset(resize_cursors),
+	XmRImmediate, (XtPointer)True
+    },
     {
 	XmNscreens, XmCScreens, XmRString,
 	sizeof(String), Offset(screens),
@@ -375,6 +467,21 @@ static XtResource mwm_resources[] =
 	sizeof(Boolean), Offset(startup_key_focus),
 	XmRImmediate, (XtPointer)True
     },
+    {
+	XmNtransientDecoration, XmCTransientDecoration, XmRWmCDecor,
+	sizeof(long), Offset(transient_decoration),
+	XmRString, (XtPointer)"menu title"
+    },
+    {
+	XmNtransientFunctions, XmCTransientFunctions, XmRWmCFunc,
+	sizeof(long), Offset(transient_functions),
+	XmRString, (XtPointer)"-minimize maximize"
+    },
+    {
+	XmNuseIconBox, XmCUseIconBox, XmRBoolean,
+	sizeof(Boolean), Offset(use_icon_box),
+	XmRImmediate, (XtPointer)False
+    },
     {
 	XmNusePager, XmCUsePager, XmRBoolean,
 	sizeof(Boolean), Offset(use_pager),
@@ -427,131 +534,6 @@ static XtResource mwm_resources[] =
     }
 };
 
-/*
- * Syntax:
- * "Mwm*screen_name*resource_name: resource_value"
- */
-#undef Offset
-#define Offset(field)   XtOffsetOf(ScreenInfo, field)
-static XtResource mwm_screen_resources[] =
-{
-    {
-	XmNbuttonBindings, XmCButtonBindings, XmRString,
-	sizeof(String), Offset(button_bindings),
-	XmRString, (XtPointer)DEFAULT_BUTTON_BINDING_NAME
-    },
-    {
-	XmNcleanText, XmCCleanText, XmRBoolean,
-	sizeof(Boolean), Offset(clean_text),
-	XmRImmediate, (XtPointer)False
-    },
-    {
-	XmNfadeNormalIcon, XmCFadeNormalIcon, XmRBoolean,
-	sizeof(Boolean), Offset(fade_normal_icon),
-	XmRImmediate, (XtPointer)False
-    },
-    {
-	XmNfeedbackGeometry, XmCFeedbackGeometry, XmRString,
-	sizeof(Geometry), Offset(feedback_geometry),
-	XmRCallProc, (XtPointer)NULL
-    },
-    {
-	XmNframeBorderWidth, XmCFrameBorderWidth, XmRDimension,
-	sizeof(Dimension), Offset(frame_border_width),
-	XmRCallProc, (XtPointer)_WmDefaultBorderWidth
-    },
-    {
-	XmNiconBoxGeometry, XmCIconBoxGeometry, XmRString,
-	sizeof(String), Offset(icon_box_geometry),
-	XmRCallProc, (XtPointer)NULL
-    },
-    {
-	XmNiconBoxName, XmCIconBoxName, XmRString,
-	sizeof(String), Offset(icon_box_name),
-	XmRImmediate, (XtPointer)"iconbox"
-    },
-    {
-	XmNiconBoxSBDisplayPolicy, XmCIconBoxSBDisplayPolicy, XmRString,
-	sizeof(String), Offset(icon_box_sb_display_policy),
-	XmRImmediate, (XtPointer)"all"
-    },
-    {
-	XmNiconBoxTitle, XmCIconBoxTitle, XmRXmString,
-	sizeof(XmString), Offset(icon_box_title),
-	XmRString, (XtPointer)"Icons"
-    },
-    {
-	XmNiconDecoration, XmCIconDecoration, XmRWmIDecor,
-	sizeof(long), Offset(icon_decoration),
-	XmRString, (XtPointer)"activelabel label image"
-    },
-    {
-	XmNiconImageMaximum, XmCIconImageMaximum, XmRWmSize,
-	sizeof(Size), Offset(icon_image_maximum),
-	XmRString, (XtPointer)"50x50"
-    },
-    {
-	XmNiconImageMinimum, XmCIconImageMinimum, XmRWmSize,
-	sizeof(Size), Offset(icon_image_minimum),
-	XmRString, (XtPointer)"16x16"
-    },
-    {
-	XmNiconPlacement, XmCIconPlacement, XmRWmIPlace,
-	sizeof(unsigned char), Offset(icon_placement),
-	XmRString, (XtPointer)"left bottom"
-    },
-    {
-	XmNiconPlacementMargin, XmCIconPlacementMargin, XmRDimension,
-	sizeof(Dimension), Offset(icon_placement_margin),
-	XmRImmediate, (XtPointer)1
-    },
-    {
-	XmNkeyBindings, XmCKeyBindings, XmRString,
-	sizeof(String), Offset(key_bindings),
-	XmRImmediate, (XtPointer)DEFAULT_KEY_BINDING_NAME
-    },
-    {
-	XmNlimitResize, XmCLimitResize, XmRBoolean,
-	sizeof(Boolean), Offset(limit_resize),
-	XmRImmediate, (XtPointer)True
-    },
-    {
-	XmNmaximumMaximumSize, XmCMaximumMaximumSize, XmRWmSize,
-	sizeof(String), Offset(maximum_maximum_size),
-	XmRCallProc, (XtPointer)NULL
-    },
-    {
-	XmNmoveOpaque, XmCMoveOpaque, XmRBoolean,
-	sizeof(Boolean), Offset(move_opaque),
-	XmRImmediate, (XtPointer)False
-    },
-    {
-	XmNresizeBorderWidth, XmCFrameBorderWidth, XmRDimension,
-	sizeof(Dimension), Offset(resize_border_width),
-	XmRCallProc, (XtPointer)_WmDefaultResizeBorderWidth
-    },
-    {
-	XmNresizeCursors, XmCResizeCursors, XmRBoolean,
-	sizeof(Boolean), Offset(resize_cursors),
-	XmRImmediate, (XtPointer)True
-    },
-    {
-	XmNtransientDecoration, XmCTransientDecoration, XmRWmCDecor,
-	sizeof(long), Offset(transient_decoration),
-	XmRString, (XtPointer)"menu title"
-    },
-    {
-	XmNtransientFunctions, XmCTransientFunctions, XmRWmCFunc,
-	sizeof(long), Offset(transient_functions),
-	XmRString, (XtPointer)"-minimize maximize"
-    },
-    {
-	XmNuseIconBox, XmCUseIconBox, XmRBoolean,
-	sizeof(Boolean), Offset(use_icon_box),
-	XmRImmediate, (XtPointer)False
-    }
-};
-
 /*
  * Syntax:
  * "Mwm*client_name*resource_name: resource_value"
@@ -895,7 +877,7 @@ WmCvtStringToCDecor(Display *dpy, XrmValuePtr args, Cardinal *num_args,
 
 	if (to->addr == NULL)
 	{
-	    to->addr = (XPointer)&val;
+	    to->addr = (XtPointer)&val;
 	    to->size = sizeof(long);
 	    return True;
 	}
@@ -918,7 +900,7 @@ WmCvtStringToCDecor(Display *dpy, XrmValuePtr args, Cardinal *num_args,
 	val = 0;
 	if (to->addr == NULL)
 	{
-	    to->addr = (XPointer)&val;
+	    to->addr = (XtPointer)&val;
 	    to->size = sizeof(long);
 	    return True;
 	}
@@ -957,7 +939,7 @@ WmCvtStringToCDecor(Display *dpy, XrmValuePtr args, Cardinal *num_args,
     }
     if (to->addr == NULL)
     {
-	to->addr = (XPointer)&val;
+	to->addr = (XtPointer)&val;
 	to->size = sizeof(long);
 	return True;
     }
@@ -1000,7 +982,7 @@ WmCvtStringToCFocus(Display *dpy, XrmValuePtr args, Cardinal *num_args,
 	    val = i;
 	    if (to->addr == NULL)
 	    {
-		to->addr = (XPointer)&val;
+		to->addr = (XtPointer)&val;
 		to->size = sizeof(unsigned char);
 		return True;
 	    }
@@ -1047,7 +1029,7 @@ WmCvtStringToCFunc(Display *dpy, XrmValuePtr args, Cardinal *num_args,
 	    MWM_FUNC_MAXIMIZE | MWM_FUNC_CLOSE;
 	if (to->addr == NULL)
 	{
-	    to->addr = (XPointer)&val;
+	    to->addr = (XtPointer)&val;
 	    to->size = sizeof(long);
 	    return True;
 	}
@@ -1070,7 +1052,7 @@ WmCvtStringToCFunc(Display *dpy, XrmValuePtr args, Cardinal *num_args,
 	val = 0;
 	if (to->addr == NULL)
 	{
-	    to->addr = (XPointer)&val;
+	    to->addr = (XtPointer)&val;
 	    to->size = sizeof(long);
 	    return True;
 	}
@@ -1109,7 +1091,7 @@ WmCvtStringToCFunc(Display *dpy, XrmValuePtr args, Cardinal *num_args,
     }
     if (to->addr == NULL)
     {
-	to->addr = (XPointer)&val;
+	to->addr = (XtPointer)&val;
 	to->size = sizeof(long);
 	return True;
     }
@@ -1150,7 +1132,7 @@ WmCvtStringToCFlags(Display *dpy, XrmValuePtr args, Cardinal *num_args,
 	val = STICKY | CIRCULATESKIP | STARTICONIC | WINDOWLISTSKIP;
 	if (to->addr == NULL)
 	{
-	    to->addr = (XPointer)&val;
+	    to->addr = (XtPointer)&val;
 	    to->size = sizeof(long);
 	    return True;
 	}
@@ -1173,7 +1155,7 @@ WmCvtStringToCFlags(Display *dpy, XrmValuePtr args, Cardinal *num_args,
 	val = 0;
 	if (to->addr == NULL)
 	{
-	    to->addr = (XPointer)&val;
+	    to->addr = (XtPointer)&val;
 	    to->size = sizeof(long);
 	    return True;
 	}
@@ -1200,7 +1182,7 @@ WmCvtStringToCFlags(Display *dpy, XrmValuePtr args, Cardinal *num_args,
     }
     if (to->addr == NULL)
     {
-	to->addr = (XPointer)&val;
+	to->addr = (XtPointer)&val;
 	to->size = sizeof(long);
 	return True;
     }
@@ -1250,7 +1232,7 @@ WmCvtStringToIDecor(Display *dpy, XrmValuePtr args, Cardinal *num_args,
     }
     if (to->addr == NULL)
     {
-	to->addr = (XPointer)&val;
+	to->addr = (XtPointer)&val;
 	to->size = sizeof(long);
 	return True;
     }
@@ -1301,7 +1283,7 @@ WmCvtStringToIPlace(Display *dpy, XrmValuePtr args, Cardinal *num_args,
     }
     if (to->addr == NULL)
     {
-	to->addr = (XPointer)&val;
+	to->addr = (XtPointer)&val;
 	to->size = sizeof(unsigned char);
 	return True;
     }
@@ -1344,7 +1326,7 @@ WmCvtStringToKFocus(Display *dpy, XrmValuePtr args, Cardinal *num_args,
 	    val = i;
 	    if (to->addr == NULL)
 	    {
-		to->addr = (XPointer)&val;
+		to->addr = (XtPointer)&val;
 		to->size = sizeof(unsigned char);
 		return True;
 	    }
@@ -1392,7 +1374,7 @@ WmCvtStringToShowFeedback(Display *dpy, XrmValuePtr args, Cardinal *num_args,
 	    MWM_FEEDBACK_RESTART;
 	if (to->addr == NULL)
 	{
-	    to->addr = (XPointer)&val;
+	    to->addr = (XtPointer)&val;
 	    to->size = sizeof(long);
 	    return True;
 	}
@@ -1415,7 +1397,7 @@ WmCvtStringToShowFeedback(Display *dpy, XrmValuePtr args, Cardinal *num_args,
 	val = 0;
 	if (to->addr == NULL)
 	{
-	    to->addr = (XPointer)&val;
+	    to->addr = (XtPointer)&val;
 	    to->size = sizeof(long);
 	    return True;
 	}
@@ -1455,7 +1437,7 @@ WmCvtStringToShowFeedback(Display *dpy, XrmValuePtr args, Cardinal *num_args,
     }
     if (to->addr == NULL)
     {
-	to->addr = (XPointer)&val;
+	to->addr = (XtPointer)&val;
 	to->size = sizeof(long);
 	return True;
     }
@@ -1495,7 +1477,7 @@ WmCvtStringToSize(Display *dpy, XrmValuePtr args, Cardinal *num_args,
     {
 	if (to->addr == NULL)
 	{
-	    to->addr = (XPointer)&val;
+	    to->addr = (XtPointer)&val;
 	    to->size = sizeof(Size);
 	    return True;
 	}
@@ -1541,7 +1523,7 @@ WmCvtStringToUsePPosition(Display *dpy, XrmValuePtr args, Cardinal *num_args,
 	    val = i;
 	    if (to->addr == NULL)
 	    {
-		to->addr = (XPointer)&val;
+		to->addr = (XtPointer)&val;
 		to->size = sizeof(unsigned char);
 		return True;
 	    }
@@ -1568,18 +1550,18 @@ WmCvtStringToUsePPosition(Display *dpy, XrmValuePtr args, Cardinal *num_args,
  */
 void
 RES_GetClientDefaults(ScreenInfo *scr, MwmWindow *tmp_win,
-		      char *name_s, char *class_s)
+		      char *name, char *class)
 {
     working_base = tmp_win;
     rscr = scr;
     XtGetSubresources(toplevel, (XtPointer)tmp_win,
-		      name_s, class_s,
+		      name, class,
 		      mwm_client_resources,
 		      XtNumber(mwm_client_resources), NULL, 0);
 }
 
 void
-RES_Initialize(void)
+RES_Initialize()
 {
     XmRegisterConverters();
 
@@ -1667,23 +1649,6 @@ RES_Initialize(void)
 			      mwm_resources, XtNumber(mwm_resources), NULL, 0);
 }
 
-/*
- * get the resources for each screen
- */
-void
-RES_GetScreenDefaults(ScreenInfo *scr)
-{
-    rscr = scr;
-#if 0
-    /*FIXME: do we need this here? A.R.*/
-    working_base = scr;
-#endif
-    XtGetSubresources(toplevel, (XtPointer)scr,
-                      scr->screen_name, scr->screen_name,
-                      mwm_screen_resources,
-                      XtNumber(mwm_screen_resources), NULL, 0);
-}
-
 /*
  * get the resources for the components in each screen
  */
