@@ -1,9 +1,8 @@
 /**
  *
- * $Id: Callback.h,v 1.1 2004/08/28 19:25:46 dannybackx Exp $
+ * $Id: Callback.h,v 1.3 1999/02/02 18:22:40 gritton Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -26,10 +25,7 @@
  *                    codesmit@southwind.net
  *
 */
-
-#ifndef _CALLBACK_H
-#define _CALLBACK_H
-
+#include <stdlib.h>
 #include <Mrm/MrmPublic.h>
 #include "ExpressionList.h"
 
@@ -68,5 +64,3 @@ CallbackType *CallbackTypeNew(char *callbackID, char *functionName,
 			      ParameterList *parameters);
 Bool Equal_CE_CE(CallbackListElement *a, CallbackListElement *b);
 void CallbackListElementDistroy(CallbackListElement *this);
-
-#endif /* #ifndef _CALLBACK_H */
