@@ -1,9 +1,8 @@
 /**
  *
- * $Id: MrmTypes.c,v 1.8 2001/06/05 20:26:54 amai Exp $
+ * $Id: MrmTypes.c,v 1.5 1999/05/28 20:43:08 danny Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -29,19 +28,18 @@
 
 #include <LTconfig.h>
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <ctype.h>
-
-#include <X11/Xlib.h>
-
 #include "FakeWidget.h"
 #include "glue.h"
 #include "uil.h"
-#include "main.h"
-
+#include <stdlib.h>
+#include <ctype.h>
+#include <X11/Xlib.h>
 #include "MrmTypes.h"
 
+extern FILE *outFile;
+
+extern ExpressionList GlobalSymbolTable;
+extern ExpressionList LocalSymbolTable;
 
 #if 0
 static Char8 *
@@ -69,7 +67,7 @@ AddrNameGetEvalValue(AddrName *this)
 
     if (NULL == t)
     {
-	__MrmExit(LOC,
+	Exit(LOC,
 	     "Can't find %s in Symbol Tables\n", this->theExpression.value);
     }
 
@@ -240,7 +238,7 @@ ColorDefinitionNew(char *color, int r, int g, int b)
 
     if (NULL != color)
     {
-	this->name = __MrmStore(color);
+	this->name = Store(color);
     }
     else
     {
@@ -315,7 +313,7 @@ FontSet16Bit(FontSet * this, int bits16)
 void
 FontSetName(FontSet * this, char *name)
 {
-    this->fontset.name = __MrmStore(name);
+    this->fontset.name = Store(name);
 }
 
 XBitmapFile *
@@ -326,7 +324,7 @@ XBitmapFileNew(char *FileName)
     this->theExpression.type = MrmRtypeXBitmapFile;
     this->theExpression.value = (long)&this->bitmap;
 
-    __MrmReadBitmapFileData(FileName, &(this->bitmap.width), &(this->bitmap.height),
+    ReadBitmapFileData(FileName, &(this->bitmap.width), &(this->bitmap.height),
 		       &(this->bitmap.data), &(this->bitmap.x_hot),
 		       &(this->bitmap.y_hot));
 
@@ -377,7 +375,7 @@ ColorElementNew(char *rep, Color *color)
     ColorElement *this = (ColorElement *)malloc(sizeof(ColorElement));
 
     this->Next = NULL;
-    this->name = __MrmStore(rep);
+    this->name = Store(rep);
     this->theColor = color;
 
     return this;
@@ -458,7 +456,7 @@ Char8ElementNew(char *s)
     this->Next = NULL;
     if (strlen(s) > 255)	/* FIX ME */
     {
-	__MrmExit(LOC, "String too long\n");
+	Exit(LOC, "String too long\n");
     }
     strcpy(this->lvalue, s);
 
@@ -738,7 +736,7 @@ PixmapImageNew(char *ColorMap, Char8Vector *pixmap)
 
     if (ColorMap)
     {
-	this->theColorMap = __MrmStore(ColorMap);
+	this->theColorMap = Store(ColorMap);
     }
     else
     {
@@ -760,7 +758,7 @@ PixmapImageNew(char *ColorMap, Char8Vector *pixmap)
 	source = (*i)->lvalue;
 	if (NULL == source)
 	{
-	    __MrmExit(LOC, "Source?\n");
+	    Exit(LOC, "Source?\n");
 	}
 
 	while (*source)
