@@ -1,5 +1,4 @@
 /**
- *  $Id: xmbind.c,v 1.7 2000/11/10 20:04:56 amai Exp $
  *
  * The xmbind client -- which is good for configuring the virtual 
  *                      key bindings.
@@ -28,20 +27,16 @@
 
 #include <LTconfig.h>
 
-#include <stdlib.h>
 #include <stdio.h>
-#include <string.h>
-
+#include <stdlib.h>
 #include <Xm/Xm.h>
+#include <XmI/XmI.h>
 #include <Xm/AtomMgr.h>
 #include <Xm/MwmUtil.h>
 #include <Xm/VirtKeysP.h>
 #include <Xm/XmosP.h>
 
-#include <XmI/XmI.h>
-
-
-static String AppName;	    /* this client's current name as found in argv[0] */
+String AppName;			/* this client's current name as found in argv[0] */
 
 /*
  * Print the release version info and exit.
@@ -194,9 +189,9 @@ main(int argc, char **argv)
 	else
 	{
 	    LoadBinding(XtDisplay(TopLevel), argv[i]);
-	    exit(0);
+	    return 0;
 	}
     }
     LoadDefaultBindings(XtDisplay(TopLevel));
-    exit(0);
+    return 0;
 }				/* main */
