@@ -1,8 +1,7 @@
 /*
- * $Id: LTglob.h,v 1.6 2000/11/01 12:06:53 amai Exp $ 
+ * $Id: LTglob.h,v 1.2 1999/10/22 08:42:23 amai Exp $ 
  *
  * Copyright (C) 1991, 1992 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  * 
  * This file is part of the GNU LessTif Library.
  *
@@ -23,8 +22,27 @@
  **/
 
 
-#ifndef	_LTGLOB_H
-#define	_LTGLOB_H
+#ifndef	_GLOB_H
+
+#define	_GLOB_H	1
+
+#ifdef	__cplusplus
+extern "C"
+{
+#endif
+
+#undef	__ptr_t
+#if defined (__cplusplus) || (defined (__STDC__) && __STDC__)
+#undef	__P
+#define	__P(protos)	protos
+#define	__ptr_t	void *
+#else /* Not C++ or ANSI C.  */
+#undef	__P
+#define	__P(protos)	()
+#undef	const
+#define	const
+#define	__ptr_t	char *
+#endif /* C++ or ANSI C.  */
 
 /* Bits set in the FLAGS argument to `glob'.  */
 #define	GLOB_ERR	(1 << 0)/* Return on read errors.  */
@@ -38,9 +56,10 @@
 #define	__GLOB_FLAGS	(GLOB_ERR|GLOB_MARK|GLOB_NOSORT|GLOB_DOOFFS| \
 			 GLOB_NOESCAPE|GLOB_NOCHECK|GLOB_APPEND|GLOB_PERIOD)
 
-/* This is not POSIX, so don't try to be too clever ... */
-#ifndef GLOB_MAGCHAR
-#define	GLOB_MAGCHAR    (1 << 8)   /* Set in gl_flags if any metachars seen. */
+/* am: I'm not sure the references given here are valid ...
+       at least I try to make it built on OSF/DU */
+#if !defined (_POSIX_C_SOURCE) || _POSIX_C_SOURCE < 2 || defined (_BSD_SOURCE) || defined(__osf__)
+#define	GLOB_MAGCHAR	(1 << 8)/* Set in gl_flags if any metachars seen.  */
 #endif
 
 /* Error returns from `glob'.  */
@@ -65,21 +84,23 @@ typedef struct
    `glob' returns GLOB_ABEND; if it returns zero, the error is ignored.
    If memory cannot be allocated for PGLOB, GLOB_NOSPACE is returned.
    Otherwise, `glob' returns zero.  */
-int _Lesstif_glob (const char *__pattern, int __flags,
-                   int (*__errfunc) (const char *, int),
-		   glob_t *__pglob);
+extern int _Lesstif_glob __P ((const char *__pattern, int __flags,
+		      int (*__errfunc) __P ((const char *, int)),
+		      glob_t *__pglob));
 
 /* Free storage allocated in PGLOB by a previous `glob' call.  */
-void _Lesstif_globfree (glob_t *__pglob);
+extern void _Lesstif_globfree __P ((glob_t *__pglob));
 
 
-#if 0
-/* We don't use these hooks ... */
-/* If they are non-NULL our `glob()' uses these functions
-   to read directories.  */
-extern void * (*__glob_opendir_hook) (const char *__directory);
-extern const char *(*__glob_readdir_hook) (void * __stream);
-extern void (*__glob_closedir_hook) (void * __stream);
+#if !defined (_POSIX_C_SOURCE) || _POSIX_C_SOURCE < 2 || defined (_GNU_SOURCE)
+/* If they are not NULL, `glob' uses these functions to read directories.  */
+extern __ptr_t (*__glob_opendir_hook) __P ((const char *__directory));
+extern const char *(*__glob_readdir_hook) __P ((__ptr_t __stream));
+extern void (*__glob_closedir_hook) __P ((__ptr_t __stream));
 #endif
 
-#endif /* _LTGLOB_H  */
+#ifdef	__cplusplus
+}
+#endif
+
+#endif /* glob.h  */
