@@ -1,8 +1,7 @@
 /*
- * $Id: LTmisc.h,v 1.6 2000/10/09 11:56:31 amai Exp $
+ * $Id: LTmisc.h,v 1.2 1998/09/02 19:22:42 danny Exp $
  * 
  * Copyright (C) 1998 Free Software Foundation, Inc.
- * Copyright (C) 1998-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,23 +21,30 @@
  *
  **/
 
-#ifndef _LTMISC_H
-#define _LTMISC_H
-
 #ifndef	HAVE_STRCASECMP
-int strcasecmp(const char *str1, const char *str2);
+#ifdef	strcasecmp
+#undef	strcasecmp
+#endif
+int strcasecmp(char *, char *);
 #endif
 
 #ifndef	HAVE_STRNCASECMP
-int strncasecmp(const char *str1, const char *str2, int count);
+#ifdef	strncasecmp
+#undef	strncasecmp
+#endif
+int strncasecmp(char *, char *, int);
 #endif
 
-#ifndef HAVE_BASENAME
-char *basename(char *path);
+#ifndef	HAVE_STRSTR
+#ifdef	strstr
+#undef	strstr
+#endif
+char *strstr(char *, char *);
 #endif
 
-#ifndef HAVE_DIRNAME
-char *dirname(char *dirname);
+#ifndef	HAVE_MEMMOVE
+#ifdef	memmove
+#undef	memmove
+#endif
+void *memmove(void *, void *, size_t);
 #endif
-
-#endif /* _LTMISC_H */
