@@ -1,6 +1,6 @@
 /**
  *
- * $Id: ManagerP.h,v 1.1 1998/09/25 22:09:23 pgw Exp $
+ * $Id: ManagerP.h,v 1.3 1999/05/31 18:27:38 danny Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -92,12 +92,6 @@ typedef struct {
     GC bottom_shadow_GC;
 
     Widget initial_focus;
-
-#if LESSTIF_BACK_COMPAT
-#else
-    XtCallbackList popup_handler_callback;  /* new for 2.0 */
-#endif
-
 } XmManagerPart;
 
 typedef struct {
@@ -214,6 +208,8 @@ void _XmGadgetTraverseHome(Widget w, XEvent *event, String *params, Cardinal *nu
 void _XmGadgetHelp(Widget w, XEvent *event, String *params, Cardinal *num_params);
 void _XmGadgetKeyInput(Widget w, XEvent *event, String *params, Cardinal *num_params);
 
+void _XmManagerHelp(Widget w, XEvent *event, String *params, Cardinal *num_params);
+
 #ifdef __cplusplus
 }
 #endif
