@@ -1,9 +1,8 @@
 /**
  *
- * $Id: DragDropI.h,v 1.1 2004/08/28 19:23:29 dannybackx Exp $
+ * $Id: DragDropI.h,v 1.11 1999/08/03 23:21:50 rwscott Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -36,8 +35,8 @@ about the suitability of this software for any purpose.  It is
 provided "as is" without express or implied warranty.
 ************************************************************/
 
-#ifndef _XMI_DRAGDROPI_H
-#define _XMI_DRAGDROPI_H
+#ifndef DRAGDROP_I_H
+#define DRAGDROP_I_H
 
 #include <X11/Xmd.h>
 
@@ -432,38 +431,17 @@ typedef struct {
 
 /* functions */
 
-Boolean _XmGetDragReceiverInfo(Display *display, Window win,
-                               XmDragReceiverInfo ri);
-void _XmSetDragReceiverInfo(Widget w, Widget widget);
-void _XmClearDragReceiverInfo(Widget shell);
-void _XmFreeDragReceiverInfo(XmShellDropSiteInfo di);
-unsigned char _XmByteOrder(void);
-int _XmMessageTypeToReason(BYTE reason);
-void _XmICCEventToICCCallback(XmDndMessage *msg, XmDragDropCallbackStruct *cbs);
-
-/* DragBS.c */
-int _XmReadDragBuffer(XmDndBufMgr bmgr, Boolean read_string,
-                      char *retbuf, int bufsize);
-int _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
-                       char *data, int size);
-
+extern Boolean _XmGetDragReceiverInfo(Display *display, Window win,
+				      XmDragReceiverInfo ri);
+extern void _XmSetDragReceiverInfo(Widget w, Widget widget);
+extern void _XmClearDragReceiverInfo(Widget shell);
+extern void _XmFreeDragReceiverInfo(XmShellDropSiteInfo di);
+extern unsigned char _XmByteOrder(void);
 
 /*
  * resources from DropSMgrI.c
  */
 extern XtResource _XmDSResources[];
 extern int _XmNumDSResources;
-/* functions for MBC */
-void _XmDSIAddChild(void* a, void* b, int c);
-void _XmDSIRemoveChild(void* a, void* b);
-void _XmDSIDestroy(void* a, int b);
-int _XmDSIGetBorderWidth(void* a);
-int _XmDSIReplaceChild(void* a);
-int _XmDSIGetChildPosition(void* a, void* b);
-void _XmDSISwapChildren(void* a, void* b, void* c);
 
-/* from TextIn.c */
-void _Lttext_process_drop(Widget w, XtPointer client_data, XtPointer call_data);
-
-
-#endif /* _XMI_DRAGDROPI_H */
+#endif /* DRAGDROP_I_H */
