@@ -1,6 +1,6 @@
 /**
  *
- * $Id: MacrosI.h,v 1.40 1999/12/23 04:25:19 rwscott Exp $
+ * $Id: MacrosI.h,v 1.38 1999/07/08 00:21:40 rwscott Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -1263,16 +1263,16 @@
     (((XmFormConstraintRec *)((w)->core.constraints))->form.preferred_height)
 
 #define FormC_X(w) \
-    (((XmFormConstraintRec *)((w)->core.constraints))->form.att[0].value)
+    (((XmFormConstraintRec *)((w)->core.constraints))->form.x)
 
 #define FormC_Y(w) \
-    (((XmFormConstraintRec *)((w)->core.constraints))->form.att[2].value)
+    (((XmFormConstraintRec *)((w)->core.constraints))->form.y)
 
 #define FormC_W(x) \
-    (((XmFormConstraintRec *)((x)->core.constraints))->form.att[1].value)
+    (((XmFormConstraintRec *)((x)->core.constraints))->form.w)
 
 #define FormC_H(w) \
-    (((XmFormConstraintRec *)((w)->core.constraints))->form.att[3].value)
+    (((XmFormConstraintRec *)((w)->core.constraints))->form.h)
 
 #define FormC_WFS(w) \
     (((XmFormConstraintRec *)((w)->core.constraints))->form.width_from_side)
@@ -1300,24 +1300,22 @@
     (((XmFormConstraintRec *)(c))->form.preferred_height)
 
 #define FCP_X(c) \
-    (((XmFormConstraintRec *)(c))->form.att[0].value)
+    (((XmFormConstraintRec *)(c))->form.x)
 
 #define FCP_Y(c) \
-    (((XmFormConstraintRec *)(c))->form.att[2].value)
+    (((XmFormConstraintRec *)(c))->form.y)
 
 #define FCP_W(c) \
-    (((XmFormConstraintRec *)(c))->form.att[1].value)
+    (((XmFormConstraintRec *)(c))->form.w)
 
 #define FCP_H(c) \
-    (((XmFormConstraintRec *)(c))->form.att[3].value)
+    (((XmFormConstraintRec *)(c))->form.h)
 
-#if 0
 #define FCP_WidthFromSide(c) \
     (((XmFormConstraintRec *)(c))->form.width_from_side)
 
 #define FCP_HeightFromSide(c) \
     (((XmFormConstraintRec *)(c))->form.height_from_side)
-#endif
 
 /*
  * FILE SELECTIONBOX WIDGET ACCESS MACROS
