@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/include/Motif-2.0/Xm/ContainerT.h,v 1.1 1997/12/28 16:03:13 u27113 Exp $
+ * $Header: /cvsroot/hungry/lesstif/include/Motif-2.0/Xm/ContainerT.h,v 1.2 1999/08/13 13:18:23 danny Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
  *
@@ -30,6 +30,31 @@
 extern "C" {
 #endif
 
+extern XrmQuark XmQTcontainer;
+
+typedef struct {
+	Mask		valueMask;
+	Cardinal	*detail_order;
+	Cardinal	detail_order_count;
+	XmTabList	detail_tablist;
+	Dimension	first_column_width;
+	unsigned char	selection_mode;
+	Pixel		select_color;
+} XmContainerDataRec, *XmContainerData;
+
+typedef void (*XmContainerGetValuesProc)(Widget, XmContainerData);
+
+typedef struct {
+	int				version;
+	XmContainerGetValuesProc	getValues;
+} XmContainerTraitRec, *XmContainerTrait;
+
+#define ContAllValid             (0xFFFF)
+#define ContDetailOrder          (1L<<0)
+#define ContDetailTabList        (1L<<1)
+#define ContFirstColumnWidth     (1L<<2)
+#define ContSelectionMode        (1L<<3)
+#define ContSelectColor          (1L<<4)
 
 #ifdef __cplusplus
 }
