@@ -1,6 +1,6 @@
 /**
  *
- * $Id: ScrolledWP.h,v 1.3 1998/09/17 10:40:00 kbwj Exp $
+ * $Id: ScrolledWP.h,v 1.2 1998/11/12 21:33:11 pgw Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -104,7 +104,24 @@ typedef struct _XmScrolledWindowClassRec {
 
 extern XmScrolledWindowClassRec xmScrolledWindowClassRec;
 
-extern void _XmInitializeScrollBars(Widget w);
+/*
+ * This is new for 2.0
+ */
+
+typedef struct _XmScrolledWindowConstraintPart {
+    unsigned char child_type;
+    Position orig_x;
+    Position orig_y;
+} XmScrolledWindowConstraintPart, *XmScrolledWindowConstraint;
+
+/*
+ * This is new for 2.0
+ */
+
+typedef struct _XmScrolledWindowConstraintRec {
+    XmManagerConstraintPart manager;
+    XmScrolledWindowConstraintPart swindow;
+} XmScrolledWindowConstraintRec;
 
 #ifdef __cplusplus
 }
