@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/include/Motif-2.0/Xm/TransferP.h,v 1.3 2000/08/10 15:59:00 amai Exp $
+ * $Header: /cvsroot/hungry/lesstif/include/Motif-2.0/Xm/TransferP.h,v 1.1 1997/12/28 16:03:14 u27113 Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
  *
@@ -30,12 +30,6 @@
 extern "C" {
 #endif
 
-Atom *XmeStandardTargets(Widget widget,
-                         int count, int *count_return);
-
-void XmeStandardConvert(Widget widget,
-                        XtPointer ignore,
-			XmConvertCallbackStruct *call_data);
 
 #ifdef __cplusplus
 }
