@@ -1,6 +1,6 @@
 /**
  *
- * $Id: XmP.h,v 1.5 1998/10/03 06:30:00 gritton Exp $
+ * $Id: XmP.h,v 1.6 1999/08/13 13:18:23 danny Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  *
@@ -1061,6 +1061,11 @@ enum { XmLABEL_FONTLIST = 1,
        XmBUTTON_FONTLIST,
        XmTEXT_FONTLIST
 };
+enum {	XmLABEL_RENDER_TABLE = 1, 
+	XmBUTTON_RENDER_TABLE, 
+	XmTEXT_RENDER_TABLE  
+};
+
 
 void _XmRegisterConverters(void);
 void _XmWarning(Widget w, char *message, ...);
@@ -1070,6 +1075,8 @@ Boolean XmeNamesAreEqual(char *in_str, char *text_str);
 XmFontList _XmGetDefaultFontList(Widget w, unsigned char fontListType);
 char *_XmConvertCSToString(XmString cs);
 Boolean _XmCvtXmStringToCT(XrmValue *from, XrmValue *to);
+XmFontList XmeGetDefaultRenderTable(Widget w, unsigned int fontListType);
+
 
 /**************************** ResInd.c *****************************/
 
@@ -1451,6 +1458,9 @@ void _XmMenuBarFix(XmGeoMatrix geoSpec, int action,
 void _XmSeparatorFix(XmGeoMatrix geoSpec, int action,
 		     XmGeoMajorLayout layoutPtr, XmKidGeometry rowPtr);
 void _XmSetKidGeo(XmKidGeometry kg, Widget instigator);
+XtGeometryResult XmeReplyToQueryGeometry(Widget w,
+	XtWidgetGeometry *request, XtWidgetGeometry *reply);
+
 
 /*************************** Region.c ***************************/
 XmRegion _XmRegionCreate(void);
