@@ -1,6 +1,6 @@
 /**
  *
- * $Id: DirectionI.h,v 1.1 1998/10/06 18:05:35 pgw Exp $
+ * $Id: DirectionI.h,v 1.2 1999/01/19 12:28:08 pgw Exp $
  *
  * Copyright (C) 1998 Free Software Foundation, Inc.
  *
@@ -30,6 +30,9 @@ extern "C" {
 #endif
 
 void _XmDirectionDefault(Widget w, int offset, XrmValue *value);
+XmDirection _XmGetLayoutDirection(Widget w);
+void _XmFromLayoutDirection(Widget widget, int offset, XtArgVal *value);
+XmImportOperator _XmToLayoutDirection(Widget widget, int offset, XtArgVal *value);
 
 #ifdef __cplusplus
 }
