@@ -1,9 +1,8 @@
 /**
  *
- * $Id: PopupUtil.h,v 1.1 2004/08/28 19:23:36 dannybackx Exp $
+ * $Id: PopupUtil.h,v 1.2 1999/01/28 21:04:48 pgw Exp $
  *
  * Copyright (C) 1998 Free Software Foundation, Inc.
- * Copyright (C) 1998-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,8 +22,12 @@
  *
  **/
 
-#ifndef _XMI_POPUPUTIL_H
-#define _XMI_POPUPUTIL_H
+#ifndef XM_POPUPUTIL_H
+#define XM_POPUPUTIL_H
+
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 /*
   These should be used instead of there Xt alternative.
@@ -33,4 +36,9 @@ void _XmPopup(Widget w, XtGrabKind kind);
 void _XmPopupSpringLoaded(Widget w);
 void _XmPopdown(Widget w);
 
-#endif /* _XMI_POPUTIL_H */
+#ifdef __cplusplus
+}
+#endif
+
+#endif
+
