@@ -1,9 +1,8 @@
 /**
  *
- * $Id: misc.h,v 1.6 2000/12/06 14:17:59 amai Exp $
+ * $Id: misc.h,v 1.2 1999/02/02 18:22:56 gritton Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -27,22 +26,40 @@
  *
 */ 
 
-
+/*
+static char *rcsid = "$Id: misc.h,v 1.2 1999/02/02 18:22:56 gritton Exp $";
+*/
 #ifndef _MISC_H
 #define _MISC_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 #define MAX_STACK 20
+extern int StackPointer;
+extern char *Stack[MAX_STACK];
+void yyerror(char *);
+void Exit(int, char *,char *, ...);
+void Warn(int, char *,char *, ...);
 
-extern int __MrmStackPointer;
-extern char *__MrmStack[MAX_STACK];
+char *pop(void);
+void push(char *s);
+char *Store(char *s);
+void GetArgValues(int index, char **theString, char *Access);
 
-void __MrmExit(int, char *, const char *, ...);
-void __MrmWarn(int, char *, const char *, ...);
-
-char *__MrmPop(void);
-void __MrmPush(char *s);
-char *__MrmStore(char *s);
+#ifdef __cplusplus
+}
+#endif
 
 #define LOC __LINE__,__FILE__
+extern int errno;
+
+#endif
+
+
+
+
+
+
+
 
-#endif /* _MISC_H */
