@@ -1,15 +1,13 @@
 /*
  * AUTHOR: Jay Schmidgall <jay.schmidgall@spdbump.sungardss.com>
  *
- * $Id: choice.c,v 1.2 2000/04/26 09:44:48 amai Exp $
+ * $Id: choice.c,v 1.1 1999/08/04 21:24:04 danny Exp $
  */
 
 #ifdef HAVE_CONFIG_H
 #include <XbaeConfig.h>
 #endif
 
-#include <stdlib.h>
-
 #include <Xbae/Matrix.h>
 #include <Xbae/Actions.h>
 #include <Xm/Form.h>
@@ -25,7 +23,8 @@
 #include <string.h>
 
 void
-LoadMatrix(Widget w)
+LoadMatrix(w)
+Widget w;
 {
     String *cells[10];
     static String rows[10][10] = {
@@ -83,7 +82,10 @@ typedef struct {
 enum { SelectSelect, SelectHighlight, SelectArm };
 
 void
-cbSelectMode(Widget w, XtPointer client, XtPointer call)
+cbSelectMode(w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
 {
     SelectModeStruct *sms;
     XmToggleButtonCallbackStruct *cbs = (XmToggleButtonCallbackStruct *) call;
@@ -137,7 +139,9 @@ cbSelectMode(Widget w, XtPointer client, XtPointer call)
 
 
 void
-UnarmAll(Widget w, SelectModeStruct *sms)
+UnarmAll(w, sms)
+Widget w;
+SelectModeStruct *sms;
 {
     int rows, columns, r, c;
     unsigned char *rowShadows, *columnShadows, **cellShadows;
@@ -173,7 +177,10 @@ UnarmAll(Widget w, SelectModeStruct *sms)
 }
 
 void
-ArmColumn(Widget w, int column, SelectModeStruct *sms)
+ArmColumn(w, column, sms)
+Widget w;
+int column;
+SelectModeStruct *sms;
 {
     int rows, columns, r;
     unsigned char *rowShadows, *columnShadows, **cellShadows;
@@ -221,7 +228,10 @@ ArmColumn(Widget w, int column, SelectModeStruct *sms)
 }
 
 void
-ArmRow(Widget w, int row, SelectModeStruct *sms)
+ArmRow(w, row, sms)
+Widget w;
+int row;
+SelectModeStruct *sms;
 {
     int rows, columns, c;
     unsigned char *rowShadows, *columnShadows, **cellShadows;
@@ -269,7 +279,11 @@ ArmRow(Widget w, int row, SelectModeStruct *sms)
 }
 
 void
-ArmCell(Widget w, int row, int column, SelectModeStruct *sms)
+ArmCell(w, row, column, sms)
+Widget w;
+int row;
+int column;
+SelectModeStruct *sms;
 {
     int rows, columns, r, c;
     unsigned char *rowShadows, *columnShadows, **cellShadows;
@@ -340,7 +354,10 @@ ArmCell(Widget w, int row, int column, SelectModeStruct *sms)
 }
 
 void
-cbRadio(Widget w, XtPointer client, XtPointer call)
+cbRadio(w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
 {
     XmToggleButtonCallbackStruct *cbs = (XmToggleButtonCallbackStruct *) call;
     SetValueStruct *svs = (SetValueStruct *) client;
@@ -351,7 +368,10 @@ cbRadio(Widget w, XtPointer client, XtPointer call)
 
 
 void
-cbScale(Widget w, XtPointer client, XtPointer call)
+cbScale(w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
 {
     XmScaleCallbackStruct *cbs = (XmScaleCallbackStruct *) call;
     SetValueStruct *svs = (SetValueStruct *) client;
@@ -360,7 +380,9 @@ cbScale(Widget w, XtPointer client, XtPointer call)
 
 
 Widget
-createButtonBox(Widget parent, char *name)
+createButtonBox(parent, name)
+Widget parent;
+char *name;
 {
     Widget frame, frame2, label, rc;
     
@@ -395,7 +417,10 @@ createButtonBox(Widget parent, char *name)
 
 
 Widget
-createScaleBox(Widget parent, char *name, int min, int max)
+createScaleBox(parent, name, min, max)
+Widget parent;
+char *name;
+int min, max;
 {
     Widget frame, frame2, label, scale;
 
@@ -429,7 +454,9 @@ createScaleBox(Widget parent, char *name, int min, int max)
 
 
 void
-createGridType(Widget parent, Widget mw)
+createGridType(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget rc, button;
     SetValueStruct *svs;
@@ -509,7 +536,9 @@ createGridType(Widget parent, Widget mw)
 
 
 void
-createCellShadowType(Widget parent, Widget mw)
+createCellShadowType(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget rc, button;
     SetValueStruct *svs;
@@ -557,7 +586,9 @@ createCellShadowType(Widget parent, Widget mw)
     
 
 void
-createShadowType(Widget parent, Widget mw)
+createShadowType(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget rc, button;
     SetValueStruct *svs;
@@ -605,7 +636,9 @@ createShadowType(Widget parent, Widget mw)
     
 
 void
-createPlacement(Widget parent, Widget mw)
+createPlacement(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget rc, button;
     SetValueStruct *svs;
@@ -653,7 +686,9 @@ createPlacement(Widget parent, Widget mw)
     
 
 void
-createFill(Widget parent, Widget mw)
+createFill(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget rc, button;
     SetValueStruct *svs;
@@ -688,7 +723,9 @@ createFill(Widget parent, Widget mw)
     
 
 void
-createColumnResize(Widget parent, Widget mw)
+createColumnResize(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget rc, button;
     SetValueStruct *svs;
@@ -722,7 +759,9 @@ createColumnResize(Widget parent, Widget mw)
 }
     
 void
-createButtonLabels(Widget parent, Widget mw)
+createButtonLabels(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget rc, button;
     SetValueStruct *svs;
@@ -756,7 +795,9 @@ createButtonLabels(Widget parent, Widget mw)
 }
 
 void
-createRowAttached(Widget parent, Widget mw)
+createRowAttached(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget rc, button;
     SetValueStruct *svs;
@@ -790,7 +831,9 @@ createRowAttached(Widget parent, Widget mw)
 }
 
 void
-createSelectMode(Widget parent, Widget mw)
+createSelectMode(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget rc, button;
     SetValueStruct *svs;
@@ -829,7 +872,9 @@ createSelectMode(Widget parent, Widget mw)
 }
 
 void
-createVerticalDisplay(Widget parent, Widget mw)
+createVerticalDisplay(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget rc, button;
     SetValueStruct *svs;
@@ -868,7 +913,9 @@ createVerticalDisplay(Widget parent, Widget mw)
     
 
 void
-createHorizontalDisplay(Widget parent, Widget mw)
+createHorizontalDisplay(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget rc, button;
     SetValueStruct *svs;
@@ -907,7 +954,9 @@ createHorizontalDisplay(Widget parent, Widget mw)
     
 
 void
-createCellShadowThickness(Widget parent, Widget mw)
+createCellShadowThickness(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget scale;
     SetValueStruct *svs;
@@ -923,7 +972,9 @@ createCellShadowThickness(Widget parent, Widget mw)
 
 
 void
-createShadowThickness(Widget parent, Widget mw)
+createShadowThickness(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget scale;
     SetValueStruct *svs;
@@ -939,7 +990,9 @@ createShadowThickness(Widget parent, Widget mw)
 
 
 void
-createFixedRows(Widget parent, Widget mw)
+createFixedRows(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget scale;
     SetValueStruct *svs;
@@ -954,7 +1007,9 @@ createFixedRows(Widget parent, Widget mw)
 
 
 void
-createFixedColumns(Widget parent, Widget mw)
+createFixedColumns(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget scale;
     SetValueStruct *svs;
@@ -969,7 +1024,9 @@ createFixedColumns(Widget parent, Widget mw)
 
 
 void
-createTrailingFixedRows(Widget parent, Widget mw)
+createTrailingFixedRows(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget scale;
     SetValueStruct *svs;
@@ -984,7 +1041,9 @@ createTrailingFixedRows(Widget parent, Widget mw)
 
 
 void
-createTrailingFixedColumns(Widget parent, Widget mw)
+createTrailingFixedColumns(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget scale;
     SetValueStruct *svs;
@@ -999,7 +1058,9 @@ createTrailingFixedColumns(Widget parent, Widget mw)
 
 
 void
-createCellMarginWidth(Widget parent, Widget mw)
+createCellMarginWidth(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget scale;
     SetValueStruct *svs;
@@ -1015,7 +1076,9 @@ createCellMarginWidth(Widget parent, Widget mw)
 
 
 void
-createCellMarginHeight(Widget parent, Widget mw)
+createCellMarginHeight(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget scale;
     SetValueStruct *svs;
@@ -1031,7 +1094,9 @@ createCellMarginHeight(Widget parent, Widget mw)
 
 
 void
-createCellHighlightThickness(Widget parent, Widget mw)
+createCellHighlightThickness(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget scale;
     SetValueStruct *svs;
@@ -1047,7 +1112,9 @@ createCellHighlightThickness(Widget parent, Widget mw)
 
 
 void
-createSpace(Widget parent, Widget mw)
+createSpace(parent, mw)
+Widget parent;
+Widget mw;
 {
     Widget scale;
     SetValueStruct *svs;
@@ -1063,7 +1130,10 @@ createSpace(Widget parent, Widget mw)
 
 
 void
-cbSelect(Widget w, XtPointer client, XtPointer call)
+cbSelect(w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
 {
     int x, y;
     char buf[200];
@@ -1127,7 +1197,9 @@ cbSelect(Widget w, XtPointer client, XtPointer call)
 
 
 int
-main(int argc, char *argv[])
+main(argc, argv)
+int argc;
+char *argv[];
 {
     SelectModeStruct *sms;
     Widget toplevel, form, rc, mw, text;
@@ -1278,3 +1350,4 @@ main(int argc, char *argv[])
     /*NOTREACHED*/
     return 0;
 }
+
