@@ -1,7 +1,6 @@
 /*
  * Copyright(c) 1992 Bell Communications Research, Inc. (Bellcore)
  * Copyright(c) 1995-99 Andrew Lister
- * Copyright (c) 1999-2000 by the LessTif Developers.
  *
  *                        All rights reserved
  * Permission to use, copy, modify and distribute this material for
@@ -22,7 +21,7 @@
  * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
  * ING TO THE SOFTWARE.
  *
- * $Id: Macros.h,v 1.17 2000/11/01 01:10:18 dannybackx Exp $
+ * $Id: Macros.h,v 1.2 1999/10/23 12:14:07 danny Exp $
  */
 
 /*
@@ -32,6 +31,23 @@
 #ifndef _Xbae_Macros_h
 #define _Xbae_Macros_h
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
+/*
+ * Prototype wrapper
+ */
+#ifndef P
+#if defined(__STDC__) || defined (__cplusplus)
+#define P(x)		x
+#else
+#define P(x)		()
+#define const
+#define volatile
+#endif
+#endif
+
 #if XmVersion <= 1001
 #include <Xm/XmP.h>
 #else
@@ -40,46 +56,18 @@
 #include <Xm/TextP.h>
 #include <Xm/PrimitiveP.h>
 
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-/*
- * The third parameter is a string added for debugging purposes.
- */
-#if	0	/* Danny - DEBUG */
-#define DRAW_SHADOW(dpy, draw, dbg, tgc, bgc, sz, x, y, w, h, type)	\
-    { 									\
-	fprintf(stderr, "_XmDrawShadows(%s)(%d,%d,%d,%d,%d,%d)\n",	\
-		dbg, x, y, w, h, sz, type);				\
-	_XmDrawShadows(dpy, draw, tgc, bgc, x, y, w, h, sz, type);	\
-    }
-#else
-#if 1
-/*
- * BX (Builder Xcessory - see http://www.ics.com) is linked with a 1.2
- * version of Motif. Use of an Xbae widget which uses a Motif 2.* function
- * will crash BX when it tries to use the function.
- */
-#define DRAW_SHADOW(dpy, draw, dbg, tgc, bgc, sz, x, y, w, h, type)	\
-    _XmDrawShadows(dpy, draw, tgc, bgc, x, y, w, h, sz, type)
-
-#else
 #if XmVersion <= 1001
-#define DRAW_SHADOW(dpy, draw, dbg, tgc, bgc, sz, x, y, w, h, type)	\
+#define DRAW_SHADOW(dpy, draw, tgc, bgc, sz, x, y, w, h, type)	\
     _XmDrawShadow(dpy, draw, tgc, bgc, sz, x, y, w, h)
 #else
 #if XmVersion >= 2000
-#define DRAW_SHADOW(dpy, draw, dbg, tgc, bgc, sz, x, y, w, h, type)	\
+#define DRAW_SHADOW(dpy, draw, tgc, bgc, sz, x, y, w, h, type)	\
     XmeDrawShadows(dpy, draw, tgc, bgc, x, y, w, h, sz, type)
 #else
-#define DRAW_SHADOW(dpy, draw, dbg, tgc, bgc, sz, x, y, w, h, type)	\
+#define DRAW_SHADOW(dpy, draw, tgc, bgc, sz, x, y, w, h, type)	\
     _XmDrawShadows(dpy, draw, tgc, bgc, x, y, w, h, sz, type)
 #endif
 #endif
-#endif
-#endif
 
 #if XmVersion <= 1001
 #define DRAW_HIGHLIGHT(dpy, draw, tgc, x, y, w, h, sz, type) \
@@ -143,19 +131,6 @@ extern "C" {
 				 mw->matrix.cell_highlight_thickness + \
 				 mw->matrix.text_shadow_thickness)
 
-#ifdef	HAVE_ROW_HEIGHTS
-#define SOME_ROW_HEIGHT(mw, row)	mw->matrix.row_heights[row]
-/* this is the original ...
- * #define ROW_HEIGHT(mw) \
- *	(int)((TEXT_HEIGHT_OFFSET(mw) * 2) + TEXT_HEIGHT(mw))
- * #define TEXT_HEIGHT(mw)		(Max(FONT_HEIGHT(mw), LABEL_HEIGHT(mw)))
- * #define FONT_HEIGHT(mw)		(mw->matrix.font_height)
- * #define LABEL_HEIGHT(mw)	(mw->matrix.label_font_height)
- */
-#else
-#define SOME_ROW_HEIGHT(mw, row)	ROW_HEIGHT(mw)
-#endif
-
 #define COLUMN_WIDTH(mw, col)	((mw->matrix.column_widths[col] * \
 				  FONT_WIDTH(mw)) + \
 				 ((int)TEXT_WIDTH_OFFSET(mw) * 2))
@@ -283,7 +258,6 @@ extern "C" {
 				 LABEL_HEIGHT(mw) : 0)
 
 #define COLUMN_POSITION(mw, column) mw->matrix.column_positions[column]
-#define ROW_POSITION(mw, row) mw->matrix.row_positions[row]
  
 #define FIXED_COLUMN_WIDTH(mw)	COLUMN_POSITION(mw, mw->matrix.fixed_columns)
 
@@ -303,9 +277,10 @@ extern "C" {
 #define TRAILING_FIXED_COLUMN_LABEL_OFFSET(mw) (FIXED_COLUMN_LABEL_OFFSET(mw)+\
 						VISIBLE_WIDTH(mw))
 
-#define	FIXED_ROW_HEIGHT(mw)	xbaeMatrixFixedRowHeight(mw)
+#define FIXED_ROW_HEIGHT(mw)	((int)mw->matrix.fixed_rows * ROW_HEIGHT(mw))
 
-#define TRAILING_FIXED_ROW_HEIGHT(mw) xbaeMatrixTrailingFixedRowHeight(mw)
+#define TRAILING_FIXED_ROW_HEIGHT(mw) ((int)mw->matrix.trailing_fixed_rows * \
+				       ROW_HEIGHT(mw))
 
 #define ROW_LABEL_OFFSET(mw)	(COLUMN_LABEL_HEIGHT(mw) + \
 				 HORIZ_SB_OFFSET(mw) + \
@@ -314,9 +289,6 @@ extern "C" {
 #define FIXED_ROW_LABEL_OFFSET(mw) (ROW_LABEL_OFFSET(mw) + \
 				    FIXED_ROW_HEIGHT(mw))
 
-#define UNATTACHED_TRAILING_COLUMNS_OFFSET(mw) (FIXED_COLUMN_LABEL_OFFSET(mw) + \
-					     VISIBLE_WIDTH(mw))
-
 #define UNATTACHED_TRAILING_ROWS_OFFSET(mw) (FIXED_ROW_LABEL_OFFSET(mw) + \
 					     VISIBLE_HEIGHT(mw))
 
@@ -332,10 +304,6 @@ extern "C" {
 					 mw->matrix.trailing_attached_bottom && \
 					 mw->matrix.trailing_fixed_rows) 
 
-#define HAS_ATTACHED_TRAILING_COLUMNS(mw)  (mw->matrix.fill &&  \
-					 mw->matrix.trailing_attached_right && \
-					 mw->matrix.trailing_fixed_columns) 
-
 #define TRAILING_FIXED_ROW_LABEL_OFFSET(mw) (HAS_ATTACHED_TRAILING_ROWS(mw) ? \
 					     ATTACHED_TRAILING_ROWS_OFFSET(mw) : \
 					     UNATTACHED_TRAILING_ROWS_OFFSET(mw))
@@ -460,12 +428,6 @@ extern "C" {
 					       mw->matrix.column_widths); \
 					}
 
-#define xbaeFreeRowHeights(mw)	{ \
-					       if (mw->matrix.row_heights) \
-					       XtFree((XtPointer) \
-					       mw->matrix.row_heights); \
-					}
-
 #define xbaeFreeColumnMaxLengths(mw)	{ \
 					       if (mw->matrix.\
 					       column_max_lengths) \
@@ -498,14 +460,6 @@ extern "C" {
 					       column_button_labels); \
 					}
 
-#define xbaeFreeColumnFontBold(mw)	{ \
-						if (mw->matrix. \
-						column_font_bold) \
-						XtFree((XtPointer) \
-						mw->matrix. \
-						column_font_bold); \
-					}
-
 #define xbaeFreeRowButtonLabels(mw)	{ \
 					       if (mw->matrix. \
 					       row_button_labels) \
@@ -554,10 +508,10 @@ extern "C" {
 					       column_shadow_types); \
 					}
 
-#define CreateRowPositions(mw) \
-	(int *)XtMalloc((mw->matrix.rows+1) * sizeof(int))
-#define CreateColumnPositions(mw) \
-	(int *)XtMalloc((mw->matrix.columns+1) * sizeof(int))
+#define CreateColumnPositions(mw)  (int *)XtMalloc((mw->matrix.columns+1)* \
+						   sizeof(int))
+#define YtoRow(mw, y)			((y) / ROW_HEIGHT(mw))
+
 
 /*
  * Evaluates to 1 if two Rectangles overlap, 0 if no overlap
@@ -604,7 +558,7 @@ extern "C" {
 #endif
 
 #ifdef NEED_24BIT_VISUAL
-#define GC_PARENT_WINDOW(w)	XtWindow(_XbaeGetShellAncestor((Widget)w))
+#define GC_PARENT_WINDOW(w)	XtWindow(get_shell_ancestor((Widget)w))
 #else
 #define GC_PARENT_WINDOW(w)	RootWindowOfScreen(XtScreen(w))
 #endif
@@ -613,7 +567,6 @@ extern "C" {
  * End of array flags for the array type converters
  */
 #define BAD_WIDTH	-1
-#define BAD_HEIGHT	-1
 #define BAD_MAXLENGTH	0
 #define BAD_ALIGNMENT	3	/* see Xm.h */
 #define BAD_PIXEL	0x10000000 /* normally 256 indices */ 
@@ -662,7 +615,7 @@ extern "C" {
 #define IN_GRID_ROW_MODE(mw)	(mw->matrix.grid_type & GRID_MODE_ROW)
 #define IN_GRID_COLUMN_MODE(mw)	(mw->matrix.grid_type & GRID_MODE_COLUMN)
 
-#ifdef __cplusplus
+#if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
 
