@@ -1,8 +1,6 @@
 /*
  * Copyright(c) 1992 Bell Communications Research, Inc. (Bellcore)
  * Copyright(c) 1995-99 Andrew Lister
- * Copyright (c) 1999-2000 by the LessTif Developers.
- *
  *                        All rights reserved
  * Permission to use, copy, modify and distribute this material for
  * any purpose and without fee is hereby granted, provided that the
@@ -24,7 +22,7 @@
  *
  * MatrixWidget Author: Andrew Wason, Bellcore, aw@bae.bellcore.com
  *
- * $Id: MatrixP.h,v 1.15 2000/06/11 17:58:39 danny Exp $
+ * $Id: MatrixP.h,v 1.4 1999/10/23 12:14:06 danny Exp $
  */
 
 /*
@@ -34,6 +32,10 @@
 #ifndef _Xbae_MatrixP_h
 #define _Xbae_MatrixP_h
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 #if XmVersion <= 1001
 #	include <Xm/XmP.h>
 #else
@@ -42,8 +44,14 @@
 
 #include <Xbae/Matrix.h>
 
-#ifdef __cplusplus
-extern "C" {
+#ifndef P
+#if defined(__STDC__) || defined (__cplusplus)
+#define P(x)		x
+#else
+#define P(x)		()
+#define const
+#define volatile
+#endif
 #endif
 
 /*
@@ -70,55 +78,55 @@ extern "C" {
  */
 _XFUNCPROTOBEGIN
 
-typedef void (*XbaeMatrixSetCellProc)(XbaeMatrixWidget, int, int,
-					 const String, Boolean);
+typedef void (*XbaeMatrixSetCellProc) P((XbaeMatrixWidget, int, int,
+					 const String, Boolean));
 
-typedef String (*XbaeMatrixGetCellProc)(XbaeMatrixWidget, int, int);
+typedef String (*XbaeMatrixGetCellProc) P((XbaeMatrixWidget, int, int));
 
-typedef void (*XbaeMatrixEditCellProc)(XbaeMatrixWidget, XEvent *,
-					  int, int, String *, Cardinal);
+typedef void (*XbaeMatrixEditCellProc) P((XbaeMatrixWidget, XEvent *,
+					  int, int, String *, Cardinal));
 
-typedef void (*XbaeMatrixSelectCellProc)(XbaeMatrixWidget, int, int);
+typedef void (*XbaeMatrixSelectCellProc) P((XbaeMatrixWidget, int, int));
 
-typedef void (*XbaeMatrixSelectRowProc)(XbaeMatrixWidget, int);
+typedef void (*XbaeMatrixSelectRowProc) P((XbaeMatrixWidget, int));
 
-typedef void (*XbaeMatrixSelectColumnProc)(XbaeMatrixWidget, int);
+typedef void (*XbaeMatrixSelectColumnProc) P((XbaeMatrixWidget, int));
 
-typedef void (*XbaeMatrixDeselectAllProc)(XbaeMatrixWidget);
+typedef void (*XbaeMatrixDeselectAllProc) P((XbaeMatrixWidget));
 
-typedef void (*XbaeMatrixSelectAllProc)(XbaeMatrixWidget);
+typedef void (*XbaeMatrixSelectAllProc) P((XbaeMatrixWidget));
 
-typedef void (*XbaeMatrixDeselectCellProc)(XbaeMatrixWidget, int, int);
+typedef void (*XbaeMatrixDeselectCellProc) P((XbaeMatrixWidget, int, int));
 
-typedef void (*XbaeMatrixDeselectRowProc)(XbaeMatrixWidget, int);
+typedef void (*XbaeMatrixDeselectRowProc) P((XbaeMatrixWidget, int));
 
-typedef void (*XbaeMatrixDeselectColumnProc)(XbaeMatrixWidget, int);
+typedef void (*XbaeMatrixDeselectColumnProc) P((XbaeMatrixWidget, int));
 
-typedef Boolean (*XbaeMatrixCommitEditProc)(XbaeMatrixWidget, XEvent *,
-					       Boolean);
+typedef Boolean (*XbaeMatrixCommitEditProc) P((XbaeMatrixWidget, XEvent *,
+					       Boolean));
 
-typedef void (*XbaeMatrixCancelEditProc)(XbaeMatrixWidget, Boolean);
+typedef void (*XbaeMatrixCancelEditProc) P((XbaeMatrixWidget, Boolean));
 
-typedef void (*XbaeMatrixAddRowsProc)(XbaeMatrixWidget, int, String *,
-					 String *, Pixel *, Pixel *, int);
+typedef void (*XbaeMatrixAddRowsProc) P((XbaeMatrixWidget, int, String *,
+					 String *, Pixel *, Pixel *, int));
 
-typedef void (*XbaeMatrixDeleteRowsProc)(XbaeMatrixWidget, int, int);
+typedef void (*XbaeMatrixDeleteRowsProc) P((XbaeMatrixWidget, int, int));
 
-typedef void (*XbaeMatrixAddColumnsProc)(XbaeMatrixWidget, int, String *,
+typedef void (*XbaeMatrixAddColumnsProc) P((XbaeMatrixWidget, int, String *,
 					    String *, short *, int *,
 					    unsigned char*, unsigned char *,
-					    Pixel *, Pixel *, int);
+					    Pixel *, Pixel *, int));
 
-typedef void (*XbaeMatrixDeleteColumnsProc)(XbaeMatrixWidget, int, int);
+typedef void (*XbaeMatrixDeleteColumnsProc) P((XbaeMatrixWidget, int, int));
 
-typedef void (*XbaeMatrixSetRowColorsProc)(XbaeMatrixWidget, int, Pixel *,
-					      int, Boolean);
+typedef void (*XbaeMatrixSetRowColorsProc) P((XbaeMatrixWidget, int, Pixel *,
+					      int, Boolean));
 
-typedef void (*XbaeMatrixSetColumnColorsProc)(XbaeMatrixWidget, int,
-						 Pixel *, int, Boolean);
+typedef void (*XbaeMatrixSetColumnColorsProc) P((XbaeMatrixWidget, int,
+						 Pixel *, int, Boolean));
 
-typedef void (*XbaeMatrixSetCellColorProc)(XbaeMatrixWidget, int, int,
-					      Pixel, Boolean);
+typedef void (*XbaeMatrixSetCellColorProc) P((XbaeMatrixWidget, int, int,
+					      Pixel, Boolean));
 
 _XFUNCPROTOEND
 
@@ -304,8 +312,6 @@ typedef struct {
     Dimension	visible_columns;	/* number of columns to make visible */
     Dimension	visible_rows;		/* number of rows to make visible    */
 
-    Pixel	all_backgrounds;	/* use this for all cell backgrounds */
-    Pixel	all_foregrounds;	/* use this for all cell foregrounds */
     Pixel	button_label_background; /* color of button label background */
     Pixel	**cell_background;	/* 2D array of Pixels		     */
     Pixel	**colors;		/* 2D array of Pixels		     */
@@ -317,7 +323,6 @@ typedef struct {
     Pixel	selected_background;	/* background for selected cells     */
     Pixel	selected_foreground;	/* foreground for selected cells     */
     Pixel	text_background;	/* background for the "text" field   */
-    Pixel	scroll_background;	/* bacground for scrollbar */
 
     XtTranslations text_translations;	/* translations for textField widget */
 
@@ -380,7 +385,10 @@ typedef struct {
     Widget	top_clip;
     Widget	bottom_clip;
     Widget	current_parent;		/* Current textField parent window   */
+#if 1
+    /* CELL_WIDGETS, but it's a bad idea to conditionally compile a field here */
     Widget	**cell_widgets;		/* array of widgets for cells	     */
+#endif
 
     GC		cell_bottom_shadow_clip_gc; /* GC for clipped bottom shadow  */
     GC          cell_grid_line_gc;
@@ -412,17 +420,6 @@ typedef struct {
     short	label_font_height;
     Font	label_fid;
 
-#if XmVersion >= 1002
-    XtIntervalId traverseId;
-#endif
-    Cursor	cursor;			/* Used to be global static */
-
-/* Implement variable height rows */
-    short	*row_heights;		/* height of each row in chars     */
-    Boolean	allow_row_resize;	/* can rows dynamically resize?   */
-    int		*row_positions;		/* pixel position of each row */
-    XtCallbackList resize_row_callback; /* called when row is resized  */
-    int		*row_max_heights;	/* max height of each row in pixels   */
 } XbaeMatrixPart;
 
 /*
@@ -443,18 +440,8 @@ typedef struct _XbaeMatrixRec {
 # undef _XFUNCPROTOEND
 #endif
 
-int xbaeCellTotalHeight(XbaeMatrixWidget mw);
-
-/*
- * Macro replacements
- */
-extern Dimension xbaeMatrixFixedRowHeight(XbaeMatrixWidget mw);
-extern int YtoRow(XbaeMatrixWidget mw, Position y);
-extern Dimension xbaeMatrixTrailingFixedRowHeight(XbaeMatrixWidget);
-extern Widget _XbaeGetShellAncestor(Widget w);
-
 #undef P
-#ifdef __cplusplus
+#if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
 
