@@ -1,8 +1,6 @@
 /*
  * Copyright(c) 1992 Bell Communications Research, Inc. (Bellcore)
  * Copyright(c) 1995-99 Andrew Lister
- * Copyright (c) 1999-2000 by the LessTif Developers.
- *
  *                        All rights reserved
  * Permission to use, copy, modify and distribute this material for
  * any purpose and without fee is hereby granted, provided that the
@@ -22,7 +20,7 @@
  * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
  * ING TO THE SOFTWARE.
  *
- * $Id: Shadow.h,v 1.6 2000/06/11 17:58:38 danny Exp $
+ * $Id: Shadow.h,v 1.2 1999/10/23 12:14:05 danny Exp $
  */
 
 /*
@@ -32,21 +30,21 @@
 #ifndef _Xbae_Shadow_h
 #define _Xbae_Shadow_h
 
-#include <Xbae/Macros.h>
-
-#ifdef __cplusplus
+#if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
 
-void xbaeDrawCellShadow(XbaeMatrixWidget, Window, int, int, int, int,
-			    int, int, Boolean, Boolean, Boolean);
+#include <Xbae/Macros.h>
+
+void xbaeDrawCellShadow P((XbaeMatrixWidget, Window, int, int, int, int,
+			    int, int, Boolean, Boolean, Boolean));
 
 #if XmVersion >= 1002
-void xbaeDrawCellHighlight(XbaeMatrixWidget, Window, GC, int, int, int,
-			       int, int, int, int);
+void xbaeDrawCellHighlight P((XbaeMatrixWidget, Window, GC, int, int, int,
+			       int, int, int, int));
 #endif
 
-#ifdef __cplusplus
+#if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
 
