@@ -1,7 +1,6 @@
 /*
  * Copyright(c) 1992 Bell Communications Research, Inc. (Bellcore)
  * Copyright(c) 1995-99 Andrew Lister
- * Copyright (c) 1999-2000 by the LessTif Developers..
  *
  *                        All rights reserved
  * Permission to use, copy, modify and distribute this material for
@@ -22,10 +21,9 @@
  * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
  * ING TO THE SOFTWARE.
  *
- * $Id: Actions.c,v 1.14 2000/09/01 20:04:33 amai Exp $
+ * $Id: Actions.c,v 1.1 1999/08/04 19:46:50 danny Exp $
  */
 
-#undef	VERBOSE_SLIDE
 /*
  * Actions.c created by Andrew Lister (7 August, 1995)
  */
@@ -48,9 +46,6 @@
 #include <Xbae/ScrollMgr.h>
 #include <Xbae/ClipP.h>
 #include <X11/cursorfont.h>
-#ifdef XBAE_VERBOSE
-#include <stdio.h>
-#endif
 
 #ifndef XlibSpecificationRelease
 #define XrmPermStringToQuark XrmStringToQuark
@@ -68,14 +63,15 @@
 typedef struct {
     XbaeMatrixWidget mw;
     GC gc;
-    int row, column;
-    int startx, starty;
-    int lastx, lasty;
-    int currentx, currenty;
-    int x, width, y, height;
-    short *columnWidths, *rowHeights;
+    int row;
+    int column;
+    int startx;
+    int lastx;
+    int currentx;
+    int y, height;
+    short *columnWidths;
     Boolean grabbed;
-    Boolean haveVSB, haveHSB;
+    Boolean haveVSB;
 } XbaeMatrixResizeColumnStruct;
 
 typedef struct {
@@ -101,14 +97,13 @@ typedef struct {
     Boolean right;
 } XbaeMatrixScrollStruct;
 
-static int DoubleClick(XbaeMatrixWidget, XEvent *, int, int);
-static void DrawSlideRow(XbaeMatrixWidget, int);
-static void DrawSlideColumn(XbaeMatrixWidget, int);
-static void SlideColumn(Widget, XtPointer, XEvent *, Boolean *);
-static void PushButton(Widget, XtPointer, XEvent *, Boolean *);
-static void updateScroll(XtPointer);
-static void checkScrollValues(Widget, XtPointer, XEvent *, Boolean *);
-static void callSelectCellAction(XbaeMatrixWidget, XEvent *);
+static int DoubleClick P((XbaeMatrixWidget, XEvent *, int, int));
+static void DrawSlideColumn P((XbaeMatrixWidget, int));
+static void SlideColumn P((Widget, XtPointer, XEvent *, Boolean *));
+static void PushButton P((Widget, XtPointer, XEvent *, Boolean *));
+static void updateScroll P((XtPointer));
+static void checkScrollValues P((Widget, XtPointer, XEvent *, Boolean *));
+static void callSelectCellAction P((XbaeMatrixWidget, XEvent *));
 
 static int last_row = 0;
 static int last_column = 0;
@@ -120,7 +115,11 @@ static Boolean scrolling = False;
 
 /* ARGSUSED */
 void
-xbaeDefaultActionACT(Widget w, XEvent *event, String *params, Cardinal *nparams)
+xbaeDefaultActionACT(w, event, params, nparams)
+Widget w;
+XEvent *event;
+String *params;
+Cardinal *nparams;
 {
     XbaeMatrixWidget mw;
     int x, y;
@@ -164,12 +163,14 @@ xbaeDefaultActionACT(Widget w, XEvent *event, String *params, Cardinal *nparams)
 
 	XtCallCallbackList((Widget)mw, mw->matrix.default_action_callback,
 			   (XtPointer)&call_data);
-
+      
     }
 }
 
 static void
-DrawSlideColumn(XbaeMatrixWidget mw, int x)
+DrawSlideColumn(mw, x)
+XbaeMatrixWidget mw;
+int x;
 {
 #ifdef DRAW_RESIZE_SHADOW
     /* These values derived through that age-old process
@@ -215,12 +216,12 @@ DrawSlideColumn(XbaeMatrixWidget mw, int x)
 		      LeftClip(mw)->core.height);
 #endif
 #ifdef DRAW_RESIZE_SHADOW
-	DRAW_SHADOW(display, win, "win 1",
+	DRAW_SHADOW(display, win,
 		    mw->matrix.resize_top_shadow_gc,
 		    mw->matrix.resize_bottom_shadow_gc,
 		    shadow_width, x, y, width, height, XmSHADOW_OUT);
 	if (XtIsManaged(LeftClip(mw)))
-	    DRAW_SHADOW(display, XtWindow(LeftClip(mw)), "LeftClip",
+	    DRAW_SHADOW(display, XtWindow(LeftClip(mw)),
 			mw->matrix.resize_top_shadow_gc,
 			mw->matrix.resize_bottom_shadow_gc,
 			shadow_width, x - COLUMN_LABEL_OFFSET(mw),
@@ -254,12 +255,12 @@ DrawSlideColumn(XbaeMatrixWidget mw, int x)
 	
 #endif
 #ifdef DRAW_RESIZE_SHADOW
-	DRAW_SHADOW(display, win, "win 2",
+	DRAW_SHADOW(display, win,
 		    mw->matrix.resize_top_shadow_gc,
 		    mw->matrix.resize_bottom_shadow_gc,
 		    shadow_width, x, y, width, height, XmSHADOW_OUT);
 	if (XtIsManaged(RightClip(mw)))
-	    DRAW_SHADOW(display, XtWindow(RightClip(mw)), "RightClip",
+	    DRAW_SHADOW(display, XtWindow(RightClip(mw)),
 			mw->matrix.resize_top_shadow_gc,
 			mw->matrix.resize_bottom_shadow_gc,
 			shadow_width,
@@ -268,7 +269,7 @@ DrawSlideColumn(XbaeMatrixWidget mw, int x)
 #endif
 	return;
     }
-
+    
     xbaeGetVisibleRows(mw, &top, &bottom);
     /*
      * we need all non-fixed rows, so add 1 to bottom
@@ -298,7 +299,7 @@ DrawSlideColumn(XbaeMatrixWidget mw, int x)
     XDrawLine(display, win, gc, adjusted_x, y, adjusted_x, y + height);
 #endif
 #ifdef DRAW_RESIZE_SHADOW
-    DRAW_SHADOW(display, win, "win 3",
+    DRAW_SHADOW(display, win,
 		mw->matrix.resize_top_shadow_gc,
 		mw->matrix.resize_bottom_shadow_gc,
 		shadow_width, adjusted_x, y, width, height, XmSHADOW_OUT);
@@ -321,7 +322,7 @@ DrawSlideColumn(XbaeMatrixWidget mw, int x)
 #endif
 #ifdef DRAW_RESIZE_SHADOW
 	if (XtIsManaged(TopClip(mw)))
-	    DRAW_SHADOW(display, XtWindow(TopClip(mw)), "TopClip",
+	    DRAW_SHADOW(display, XtWindow(TopClip(mw)),
 			mw->matrix.resize_top_shadow_gc,
 			mw->matrix.resize_bottom_shadow_gc,
 			shadow_width, adjusted_x,
@@ -330,7 +331,7 @@ DrawSlideColumn(XbaeMatrixWidget mw, int x)
 #endif
 	xbaeSetClipMask(mw, CLIP_NONE);			 
     }
-
+    
     /*
      * The trailingFixedRows
      */
@@ -355,7 +356,7 @@ DrawSlideColumn(XbaeMatrixWidget mw, int x)
 #endif
 #ifdef DRAW_RESIZE_SHADOW
 	if (XtIsManaged(BottomClip(mw)))
-	    DRAW_SHADOW(display, XtWindow(BottomClip(mw)), "BottomClip",
+	    DRAW_SHADOW(display, XtWindow(BottomClip(mw)),
 			mw->matrix.resize_top_shadow_gc,
 			mw->matrix.resize_bottom_shadow_gc,
 			shadow_width, adjusted_x,
@@ -387,7 +388,7 @@ DrawSlideColumn(XbaeMatrixWidget mw, int x)
 		  adjusted_x, y, adjusted_x, height);
 #endif
 #ifdef DRAW_RESIZE_SHADOW
-	DRAW_SHADOW(display, XtWindow(mw), "win 4",
+	DRAW_SHADOW(display, XtWindow(mw),
 		    mw->matrix.resize_top_shadow_gc,
 		    mw->matrix.resize_bottom_shadow_gc,
 		    shadow_width, x, y,
@@ -396,15 +397,20 @@ DrawSlideColumn(XbaeMatrixWidget mw, int x)
     }
 }
 
+
 static void
-SlideColumn(Widget w, XtPointer data, XEvent *event, Boolean *cont)
+SlideColumn(w, data, event, cont)
+Widget w;
+XtPointer data;
+XEvent *event;
+Boolean *cont;
 {
     XbaeMatrixResizeColumnStruct *rd = (XbaeMatrixResizeColumnStruct *)data;
     XMotionEvent *motionEvent;
     Boolean relayout = False;
     int numCharacters;
     int i;
-
+    
     if (event->type == ButtonRelease)
     {
 	DrawSlideColumn(rd->mw, rd->lastx);
@@ -477,7 +483,7 @@ SlideColumn(Widget w, XtPointer data, XEvent *event, Boolean *cont)
 	rd->currentx -= numCharacters * FONT_WIDTH(rd->mw);
 	relayout = True;
     }	
-
+    
     if (motionEvent->x - rd->currentx > FONT_WIDTH(rd->mw))
     {
 	/*
@@ -504,396 +510,21 @@ SlideColumn(Widget w, XtPointer data, XEvent *event, Boolean *cont)
     }
 }
 
-/* Derived from DrawSlideColumn */
-static void
-DrawSlideRow(XbaeMatrixWidget mw, int y)
-{
-#ifdef DRAW_RESIZE_SHADOW
-    /* These values derived through that age-old process
-     * of what looks good to me */
-#define SHADOW_WIDTH 2
-#define RESIZE_COLUMN_LINE_WIDTH 4
-    Dimension height = RESIZE_COLUMN_LINE_WIDTH;
-    Dimension shadow_width = SHADOW_WIDTH;
-#endif
-    Dimension width;
-    Window win;
-    Display *display = XtDisplay(mw);
-    int row = xbaeYtoRow(mw, y - ROW_LABEL_OFFSET(mw));
-    int left, right;
-    int adjusted_y;
-    int x;
-#ifdef DRAW_RESIZE_LINE
-    GC gc = mw->matrix.draw_gc;
-#endif
-    Boolean need_vert_dead_space_fill = NEED_VERT_DEAD_SPACE_FILL(mw);
-    unsigned int clip_reason;
-
-#ifdef	VERBOSE_SLIDE
-    fprintf(stderr, "DrawSlideRow(%d)\n", y);
-#endif
-
-    /*
-     * If the column being resized is a fixed one then we don't need to
-     * bother with the clip region
-     */
-    if (row < (int)mw->matrix.fixed_rows)
-    {
-	x = COLUMN_LABEL_OFFSET(mw);
-	width = VISIBLE_WIDTH(mw) + FIXED_COLUMN_WIDTH(mw) +
-	    TRAILING_FIXED_COLUMN_WIDTH(mw);
-	win = XtWindow (mw);
-
-	if (need_vert_dead_space_fill)
-	    width += VERT_DEAD_SPACE_HEIGHT(mw);
-
-#ifdef DRAW_RESIZE_LINE
-#ifdef	VERBOSE_SLIDE
-	fprintf(stderr, "XDrawLine(%d,%d,%d,%d)\n", x, y, x + width, y);
-#endif
-	XDrawLine(display, win, gc, x, y, x + width, y);
-	if (XtIsManaged(TopClip(mw))) {					/* Used to be left */
-#ifdef	VERBOSE_SLIDE
-	    fprintf(stderr, "XDrawLine(%d,%d,%d,%d)\n",
-		      0, y - ROW_LABEL_OFFSET(mw),
-		      TopClip(mw)->core.width, y - ROW_LABEL_OFFSET(mw));
-#endif
-	    XDrawLine(display, XtWindow(TopClip(mw)), gc,
-		      0, y - ROW_LABEL_OFFSET(mw),
-		      TopClip(mw)->core.width, y - ROW_LABEL_OFFSET(mw));
-	}
-#endif
-#ifdef DRAW_RESIZE_SHADOW
-	DRAW_SHADOW(display, win, "win 5",
-		    mw->matrix.resize_top_shadow_gc,
-		    mw->matrix.resize_bottom_shadow_gc,
-		    shadow_width, x, y, width, height, XmSHADOW_OUT);
-	if (XtIsManaged(TopClip(mw)))
-	    DRAW_SHADOW(display, XtWindow(TopClip(mw)), "TopClip",
-			mw->matrix.resize_top_shadow_gc,
-			mw->matrix.resize_bottom_shadow_gc,
-			shadow_width,
-			0, y - ROW_LABEL_OFFSET(mw),
-			TopClip(mw)->core.width, height, XmSHADOW_OUT);
-#endif
-	return;
-    }
-    /*
-     * Similarly for trailingFixedRows - beware going off the clip child
-     * here also
-     */
-    if (row >= TRAILING_VERT_ORIGIN(mw) ||
-	y >= (int)(ClipChild(mw)->core.y + ClipChild(mw)->core.height))
-    {
-	x = COLUMN_LABEL_OFFSET(mw);
-	width = VISIBLE_WIDTH(mw) + FIXED_COLUMN_WIDTH(mw) +
-	    TRAILING_FIXED_COLUMN_WIDTH(mw);
-	win = XtWindow(mw);
-
-	if (need_vert_dead_space_fill)
-	    width += VERT_DEAD_SPACE_HEIGHT(mw);
-
-#ifdef DRAW_RESIZE_LINE
-#ifdef	VERBOSE_SLIDE
-	fprintf(stderr, "XDrawLine(%d,%d,%d,%d)\n", x, y, x + width, y);
-#endif
-	XDrawLine(display, win, gc, x, y, x + width, y);
-	if (XtIsManaged(BottomClip(mw))) {			/* Used to be RightClip */
-#ifdef	VERBOSE_SLIDE
-	    fprintf(stderr, "XDrawLine(BottomClip %d,%d,%d,%d)\n",
-		0, y - TRAILING_FIXED_ROW_LABEL_OFFSET(mw),
-		BottomClip(mw)->core.width, y - TRAILING_FIXED_ROW_LABEL_OFFSET(mw));
-#endif
-	    XDrawLine(display, XtWindow(BottomClip(mw)), gc,
-		0, y - TRAILING_FIXED_ROW_LABEL_OFFSET(mw),
-		BottomClip(mw)->core.width, y - TRAILING_FIXED_ROW_LABEL_OFFSET(mw));
-	}
-#endif
-#ifdef DRAW_RESIZE_SHADOW
-	DRAW_SHADOW(display, win, "win 6",
-		    mw->matrix.resize_top_shadow_gc,
-		    mw->matrix.resize_bottom_shadow_gc,
-		    shadow_width, x, y, width, height, XmSHADOW_OUT);
-	if (XtIsManaged(BottomClip(mw)))
-	    DRAW_SHADOW(display, XtWindow(BottomClip(mw)), "BottopClip",
-			mw->matrix.resize_top_shadow_gc,
-			mw->matrix.resize_bottom_shadow_gc,
-			shadow_width,
-		       	0, y - TRAILING_FIXED_ROW_LABEL_OFFSET(mw),
-		       	BottomClip(mw)->core.width, height,
-			XmSHADOW_OUT);
-#endif
-	return;
-    }
-
-    xbaeGetVisibleColumns(mw, &left, &right);
-    /*
-     * we need all non-fixed columns, so add 1 to left to include the last one
-     * as the return values are inclusive
-    left += 1;
-     */
-    right += 1;
-
-    /*
-     * The area between left and right rows are the non fixed columns.
-     * They fall on the ClipChild
-     */
-    x = -mw->matrix.cell_shadow_thickness; /* relative to clip */
-
-    width = COLUMN_POSITION(mw, right) - COLUMN_POSITION(mw, left)
-	+ 2 * mw->matrix.cell_shadow_thickness;
-#ifdef	VERBOSE_SLIDE
-    fprintf(stderr, "Width %d = %d - %d + 2 * %d (left %d, right %d)\n",
-	width, COLUMN_POSITION(mw, right), COLUMN_POSITION(mw, left),
-	mw->matrix.cell_shadow_thickness, left, right);
-#endif
-
-    /*
-     * If we are on the clip, the y location is offset by the
-     * fixed row height, label offset and label height
-     */
-    adjusted_y = y - FIXED_ROW_LABEL_OFFSET(mw);
-
-#ifdef	VERBOSE_SLIDE
-    fprintf(stderr, "DrawSlideRow(%d) adjust %d\n", y, adjusted_y);
-#endif
-
-    win = XtWindow(ClipChild(mw));
-
-#ifdef DRAW_RESIZE_LINE
-#ifdef	VERBOSE_SLIDE
-    fprintf(stderr, "XDrawLine(%d,%d,%d,%d)\n", x, adjusted_y, x + width, adjusted_y);
-#endif
-    XDrawLine(display, win, gc, x, adjusted_y, x + width, adjusted_y);
-#endif
-#ifdef DRAW_RESIZE_SHADOW
-    DRAW_SHADOW(display, win, "win 7",
-		mw->matrix.resize_top_shadow_gc,
-		mw->matrix.resize_bottom_shadow_gc,
-		shadow_width, x, adjusted_y, width, height, XmSHADOW_OUT);
-#endif
-    /*
-     * Now draw the line (or shadow) on the non clipped region - that is
-     * the fixed and trailingFixed rows.  First, do the leading rows.
-     */
-    if (mw->matrix.fixed_columns)
-    {
-	x = COLUMN_LABEL_OFFSET(mw);
-	width = FIXED_COLUMN_WIDTH(mw) + 2 * mw->matrix.cell_shadow_thickness;
-	win = XtWindow(mw);
-	xbaeSetClipMask(mw, CLIP_FIXED_COLUMNS);
-
-#ifdef DRAW_RESIZE_LINE
-	if (XtIsManaged(LeftClip(mw))) {
-#ifdef	VERBOSE_SLIDE
-	    fprintf(stderr, "XDrawLine(%d,%d,%d,%d)\n",
-		-mw->matrix.cell_shadow_thickness, adjusted_y, height, adjusted_y);
-#endif
-	    XDrawLine(display, XtWindow(TopClip(mw)), gc,
-		-mw->matrix.cell_shadow_thickness, adjusted_y, height, adjusted_y);
-	}
-#endif
-#ifdef DRAW_RESIZE_SHADOW
-	if (XtIsManaged(LeftClip(mw)))
-	    DRAW_SHADOW(display, XtWindow(TopClip(mw)), "LeftClip",
-			mw->matrix.resize_top_shadow_gc,
-			mw->matrix.resize_bottom_shadow_gc,
-			shadow_width,
-			-mw->matrix.cell_shadow_thickness, adjusted_y,
-			width, height, XmSHADOW_OUT);
-#endif
-	xbaeSetClipMask(mw, CLIP_NONE);			 
-    }
-
-    /*
-     * The trailingFixedRows
-     */
-    if (mw->matrix.trailing_fixed_columns)
-    {
-	x = TRAILING_FIXED_COLUMN_LABEL_OFFSET(mw);
-	width = TRAILING_FIXED_COLUMN_WIDTH(mw) +
-	    2 * mw->matrix.cell_shadow_thickness;
-
-	clip_reason = CLIP_TRAILING_FIXED_COLUMNS;
-	if (IS_LEADING_FIXED_ROW(mw, row))
-	    clip_reason |= CLIP_FIXED_ROWS;
-	else if (IS_TRAILING_FIXED_ROW(mw, row))
-	    clip_reason |= CLIP_TRAILING_FIXED_ROWS;
-	
-	xbaeSetClipMask(mw, clip_reason);
-
-#ifdef DRAW_RESIZE_LINE
-	if (XtIsManaged(RightClip(mw)))
-	    XDrawLine(display, XtWindow(RightClip(mw)), gc,
-		-mw->matrix.cell_shadow_thickness, adjusted_y, width, adjusted_y);
-#endif
-#ifdef DRAW_RESIZE_SHADOW
-	if (XtIsManaged(RightClip(mw)))
-	    DRAW_SHADOW(display, XtWindow(RightClip(mw)), "RightClip",
-			mw->matrix.resize_top_shadow_gc,
-			mw->matrix.resize_bottom_shadow_gc,
-			shadow_width,
-			-mw->matrix.cell_shadow_thickness, adjusted_y,
-			width, height, XmSHADOW_OUT);
-#endif
-	xbaeSetClipMask(mw, CLIP_NONE);
-    }
-
-    if ((NEED_HORIZ_FILL(mw) && (! HAS_ATTACHED_TRAILING_COLUMNS(mw))) ||
-	need_vert_dead_space_fill)
-    {
-	if (need_vert_dead_space_fill)
-	{
-	    x = UNATTACHED_TRAILING_COLUMNS_OFFSET(mw) -
-		mw->matrix.cell_shadow_thickness;
-	    width = 2 * mw->matrix.cell_shadow_thickness +
-		VERT_DEAD_SPACE_HEIGHT(mw);
-	}
-	else
-	{
-	    x = TRAILING_FIXED_COLUMN_LABEL_OFFSET(mw) +
-		TRAILING_FIXED_COLUMN_WIDTH(mw);
-	    width = FILL_HORIZ_WIDTH(mw) - VERT_SB_SPACE(mw);
-	}
-
-#ifdef DRAW_RESIZE_LINE
-	XDrawLine(display, XtWindow(mw), gc,
-		  x, adjusted_y, width, adjusted_y);
-#endif
-#ifdef DRAW_RESIZE_SHADOW
-	DRAW_SHADOW(display, XtWindow(mw), "win 8",
-		    mw->matrix.resize_top_shadow_gc,
-		    mw->matrix.resize_bottom_shadow_gc,
-		    shadow_width, x, y,
-		    width, height, XmSHADOW_OUT);
-#endif
-    }
-}
-
-/* Derived from SlideColumn */
-static void
-SlideRow(Widget w, XtPointer data, XEvent *event, Boolean *cont)
-{
-#ifdef	HAVE_ROW_HEIGHTS
-    XbaeMatrixResizeColumnStruct *rd = (XbaeMatrixResizeColumnStruct *)data;
-    XMotionEvent *motionEvent;
-    Boolean relayout = False;
-    int numCharacters;
-    int i;
-
-    if (event->type == ButtonRelease)
-    {
-	DrawSlideRow(rd->mw, rd->lasty);
-	XUngrabPointer(XtDisplay(w), CurrentTime);
-	rd->grabbed = False;
-	/*
-	 * Remanage the HSB if we unmapped it earlier
-	 */
-	if (rd->haveHSB)
-	    XtManageChild(HorizScrollChild(rd->mw));
-
-	if (rd->mw->matrix.resize_row_callback)
-	{
-	    XbaeMatrixResizeRowCallbackStruct call_data;
-
-	    call_data.reason = XbaeResizeColumnReason;
-	    call_data.event = event;
-	    call_data.row = rd->row - 1;
-	    call_data.column = rd->column;
-	    call_data.which = rd->row - 1;
-	    call_data.rows = rd->mw->matrix.rows;
-	    call_data.row_heights  = rd->rowHeights;
-	    XtCallCallbackList ((Widget)rd->mw,
-				rd->mw->matrix.resize_row_callback,
-				(XtPointer)&call_data);	    
-	}
-
-	for (i = 0; i < rd->mw->matrix.rows; i++)
-	    if (rd->rowHeights[i] != rd->mw->matrix.row_heights[i])
-	    {
-		/* Make sure everything is handled correctly with SetValues */
-		XtVaSetValues((Widget)rd->mw, XmNrowHeights,
-			       rd->rowHeights, NULL);
-		break;
-	    }
-#if 0
-	/*
-	 * If maxColumnLengths are set and we have resized the column to
-	 * larger, reset the corresponding maxColumnLength
-	 */
-	if (rd->mw->matrix.column_max_lengths &&
-	    rd->columnWidths[rd->column - 1] >
-	    rd->mw->matrix.column_max_lengths[rd->column - 1])
-	    rd->mw->matrix.column_max_lengths[rd->column - 1] =
-		rd->columnWidths[rd->column - 1];
-#endif
-	XtFree((char *)rd->rowHeights);
-	return;
-    }
-
-    if (event->type != MotionNotify) /* Double check! */
-	return;
-
-    motionEvent = (XMotionEvent *)event;
-
-    if (rd->currenty - motionEvent->y > 4)	/* ??? FONT_HEIGHT is not right */
-    {
-	/* If we're only one character wide, we cannae get any smaller */
-	if (rd->rowHeights[rd->row - 1] == 0)
-	    return;	
-	/*
-	 * Moved left a full character - update the column widths and force
-	 * a redisplay
-	 */	
-	numCharacters = (rd->currenty - motionEvent->y);
-	if (numCharacters < 0)
-	    numCharacters = 0;
-
-	rd->rowHeights[rd->row - 1] -= numCharacters;
-	rd->currenty -= numCharacters;
-	relayout = True;
-    }
-
-    if (motionEvent->y - rd->currenty > 4)	/* ??? FONT_HEIGHT is not right */
-    {
-	/*
-	 * Moved right a full character - update the column widths and force
-	 * a redisplay
-	 */
-	numCharacters = (motionEvent->y - rd->currenty);
-	rd->rowHeights[rd->row - 1] += numCharacters;
-	rd->currenty += numCharacters;
-	relayout = True;
-    }
-
-    if (relayout)
-    {
-	/* Draw the marker line in the new location */
-	if (rd->lasty != rd->currenty)
-	{
-	    DrawSlideRow(rd->mw, rd->currenty);
-	    DrawSlideRow(rd->mw, rd->lasty);
-
-	    rd->lasty = rd->currenty;
-	}
-    }
-#endif
-}
-
 /* ARGSUSED */
 void
-xbaeResizeRowsACT(Widget w,
-	XEvent *event,
-	String *params,
-	Cardinal *nparams)
+xbaeResizeColumnsACT(w, event, params, nparams)
+Widget w;
+XEvent *event;
+String *params;
+Cardinal *nparams;
 {
-#ifdef	HAVE_ROW_HEIGHTS
     XbaeMatrixWidget mw;
     int x, y;
     int eventx;
     int i;
     int row, column;
     CellType cell;
+    static Cursor cursor;
     XbaeMatrixResizeColumnStruct resizeData;
     XGCValues values;
     XtAppContext appcontext;
@@ -905,10 +536,7 @@ xbaeResizeRowsACT(Widget w,
 #define FUZZ_FACTOR	3
     int	fuzzy = FUZZ_FACTOR;
 #undef FUZZ_FACTOR
-
-#ifdef	XBAE_VERBOSE
-    fprintf(stderr, "xbaeResizeRowsACT()\n");
-#endif
+    
     /*
      * Get Matrix widget and make sure it is a Matrix subclass.
      * w could be Matrix, or the Clip or textField children of Matrix
@@ -925,183 +553,21 @@ xbaeResizeRowsACT(Widget w,
 	    NULL, 0);
 	return;
     }
-
+    
     /*
      * If we won't allow dynamic column resize, leave.
      */
-    if ((!mw->matrix.allow_column_resize) && (!mw->matrix.allow_row_resize))
+    if (!mw->matrix.allow_column_resize)
 	return;
-
+    
     if (!xbaeEventToXY(mw, event, &x, &y, &cell))
 	return;
-
+    
     eventx = x;
-
+    
     if (!xbaeXYToRowCol(mw, &x, &y, &row, &column, cell))
 	return;
 
-    /*
-     * Figure out if we're resizing a row height...
-     */
-    if ((int)mw->matrix.cell_shadow_thickness > fuzzy)
-	fuzzy = mw->matrix.cell_shadow_thickness;
-
-    if (y > fuzzy && SOME_ROW_HEIGHT(mw, row) - y > fuzzy)
-	return;
-
-    /* FIX ME currently not implemented yet */
-
-#ifdef	XBAE_VERBOSE
-    fprintf(stderr, "xbaeResizeRowsACT() : do something\n");
-#endif
-
-    /*
-     * Make it here and it's time to start the fun stuff!
-     */
-    /* Create the left / right cursor */
-    if (!mw->matrix.cursor)
-	mw->matrix.cursor = XCreateFontCursor(display, XC_sb_h_double_arrow);
-
-    /* Can't adjust the origin or should you be able to?? */
-    if (row == 0)
-	return;
-
-    /* Commit any edit in progress and unmap the text field -
-       it's just bad luck */
-    (*((XbaeMatrixWidgetClass)XtClass(mw))->matrix_class.commit_edit)
-	(mw, event, True);
-
-    /*
-     * Redraw the cell that had the text field in it or it might stay blank
-     */
-    xbaeDrawCell(mw, mw->matrix.current_row, mw->matrix.current_column);
-
-    /*
-     * Say goodbye to the Horizontal ScrollBar -> it only gets in the way!
-     */
-    if ((resizeData.haveHSB = XtIsManaged(HorizScrollChild(mw)) &&
-	   ((mw->matrix.scrollbar_placement == XmTOP_RIGHT) ||
-	    (mw->matrix.scrollbar_placement == XmBOTTOM_RIGHT))))
-        XtUnmanageChild(HorizScrollChild(mw));
-    /*
-     * Flush the commit events out to the server.  Otherwise, our changes
-     * to the GCs below have a bad effect.
-     */
-    XSync(display, False);
-
-    event_mask = PointerMotionMask | ButtonReleaseMask;
-    XtAddEventHandler(w, event_mask,
-		       True, (XtEventHandler)SlideRow,
-		       (XtPointer)&resizeData);
-
-    XGrabPointer(display, XtWindow(w), True, event_mask,
-		  GrabModeAsync, GrabModeAsync, XtWindow((Widget)mw),
-		  mw->matrix.cursor, CurrentTime);
-
-    /* Copy the rowHeights array */
-    resizeData.rowHeights =
-	 (short *)XtMalloc(mw->matrix.rows * sizeof(short));
-    for (i = 0; i < mw->matrix.rows; i++)
-	resizeData.rowHeights[i] = mw->matrix.row_heights[i];
-    resizeData.grabbed = True;
-    resizeData.mw = mw;
-    resizeData.row = row;
-    resizeData.starty = resizeData.currenty = resizeData.lasty =
-	event->xbutton.y;
-
-    gcmask = GCForeground | GCBackground | GCFunction;
-    values.function = GXxor;
-#ifdef DRAW_RESIZE_LINE
-    XGetGCValues(display, mw->matrix.draw_gc, gcmask, &save);
-    values.foreground = values.background = save.background;
-
-    XChangeGC(display, mw->matrix.draw_gc, gcmask, &values);
-#endif
-
-    DrawSlideRow(mw, resizeData.currenty);
-
-    appcontext = XtWidgetToApplicationContext(w);
-
-    while (resizeData.grabbed)
-	XtAppProcessEvent(appcontext, XtIMAll);
-
-    XtRemoveEventHandler(w, event_mask, True,
-			   (XtEventHandler)SlideRow,
-			   (XtPointer)&resizeData);
-
-#ifdef DRAW_RESIZE_LINE
-    XSetFunction(display, mw->matrix.draw_gc, GXcopy);
-#endif
-#endif
-}
-
-/* ARGSUSED */
-void
-xbaeResizeColumnsACT(Widget w,
-		XEvent *event,
-		String *params,
-		Cardinal *nparams)
-{
-    XbaeMatrixWidget mw;
-    int x, y;
-    int eventx;
-    int i;
-    int row, column;
-    CellType cell;
-    XbaeMatrixResizeColumnStruct resizeData;
-    XGCValues values;
-    XtAppContext appcontext;
-#ifdef DRAW_RESIZE_LINE
-    XGCValues save;
-#endif
-    unsigned long gcmask, event_mask;
-    Display *display = XtDisplay(w);
-#define FUZZ_FACTOR	3
-    int	fuzzy = FUZZ_FACTOR;
-#undef FUZZ_FACTOR
-
-    /*
-     * Get Matrix widget and make sure it is a Matrix subclass.
-     * w could be Matrix, or the Clip or textField children of Matrix
-     */
-    if (XtIsSubclass(w, xbaeMatrixWidgetClass))
-	mw = (XbaeMatrixWidget)w;
-    else if (XtIsSubclass(XtParent(w), xbaeMatrixWidgetClass))
-	mw = (XbaeMatrixWidget)XtParent(w);
-    else {
-	XtAppWarningMsg(
-	    XtWidgetToApplicationContext(w),
-	    "resizeColumnsACT", "badWidget", "XbaeMatrix",
-	    "XbaeMatrix: Bad widget passed to ResizeColumns action",
-	    NULL, 0);
-	return;
-    }
-
-    /*
-     * If we won't allow dynamic column resize, leave.
-     */
-    if ((!mw->matrix.allow_column_resize) && (!mw->matrix.allow_row_resize))
-	return;
-
-    if (!xbaeEventToXY(mw, event, &x, &y, &cell))
-	return;
-
-    eventx = x;
-
-    if (!xbaeXYToRowCol(mw, &x, &y, &row, &column, cell))
-	return;
-
-    /*
-     * Figure out if we're resizing a row height...
-     */
-    if ((int)mw->matrix.cell_shadow_thickness > fuzzy)
-	fuzzy = mw->matrix.cell_shadow_thickness;
-
-    if (y <= fuzzy || SOME_ROW_HEIGHT(mw, row) - y <= fuzzy) {
-	xbaeResizeRowsACT(w, event, params, nparams);
-	return;
-    }
-
     /*
      * Calculate if the x and y of the middle button event is on
      * a column border.  Allow the width of the shadow to be the
@@ -1110,29 +576,29 @@ xbaeResizeColumnsACT(Widget w,
      */
     if ((int)mw->matrix.cell_shadow_thickness > fuzzy)
 	fuzzy = mw->matrix.cell_shadow_thickness;
-
+    
     if (x > fuzzy && COLUMN_WIDTH(mw, column) - x > fuzzy)
 	return;
-
+    
     /*
      * Looks like we hit a column border, determine the column that is
      * intended to be resized
      */
     if ((COLUMN_WIDTH(mw, column) - x) <= fuzzy)
 	column++;
-
+    
     /* Can't adjust the origin or should you be able to?? */
     if (column == 0)
 	return;
-
+    
     /*
      * Make it here and it's time to start the fun stuff!
      */
-
+    
     /* Create the left / right cursor */
-    if (!mw->matrix.cursor)
-	mw->matrix.cursor = XCreateFontCursor(display, XC_sb_h_double_arrow);
-
+    if (!cursor)
+	cursor = XCreateFontCursor(display, XC_sb_h_double_arrow);
+    
     /* Commit any edit in progress and unmap the text field -
        it's just bad luck */
     (*((XbaeMatrixWidgetClass)XtClass(mw))->matrix_class.commit_edit)
@@ -1155,16 +621,16 @@ xbaeResizeColumnsACT(Widget w,
      * to the GCs below have a bad effect.
      */
     XSync(display, False);
-
+    
     event_mask = PointerMotionMask | ButtonReleaseMask;
     XtAddEventHandler(w, event_mask,
 		       True, (XtEventHandler)SlideColumn,
 		       (XtPointer)&resizeData);
-
+    
     XGrabPointer(display, XtWindow(w), True, event_mask,
 		  GrabModeAsync, GrabModeAsync, XtWindow((Widget)mw),
-		  mw->matrix.cursor, CurrentTime);
-
+		  cursor, CurrentTime);
+    
     /* Copy the columnWidth array */
     resizeData.columnWidths =
 	 (short *)XtMalloc(mw->matrix.columns * sizeof(short));
@@ -1184,14 +650,14 @@ xbaeResizeColumnsACT(Widget w,
 
     XChangeGC(display, mw->matrix.draw_gc, gcmask, &values);
 #endif
-
+    
     DrawSlideColumn(mw, resizeData.currentx);
 
     appcontext = XtWidgetToApplicationContext(w);
-
+    
     while (resizeData.grabbed)
 	XtAppProcessEvent(appcontext, XtIMAll);
-
+    
     XtRemoveEventHandler(w, event_mask, True,
 			   (XtEventHandler)SlideColumn,
 			   (XtPointer)&resizeData);
@@ -1206,10 +672,11 @@ xbaeResizeColumnsACT(Widget w,
  */
 /* ARGSUSED */
 void
-xbaeProcessDragACT(Widget w,
-		XEvent *event,
-		String *params,
-		Cardinal *nparams)
+xbaeProcessDragACT(w, event, params, nparams)
+Widget w;
+XEvent *event;
+String *params;
+Cardinal *nparams;
 {
 #if XmVersion > 1001
     XbaeMatrixWidget mw;
@@ -1261,7 +728,7 @@ xbaeProcessDragACT(Widget w,
     else
 	call_data.string = mw->matrix.cells ?
 	    mw->matrix.cells[row][column] : "";
-
+    
     call_data.num_params = *nparams;
     call_data.params = params;
 
@@ -1275,10 +742,11 @@ xbaeProcessDragACT(Widget w,
  */
 /* ARGSUSED */
 void
-xbaeEditCellACT(Widget w,
-		XEvent *event,
-		String *params,
-		Cardinal *nparams)
+xbaeEditCellACT(w, event, params, nparams)
+Widget w;
+XEvent *event;
+String *params;
+Cardinal *nparams;
 {
     XbaeMatrixWidget mw;
     int row, column;
@@ -1553,10 +1021,11 @@ xbaeEditCellACT(Widget w,
  */
 /* ARGSUSED */
 void
-xbaeCancelEditACT(Widget w,
-		XEvent *event,
-		String *params,
-		Cardinal *nparams)
+xbaeCancelEditACT(w, event, params, nparams)
+Widget w;
+XEvent *event;
+String *params;
+Cardinal *nparams;
 {
     XbaeMatrixWidget mw;
     Boolean unmap;
@@ -1620,10 +1089,11 @@ xbaeCancelEditACT(Widget w,
  */
 /* ARGSUSED */
 void
-xbaeCommitEditACT(Widget w,
-		XEvent *event,
-		String *params,
-		Cardinal *nparams)
+xbaeCommitEditACT(w, event, params, nparams)
+Widget w;
+XEvent *event;
+String *params;
+Cardinal *nparams;
 {
     XbaeMatrixWidget mw;
     Boolean unmap;
@@ -1681,10 +1151,11 @@ xbaeCommitEditACT(Widget w,
 }
 
 static int
-DoubleClick(XbaeMatrixWidget mw,
-	XEvent *event,
-	int row,
-	int column)
+DoubleClick(mw, event, row, column)
+XbaeMatrixWidget mw;
+XEvent *event;
+int row;
+int column;
 {
     /* A double click in this instance is two clicks in the
        same cell in a time period < double_click_interval */
@@ -1721,10 +1192,11 @@ DoubleClick(XbaeMatrixWidget mw,
 
 /*ARGSUSED*/
 static void
-PushButton(Widget w,
-	XtPointer data,
-	XEvent *event,
-	Boolean *cont)
+PushButton(w, data, event, cont)
+Widget w;
+XtPointer data;
+XEvent *event;
+Boolean *cont;
 {
     XbaeMatrixButtonPressedStruct *button =
 	 (XbaeMatrixButtonPressedStruct *)data;
@@ -1734,10 +1206,6 @@ PushButton(Widget w,
     Boolean pressed = button->pressed;
     CellType cell;
 
-#ifdef	XBAE_VERBOSE
-    fprintf(stderr, "PushButton()\n");
-#endif
-
     if (event->type == ButtonRelease)
     {
 	button->grabbed = False;
@@ -1785,10 +1253,10 @@ PushButton(Widget w,
     motionEvent = (XMotionEvent *)event;
     x = motionEvent->x;
     y = motionEvent->y;
-
+    
     if (!xbaeEventToXY(button->mw, event, &x, &y, &cell))
 	return;
-
+    
     if (xbaeXYToRowCol(button->mw, &x, &y, &row, &column, cell))
 	/* Moved off the labels */
 	pressed = False;
@@ -1815,31 +1283,24 @@ PushButton(Widget w,
 
 /*ARGSUSED*/
 void
-xbaeHandleClick(Widget w,
-	XtPointer data,
-	XEvent *event,
-	Boolean *cont)
+xbaeHandleClick(w, data, event, cont)
+Widget w;
+XtPointer data;
+XEvent *event;
+Boolean *cont;
 {
     XbaeMatrixWidget mw = (XbaeMatrixWidget)data;
     int x, y;
     CellType cell;
     int row, column;
     Boolean translation;
-
-#ifdef	XBAE_VERBOSE
-    fprintf(stderr, "xbaeHandleClick()\n");
-#endif
-
+    
     /* if we have a double click and a callback - break out! */
     if (event->type != ButtonPress && event->type != ButtonRelease)
 	return;
 
-    if (!xbaeEventToXY(mw, event, &x, &y, &cell)) {
-#ifdef	XBAE_VERBOSE
-	fprintf(stderr, "xbaeEventToXY() fails\n");
-#endif
+    if (!xbaeEventToXY(mw, event, &x, &y, &cell))
 	return;
-    }
 
     translation = xbaeXYToRowCol(mw, &x, &y, &row, &column, cell);
 
@@ -1858,26 +1319,15 @@ xbaeHandleClick(Widget w,
 	/* If the row and column are invalid, return. If it is ButtonRelease
 	   event, also return - the ButtonRelease events are handled in the
 	   event handler loop below */
-	if (event->type != ButtonPress) {
-#ifdef	XBAE_VERBOSE
-	    fprintf(stderr, "xbaeHandleClick - no ButtonPress, return\n");
-#endif
+	if (event->type != ButtonPress)
 	    return;
-	}
 
-	if (column == -1 && event->type == ButtonPress) {
+	if (column == -1 && event->type == ButtonPress)
 	    /* row label */
-#ifdef	XBAE_VERBOSE
-	    fprintf(stderr, "Action in row label\n");
-#endif
 	    xbaeDrawRowLabel(mw, row, True);
-	} else if (row == -1 && event->type == ButtonPress) {
+	else if (row == -1 && event->type == ButtonPress)
 	    /* Column label */
-#ifdef	XBAE_VERBOSE
-	    fprintf(stderr, "Action in column label\n");
-#endif
 	    xbaeDrawColumnLabel(mw, column, True);
-	}
 
 	/* Action stations! */
 	event_mask = ButtonReleaseMask | PointerMotionMask;
@@ -1898,7 +1348,7 @@ xbaeHandleClick(Widget w,
 	XtAddEventHandler(TextChild(mw), event_mask,
 			   True, (XtEventHandler)PushButton,
 			   (XtPointer)&button);
-
+    
 	appcontext = XtWidgetToApplicationContext(w);
 
 	while (button.grabbed)
@@ -1921,17 +1371,9 @@ xbaeHandleClick(Widget w,
 	   to be recognised */
 	XbaeMatrixDefaultActionCallbackStruct call_data;
 
-	if (row == -1 || column == -1) {
-#ifdef	XBAE_VERBOSE
-	    fprintf(stderr, "xbaeHandleClick - row/col < 0, return\n");
-#endif
+	if (row == -1 || column == -1)
 	    return;
-	}
 	
-#ifdef	XBAE_VERBOSE
-	fprintf(stderr, "xbaeHandleClick - DefaultActionCallback\n");
-#endif
-
 	call_data.reason = XbaeDefaultActionReason;
 	call_data.event = event;
 	call_data.row = row;
@@ -1939,20 +1381,16 @@ xbaeHandleClick(Widget w,
 
 	XtCallCallbackList((Widget)mw, mw->matrix.default_action_callback,
 			   (XtPointer)&call_data);
-    } else {
-#ifdef	XBAE_VERBOSE
-	fprintf(stderr, "xbaeHandleClick() uncaught case (x %d y %d, row %d col %d)\n",
-		x, y, row, column);
-#endif
-    }
+    }	
 }
 
 /* ARGSUSED */
 void
-xbaeSelectCellACT(Widget w,
-	XEvent *event,
-	String *params,
-	Cardinal *nparams)
+xbaeSelectCellACT(w, event, params, nparams)
+Widget w;
+XEvent *event;
+String *params;
+Cardinal *nparams;
 {
     XbaeMatrixWidget mw;
     int x, y;
@@ -2022,10 +1460,10 @@ xbaeSelectCellACT(Widget w,
 	call_data.row = row;
 	call_data.column = column;
     }
-
+    
     last_selected_column = call_data.column;
     last_selected_row = call_data.row;
-
+    
     call_data.selected_cells = mw->matrix.selected_cells;
     call_data.cells = mw->matrix.cells;
     call_data.num_params = *nparams;
@@ -2038,10 +1476,11 @@ xbaeSelectCellACT(Widget w,
 
 /* ARGSUSED */
 void
-xbaeTraverseNextACT(Widget w,
-		XEvent *event,
-		String *params,
-		Cardinal *nparams)
+xbaeTraverseNextACT(w, event, params, nparams)
+Widget w;
+XEvent *event;
+String *params;
+Cardinal *nparams;
 {
     XbaeMatrixWidget mw;
 
@@ -2074,10 +1513,11 @@ xbaeTraverseNextACT(Widget w,
 
 /* ARGSUSED */
 void
-xbaeTraversePrevACT(Widget w,
-		XEvent *event,
-		String *params,
-		Cardinal *nparams)
+xbaeTraversePrevACT(w, event, params, nparams)
+Widget w;
+XEvent *event;
+String *params;
+Cardinal *nparams;
 {
     XbaeMatrixWidget mw;
 
@@ -2109,11 +1549,13 @@ xbaeTraversePrevACT(Widget w,
 }
 
 static void
-callSelectCellAction(XbaeMatrixWidget mw, XEvent *event)
+callSelectCellAction(mw, event)
+XbaeMatrixWidget mw;
+XEvent *event;
 {
     XbaeMatrixSelectCellCallbackStruct call_data;
     Boolean old_scroll_select = mw->matrix.scroll_select;
-
+    
     mw->matrix.scroll_select = False;
 
     call_data.reason = XbaeSelectCellReason;
@@ -2125,7 +1567,7 @@ callSelectCellAction(XbaeMatrixWidget mw, XEvent *event)
     call_data.num_params = 1;
     call_data.params = (char **)XtMalloc(sizeof(char *));
     call_data.params[0] = "extend";
-
+    
     XtCallCallbackList(
 	 (Widget)mw, mw->matrix.select_cell_callback,
 	 (XtPointer)&call_data);
@@ -2138,10 +1580,11 @@ callSelectCellAction(XbaeMatrixWidget mw, XEvent *event)
 
 /*ARGSUSED*/
 static void
-checkScrollValues(Widget w,
-		XtPointer data,
-		XEvent *event,
-		Boolean *cont)
+checkScrollValues(w, data, event, cont)
+Widget w;
+XtPointer data;
+XEvent *event;
+Boolean *cont;
 {
     XbaeMatrixScrollStruct *ss = (XbaeMatrixScrollStruct *)data;
     XMotionEvent *motionEvent;
@@ -2245,7 +1688,7 @@ checkScrollValues(Widget w,
 	     */
 	    if (!ss->below && !ss->above)
 	    {
-		last_row = xbaeYtoRow(ss->mw, motionEvent->y -
+		last_row = YtoRow(ss->mw, motionEvent->y -
 				   COLUMN_LABEL_HEIGHT(ss->mw)) +
 		    VERT_ORIGIN(ss->mw);
 		SANITY_CHECK_ROW(ss->mw, last_row);
@@ -2260,7 +1703,7 @@ checkScrollValues(Widget w,
 			    ss->cw->core.width));
 	    if (!ss->below && !ss->above)
 	    {
-		last_row = xbaeYtoRow(ss->mw, motionEvent->y -
+		last_row = YtoRow(ss->mw, motionEvent->y -
 				   COLUMN_LABEL_HEIGHT(ss->mw)) +
 		    VERT_ORIGIN(ss->mw);
 		SANITY_CHECK_ROW(ss->mw, last_row);
@@ -2285,7 +1728,8 @@ checkScrollValues(Widget w,
 }
 
 static void
-updateScroll(XtPointer data)
+updateScroll(data)
+XtPointer data;
 {
     XbaeMatrixScrollStruct *ss = (XbaeMatrixScrollStruct *)data;
     Boolean callCallback = False;
@@ -2293,7 +1737,7 @@ updateScroll(XtPointer data)
 
     if (!scrolling)
 	return;
-
+    
     if (my_last_column != last_column || my_last_row != last_row)
 	callCallback = True;
 
@@ -2330,7 +1774,7 @@ updateScroll(XtPointer data)
 	 (ss->mw->matrix.selection_policy == XmMULTIPLE_SELECT ||
 	  ss->mw->matrix.selection_policy == XmEXTENDED_SELECT))
 	callSelectCellAction(ss->mw, ss->event);
-
+    
     /*
      * Flush the updates out to the server so we don't end up lagging
      * behind too far and end up with a million redraw requests.
@@ -2345,10 +1789,11 @@ updateScroll(XtPointer data)
 
 /* ARGSUSED */
 void
-xbaeHandleMotionACT(Widget w,
-		XEvent *event,
-		String *params,
-		Cardinal *nparams)
+xbaeHandleMotionACT(w, event, params, nparams)
+Widget w;
+XEvent *event;
+String *params;
+Cardinal *nparams;
 {
     XbaeMatrixWidget mw;
     XbaeClipWidget cw;
@@ -2472,10 +1917,11 @@ xbaeHandleMotionACT(Widget w,
 
 /* ARGSUSED */
 void
-xbaePageDownACT(Widget w,
-		XEvent *event,
-		String *params,
-		Cardinal *nparams)
+xbaePageDownACT(w, event, params, nparams)
+Widget w;
+XEvent *event;
+String *params;
+Cardinal *nparams;
 {
     XbaeMatrixWidget mw;
     char *down = "0";
@@ -2519,10 +1965,11 @@ xbaePageDownACT(Widget w,
 
 /* ARGSUSED */
 void
-xbaePageUpACT(Widget w,
-		XEvent *event,
-		String *params,
-		Cardinal *nparams)
+xbaePageUpACT(w, event, params, nparams)
+Widget w;
+XEvent *event;
+String *params;
+Cardinal *nparams;
 {
     XbaeMatrixWidget mw;
     char *up = "0";
@@ -2564,3 +2011,4 @@ xbaePageUpACT(Widget w,
 	XbaeMatrixEditCell((Widget)mw, VERT_ORIGIN(mw) +
 			   mw->matrix.fixed_rows, mw->matrix.current_column);
 }
+
