@@ -1,8 +1,6 @@
 /*
  * Copyright(c) 1992 Bell Communications Research, Inc. (Bellcore)
  * Copyright(c) 1995-99 Andrew Lister
- * Copyright (c) 1999-2000 by the LessTif Developers.
- *
  *                        All rights reserved
  * Permission to use, copy, modify and distribute this material for
  * any purpose and without fee is hereby granted, provided that the
@@ -24,7 +22,7 @@
  *
  * MatrixWidget Author: Andrew Wason, Bellcore, aw@bae.bellcore.com
  *
- * $Id: Converters.c,v 1.4 2000/06/11 17:58:54 danny Exp $
+ * $Id: Converters.c,v 1.1 1999/08/04 19:46:52 danny Exp $
  */
 
 /*
@@ -54,16 +52,16 @@
 #define tolower(c)      ((c) - 'A' + 'a')
 #endif
 
-static Boolean XbaeStringsAreEqual(String, String, int);
+static Boolean StringsAreEqual P((String, String, int));
 
 /* ARGSUSED */
 Boolean
-XbaeCvtStringToStringArray(Display *dpy,
-		XrmValuePtr args,
-		Cardinal *num_args,
-		XrmValuePtr from,
-		XrmValuePtr to,
-		XtPointer *data)
+CvtStringToStringArray(dpy, args, num_args, from, to, data)
+Display *dpy;
+XrmValuePtr args;
+Cardinal *num_args;
+XrmValuePtr from, to;
+XtPointer *data;
 {
     static String *array;
     String start = from->addr;
@@ -209,11 +207,12 @@ XbaeCvtStringToStringArray(Display *dpy,
  */
 /* ARGSUSED */
 void
-XbaeStringArrayDestructor(XtAppContext app,
-			XrmValuePtr to,
-			XtPointer converter_data,
-			XrmValuePtr args,
-			Cardinal *num_args)
+StringArrayDestructor(app, to, converter_data, args, num_args)
+XtAppContext app;
+XrmValuePtr to;
+XtPointer converter_data;
+XrmValuePtr args;
+Cardinal *num_args;
 {
     String *array = *(String **) to->addr;
     String *entry;
@@ -229,12 +228,12 @@ XbaeStringArrayDestructor(XtAppContext app,
 
 /* ARGSUSED */
 Boolean
-XbaeCvtStringToCellTable(Display *dpy,
-		XrmValuePtr args,
-		Cardinal *num_args,
-		XrmValuePtr from,
-		XrmValuePtr to,
-		XtPointer *data)
+CvtStringToCellTable(dpy, args, num_args, from, to, data)
+Display *dpy;
+XrmValuePtr args;
+Cardinal *num_args;
+XrmValuePtr from, to;
+XtPointer *data;
 {
     static String **array;
     String start = from->addr;
@@ -291,14 +290,14 @@ XbaeCvtStringToCellTable(Display *dpy,
             lto.addr = (char *)(&array[k]);
             lto.size = sizeof(String *);
             
-            if (!XbaeCvtStringToStringArray(dpy, args, num_args, &lfrom, &lto, data))
+            if (!CvtStringToStringArray(dpy, args, num_args, &lfrom, &lto, data))
             {
                 *ch = c;
 		XtDisplayStringConversionWarning(dpy, from->addr,
 						 XmRCellTable);
 		array[k] = (String *)0;
                 lto.addr = (char *)&array;
-                XbaeStringCellDestructor(0, &lto, 0, 0, 0);
+                StringCellDestructor(0, &lto, 0, 0, 0);
        		return False;
 	    }
             *ch = c;
@@ -325,11 +324,12 @@ XbaeCvtStringToCellTable(Display *dpy,
  */
 /* ARGSUSED */
 void
-XbaeStringCellDestructor(XtAppContext app,
-		XrmValuePtr to,
-		XtPointer converter_data,
-		XrmValuePtr args,
-		Cardinal *num_args)
+StringCellDestructor(app, to, converter_data, args, num_args)
+XtAppContext app;
+XrmValuePtr to;
+XtPointer converter_data;
+XrmValuePtr args;
+Cardinal *num_args;
 {
     String **array = *(String ***) to->addr;
     String **entry, *row;
@@ -353,12 +353,12 @@ XbaeStringCellDestructor(XtAppContext app,
  */
 /* ARGSUSED */
 Boolean
-XbaeCvtStringToWidthArray(Display *dpy,
-			XrmValuePtr args,
-			Cardinal *num_args,
-			XrmValuePtr from,
-			XrmValuePtr to,
-			XtPointer *data)
+CvtStringToWidthArray(dpy, args, num_args, from, to, data)
+Display *dpy;
+XrmValuePtr args;
+Cardinal *num_args;
+XrmValuePtr from, to;
+XtPointer *data;
 {
     static short *array;
     String start = from->addr;
@@ -431,11 +431,12 @@ XbaeCvtStringToWidthArray(Display *dpy,
  */
 /* ARGSUSED */
 void
-XbaeWidthArrayDestructor(XtAppContext app,
-		XrmValuePtr to,
-		XtPointer converter_data,
-		XrmValuePtr args,
-		Cardinal *num_args)
+WidthArrayDestructor(app, to, converter_data, args, num_args)
+XtAppContext app;
+XrmValuePtr to;
+XtPointer converter_data;
+XrmValuePtr args;
+Cardinal *num_args;
 {
     short *array = *(short **) to->addr;
 
@@ -448,12 +449,12 @@ XbaeWidthArrayDestructor(XtAppContext app,
  */
 /* ARGSUSED */
 Boolean
-XbaeCvtStringToMaxLengthArray(Display *dpy,
-			XrmValuePtr args,
-			Cardinal *num_args,
-			XrmValuePtr from,
-			XrmValuePtr to,
-			XtPointer *data)
+CvtStringToMaxLengthArray(dpy, args, num_args, from, to, data)
+Display *dpy;
+XrmValuePtr args;
+Cardinal *num_args;
+XrmValuePtr from, to;
+XtPointer *data;
 {
     static int *array;
     String start = from->addr;
@@ -527,11 +528,12 @@ XbaeCvtStringToMaxLengthArray(Display *dpy,
  */
 /* ARGSUSED */
 void
-XbaeMaxLengthArrayDestructor(XtAppContext app,
-			XrmValuePtr to,
-			XtPointer converter_data,
-			XrmValuePtr args,
-			Cardinal *num_args)
+MaxLengthArrayDestructor(app, to, converter_data, args, num_args)
+XtAppContext app;
+XrmValuePtr to;
+XtPointer converter_data;
+XrmValuePtr args;
+Cardinal *num_args;
 {
     int *array = *(int **) to->addr;
 
@@ -544,7 +546,10 @@ XbaeMaxLengthArrayDestructor(XtAppContext app,
  * Used by StringToAlignmentArray converter.
  */
 static Boolean
-XbaeStringsAreEqual(String in, String test, int length)
+StringsAreEqual(in, test, length)
+String in;
+String test;
+int length;
 {
     int i;
 
@@ -578,12 +583,12 @@ XbaeStringsAreEqual(String in, String test, int length)
  */
 /* ARGSUSED */
 Boolean
-XbaeCvtStringToBooleanArray(Display *dpy,
-			XrmValuePtr args,
-			Cardinal *num_args,
-			XrmValuePtr from,
-			XrmValuePtr to,
-			XtPointer *data)
+CvtStringToBooleanArray(dpy, args, num_args, from, to, data)
+Display *dpy;
+XrmValuePtr args;
+Cardinal *num_args;
+XrmValuePtr from, to;
+XtPointer *data;
 {
     static Boolean *array;
     String start = from->addr;
@@ -636,13 +641,13 @@ XbaeCvtStringToBooleanArray(Display *dpy,
 	    while (isspace(*start))
 		start++;
 
-	    if (XbaeStringsAreEqual(start, "true", 4))
+	    if (StringsAreEqual(start, "true", 4))
 		array[i] = True;
-	    else if (XbaeStringsAreEqual(start, "1", 1))
+	    else if (StringsAreEqual(start, "1", 1))
 		array[i] = True;
-	    else if (XbaeStringsAreEqual(start, "false", 5))
+	    else if (StringsAreEqual(start, "false", 5))
 		array[i] = False;
-	    else if (XbaeStringsAreEqual(start, "0", 1))
+	    else if (StringsAreEqual(start, "0", 1))
 		array[i] = False;
 	    else
 	    {
@@ -676,11 +681,12 @@ XbaeCvtStringToBooleanArray(Display *dpy,
  */
 /* ARGSUSED */
 void
-XbaeBooleanArrayDestructor(XtAppContext app,
-			XrmValuePtr to,
-			XtPointer converter_data,
-			XrmValuePtr args,
-			Cardinal *num_args)
+BooleanArrayDestructor(app, to, converter_data, args, num_args)
+XtAppContext app;
+XrmValuePtr to;
+XtPointer converter_data;
+XrmValuePtr args;
+Cardinal *num_args;
 {
     Boolean *array = *(Boolean **) to->addr;
 
@@ -694,12 +700,12 @@ XbaeBooleanArrayDestructor(XtAppContext app,
  */
 /* ARGSUSED */
 Boolean
-XbaeCvtStringToAlignmentArray(Display *dpy,
-			XrmValuePtr args,
-			Cardinal *num_args,
-			XrmValuePtr from,
-			XrmValuePtr to,
-			XtPointer *data)
+CvtStringToAlignmentArray(dpy, args, num_args, from, to, data)
+Display *dpy;
+XrmValuePtr args;
+Cardinal *num_args;
+XrmValuePtr from, to;
+XtPointer *data;
 {
     static unsigned char *array;
     String start = from->addr;
@@ -759,11 +765,11 @@ XbaeCvtStringToAlignmentArray(Display *dpy,
 	    while (isspace(*start))
 		start++;
 
-	    if (XbaeStringsAreEqual(start, "alignment_beginning", 19))
+	    if (StringsAreEqual(start, "alignment_beginning", 19))
 		array[i] = XmALIGNMENT_BEGINNING;
-	    else if (XbaeStringsAreEqual(start, "alignment_center", 16))
+	    else if (StringsAreEqual(start, "alignment_center", 16))
 		array[i] = XmALIGNMENT_CENTER;
-	    else if (XbaeStringsAreEqual(start, "alignment_end", 13))
+	    else if (StringsAreEqual(start, "alignment_end", 13))
 		array[i] = XmALIGNMENT_END;
 	    else
 	    {
@@ -797,11 +803,12 @@ XbaeCvtStringToAlignmentArray(Display *dpy,
  */
 /* ARGSUSED */
 void
-XbaeAlignmentArrayDestructor(XtAppContext app,
-			XrmValuePtr to,
-			XtPointer converter_data,
-			XrmValuePtr args,
-			Cardinal *num_args)
+AlignmentArrayDestructor(app, to, converter_data, args, num_args)
+XtAppContext app;
+XrmValuePtr to;
+XtPointer converter_data;
+XrmValuePtr args;
+Cardinal *num_args;
 {
     unsigned char *array = *(unsigned char **) to->addr;
 
@@ -814,12 +821,12 @@ XbaeAlignmentArrayDestructor(XtAppContext app,
  */
 /* ARGSUSED */
 Boolean
-XbaeCvtStringToPixelTable(Display *dpy,
-			XrmValuePtr args,
-			Cardinal *num_args,
-			XrmValuePtr from,
-			XrmValuePtr to,
-			XtPointer *data)
+CvtStringToPixelTable(dpy, args, num_args, from, to, data)
+Display *dpy;
+XrmValuePtr args;
+Cardinal *num_args;
+XrmValuePtr from, to;
+XtPointer *data;
 {
     static Pixel **array, *row;
     String start = from->addr;
@@ -950,11 +957,12 @@ XbaeCvtStringToPixelTable(Display *dpy,
  */
 /* ARGSUSED */
 void
-XbaePixelTableDestructor(XtAppContext app,
-			XrmValuePtr to,
-			XtPointer converter_data,
-			XrmValuePtr args,
-			Cardinal *num_args)
+PixelTableDestructor(app, to, converter_data, args, num_args)
+XtAppContext app;
+XrmValuePtr to;
+XtPointer converter_data;
+XrmValuePtr args;
+Cardinal *num_args;
 {
     Pixel **array = *(Pixel ***) to->addr;
     Pixel **col;
@@ -969,12 +977,12 @@ XbaePixelTableDestructor(XtAppContext app,
 
 /* ARGSUSED */
 Boolean
-XbaeCvtStringToGridType(Display *dpy,
-		XrmValuePtr args,
-		Cardinal *num_args,
-		XrmValuePtr from,
-		XrmValuePtr to,
-		XtPointer *data)
+CvtStringToGridType(dpy, args, num_args, from, to, data)
+Display *dpy;
+XrmValuePtr args;
+Cardinal *num_args;
+XrmValuePtr from, to;
+XtPointer *data;
 {
     static unsigned char grid_type;
     String start = from->addr;
@@ -1000,26 +1008,26 @@ XbaeCvtStringToGridType(Display *dpy,
     while (isspace(*start))
 	start++;
 
-    if (XbaeStringsAreEqual(start, "grid_none", 9))
+    if (StringsAreEqual(start, "grid_none", 9))
 	grid_type = XmGRID_NONE;
-    else if (XbaeStringsAreEqual(start, "grid_cell_line", 14))
+    else if (StringsAreEqual(start, "grid_cell_line", 14))
 	grid_type = XmGRID_CELL_LINE;
-    else if (XbaeStringsAreEqual(start, "grid_cell_shadow", 16))
+    else if (StringsAreEqual(start, "grid_cell_shadow", 16))
 	grid_type = XmGRID_CELL_SHADOW;
-    else if (XbaeStringsAreEqual(start, "grid_row_line", 13))
+    else if (StringsAreEqual(start, "grid_row_line", 13))
 	grid_type = XmGRID_ROW_LINE;
-    else if (XbaeStringsAreEqual(start, "grid_row_shadow", 15))
+    else if (StringsAreEqual(start, "grid_row_shadow", 15))
 	grid_type = XmGRID_ROW_SHADOW;
-    else if (XbaeStringsAreEqual(start, "grid_column_line", 16))
+    else if (StringsAreEqual(start, "grid_column_line", 16))
 	grid_type = XmGRID_COLUMN_LINE;
-    else if (XbaeStringsAreEqual(start, "grid_column_shadow", 15))
+    else if (StringsAreEqual(start, "grid_column_shadow", 15))
 	grid_type = XmGRID_COLUMN_SHADOW;
     /* Deprecated types. To be removed in next version. */
-    else if (XbaeStringsAreEqual(start, "grid_line", 9))
+    else if (StringsAreEqual(start, "grid_line", 9))
 	grid_type = XmGRID_LINE;
-    else if (XbaeStringsAreEqual(start, "grid_shadow_in", 14))
+    else if (StringsAreEqual(start, "grid_shadow_in", 14))
 	grid_type = XmGRID_SHADOW_IN;
-    else if (XbaeStringsAreEqual(start, "grid_shadow_out", 15))
+    else if (StringsAreEqual(start, "grid_shadow_out", 15))
 	grid_type = XmGRID_SHADOW_OUT;
     else {
 	XtDisplayStringConversionWarning(dpy, from->addr, XmRGridType);
@@ -1052,16 +1060,15 @@ Boolean
 #ifdef __VMS
 /* According to Barry Stone VMS only allows function names with a
    maximum length of 31 characters */
-XbaeCvtStringToMatrixScrollBarD
+CvtStringToMatrixScrollBarDisp(dpy, args, num_args, from, to, data)
 #else
-XbaeCvtStringToMatrixScrollBarDisplayPolicy
+CvtStringToMatrixScrollBarDisplayPolicy(dpy, args, num_args, from, to, data)
 #endif
-	(Display *dpy,
-	XrmValuePtr args,
-	Cardinal *num_args,
-	XrmValuePtr from,
-	XrmValuePtr to,
-	XtPointer *data)
+Display *dpy;
+XrmValuePtr args;
+Cardinal *num_args;
+XrmValuePtr from, to;
+XtPointer *data;
 {
     static unsigned char display_policy;
     String start = from->addr;
@@ -1087,11 +1094,11 @@ XbaeCvtStringToMatrixScrollBarDisplayPolicy
     while (isspace(*start))
 	start++;
 
-    if (XbaeStringsAreEqual(start, "display_none", 12))
+    if (StringsAreEqual(start, "display_none", 12))
 	display_policy = XmDISPLAY_NONE;
-    else if (XbaeStringsAreEqual(start, "display_as_needed", 17))
+    else if (StringsAreEqual(start, "display_as_needed", 17))
 	display_policy = XmDISPLAY_AS_NEEDED;
-    else if (XbaeStringsAreEqual(start, "display_static", 14))
+    else if (StringsAreEqual(start, "display_static", 14))
 	display_policy = XmDISPLAY_STATIC;
     else {
 	XtDisplayStringConversionWarning(dpy, from->addr,
