@@ -1,8 +1,6 @@
 /*
  * Copyright(c) 1992 Bell Communications Research, Inc. (Bellcore)
  * Copyright(c) 1995-99 Andrew Lister
- * Copyright (c) 1999-2000 by the LessTif Developers.
- *
  *                        All rights reserved
  * Permission to use, copy, modify and distribute this material for
  * any purpose and without fee is hereby granted, provided that the
@@ -24,7 +22,7 @@
  *
  * MatrixWidget Author: Andrew Wason, Bellcore, aw@bae.bellcore.com
  *
- * $Id: Create.c,v 1.11 2000/11/01 01:10:23 dannybackx Exp $
+ * $Id: Create.c,v 1.1 1999/08/04 19:46:53 danny Exp $
  */
 
 /*
@@ -35,12 +33,6 @@
 #include <XbaeConfig.h>
 #endif
 
-#ifdef	WITH_DMALLOC
-#include <dmalloc.h>
-#endif
-
-#include <stdlib.h>
-
 #include <Xm/Xm.h>
 #include <Xbae/MatrixP.h>
 #include <Xbae/Macros.h>
@@ -49,23 +41,36 @@
 #include <Xm/ScrollBar.h>
 #include <Xbae/Create.h>
 
-static Pixmap createInsensitivePixmap(XbaeMatrixWidget mw);
+static Pixmap createInsensitivePixmap P((XbaeMatrixWidget mw));
+
+#ifndef MAXSCREENS
+#define MAXSCREENS 1
+#endif
 
 void
-xbaeCopyBackground(Widget widget, int offset, XrmValue *value)
+xbaeCopyBackground(widget, offset, value)
+Widget widget;
+int offset;
+XrmValue *value;
 {
     value->addr = (XtPointer)&(widget->core.background_pixel);
 }
 
 
 void
-xbaeCopyForeground(Widget widget, int offset, XrmValue *value)
+xbaeCopyForeground(widget, offset, value)
+Widget widget;
+int offset;
+XrmValue *value;
 {
     value->addr = (XtPointer)&(((XmManagerWidget)widget)->manager.foreground);
 }
 
 void
-xbaeCopyDoubleClick(Widget widget, int offset, XrmValue *value)
+xbaeCopyDoubleClick(widget, offset, value)
+Widget widget;
+int offset;
+XrmValue *value;
 {
     static int interval;
   
@@ -74,14 +79,13 @@ xbaeCopyDoubleClick(Widget widget, int offset, XrmValue *value)
 }
 
 void
-xbaeCopyCells(XbaeMatrixWidget mw)
+xbaeCopyCells(mw)
+XbaeMatrixWidget mw;
 {
     String **copy = NULL;
     int i, j;
     Boolean empty_row;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.rows && mw->matrix.columns)
     {
 	/*
@@ -133,18 +137,16 @@ xbaeCopyCells(XbaeMatrixWidget mw)
 	}
     }
     mw->matrix.cells = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
+#if CELL_WIDGETS
 void
-xbaeCopyCellWidgets(XbaeMatrixWidget mw)
+xbaeCopyCellWidgets(mw)
+XbaeMatrixWidget mw;
 {
     Widget **copy = NULL;
     int i, j;
 
-    xbaeObjectLock((Widget)mw);
-
     /*
      * Malloc an array of row pointers
      */
@@ -164,17 +166,16 @@ xbaeCopyCellWidgets(XbaeMatrixWidget mw)
 	}
     }
     mw->matrix.cell_widgets = copy;
-    xbaeObjectUnlock((Widget)mw);
 }
+#endif
 
 void
-xbaeCopyCellShadowTypes(XbaeMatrixWidget mw)
+xbaeCopyCellShadowTypes(mw)
+XbaeMatrixWidget mw;
 {
     unsigned char **copy = NULL;
     int i, j;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.rows && mw->matrix.columns)
     {
 	copy = (unsigned char **) XtMalloc(mw->matrix.rows *
@@ -202,17 +203,15 @@ xbaeCopyCellShadowTypes(XbaeMatrixWidget mw)
 	    }
     }
     mw->matrix.cell_shadow_types = copy;
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCopyRowShadowTypes(XbaeMatrixWidget mw)
+xbaeCopyRowShadowTypes(mw)
+XbaeMatrixWidget mw;
 {
     unsigned char *copy = NULL;
     int i;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.rows)
     {
 	copy = (unsigned char *) XtMalloc(mw->matrix.rows *
@@ -232,17 +231,15 @@ xbaeCopyRowShadowTypes(XbaeMatrixWidget mw)
 		copy[i] = mw->matrix.row_shadow_types[i];
     }
     mw->matrix.row_shadow_types = copy;
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCopyColumnShadowTypes(XbaeMatrixWidget mw)
+xbaeCopyColumnShadowTypes(mw)
+XbaeMatrixWidget mw;
 {
     unsigned char *copy = NULL;
     int i;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.columns)
     {
 	copy = (unsigned char *) XtMalloc(mw->matrix.columns *
@@ -262,18 +259,16 @@ xbaeCopyColumnShadowTypes(XbaeMatrixWidget mw)
 		copy[i] = mw->matrix.column_shadow_types[i];
     }
     mw->matrix.column_shadow_types = copy;
-    xbaeObjectUnlock((Widget)mw);
 }
 
 
 void
-xbaeCopyCellUserData(XbaeMatrixWidget mw)
+xbaeCopyCellUserData(mw)
+XbaeMatrixWidget mw;
 {
     XtPointer **copy = NULL;
     int i, j;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.rows && mw->matrix.columns)
     {
 	copy = (XtPointer **) XtMalloc(mw->matrix.rows * sizeof(XtPointer*));
@@ -287,18 +282,15 @@ xbaeCopyCellUserData(XbaeMatrixWidget mw)
 		copy[i][j] = mw->matrix.cell_user_data[i][j];
     }
     mw->matrix.cell_user_data = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCopyRowUserData(XbaeMatrixWidget mw)
+xbaeCopyRowUserData(mw)
+XbaeMatrixWidget mw;
 {
     XtPointer *copy = NULL;
     int i;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.rows)
     {
 	copy = (XtPointer *) XtMalloc(mw->matrix.rows * sizeof(XtPointer));
@@ -307,18 +299,15 @@ xbaeCopyRowUserData(XbaeMatrixWidget mw)
 	    copy[i] = mw->matrix.row_user_data[i];
     }
     mw->matrix.row_user_data = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCopyColumnUserData(XbaeMatrixWidget mw)
+xbaeCopyColumnUserData(mw)
+XbaeMatrixWidget mw;
 {
     XtPointer *copy = NULL;
     int i;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.columns)
     {
 	copy = (XtPointer *) XtMalloc(mw->matrix.columns * sizeof(XtPointer));
@@ -327,19 +316,16 @@ xbaeCopyColumnUserData(XbaeMatrixWidget mw)
 	    copy[i] = mw->matrix.column_user_data[i];
     }
     mw->matrix.column_user_data = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCopyRowLabels(XbaeMatrixWidget mw)
+xbaeCopyRowLabels(mw)
+XbaeMatrixWidget mw;
 {
     String *copy = NULL;
     int i;
     Boolean empty_label;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.rows)
     {
 	copy = (String *) XtMalloc(mw->matrix.rows * sizeof(String));
@@ -359,19 +345,16 @@ xbaeCopyRowLabels(XbaeMatrixWidget mw)
 		copy[i] = XtNewString(mw->matrix.row_labels[i]);
     }
     mw->matrix.row_labels = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCopyColumnLabels(XbaeMatrixWidget mw)
+xbaeCopyColumnLabels(mw)
+XbaeMatrixWidget mw;
 {
     String *copy = NULL;
     int i;
     Boolean empty_column;
     
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.columns)
     {
 	copy = (String *) XtMalloc(mw->matrix.columns * sizeof(String));
@@ -412,19 +395,16 @@ xbaeCopyColumnLabels(XbaeMatrixWidget mw)
 		    mw->matrix.column_label_lines[i].lines;
     }
     mw->matrix.column_labels = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCopyColumnWidths(XbaeMatrixWidget mw)
+xbaeCopyColumnWidths(mw)
+XbaeMatrixWidget mw;
 {
     short *copy = NULL;
     int i;
     Boolean bad = False;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.columns)
     {
 	copy = (short *) XtMalloc(mw->matrix.columns * sizeof(short));
@@ -448,57 +428,16 @@ xbaeCopyColumnWidths(XbaeMatrixWidget mw)
 	}
     }
     mw->matrix.column_widths = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCopyRowHeights(XbaeMatrixWidget mw)
-{
-#ifdef	HAVE_ROW_HEIGHTS
-    short *copy = NULL;
-    int i;
-    Boolean bad = False;
-
-    xbaeObjectLock((Widget)mw);
-
-    if (mw->matrix.rows)
-    {
-	copy = (short *) XtMalloc(mw->matrix.rows * sizeof(short));
-
-	for (i = 0; i < mw->matrix.rows; i++)
-	{
-	    if (!bad && mw->matrix.row_heights[i] == BAD_HEIGHT)
-	    {
-		bad = True;
-		XtAppWarningMsg(
-		    XtWidgetToApplicationContext((Widget) mw),
-		    "copyRowHeights", "tooShort", "XbaeMatrix",
-		    "XbaeMatrix: Row heights array is too short",
-		    NULL, 0);
-		copy[i] = 1;
-	    }
-	    else if (bad)
-		copy[i] = 1;
-	    else
-		copy[i] = mw->matrix.row_heights[i];
-	}
-    }
-    mw->matrix.row_heights = copy;
-
-    xbaeObjectUnlock((Widget)mw);
-#endif
-}
-
-void
-xbaeCopyColumnMaxLengths(XbaeMatrixWidget mw)
+xbaeCopyColumnMaxLengths(mw)
+XbaeMatrixWidget mw;
 {
     int *copy = NULL;
     int i;
     Boolean bad = False;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.columns)
     {
 	copy = (int *) XtMalloc(mw->matrix.columns * sizeof(int));
@@ -522,19 +461,16 @@ xbaeCopyColumnMaxLengths(XbaeMatrixWidget mw)
 	}
     }
     mw->matrix.column_max_lengths = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCopyColumnAlignments(XbaeMatrixWidget mw)
+xbaeCopyColumnAlignments(mw)
+XbaeMatrixWidget mw;
 {
     unsigned char *copy = NULL;
     int i;
     Boolean bad = False;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.columns)
     {
 	copy = (unsigned char *) XtMalloc(mw->matrix.columns *
@@ -559,18 +495,15 @@ xbaeCopyColumnAlignments(XbaeMatrixWidget mw)
 	}
     }
     mw->matrix.column_alignments = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCopyColumnButtonLabels(XbaeMatrixWidget mw)
+xbaeCopyColumnButtonLabels(mw)
+XbaeMatrixWidget mw;
 {
     Boolean *copy = NULL;
     int i;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.columns)
     {
 	copy = (Boolean *) XtMalloc(mw->matrix.columns *
@@ -582,41 +515,15 @@ xbaeCopyColumnButtonLabels(XbaeMatrixWidget mw)
 	}
     }
     mw->matrix.column_button_labels = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCopyColumnFontBold(XbaeMatrixWidget mw)
+xbaeCopyRowButtonLabels(mw)
+XbaeMatrixWidget mw;
 {
     Boolean *copy = NULL;
     int i;
 
-    xbaeObjectLock((Widget)mw);
-
-    if (mw->matrix.columns)
-    {
-      copy = (Boolean *) XtMalloc(mw->matrix.columns *
-                                  sizeof(Boolean));
-
-      for (i = 0; i < mw->matrix.columns; i++)
-      {
-          copy[i] = mw->matrix.column_font_bold[i];
-      }
-    }
-    mw->matrix.column_font_bold = copy;
-
-    xbaeObjectUnlock((Widget)mw);
-}
-
-void
-xbaeCopyRowButtonLabels(XbaeMatrixWidget mw)
-{
-    Boolean *copy = NULL;
-    int i;
-
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.rows)
     {
 	copy = (Boolean *) XtMalloc(mw->matrix.rows *
@@ -628,19 +535,16 @@ xbaeCopyRowButtonLabels(XbaeMatrixWidget mw)
 	}
     }
     mw->matrix.row_button_labels = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCopyColumnLabelAlignments(XbaeMatrixWidget mw)
+xbaeCopyColumnLabelAlignments(mw)
+XbaeMatrixWidget mw;
 {
     unsigned char *copy = NULL;
     int i;
     Boolean bad = False;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.columns)
     {
 	copy = (unsigned char *) XtMalloc(mw->matrix.columns *
@@ -667,19 +571,17 @@ xbaeCopyColumnLabelAlignments(XbaeMatrixWidget mw)
 	}
     }
     mw->matrix.column_label_alignments = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCopyColors(XbaeMatrixWidget mw)
+xbaeCopyColors(mw)
+XbaeMatrixWidget mw;
 {
     Pixel **copy = NULL;
     int i, j;
     Boolean badrow = False;
     Boolean badcol;
 
-    xbaeObjectLock((Widget)mw);
 
     if (mw->matrix.rows && mw->matrix.columns)
     {
@@ -732,20 +634,17 @@ xbaeCopyColors(XbaeMatrixWidget mw)
 	}
     }
     mw->matrix.colors = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCopyBackgrounds(XbaeMatrixWidget mw)
+xbaeCopyBackgrounds(mw)
+XbaeMatrixWidget mw;
 {
     Pixel **copy = NULL;
     int i, j;
     Boolean badrow = False;
     Boolean badcol;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.rows && mw->matrix.columns)
     {
 	/*
@@ -811,8 +710,6 @@ xbaeCopyBackgrounds(XbaeMatrixWidget mw)
 	}
     }
     mw->matrix.cell_background = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 /*
@@ -820,24 +717,19 @@ xbaeCopyBackgrounds(XbaeMatrixWidget mw)
  * represent selected cells if it is NULL.
  */
 void
-xbaeCopySelectedCells(XbaeMatrixWidget mw)
+xbaeCopySelectedCells(mw)
+XbaeMatrixWidget mw;
 {
     Boolean **copy = NULL;
     int i, j;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.rows && mw->matrix.columns)
     {
 	/*
 	 * Malloc an array of row pointers
 	 */
 	mw->matrix.num_selected_cells = 0;
-#if 0
 	copy = (Boolean **) XtMalloc(mw->matrix.rows * sizeof(Boolean *));
-#else
-	copy = (Boolean **) XtCalloc(mw->matrix.rows, sizeof(Boolean *));
-#endif
 
 	/*
 	 * Malloc an array of Booleans for each row pointer
@@ -859,8 +751,6 @@ xbaeCopySelectedCells(XbaeMatrixWidget mw)
 		}
     }
     mw->matrix.selected_cells = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 #if XmVersion >= 1002
@@ -869,13 +759,12 @@ xbaeCopySelectedCells(XbaeMatrixWidget mw)
  * represent highlighted cells if it is NULL.
  */
 void
-xbaeCopyHighlightedCells(XbaeMatrixWidget mw)
+xbaeCopyHighlightedCells(mw)
+XbaeMatrixWidget mw;
 {
     unsigned char **copy = NULL;
     int i, j;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.rows && mw->matrix.columns)
     {
 	/*
@@ -900,8 +789,6 @@ xbaeCopyHighlightedCells(XbaeMatrixWidget mw)
 		    copy[i][j] = mw->matrix.highlighted_cells[i][j];
     }
     mw->matrix.highlighted_cells = copy;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 #endif
 
@@ -909,12 +796,11 @@ xbaeCopyHighlightedCells(XbaeMatrixWidget mw)
  * Create a matrix of Pixels
  */
 void
-xbaeCreateColors(XbaeMatrixWidget mw)
+xbaeCreateColors(mw)
+XbaeMatrixWidget mw;
 {
     int i;
 
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.rows && mw->matrix.columns)
     {
 	/*
@@ -932,8 +818,6 @@ xbaeCreateColors(XbaeMatrixWidget mw)
     }
     else
 	mw->matrix.colors = NULL;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 /*
@@ -941,47 +825,40 @@ xbaeCreateColors(XbaeMatrixWidget mw)
  * XmNsensitive is set to False
  */
 static Pixmap
-createInsensitivePixmap(XbaeMatrixWidget mw)
+createInsensitivePixmap(mw)
+XbaeMatrixWidget mw;
 {
     static char stippleBits[] = { 0x01, 0x02 };
-    static Pixmap *stipple = NULL;
+    static Pixmap stipple[MAXSCREENS] = {(Pixmap)NULL};
     Display *dpy = XtDisplay(mw);
     Screen *scr  = XtScreen (mw);
     int i;
     int maxScreens = ScreenCount(dpy);
     
-    xbaeObjectLock((Widget)mw);
-
-    if (!stipple)
+    if (maxScreens > MAXSCREENS)
+	maxScreens = MAXSCREENS;
+    
+    if (!stipple[0])
     {
-	stipple = malloc(maxScreens*sizeof(Pixmap));
-	if (!stipple) {
-            return (Pixmap) NULL;
-	}
 	for (i = 0 ; i < maxScreens ; i++)
 	    stipple[i] = XCreatePixmapFromBitmapData(
 		dpy, RootWindow(dpy,i), stippleBits, 2, 2, 0, 1, 1);
     }
     for (i = 0; i < maxScreens; i++)
     {
-	if (ScreenOfDisplay(dpy, i) == scr) {
-	    xbaeObjectUnlock((Widget)mw);
+	if (ScreenOfDisplay(dpy, i) == scr)
 	    return stipple[i];
-	}
     }
-
-    xbaeObjectUnlock((Widget)mw);
     return (Pixmap)NULL;
 }
     
 void
-xbaeCreateGridLineGC(XbaeMatrixWidget mw)
+xbaeCreateGridLineGC(mw)
+XbaeMatrixWidget mw;
 {
     XGCValues values;
     XtGCMask mask = GCForeground | GCBackground;
 
-    xbaeObjectLock((Widget)mw);
-
     values.foreground = mw->matrix.grid_line_color;
     values.background = mw->manager.foreground;
     
@@ -996,18 +873,15 @@ xbaeCreateGridLineGC(XbaeMatrixWidget mw)
     mw->matrix.cell_grid_line_gc = XCreateGC(XtDisplay(mw),
 					     GC_PARENT_WINDOW(mw),
 					     mask, &values);
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCreateDrawGC(XbaeMatrixWidget mw)
+xbaeCreateDrawGC(mw)
+XbaeMatrixWidget mw;
 {
     XGCValues values;
     unsigned long mask = GCForeground | GCFont | GCStipple;
 
-    xbaeObjectLock((Widget)mw);
-
     /*
      * GC for drawing cells. We create it instead of using a cached one,
      * since the foreground may change frequently.
@@ -1019,18 +893,15 @@ xbaeCreateDrawGC(XbaeMatrixWidget mw)
     mw->matrix.draw_gc = XCreateGC(XtDisplay(mw),
 				   GC_PARENT_WINDOW(mw),
 				   mask, &values);
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCreatePixmapGC(XbaeMatrixWidget mw)
+xbaeCreatePixmapGC(mw)
+XbaeMatrixWidget mw;
 {
     XGCValues values;
     unsigned long mask = GCForeground | GCGraphicsExposures | GCStipple;
 
-    xbaeObjectLock((Widget)mw);
-
     values.foreground = mw->manager.foreground;
     values.graphics_exposures = False;
     values.stipple = createInsensitivePixmap(mw);
@@ -1038,18 +909,15 @@ xbaeCreatePixmapGC(XbaeMatrixWidget mw)
     mw->matrix.pixmap_gc = XCreateGC(XtDisplay(mw),
 				     GC_PARENT_WINDOW(mw),
 				     mask, &values);
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCreateLabelGC(XbaeMatrixWidget mw)
+xbaeCreateLabelGC(mw)
+XbaeMatrixWidget mw;
 {
     XGCValues values;
     unsigned long mask = GCForeground | GCFont | GCStipple;
 
-    xbaeObjectLock((Widget)mw);
-
     /*
      * GC for drawing labels
      */
@@ -1059,18 +927,15 @@ xbaeCreateLabelGC(XbaeMatrixWidget mw)
     mw->matrix.label_gc = XCreateGC(XtDisplay(mw),
 				    GC_PARENT_WINDOW(mw),
 				    mask, &values);
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCreateLabelClipGC(XbaeMatrixWidget mw)
+xbaeCreateLabelClipGC(mw)
+XbaeMatrixWidget mw;
 {
     XGCValues values;
     unsigned long mask = GCForeground | GCFont | GCStipple;
 
-    xbaeObjectLock((Widget)mw);
-
     /*
      * GC for drawing labels with clipping.
      */
@@ -1080,18 +945,15 @@ xbaeCreateLabelClipGC(XbaeMatrixWidget mw)
     mw->matrix.label_clip_gc = XCreateGC(XtDisplay(mw),
 					 GC_PARENT_WINDOW(mw),
 					 mask, &values);
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCreateTopShadowClipGC(XbaeMatrixWidget mw)
+xbaeCreateTopShadowClipGC(mw)
+XbaeMatrixWidget mw;
 {
     XGCValues values;
     XtGCMask mask = GCForeground | GCBackground;
 
-    xbaeObjectLock((Widget)mw);
-
     /*
      * GC for drawing top shadow inside cells with clipping.
      */
@@ -1111,18 +973,15 @@ xbaeCreateTopShadowClipGC(XbaeMatrixWidget mw)
     values.function = GXxor;
     mw->matrix.resize_top_shadow_gc = XtGetGC(
 	(Widget) mw, mask, &values);
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeCreateBottomShadowClipGC(XbaeMatrixWidget mw)
+xbaeCreateBottomShadowClipGC(mw)
+XbaeMatrixWidget mw;
 {
     XGCValues values;
     XtGCMask mask = GCForeground | GCBackground;
 
-    xbaeObjectLock((Widget)mw);
-
     /*
      * GC for drawing bottom shadow inside cells with clipping.
      */
@@ -1142,12 +1001,11 @@ xbaeCreateBottomShadowClipGC(XbaeMatrixWidget mw)
     values.function = GXxor;
     mw->matrix.resize_bottom_shadow_gc = XtGetGC(
 	(Widget) mw, mask, &values);
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeNewFont(XbaeMatrixWidget mw)
+xbaeNewFont(mw)
+XbaeMatrixWidget mw;
 {
     XmFontContext context;
     XFontStruct *font;
@@ -1157,8 +1015,6 @@ xbaeNewFont(XbaeMatrixWidget mw)
     XFontStruct **fonts;
     char **font_names;
 
-    xbaeObjectLock((Widget)mw);
-
     /*
      * Make a private copy of the FontList
      */
@@ -1209,12 +1065,11 @@ xbaeNewFont(XbaeMatrixWidget mw)
     }
 
     XmFontListFreeFontContext(context);
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeNewLabelFont(XbaeMatrixWidget mw)
+xbaeNewLabelFont(mw)
+XbaeMatrixWidget mw;
 {
     XmFontContext context;
     XFontStruct *font;
@@ -1224,8 +1079,6 @@ xbaeNewLabelFont(XbaeMatrixWidget mw)
     XFontStruct **fonts;
     char **font_names;
 
-    xbaeObjectLock((Widget)mw);
-
     /*
      * Make a private copy of the FontList
      */
@@ -1276,20 +1129,17 @@ xbaeNewLabelFont(XbaeMatrixWidget mw)
     }
 
     XmFontListFreeFontContext(context);
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeFreeCells(XbaeMatrixWidget mw)
+xbaeFreeCells(mw)
+XbaeMatrixWidget mw;
 {
     int i, j;
 
     if (!mw->matrix.cells)
 	return;
 
-    xbaeObjectLock((Widget)mw);
-
     /*
      * Free each cell in a row, then free the row and go to the next one
      */
@@ -1305,29 +1155,25 @@ xbaeFreeCells(XbaeMatrixWidget mw)
      */
     XtFree((XtPointer) mw->matrix.cells);
     mw->matrix.cells = NULL;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
+#if CELL_WIDGETS
 void
-xbaeFreeCellWidgets(XbaeMatrixWidget mw)
+xbaeFreeCellWidgets(mw)
+XbaeMatrixWidget mw;
 {
     int i, j;
 
     if (!mw->matrix.cell_widgets)
 	return;
 
-    xbaeObjectLock((Widget)mw);
-
     /*
-     * Destroy each cell widget (don't XtFree ! as Linas suggests),
-     * then free the row and go to the next one.
+     * Free each cell in a row, then free the row and go to the next one
      */
     for (i = 0; i < mw->matrix.rows; i++)
     {
 	for (j = 0; j < mw->matrix.columns; j++)
-	    if (mw->matrix.cell_widgets[i][j])
-		XtDestroyWidget(mw->matrix.cell_widgets[i][j]);
+	    XtFree((XtPointer) mw->matrix.cell_widgets[i][j]);
 	XtFree((XtPointer) mw->matrix.cell_widgets[i]);
     }
 
@@ -1336,39 +1182,34 @@ xbaeFreeCellWidgets(XbaeMatrixWidget mw)
      */
     XtFree((XtPointer) mw->matrix.cell_widgets);
     mw->matrix.cell_widgets = NULL;
-
-    xbaeObjectUnlock((Widget)mw);
 }
+#endif
 
 void
-xbaeFreeRowLabels(XbaeMatrixWidget mw)
+xbaeFreeRowLabels(mw)
+XbaeMatrixWidget mw;
 {
     int i;
 
     if (!mw->matrix.row_labels)
 	return;
 
-    xbaeObjectLock((Widget)mw);
-
     for (i = 0; i < mw->matrix.rows; i++)
 	XtFree((XtPointer) mw->matrix.row_labels[i]);
 
     XtFree((XtPointer) mw->matrix.row_labels);
     mw->matrix.row_labels = NULL;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeFreeColumnLabels(XbaeMatrixWidget mw)
+xbaeFreeColumnLabels(mw)
+XbaeMatrixWidget mw;
 {
     int i;
 
     if (!mw->matrix.column_labels)
 	return;
 
-    xbaeObjectLock((Widget)mw);
-
     for (i = 0; i < mw->matrix.columns; i++)
     {
 	XtFree((XtPointer) mw->matrix.column_labels[i]);
@@ -1378,21 +1219,18 @@ xbaeFreeColumnLabels(XbaeMatrixWidget mw)
     XtFree((XtPointer) mw->matrix.column_label_lines);
     XtFree((XtPointer) mw->matrix.column_labels);
     mw->matrix.column_labels = NULL;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 
 void
-xbaeFreeColors(XbaeMatrixWidget mw)
+xbaeFreeColors(mw)
+XbaeMatrixWidget mw;
 {
     int i;
 
     if (!mw->matrix.colors)
 	return;
 
-    xbaeObjectLock((Widget)mw);
-
     /*
      * Free each row of Pixels
      */
@@ -1404,20 +1242,17 @@ xbaeFreeColors(XbaeMatrixWidget mw)
      */
     XtFree((XtPointer) mw->matrix.colors);
     mw->matrix.colors = NULL;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeFreeBackgrounds(XbaeMatrixWidget mw)
+xbaeFreeBackgrounds(mw)
+XbaeMatrixWidget mw;
 {
     int i;
 
     if (!mw->matrix.cell_background)
 	return;
 
-    xbaeObjectLock((Widget)mw);
-
     /*
      * Free each row of Pixels
      */
@@ -1429,12 +1264,11 @@ xbaeFreeBackgrounds(XbaeMatrixWidget mw)
      */
     XtFree((XtPointer) mw->matrix.cell_background);
     mw->matrix.cell_background = NULL;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 void
-xbaeFreeSelectedCells(XbaeMatrixWidget mw)
+xbaeFreeSelectedCells(mw)
+XbaeMatrixWidget mw;
 {
     int i;
 
@@ -1444,8 +1278,6 @@ xbaeFreeSelectedCells(XbaeMatrixWidget mw)
     if (!mw->matrix.selected_cells)
 	return;
 
-    xbaeObjectLock((Widget)mw);
-
     for (i = 0; i < mw->matrix.rows; i++)
 	XtFree((XtPointer) mw->matrix.selected_cells[i]);
 
@@ -1454,21 +1286,18 @@ xbaeFreeSelectedCells(XbaeMatrixWidget mw)
      */
     XtFree((XtPointer) mw->matrix.selected_cells);
     mw->matrix.selected_cells = NULL;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 #if XmVersion >= 1002
 void
-xbaeFreeHighlightedCells(XbaeMatrixWidget mw)
+xbaeFreeHighlightedCells(mw)
+XbaeMatrixWidget mw;
 {
     int i;
 
     if (!mw->matrix.highlighted_cells)
 	return;
     
-    xbaeObjectLock((Widget)mw);
-
     /*
      * Free each row of XtPointer pointers
      */
@@ -1480,16 +1309,13 @@ xbaeFreeHighlightedCells(XbaeMatrixWidget mw)
      */
     XtFree((XtPointer) mw->matrix.highlighted_cells);
     mw->matrix.highlighted_cells = NULL;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 #endif
 
 void
-xbaeFreeCellUserData(XbaeMatrixWidget mw)
+xbaeFreeCellUserData(mw)
+XbaeMatrixWidget mw;
 {
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.cell_user_data)
     {
 	int i;
@@ -1506,16 +1332,13 @@ xbaeFreeCellUserData(XbaeMatrixWidget mw)
 	XtFree((XtPointer) mw->matrix.cell_user_data);
     }
     mw->matrix.cell_user_data = NULL;
-
-    xbaeObjectUnlock((Widget)mw);
 }
 
 
 void
-xbaeFreeCellShadowTypes(XbaeMatrixWidget mw)
+xbaeFreeCellShadowTypes(mw)
+XbaeMatrixWidget mw;
 {
-    xbaeObjectLock((Widget)mw);
-
     if (mw->matrix.cell_shadow_types)
     {
 	int i;
@@ -1532,6 +1355,5 @@ xbaeFreeCellShadowTypes(XbaeMatrixWidget mw)
 	XtFree((XtPointer) mw->matrix.cell_shadow_types);
     }
     mw->matrix.cell_shadow_types = NULL;
-
-    xbaeObjectUnlock((Widget)mw);
 }
+
