@@ -1,8 +1,6 @@
 /*
  * Copyright(c) 1992 Bell Communications Research, Inc. (Bellcore)
  * Copyright(c) 1995-99 Andrew Lister
- * Copyright (c) 1999-2000 by the LessTif Developers.
- *
  *                        All rights reserved
  * Permission to use, copy, modify and distribute this material for
  * any purpose and without fee is hereby granted, provided that the
@@ -22,7 +20,7 @@
  * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
  * ING TO THE SOFTWARE.
  *
- * $Id: Draw.c,v 1.20 2000/12/09 12:40:46 dannybackx Exp $
+ * $Id: Draw.c,v 1.3 1999/09/16 19:42:32 danny Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -39,50 +37,40 @@
 #include <Xbae/Shadow.h>
 #include <Xbae/Draw.h>
 #include <stdlib.h>
-#ifdef XBAE_VERBOSE
-#include <stdio.h>
-#endif
 
-static void xbaeDrawCellString(XbaeMatrixWidget, int, int, int, int,
-				  String, Pixel, Pixel);
-static void xbaeDrawCellWidget(XbaeMatrixWidget, int, int, int, int,
-				  Widget, Pixel, Pixel);
-static void xbaeDrawCellPixmap(XbaeMatrixWidget, int, int, int, int,
+static void xbaeDrawCellString P((XbaeMatrixWidget, int, int, int, int,
+				  String, Pixel, Pixel));
+#if CELL_WIDGETS
+static void xbaeDrawCellWidget P((XbaeMatrixWidget, int, int, int, int,
+				  Widget, Pixel, Pixel));
+#endif
+static void xbaeDrawCellPixmap P((XbaeMatrixWidget, int, int, int, int,
 				  Pixmap, Pixmap, int, int, Pixel,
-				  Pixel, int);
-static void xbaeDrawString(XbaeMatrixWidget mw, Window win, GC gc,
-			String string, int length,
-			int x, int y,
-			int maxlen, int maxht,
-			unsigned char alignment, Boolean highlight,
-			Boolean bold, Boolean rowLabel,
-			Boolean colLabel, Pixel color);
+				  Pixel, int));
 
 /*
  * Draw a fixed or non-fixed cell. The coordinates are calculated relative
  * to the correct window and pixmap is copied to that window.
  */
 static void
-xbaeDrawCellPixmap(XbaeMatrixWidget mw,
-		int row,
-		int column,
-		int x,
-		int y,
-		Pixmap pixmap,
-		Pixmap mask,
-		int width,
-		int height,
-		Pixel bg,
-		Pixel fg,
-		int depth)
+xbaeDrawCellPixmap(mw, row, column, x, y, pixmap, mask, width, height, bg,
+		   fg, depth)
+XbaeMatrixWidget mw;
+int row;
+int column;
+int x;
+int y;
+Pixmap pixmap;
+Pixmap mask;
+int width;
+int height;
+Pixel bg;
+Pixel fg;
+int depth;
 {
     int src_x = 0, src_y, dest_x, dest_y;
     int copy_width, copy_height;
-#ifdef	HAVE_ROW_HEIGHTS
-    int cell_height = SOME_ROW_HEIGHT(mw, row);
-#else
     int cell_height = ROW_HEIGHT(mw);
-#endif
     int cell_width = COLUMN_WIDTH(mw, column);
     Widget w;
     unsigned char alignment = mw->matrix.column_alignments ?
@@ -119,7 +107,7 @@ xbaeDrawCellPixmap(XbaeMatrixWidget mw,
 #endif
 
     XFillRectangle(display, win, gc, x, y,
-		   COLUMN_WIDTH(mw, column), cell_height);
+		   COLUMN_WIDTH(mw, column), ROW_HEIGHT(mw));
 
     XSetForeground(display, gc, fg);
     XSetBackground(display, gc, bg);
@@ -246,128 +234,12 @@ xbaeDrawCellPixmap(XbaeMatrixWidget mw,
  * to the correct window and the cell is drawn in that window.
  */
 static void
-xbaeDrawCellString(XbaeMatrixWidget mw,
-		int row,
-		int column,
-		int x,
-		int y,
-		String string,
-		Pixel bg,
-		Pixel fg)
+xbaeDrawCellString(mw, row, column, x, y, string, bg, fg)
+XbaeMatrixWidget mw;
+int row, column;
+String string;
+Pixel bg, fg;
 {
-#ifdef	HAVE_ROW_HEIGHTS
-    GC gc;
-    Widget w;
-    Window win = xbaeGetCellWindow(mw, &w, row, column);
-    Dimension column_width = COLUMN_WIDTH(mw, column);
-    Dimension row_height = SOME_ROW_HEIGHT(mw, row);
-    Dimension width = column_width;
-    Dimension height = row_height;
-    Boolean selected = mw->matrix.selected_cells ?
-	mw->matrix.selected_cells[row][column] : False;
-    String str = string;
-
-    if (!win)
-	return;
-
-    if (row_height == 0)
-	return;		/* Quick fix */
-
-#if 0
-    /*
-     * Probably not needed - time will tell!  If anybody gets a segv on
-     * ignoring this code, be sure to let me know - AL 11/96
-     *
-     * Make sure y coordinate is valid 
-     */
-    if ((win == XtWindow(mw)) &&
-	((y > (CLIP_VERT_VISIBLE_SPACE(mw) + ROW_LABEL_OFFSET(mw) - 1)) ||
-	 (y < ROW_LABEL_OFFSET(mw))))
-	return;
-#endif
-    gc = mw->matrix.draw_gc;
-    XSetForeground(XtDisplay(mw), gc, bg);
-
-    /*
-     * If we are only changing the highlighting of a cell, we don't need
-     * to do anything other than draw (or undraw) the highlight
-     */
-    if (mw->matrix.highlighted_cells &&
-	mw->matrix.highlight_location != HighlightNone)
-    {
-	xbaeDrawCellHighlight(mw, win, gc, row, column, x, y, width, height,
-			      mw->matrix.highlight_location);
-	return;
-    }
-
-    /*
-     * Fill the cell's background if it can be done
-     * without duplicating work below
-     */
-    if ((XtWindow(mw) != win) ||
-	(!(IN_GRID_COLUMN_MODE(mw) && NEED_VERT_FILL(mw) &&
-	   ((mw->matrix.rows - 1) == row)) &&
-	 !(IN_GRID_ROW_MODE(mw) && NEED_HORIZ_FILL(mw) &&
-	   ((mw->matrix.columns - 1) == column))))
-	XFillRectangle(XtDisplay(mw), win, gc, x, y,
-		       column_width, row_height);
-
-    /*
-     * If we need to fill the rest of the space, do so
-     */
-    if (IN_GRID_COLUMN_MODE(mw) && NEED_VERT_FILL(mw) &&
-	((mw->matrix.rows - 1) == row))
-    {
-	int ax, ay;
-	int fill_width, fill_height;
-	/*
-	 * Need to check the actual window we are drawing on to ensure
-	 * the correct visual
-	 */
-	xbaeCalcVertFill(mw, win, x, y, row, column, &ax, &ay,
-			 &fill_width, &fill_height);
-	XFillRectangle(XtDisplay(mw), XtWindow(mw), gc,
-		       ax, ay, fill_width, fill_height);
-    }
-    else if (IN_GRID_ROW_MODE(mw) && NEED_HORIZ_FILL(mw) &&
-	     (column == (mw->matrix.columns - 1)))
-    {
-	int ax, ay;
-	int fill_width, fill_height;
-
-	xbaeCalcHorizFill(mw, win, x, y, row, column, &ax, &ay,
-			  &fill_width, &fill_height);
-	XFillRectangle(XtDisplay(mw), XtWindow(mw), gc,
-		       ax, ay, fill_width, fill_height);
-    }
-
-    /*
-     * Draw the string in the cell.
-     */
-    xbaeDrawString(mw, win, gc, str, strlen(str),
-		x + TEXT_X_OFFSET(mw), y + TEXT_Y_OFFSET(mw),
-		mw->matrix.column_widths[column],
-		row_height,
-		mw->matrix.column_alignments ?
-		mw->matrix.column_alignments[column] :
-		XmALIGNMENT_BEGINNING, selected,
-		mw->matrix.column_font_bold ? mw->matrix.column_font_bold[column] : 0,
-		False, False, fg);
-
-#if XmVersion >= 1002
-    if (mw->matrix.highlighted_cells &&
-	mw->matrix.highlighted_cells[row][column])
-    {
-	xbaeDrawCellHighlight(mw, win, gc, row, column, x, y, width, height,
-			      HIGHLIGHTING_SOMETHING);
-    }
-#endif
-
-    xbaeDrawCellShadow(mw, win, row, column, x, y, COLUMN_WIDTH(mw, column),
-		       SOME_ROW_HEIGHT(mw, row), False, False, False);
-
-#else	/* ~HAVE_ROW_HEIGHTS */
-
     GC gc;
     Widget w;
     Window win = xbaeGetCellWindow(mw, &w, row, column);
@@ -453,15 +325,14 @@ xbaeDrawCellString(XbaeMatrixWidget mw,
     /*
      * Draw the string in the cell.
      */
+
     xbaeDrawString(mw, win, gc, str, strlen(str),
-	x + TEXT_X_OFFSET(mw), y + TEXT_Y_OFFSET(mw),
-	mw->matrix.column_widths[column],
-	-1,
-	mw->matrix.column_alignments ?
-	mw->matrix.column_alignments[column] :
-	XmALIGNMENT_BEGINNING, selected,
-	mw->matrix.column_font_bold ? mw->matrix.column_font_bold[column] : 0,
-	False, False, fg);
+		   x + TEXT_X_OFFSET(mw), y + TEXT_Y_OFFSET(mw),
+		   mw->matrix.column_widths[column],
+		   mw->matrix.column_alignments ?
+		   mw->matrix.column_alignments[column] :
+		   XmALIGNMENT_BEGINNING, selected,
+		   False, False, False, fg);
 
 #if XmVersion >= 1002
     if (mw->matrix.highlighted_cells &&
@@ -474,52 +345,46 @@ xbaeDrawCellString(XbaeMatrixWidget mw,
 
     xbaeDrawCellShadow(mw, win, row, column, x, y, COLUMN_WIDTH(mw, column),
 		       ROW_HEIGHT(mw), False, False, False);
-#endif
 }
-
+#if CELL_WIDGETS
 /*
  * Draw a user defined widget in the cell
  */
 static void
-xbaeDrawCellWidget(XbaeMatrixWidget mw,
-		int row,
-		int column,
-		int x,
-		int y,
-		Widget widget,
-		Pixel bg,
-		Pixel fg)
+xbaeDrawCellWidget(mw, row, column, x, y, widget, bg, fg)
+XbaeMatrixWidget mw;
+int row, column;
+int x, y;
+Widget widget;
+Pixel bg, fg;
 {
     GC gc;
     Widget w;
     Window win = xbaeGetCellWindow(mw, &w, row, column);
 
     Boolean clipped = False;	/* To get 4.7 to compile. */
-#ifdef	HAVE_ROW_HEIGHTS
-    int	r = SOME_ROW_HEIGHT(mw, row);
-#else
-    int	r = ROW_HEIGHT(mw);
-#endif
 
     if (!win)
 	return;
-    if (! XtIsManaged(widget))
-	return;
 
     gc = mw->matrix.draw_gc;
     XSetForeground(XtDisplay(mw), gc, bg);
-    XFillRectangle(XtDisplay(mw), win, gc, x, y, COLUMN_WIDTH(mw, column), r);
+    XFillRectangle(XtDisplay(mw), win, gc, x, y,
+		   COLUMN_WIDTH(mw, column), ROW_HEIGHT(mw));
 
     /*
      * Draw the widget in the cell.
      */
     XtMoveWidget(widget,
-		 x + mw->matrix.cell_shadow_thickness + mw->matrix.cell_highlight_thickness,
-		 y + mw->matrix.cell_shadow_thickness + mw->matrix.cell_highlight_thickness);
+		 x + mw->matrix.cell_shadow_thickness +
+		 mw->matrix.cell_highlight_thickness,
+		 y + mw->matrix.cell_shadow_thickness +
+		 mw->matrix.cell_highlight_thickness);
 
     xbaeDrawCellShadow(mw, win, row, column, x, y, COLUMN_WIDTH(mw, column),
-		       r, False, clipped, False);
+		       ROW_HEIGHT(mw), False, clipped, False);
 }
+#endif
 
 /*
  * Width in pixels of a character in a given font
@@ -536,23 +401,30 @@ xbaeDrawCellWidget(XbaeMatrixWidget mw,
  * Draw a string with specified attributes. We want to avoid having to
  * use a GC clip_mask, so we clip by characters. This complicates the code.
  */
-	/* FIX ME this should be clipped with the row height for the last row */
-static void
-xbaeDrawString(XbaeMatrixWidget mw,
-		Window win,
-		GC gc,
-		String string,
-		int length,
-		int x,
-		int y,
-		int maxlen,
-		int maxht,		/* Added for row heights */
-		unsigned char alignment,
-		Boolean highlight,
-		Boolean bold,
-		Boolean rowLabel,
-		Boolean colLabel,
-		Pixel color)
+void
+#if NeedFunctionPrototypes
+xbaeDrawString(XbaeMatrixWidget mw, Window win, GC gc, String string,
+	       int length, int x, int y, int maxlen, unsigned char alignment,
+	       Boolean highlight, Boolean bold, Boolean rowLabel,
+	       Boolean colLabel, Pixel color)
+#else
+xbaeDrawString(mw, win, gc, string, length, x, y, maxlen, alignment,
+	       highlight, bold, rowLabel, colLabel, color)
+XbaeMatrixWidget mw;
+Window win;
+GC gc;
+String string;
+int length;
+int x;
+int y;
+int maxlen;
+unsigned char alignment;
+Boolean highlight;
+Boolean bold;
+Boolean rowLabel;
+Boolean colLabel;
+Pixel color;
+#endif
 {
     int start, width, maxwidth;
     XFontStruct	*font_struct;
@@ -561,12 +433,8 @@ xbaeDrawString(XbaeMatrixWidget mw,
     Boolean choppedEnd = False;
     XRectangle *ink_array = NULL;
     XRectangle *logical_array = NULL;
-    int num_chars, doclip;
-    XRectangle overall_logical, clipht;
-
-#ifdef	XBAE_VERBOSE
-    fprintf(stderr, "xbaeDrawString(%s) x %d y %d, clip w %d h %d\n", string, x, y, maxlen, maxht);
-#endif
+    int num_chars;
+    XRectangle overall_logical;
 
     if (rowLabel || colLabel)
     {
@@ -578,7 +446,6 @@ xbaeDrawString(XbaeMatrixWidget mw,
 	font_struct = mw->matrix.font_struct;
 	font_set = mw->matrix.font_set;
     }
-
     /*
      * Initialize starting character in string
      */
@@ -589,28 +456,6 @@ xbaeDrawString(XbaeMatrixWidget mw,
     else 
 	maxwidth = maxlen * LABEL_WIDTH(mw);
 
-    /*
-     * Clip height
-     */
-    if (maxht < 0) {
-	doclip = 0;
-    } else {
-	doclip = 1;
-    }
-
-#if 0
-    clipht.height = y + maxht;
-    clipht.width = x + maxwidth;
-    clipht.x = 0;
-    clipht.y = 0;
-
-    if (doclip) {
-	fprintf(stderr, "XSetClipRectangles - x %d y %d w %d h %d\n",
-		x, y, clipht.width, clipht.height);
-	XSetClipRectangles(XtDisplay(mw), gc, 0, 0, &clipht, 1, Unsorted);
-    }
-#endif
-
     if (font_set)
     {
 	ink_array = (XRectangle*)XtMalloc(length * sizeof(XRectangle));
@@ -841,20 +686,6 @@ xbaeDrawString(XbaeMatrixWidget mw,
 	 */
 	x -= overall_logical.x;
 
-#if 1
-    clipht.height = y + maxht;
-    clipht.width = x + maxwidth;
-    clipht.x = 0;
-    clipht.y = 0;
-
-    if (doclip) {
-#ifdef XBAE_VERBOSE
-	fprintf(stderr, "XSetClipRectangles - x %d y %d w %d h %d\n",
-		x, y, clipht.width, clipht.height);
-#endif
-	XSetClipRectangles(XtDisplay(mw), gc, 0, 0, &clipht, 1, Unsorted);
-    }
-#endif
 	/*
 	 * Now draw the string at x starting at char 'start' and of
 	 * length 'length'
@@ -1043,20 +874,6 @@ xbaeDrawString(XbaeMatrixWidget mw,
 	 * Now draw the string at x starting at char 'start' and of length
 	 * 'length'
 	 */
-#if 1
-    clipht.width = maxwidth + x;
-    clipht.height = maxht + y;
-    clipht.x = 0;
-    clipht.y = 0;
-
-    if (doclip) {
-#ifdef XBAE_VERBOSE
-	fprintf(stderr, "XSetClipRectangles 2 - x %d y %d w %d h %d\n",
-		x, y, clipht.width, clipht.height);
-#endif
-	XSetClipRectangles(XtDisplay(mw), gc, 0, 0, &clipht, 1, Unsorted);
-    }
-#endif
 #ifdef NEED_WCHAR
 	if (TWO_BYTE_FONT(mw))
 	    XDrawString16(XtDisplay(mw), win, gc, x, y, &string[start],
@@ -1078,18 +895,13 @@ xbaeDrawString(XbaeMatrixWidget mw,
 		XDrawString(XtDisplay(mw), win, gc, x - 1, y,
 			    &string[start], length);
     }
-
-    if (doclip) {
-	XSetClipMask(XtDisplay(mw), gc, None);
-    }
 }
 
 void
-xbaeComputeCellColors(XbaeMatrixWidget mw,
-			int row,
-			int column,
-			Pixel *fg,
-			Pixel *bg)
+xbaeComputeCellColors(mw, row, column, fg, bg)
+XbaeMatrixWidget mw;
+int row, column;
+Pixel *fg, *bg;
 {
     Boolean alt = mw->matrix.alt_row_count ?
 	(row / mw->matrix.alt_row_count) % 2 : False;
@@ -1136,20 +948,18 @@ xbaeComputeCellColors(XbaeMatrixWidget mw,
 }
 
 void
-xbaeDrawCell(XbaeMatrixWidget mw, int row, int column)
+xbaeDrawCell(mw, row, column)
+XbaeMatrixWidget mw;
+int row, column;
 {
     Pixel bg, fg;
     String string;
     int x, y;
-
+    
     if (mw->matrix.disable_redisplay || mw->matrix.rows == 0 ||
 	mw->matrix.columns == 0)
 	return;
 
-#ifdef XBAE_VERBOSE
-    fprintf(stderr, "xbaeDrawCell: %d %d\n", row, column);
-#endif
-
     /*
      * Convert the row/column to the coordinates relative to the correct
      * window
@@ -1158,10 +968,13 @@ xbaeDrawCell(XbaeMatrixWidget mw, int row, int column)
 
     xbaeComputeCellColors(mw, row, column, &fg, &bg);
 
+#if CELL_WIDGETS
     if (mw->matrix.cell_widgets && mw->matrix.cell_widgets[row][column])
 	xbaeDrawCellWidget(mw, row, column, x, y,
 			   mw->matrix.cell_widgets[row][column], bg, fg);
     else
+#endif
+
 	if (!mw->matrix.draw_cell_callback)
 	{
 	    if (row < mw->matrix.rows && column < mw->matrix.columns)
@@ -1194,17 +1007,17 @@ xbaeDrawCell(XbaeMatrixWidget mw, int row, int column)
 }
 
 XbaeCellType
-xbaeGetDrawCellValue(XbaeMatrixWidget mw,
-			int row,
-			int column,
-			String *string,
-			Pixmap *pixmap,
-			Pixmap *mask,
-			int *width,
-			int *height,
-			Pixel *bg,
-			Pixel  *fg,
-			int *depth)
+xbaeGetDrawCellValue(mw, row, column, string, pixmap, mask, width,
+		     height, bg, fg, depth)
+XbaeMatrixWidget mw;
+int row;
+int column;
+String *string;
+Pixmap *pixmap;
+Pixmap *mask;
+int *width, *height;
+Pixel *bg, *fg;
+int *depth;
 {
     XbaeMatrixDrawCellCallbackStruct call_data;
 
@@ -1213,11 +1026,7 @@ xbaeGetDrawCellValue(XbaeMatrixWidget mw,
     call_data.row = row;
     call_data.column = column;
     call_data.width = COLUMN_WIDTH(mw, column) - TEXT_WIDTH_OFFSET(mw) * 2;
-#ifdef	HAVE_ROW_HEIGHTS
-    call_data.height = SOME_ROW_HEIGHT(mw, row) - TEXT_HEIGHT_OFFSET(mw) * 2;
-#else
     call_data.height = ROW_HEIGHT(mw) - TEXT_HEIGHT_OFFSET(mw) * 2;
-#endif
     call_data.type = XbaeString;
     call_data.string = "";
     call_data.pixmap = (Pixmap)NULL;
@@ -1305,7 +1114,14 @@ xbaeGetDrawCellValue(XbaeMatrixWidget mw,
  * fixed and non-fixed columns.
  */
 void
+#if NeedFunctionPrototypes
 xbaeDrawColumnLabel(XbaeMatrixWidget mw, int column, Boolean pressed)
+#else
+xbaeDrawColumnLabel(mw, column, pressed)
+XbaeMatrixWidget mw;
+int column;
+Boolean pressed;
+#endif
 {
     String label;
     int labelX, labelY;
@@ -1387,10 +1203,9 @@ xbaeDrawColumnLabel(XbaeMatrixWidget mw, int column, Boolean pressed)
 	    xbaeDrawString(mw, XtWindow(mw), gc, label,
 			   mw->matrix.column_label_lines[column].lengths[i],
 			   labelX, labelY, mw->matrix.column_widths[column],
-                         -1,
 			   mw->matrix.column_label_alignments ?
 			   mw->matrix.column_label_alignments[column] :
-                         XmALIGNMENT_BEGINNING, False,
+			   XmALIGNMENT_BEGINNING, False,
 			   mw->matrix.bold_labels, False, True,
 			   mw->matrix.column_label_color);
 	
@@ -1409,12 +1224,16 @@ xbaeDrawColumnLabel(XbaeMatrixWidget mw, int column, Boolean pressed)
  * non-fixed rows.
  */
 void
+#if NeedFunctionPrototypes
 xbaeDrawRowLabel(XbaeMatrixWidget mw, int row, Boolean pressed)
-{
-    int		y;
-#ifdef	HAVE_ROW_HEIGHTS
-    int		 i;
+#else
+xbaeDrawRowLabel(mw, row, pressed)
+XbaeMatrixWidget mw;
+int row;
+Boolean pressed;
 #endif
+{
+    int y;
     GC gc;
     Window win = XtWindow(mw);
     Boolean clipped = (row >= (int)mw->matrix.fixed_rows &&
@@ -1426,50 +1245,19 @@ xbaeDrawRowLabel(XbaeMatrixWidget mw, int row, Boolean pressed)
     if (mw->matrix.row_labels[row][0] == '\0' && !button)
 	return;
 
-#ifdef	HAVE_ROW_HEIGHTS
-    /*
-     * FIX ME - This is simplistic.
-     *
-     * Don't draw a label unless there's enough space for it
-     */
-    if (mw->matrix.row_heights[row] < ROW_HEIGHT(mw))
-	return;
-#endif
-
     /*
      * If the row label is in a fixed row we don't need to account
      * for the vert_origin
      */
-#ifdef	HAVE_ROW_HEIGHTS
-    if (row < (int)mw->matrix.fixed_rows) {
-	if (mw->matrix.row_heights) {
-	    y = ROW_LABEL_OFFSET(mw) + TEXT_Y_OFFSET(mw);
-	    for (i=0; i<row; i++)
-		y += mw->matrix.row_heights[i];
-	} else {
-	    y = ROW_LABEL_OFFSET(mw) + ROW_HEIGHT(mw) * row + TEXT_Y_OFFSET(mw);
-	}
-    } else if (row >= TRAILING_VERT_ORIGIN(mw)) {
-	y = TRAILING_FIXED_ROW_LABEL_OFFSET(mw) +
-	    TEXT_Y_OFFSET(mw);
-	for (i=TRAILING_VERT_ORIGIN(mw); i<row; i++)
-		y += mw->matrix.row_heights[i];
-    } else {
-	y = ROW_LABEL_OFFSET(mw) + LABEL_Y_OFFSET(mw) - mw->matrix.first_row_offset;
-	for (i=VERT_ORIGIN(mw); i<row; i++)
-		y += mw->matrix.row_heights[i];
-    }
-#else
     if (row < (int)mw->matrix.fixed_rows)
-        y = ROW_LABEL_OFFSET(mw) + ROW_HEIGHT(mw) * row + TEXT_Y_OFFSET(mw);
+	y = ROW_LABEL_OFFSET(mw) + ROW_HEIGHT(mw) * row + TEXT_Y_OFFSET(mw);
     else if (row >= TRAILING_VERT_ORIGIN(mw))
-        y = TRAILING_FIXED_ROW_LABEL_OFFSET(mw) +
-            ROW_HEIGHT(mw) * (row - TRAILING_VERT_ORIGIN(mw)) +
-            TEXT_Y_OFFSET(mw);
-    else 
-        y = ROW_LABEL_OFFSET(mw) + ROW_HEIGHT(mw) * (row - VERT_ORIGIN(mw)) +
-            LABEL_Y_OFFSET(mw) - mw->matrix.first_row_offset;
-#endif
+	y = TRAILING_FIXED_ROW_LABEL_OFFSET(mw) +
+	    ROW_HEIGHT(mw) * (row - TRAILING_VERT_ORIGIN(mw)) +
+	    TEXT_Y_OFFSET(mw);
+    else
+	y = ROW_LABEL_OFFSET(mw) + ROW_HEIGHT(mw) * (row - VERT_ORIGIN(mw)) +
+	    LABEL_Y_OFFSET(mw) - mw->matrix.first_row_offset;
 
     if (clipped)
 	gc = mw->matrix.label_clip_gc;
@@ -1489,14 +1277,13 @@ xbaeDrawRowLabel(XbaeMatrixWidget mw, int row, Boolean pressed)
 
     if (mw->matrix.row_labels[row][0] != '\0')
 	xbaeDrawString(mw, win, gc,
-		mw->matrix.row_labels[row],
-		strlen(mw->matrix.row_labels[row]),
-		TEXT_X_OFFSET(mw) + VERT_SB_OFFSET(mw), y,
-		mw->matrix.row_label_width,	/* width clip */
-		-1,				/* height clip */
-		mw->matrix.row_label_alignment, False,
-		mw->matrix.bold_labels, True, False,
-		mw->matrix.row_label_color);
+		       mw->matrix.row_labels[row],
+		       strlen(mw->matrix.row_labels[row]),
+		       TEXT_X_OFFSET(mw) + VERT_SB_OFFSET(mw), y,
+		       mw->matrix.row_label_width,
+		       mw->matrix.row_label_alignment, False,
+		       mw->matrix.bold_labels, True, False,
+		       mw->matrix.row_label_color);
     
     if (button)
 	xbaeDrawCellShadow(mw, win, row, -1, VERT_SB_OFFSET(mw),
