@@ -1,6 +1,5 @@
 /*
  * Copyright(c) 1999 Andrew Lister
- * Copyright (c) 1999-2000 by the LessTif Developers.
  *
  *                        All rights reserved
  * Permission to use, copy, modify and distribute this material for
@@ -22,7 +21,7 @@
  *
  * Author: Andrew Lister
  *
- * $Id: Input.c,v 1.8 2000/09/01 20:04:33 amai Exp $
+ * $Id: Input.c,v 1.1 1999/08/04 19:46:55 danny Exp $
  */
 
 /*#define DEBUG*/
@@ -31,12 +30,10 @@
 #include <XbaeConfig.h>
 #endif
 
-#include <stdio.h>
-#include <ctype.h>
-
 /* For memmove/bcopy */
 #include <string.h>
 
+#include <ctype.h>
 #include <Xbae/InputP.h>
 #if XmVersion <= 1001
 #include <Xm/XmP.h>
@@ -48,7 +45,7 @@
 #define XBAE_NEED_BCOPY
 #endif
 
-#if !defined(XBAE_NEED_BCOPY) || defined(SVR4) || defined(VMS)
+#if !defined(XBAE_NEED_BCOPY) || defined(SVR4) || defined(VMS) || defined(__EMX__)
 #define BCOPY(src, dest, n)     memmove((void *)(dest), (void *)(src), (n))
 #else
 #define BCOPY(src, dest, n)     bcopy((void *)(src), (void *)(dest), (n))
@@ -79,22 +76,22 @@
 /* Declaration of Actions */
 
 /* ARGSUSED */
-static void ToggleOverwriteACT(Widget, XEvent *,
-				  String *, Cardinal *nparams);
+static void ToggleOverwriteACT P((Widget, XEvent *,
+				  String *, Cardinal *nparams));
 
-static void validate(Widget, XtPointer, XtPointer);
+static void validate P((Widget, XtPointer, XtPointer));
 
 /* Declaration of Methods */
-static void Initialize(Widget, Widget, ArgList, Cardinal *);
-static Boolean SetValues(Widget, Widget, Widget, ArgList, Cardinal *);
-static void Destroy(Widget);
+static void Initialize P((Widget, Widget, ArgList, Cardinal *));
+static Boolean SetValues P((Widget, Widget, Widget, ArgList, Cardinal *));
+static void Destroy P((Widget));
 
 /* Utility routines */
-static void parsePattern(XbaeInputWidget, String);
-static int match(XbaeInputWidget, char *, int);
+static void parsePattern P((XbaeInputWidget, String));
+static int match P((XbaeInputWidget, char *, int));
 
 /* Internal callbacks */
-static void checkInput(Widget, XtPointer, XtPointer);
+static void checkInput P((Widget, XtPointer, XtPointer));
 
 static char defaultTranslations[] =
 "<Key>osfInsert : ToggleOverwrite()\n\
@@ -200,7 +197,10 @@ WidgetClass xbaeInputWidgetClass = (WidgetClass) &xbaeInputClassRec;
 
 /*ARGSUSED*/
 static void
-validate(Widget w, XtPointer cd, XtPointer cb)
+validate(w, cd, cb)
+Widget w;
+XtPointer cd;
+XtPointer cb;
 {
     XmAnyCallbackStruct *cbs = (XmAnyCallbackStruct *)cb;
     XmTextVerifyCallbackStruct *vcbs = (XmTextVerifyCallbackStruct *)cb;
@@ -296,7 +296,11 @@ validate(Widget w, XtPointer cd, XtPointer cb)
 
 /* ARGSUSED */
 static void
-ToggleOverwriteACT(Widget w, XEvent *event, String *params, Cardinal *nparams)
+ToggleOverwriteACT(w, event, params, nparams)
+Widget w;
+XEvent *event;
+String *params;
+Cardinal *nparams;
 {
     XbaeInputWidget iw = (XbaeInputWidget)w;
 
@@ -314,7 +318,10 @@ ToggleOverwriteACT(Widget w, XEvent *event, String *params, Cardinal *nparams)
 
 
 static void
-Initialize(Widget request, Widget new, ArgList args, Cardinal *num_args)
+Initialize(request, new, args, num_args)
+Widget request, new;
+ArgList args;
+Cardinal *num_args;
 {
     XbaeInputWidget iw = (XbaeInputWidget)new;
 
@@ -355,8 +362,10 @@ Initialize(Widget request, Widget new, ArgList args, Cardinal *num_args)
 }
 
 static Boolean
-SetValues(Widget current, Widget request, Widget new,
-	  ArgList args, Cardinal *num_args)
+SetValues(current, request, new, args, num_args)
+Widget current, request, new;
+ArgList args;
+Cardinal *num_args;
 {
     XbaeInputWidget c = (XbaeInputWidget)current;
     XbaeInputWidget n = (XbaeInputWidget)new;
@@ -414,7 +423,8 @@ SetValues(Widget current, Widget request, Widget new,
 }
 
 static void
-Destroy(Widget w)
+Destroy(w)
+Widget w;
 {
     XbaeInputWidget iw = (XbaeInputWidget)w;
 
@@ -423,7 +433,9 @@ Destroy(Widget w)
 }
 
 static void
-parsePattern(XbaeInputWidget iw, String pattern)
+parsePattern(iw, pattern)
+XbaeInputWidget iw;
+String pattern;
 {
     char *ptr = pattern;
     Boolean optional = False;
@@ -502,7 +514,10 @@ parsePattern(XbaeInputWidget iw, String pattern)
 }
 
 static int
-match(XbaeInputWidget iw, char *string, int exact)
+match(iw, string, exact)
+XbaeInputWidget iw;
+char *string;
+int exact;
 {
     char *tptr, *sptr, *ntptr;
     char *lastopt = NULL;	/* last optional block */
@@ -679,9 +694,10 @@ match(XbaeInputWidget iw, char *string, int exact)
 		while (*tptr &&
 		       (*tptr != CHAR_EOPTION || *(tptr-1) == CHAR_ESCAPE))
 		    tptr++;
-		if (!*tptr) {
-		    (void)fprintf(stderr, "Mismatched parentheses\n");	/* FIX ME */
-		} else {
+		if (!*tptr)
+		    (void)fprintf(stderr, "Mismatched parentheses\n");
+		else
+		{
 		    tptr++;	/* move past the ']' */
 #ifdef OLD
 		    if (!lastopt)
@@ -871,7 +887,10 @@ match(XbaeInputWidget iw, char *string, int exact)
 
 /*ARGSUSED*/
 static void
-checkInput(Widget w, XtPointer cd, XtPointer cb)
+checkInput(w, cd, cb)
+Widget w;
+XtPointer cd;
+XtPointer cb;
 {
     XbaeInputWidget iw = (XbaeInputWidget)w;
     XmTextVerifyCallbackStruct *cbs = (XmTextVerifyCallbackStruct *)cb;
@@ -890,21 +909,6 @@ checkInput(Widget w, XtPointer cd, XtPointer cb)
     if (cbs->startPos < cbs->currInsert || cbs->text->length == 0 ||
 	!cbs->text->ptr || *cbs->text->ptr == 0)
     {
-#if 1
-	/*
-	 * Fix by Anphong Nguyen <anphongn@davsys.com> :
-	 * codes added to move the cursor back one position, instead of deleting
-	 * the character because in overstriking mode, user uses backspace key
-	 * to move the cursor to overwrite the text, not to delete the character
-	 * then inserting a new value */
-	if (iw->input.overwrite_mode == True) {
-#if 0
-		fprintf(stderr, "Yow\n");
-#endif
-		XmTextSetInsertionPosition((Widget)iw,(cbs->currInsert - 1));
-		cbs->doit = False;
-	}
-#endif
 	/*
 	 * Allow a backspace or delete to do it's bit.
 	 */	
@@ -1039,7 +1043,11 @@ checkInput(Widget w, XtPointer cd, XtPointer cb)
 }
 
 Widget
-XbaeCreateInput(Widget parent, String name, ArgList args, Cardinal ac) 
+XbaeCreateInput(parent, name, args, ac) 
+Widget parent;
+String name;
+ArgList args;
+Cardinal ac;
 { 
     return XtCreateWidget(name, xbaeInputWidgetClass, parent, args, ac); 
 } 
