@@ -1,8 +1,6 @@
 /*
  * Copyright(c) 1992 Bell Communications Research, Inc. (Bellcore)
  * Copyright(c) 1995-99 Andrew Lister
- * Copyright (c) 1999-2000 by the LessTif Developers.
- *
  *                        All rights reserved
  * Permission to use, copy, modify and distribute this material for
  * any purpose and without fee is hereby granted, provided that the
@@ -22,7 +20,7 @@
  * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
  * ING TO THE SOFTWARE.
  *
- * $Id: Shadow.c,v 1.8 2000/09/01 20:04:33 amai Exp $
+ * $Id: Shadow.c,v 1.1 1999/08/04 19:47:01 danny Exp $
  */
 
 
@@ -44,33 +42,41 @@
 #include <Xbae/Shadow.h>
 #include <Xbae/Draw.h>
 #include <Xbae/Utils.h>
-#ifdef XBAE_VERBOSE
-#include <stdio.h>
-#endif
 
-static void DrawRowShadow(XbaeMatrixWidget, Window, int, int, int,
-			     int, int, int, GC, GC);
+static void DrawRowShadow P((XbaeMatrixWidget, Window, int, int, int,
+			     int, int, int, GC, GC));
 
-static void DrawColumnShadow(XbaeMatrixWidget, Window, int, int, int,
-				int, int, int, GC, GC);
+static void DrawColumnShadow P((XbaeMatrixWidget, Window, int, int, int,
+				int, int, int, GC, GC));
 
-static void DrawRowHighlight(XbaeMatrixWidget, Window, GC, int, int,
-				 int, int, int, int, int);
-static void DrawColumnHighlight(XbaeMatrixWidget, Window, GC, int,
-				    int, int, int, int, int, int);
+static void DrawRowHighlight P((XbaeMatrixWidget, Window, GC, int, int,
+				 int, int, int, int, int));
+static void DrawColumnHighlight P((XbaeMatrixWidget, Window, GC, int,
+				    int, int, int, int, int, int));
 
 void
+#if NeedFunctionPrototypes
 xbaeDrawCellShadow(XbaeMatrixWidget mw, Window win, int row, int column, int x,
 		   int y, int width, int height, Boolean label,
 		   Boolean clipped, Boolean pressed)
+#else
+xbaeDrawCellShadow(mw, win, row, column, x, y, width, height, label, clipped,
+		   pressed)
+XbaeMatrixWidget mw;
+Window win;
+int row;
+int column;
+int x;
+int y;
+int width;
+int height;
+Boolean label;
+Boolean clipped;
+Boolean pressed;
+#endif
 {
     unsigned char grid_type;
     unsigned char shadow;
-
-#ifdef	XBAE_VERBOSE
-    fprintf(stderr, "xbaeDrawCellShadow [%d,%d] wid %d, ht %d\n",
-		row, column, width, height);
-#endif
     
     if ((mw->matrix.cell_shadow_thickness == 0) &&
 	(!IN_GRID_ROW_MODE(mw)) && (!IN_GRID_COLUMN_MODE(mw)))
@@ -97,7 +103,7 @@ xbaeDrawCellShadow(XbaeMatrixWidget mw, Window win, int row, int column, int x,
 	switch (grid_type)
 	{
 	    case XmGRID_CELL_SHADOW:
-		DRAW_SHADOW(XtDisplay(mw), win, "win",
+		DRAW_SHADOW(XtDisplay(mw), win,
 			    mw->matrix.cell_top_shadow_clip_gc,
 			    mw->matrix.cell_bottom_shadow_clip_gc,
 			    mw->matrix.cell_shadow_thickness,
@@ -106,14 +112,14 @@ xbaeDrawCellShadow(XbaeMatrixWidget mw, Window win, int row, int column, int x,
 
 	    /* Deprecated types. To be removed in next version. */
 	    case XmGRID_SHADOW_OUT:
-		DRAW_SHADOW(XtDisplay(mw), win, "win",
+		DRAW_SHADOW(XtDisplay(mw), win,
 			    mw->matrix.cell_bottom_shadow_clip_gc,
 			    mw->matrix.cell_top_shadow_clip_gc,
 			    mw->matrix.cell_shadow_thickness,
 			    x, y, width, height, shadow);
 		break;
 	    case XmGRID_SHADOW_IN:
-		DRAW_SHADOW(XtDisplay(mw), win, "win",
+		DRAW_SHADOW(XtDisplay(mw), win,
 			    mw->matrix.cell_top_shadow_clip_gc,
 			    mw->matrix.cell_bottom_shadow_clip_gc,
 			    mw->matrix.cell_shadow_thickness,
@@ -146,14 +152,14 @@ xbaeDrawCellShadow(XbaeMatrixWidget mw, Window win, int row, int column, int x,
 			     mw->matrix.grid_line_gc, mw->matrix.grid_line_gc);
 	    break;
 	case XmGRID_CELL_LINE:
-	    DRAW_SHADOW(XtDisplay(mw), win, "win",
+	    DRAW_SHADOW(XtDisplay(mw), win,
 			mw->matrix.grid_line_gc,
 			mw->matrix.grid_line_gc,
 			mw->matrix.cell_shadow_thickness,
 			x, y, width, height, shadow);
 	    break;
 	case XmGRID_CELL_SHADOW:
-	    DRAW_SHADOW(XtDisplay(mw), win, "win",
+	    DRAW_SHADOW(XtDisplay(mw), win,
 			mw->manager.top_shadow_GC,
 			mw->manager.bottom_shadow_GC,
 			mw->matrix.cell_shadow_thickness,
@@ -162,21 +168,21 @@ xbaeDrawCellShadow(XbaeMatrixWidget mw, Window win, int row, int column, int x,
 
 	/* Deprecated types. To be removed in next version. */
 	case XmGRID_LINE:
-	    DRAW_SHADOW(XtDisplay(mw), win, "win",
+	    DRAW_SHADOW(XtDisplay(mw), win,
 			mw->matrix.grid_line_gc,
 			mw->matrix.grid_line_gc,
 			mw->matrix.cell_shadow_thickness,
 			x, y, width, height, shadow);
 	    break;
 	case XmGRID_SHADOW_OUT:
-	    DRAW_SHADOW(XtDisplay(mw), win, "win",
+	    DRAW_SHADOW(XtDisplay(mw), win,
 			mw->manager.bottom_shadow_GC,
 			mw->manager.top_shadow_GC,
 			mw->matrix.cell_shadow_thickness,
 			x, y, width, height, shadow);
 	    break;
 	case XmGRID_SHADOW_IN:
-	    DRAW_SHADOW(XtDisplay(mw), win, "win",
+	    DRAW_SHADOW(XtDisplay(mw), win,
 			mw->manager.top_shadow_GC,
 			mw->manager.bottom_shadow_GC,
 			mw->matrix.cell_shadow_thickness,
@@ -188,24 +194,20 @@ xbaeDrawCellShadow(XbaeMatrixWidget mw, Window win, int row, int column, int x,
 
 #if XmVersion >= 1002
 void
-xbaeDrawCellHighlight(XbaeMatrixWidget mw,
-	Window win,
-	GC gc,
-	int row,
-	int column,
-	int x,
-	int y,
-	int width,
-	int height,
-	int reason)
+xbaeDrawCellHighlight(mw, win, gc, row, column, x, y, width, height, reason)
+XbaeMatrixWidget mw;
+Window win;
+GC gc;
+int row;
+int column;
+int x;
+int y;
+int width;
+int height;
+int reason;
 {    
     int thick;
 
-#ifdef	XBAE_VERBOSE
-    fprintf(stderr, "xbaeDrawCellHighlight [%d,%d], wid %d, ht %d\n",
-		row, column, width, height);
-#endif
-
     if (!mw->matrix.highlighted_cells) /* Just a precaution */
 	return;
 
@@ -239,24 +241,20 @@ xbaeDrawCellHighlight(XbaeMatrixWidget mw,
 }
 
 static void
-DrawRowHighlight(XbaeMatrixWidget mw,
-	Window win,
-	GC gc,
-	int row,
-	int column,
-	int x,
-	int y,
-	int width,
-	int height,
-	int reason)
-{
+DrawRowHighlight(mw, win, gc, row, column, x, y, width, height, reason)
+XbaeMatrixWidget mw;
+Window win;
+GC gc;
+int row;
+int column;
+int x;
+int y;
+int width;
+int height;
+int reason;
+{    
     XRectangle rect[1];
-
-#ifdef	XBAE_VERBOSE
-    fprintf(stderr, "DrawRowHighlight [%d,%d] wid %d ht %d\n",
-		row, column, width, height);
-#endif
-
+    
     rect[0].x = 0;
     rect[0].y = 0;
     rect[0].width = width;
@@ -316,17 +314,18 @@ DrawRowHighlight(XbaeMatrixWidget mw,
 }
 
 static void
-DrawColumnHighlight(XbaeMatrixWidget mw,
-	Window win,
-	GC gc,
-	int row,
-	int column,
-	int x,
-	int y,
-	int width,
-	int height,
-	int reason)
-{
+DrawColumnHighlight(mw, win, gc, row, column, x, y, width, height, reason)
+XbaeMatrixWidget mw;
+Window win;
+GC gc;
+int row;
+int column;
+int x;
+int y;
+int width;
+int height;
+int reason;
+{    
     XRectangle rect[1];
     int vert_dead_space_height = VERT_DEAD_SPACE_HEIGHT(mw);
     int clip_vert_visible_space = CLIP_VERT_VISIBLE_SPACE(mw);
@@ -420,26 +419,22 @@ DrawColumnHighlight(XbaeMatrixWidget mw,
 #endif
 
 static void
-DrawRowShadow(XbaeMatrixWidget mw,
-	Window win,
-	int row,
-	int column,
-	int x,
-	int y,
-	int width,
-	int height,
-	GC  topGC,
-	GC  bottomGC)
+DrawRowShadow(mw, win, row, column, x, y, width, height, topGC, bottomGC)
+XbaeMatrixWidget mw;
+Window win;
+int row;
+int column;
+int x;
+int y;
+int width;
+int height;
+GC  topGC;
+GC  bottomGC;
 {
     XRectangle rect[1];
     unsigned char shadow = mw->matrix.row_shadow_types ?
 	mw->matrix.row_shadow_types[row] : mw->matrix.cell_shadow_type;
 
-#ifdef	XBAE_VERBOSE
-    fprintf(stderr, "DrawRowShadow [%d,%d] wid %d, ht %d\n",
-		row, column, width, height);
-#endif
-
     rect[0].x = 0;
     rect[0].y = 0;
     rect[0].width = width;
@@ -468,7 +463,7 @@ DrawRowShadow(XbaeMatrixWidget mw,
 	if (column != 0)
 	    x -= mw->matrix.cell_shadow_thickness;
 
-	DRAW_SHADOW(XtDisplay(mw), win, "win",
+	DRAW_SHADOW(XtDisplay(mw), win,
 		    topGC, bottomGC,
 		    mw->matrix.cell_shadow_thickness,
 		    x, y, width, height, shadow);
@@ -484,7 +479,7 @@ DrawRowShadow(XbaeMatrixWidget mw,
 	else
 	    width += mw->matrix.cell_shadow_thickness;
 
-	DRAW_SHADOW(XtDisplay(mw), win, "win",
+	DRAW_SHADOW(XtDisplay(mw), win,
 		    topGC, bottomGC,
 		    mw->matrix.cell_shadow_thickness,
 		    x - mw->matrix.cell_shadow_thickness, y, width,
@@ -519,7 +514,7 @@ DrawRowShadow(XbaeMatrixWidget mw,
 	     */
 
 	    if ((win == XtWindow(ClipChild(mw))) &&
-		(height != SOME_ROW_HEIGHT(mw, row)))
+		(height != ROW_HEIGHT(mw)))
 	    {
 		if (height == (ClipChild(mw)->core.height +
 			       ClipChild(mw)->core.y - ay))
@@ -538,7 +533,7 @@ DrawRowShadow(XbaeMatrixWidget mw,
 	     * we've got trailing fixed columns. */
 	    if (mw->matrix.trailing_fixed_columns &&
 		(win == XtWindow(RightClip(mw))) &&
-		(height != SOME_ROW_HEIGHT(mw, row)))
+		(height != ROW_HEIGHT(mw)))
 	    {
 		if (height == (RightClip(mw)->core.height +
 			       RightClip(mw)->core.y - ay))
@@ -554,7 +549,7 @@ DrawRowShadow(XbaeMatrixWidget mw,
 	    /*
 	     * Draw the remaining shadow directly onto the matrix window
 	     */
-	    DRAW_SHADOW(XtDisplay(mw), XtWindow(mw), "win",
+	    DRAW_SHADOW(XtDisplay(mw), XtWindow(mw),
 			topGC, bottomGC,
 			mw->matrix.cell_shadow_thickness,
 			ax - mw->matrix.cell_shadow_thickness,
@@ -573,16 +568,17 @@ DrawRowShadow(XbaeMatrixWidget mw,
 }
 
 static void
-DrawColumnShadow(XbaeMatrixWidget mw,
-	Window win,
-	int row,
-	int column,
-	int x,
-	int y,
-	int width,
-	int height,
-	GC  topGC,
-	GC  bottomGC)
+DrawColumnShadow(mw, win, row, column, x, y, width, height, topGC, bottomGC)
+XbaeMatrixWidget mw;
+Window win;
+int row;
+int column;
+int x;
+int y;
+int width;
+int height;
+GC  topGC;
+GC  bottomGC;
 {
     XRectangle rect[1];
     unsigned char shadow = mw->matrix.column_shadow_types ?
@@ -629,7 +625,7 @@ DrawColumnShadow(XbaeMatrixWidget mw,
 	if (row != 0)
 	    y -= mw->matrix.cell_shadow_thickness;
 
-	DRAW_SHADOW(XtDisplay(mw), win, "win",
+	DRAW_SHADOW(XtDisplay(mw), win,
 		    topGC, bottomGC,
 		    mw->matrix.cell_shadow_thickness,
 		    x, y, width, height, shadow);
@@ -645,7 +641,7 @@ DrawColumnShadow(XbaeMatrixWidget mw,
 	else
 	    height += mw->matrix.cell_shadow_thickness;
 
-	DRAW_SHADOW(XtDisplay(mw), win, "win",
+	DRAW_SHADOW(XtDisplay(mw), win,
 		    topGC, bottomGC,
 		    mw->matrix.cell_shadow_thickness,
 		    x, y - mw->matrix.cell_shadow_thickness,
@@ -745,7 +741,7 @@ DrawColumnShadow(XbaeMatrixWidget mw,
 	    /*
 	     * Draw the remaining shadow directly onto the matrix window
 	     */
-	    DRAW_SHADOW(XtDisplay(mw), XtWindow(mw), "win",
+	    DRAW_SHADOW(XtDisplay(mw), XtWindow(mw),
 			topGC, bottomGC,
 			mw->matrix.cell_shadow_thickness,
 			ax, ay - mw->matrix.cell_shadow_thickness,
