@@ -1,8 +1,6 @@
 /*
  * Copyright(c) 1992 Bell Communications Research, Inc. (Bellcore)
  * Copyright(c) 1995-99 Andrew Lister
- * Copyright (c) 1999-2000 by the LessTif Developers.
- *
  *                        All rights reserved
  * Permission to use, copy, modify and distribute this material for
  * any purpose and without fee is hereby granted, provided that the
@@ -24,7 +22,7 @@
  *
  * MatrixWidget Author: Andrew Wason, Bellcore, aw@bae.bellcore.com
  *
- * $Id: Utils.c,v 1.20 2000/09/01 20:04:33 amai Exp $
+ * $Id: Utils.c,v 1.2 1999/09/16 19:42:32 danny Exp $
  */
 
 /*
@@ -41,43 +39,26 @@
 #include <Xbae/Utils.h>
 #include <Xbae/Actions.h>
 #include <Xm/ScrollBar.h>
-#ifdef XBAE_VERBOSE
-#include <stdio.h>
-#endif
-
 /*
  * Return the top and bottom-most visible non-fixed row
  */
 void
-xbaeGetVisibleRows(XbaeMatrixWidget mw, int *top_row, int *bottom_row)
+xbaeGetVisibleRows(mw, top_row, bottom_row)
+XbaeMatrixWidget mw;
+int *top_row, *bottom_row;
 {
-#ifdef	HAVE_ROW_HEIGHTS
-    int		i;
-    Dimension	h;
-
-    *top_row = VERT_ORIGIN(mw) + mw->matrix.fixed_rows;
-    h = 0;
-    for (i=VERT_ORIGIN(mw); i<mw->matrix.rows && h < VISIBLE_HEIGHT(mw); i++)
-	h += mw->matrix.row_heights[i];
-    *bottom_row = i;
-
-#ifdef	XBAE_VERBOSE
-    fprintf(stderr, "xbaeGetVisibleRows -> top %d bottom %d\n", *top_row, *bottom_row);
-#endif
-
-    SANITY_CHECK_ROW(mw, *bottom_row);
-#else
     *top_row = VERT_ORIGIN(mw) + mw->matrix.fixed_rows;
     *bottom_row = *top_row + (VISIBLE_HEIGHT(mw) - 1) / ROW_HEIGHT(mw);
     SANITY_CHECK_ROW(mw, *bottom_row);
-#endif
 }
 
 /*
  * Return the left and right-most visible non-fixed column
  */
 void
-xbaeGetVisibleColumns(XbaeMatrixWidget mw, int *left_column, int *right_column)
+xbaeGetVisibleColumns(mw, left_column, right_column)
+XbaeMatrixWidget mw;
+int *left_column, *right_column;
 {
     *left_column = xbaeXtoCol(mw, FIXED_COLUMN_WIDTH(mw) + HORIZ_ORIGIN(mw));
     *right_column = xbaeXtoCol(mw, FIXED_COLUMN_WIDTH(mw) + HORIZ_ORIGIN(mw) +
@@ -89,9 +70,9 @@ xbaeGetVisibleColumns(XbaeMatrixWidget mw, int *left_column, int *right_column)
  * the visible non-fixed cells
  */
 void
-xbaeGetVisibleCells(XbaeMatrixWidget mw,
-	int *top_row, int *bottom_row,
-	int *left_column, int *right_column)
+xbaeGetVisibleCells(mw, top_row, bottom_row, left_column, right_column)
+XbaeMatrixWidget mw;
+int *top_row, *bottom_row, *left_column, *right_column;
 {
     xbaeGetVisibleRows(mw, top_row, bottom_row);
     xbaeGetVisibleColumns(mw, left_column, right_column);
@@ -104,7 +85,8 @@ xbaeGetVisibleCells(XbaeMatrixWidget mw,
  * If we can't make leftColumn the left column, make it as close as possible.
  */
 void
-xbaeAdjustLeftColumn(XbaeMatrixWidget mw)
+xbaeAdjustLeftColumn(mw)
+XbaeMatrixWidget mw;
 {
     int y;
     int i;
@@ -156,13 +138,10 @@ xbaeAdjustLeftColumn(XbaeMatrixWidget mw)
  * If we can't make topRow the top row, make it as close as possible.
  */
 void
-xbaeAdjustTopRow(XbaeMatrixWidget mw)
+xbaeAdjustTopRow(mw)
+XbaeMatrixWidget mw;
 {
-#ifdef	HAVE_ROW_HEIGHTS
-    int rows_visible = VISIBLE_HEIGHT(mw) / SOME_ROW_HEIGHT(mw, mw->matrix.top_row);
-#else
     int rows_visible = VISIBLE_HEIGHT(mw) / ROW_HEIGHT(mw);
-#endif
 
     /*
      * If we have less than one full row visible, then count it as a full row
@@ -190,7 +169,9 @@ xbaeAdjustTopRow(XbaeMatrixWidget mw)
  * Does not check if the cell is actually visible before clearing it.
  */
 void
-xbaeClearCell(XbaeMatrixWidget mw, int row, int column)
+xbaeClearCell(mw, row, column)
+XbaeMatrixWidget mw;
+int row, column;
 {
     int x, y;
     Boolean fixed = IS_FIXED(mw, row, column);
@@ -211,16 +192,17 @@ xbaeClearCell(XbaeMatrixWidget mw, int row, int column)
 	 (y < (int)ROW_LABEL_OFFSET(mw))))
 	return;
 #endif
-
     XClearArea(XtDisplay(mw), win, x, y, COLUMN_WIDTH(mw, column),
-	       SOME_ROW_HEIGHT(mw, row), fixed);
+	       ROW_HEIGHT(mw), fixed);
 }
 
 /*
  * Return True if a row is visible on the screen (not scrolled totally off)
  */
 Boolean
-xbaeIsRowVisible(XbaeMatrixWidget mw, int row)
+xbaeIsRowVisible(mw, row)
+XbaeMatrixWidget mw;
+int row;
 {
     /*
      * If we are not in a fixed row or trailing fixed row,
@@ -234,13 +216,13 @@ xbaeIsRowVisible(XbaeMatrixWidget mw, int row)
 	if (row >= VERT_ORIGIN(mw))
 	{
 	    double height = ((double)ClipChild(mw)->core.height /
-			     SOME_ROW_HEIGHT(mw, row)) + VERT_ORIGIN(mw);
+			     ROW_HEIGHT(mw)) + VERT_ORIGIN(mw);
 	    if (row < height)
 		return True;
 	    
 	    if ((int)ClipChild(mw)->core.height >
 		(int)TEXT_HEIGHT_OFFSET(mw) &&
-		(int)ClipChild(mw)->core.height < SOME_ROW_HEIGHT(mw, row) &&
+		(int)ClipChild(mw)->core.height < ROW_HEIGHT(mw) &&
 		row == VERT_ORIGIN(mw))
 
 		return True;
@@ -256,7 +238,9 @@ xbaeIsRowVisible(XbaeMatrixWidget mw, int row)
  * Return True if a column is visible on the screen (not scrolled totally off)
  */
 Boolean
-xbaeIsColumnVisible(XbaeMatrixWidget mw, int column)
+xbaeIsColumnVisible(mw, column)
+XbaeMatrixWidget mw;
+int column;
 {
     /*
      * If we are not in a fixed column, see if we are on the screen
@@ -289,7 +273,9 @@ xbaeIsColumnVisible(XbaeMatrixWidget mw, int column)
  * Return True if a cell is visible on the screen (not scrolled totally off)
  */
 Boolean
-xbaeIsCellVisible(XbaeMatrixWidget mw, int row, int column)
+xbaeIsCellVisible(mw, row, column)
+XbaeMatrixWidget mw;
+int row, column;
 {
     return xbaeIsRowVisible(mw, row) && xbaeIsColumnVisible(mw, column);
 }
@@ -298,9 +284,11 @@ xbaeIsCellVisible(XbaeMatrixWidget mw, int row, int column)
  * Scroll a row so it is visible on the screen.
  */
 void
-xbaeMakeRowVisible(XbaeMatrixWidget mw, int row)
+xbaeMakeRowVisible(mw, row)
+XbaeMatrixWidget mw;
+int row;
 {
-    int rows_visible, rel_row;
+    int rows_visible;
     int value, slider_size, increment, page_increment, vert_value;
 
     /*
@@ -314,8 +302,8 @@ xbaeMakeRowVisible(XbaeMatrixWidget mw, int row)
      * Calculate the number of rows visible. If less than one full
      * row is visible, use one full row.
      */
-    rel_row = row - mw->matrix.fixed_rows;
-    rows_visible = VISIBLE_HEIGHT(mw) / SOME_ROW_HEIGHT(mw, row);
+    row -= mw->matrix.fixed_rows;
+    rows_visible = VISIBLE_HEIGHT(mw) / ROW_HEIGHT(mw);
     if (rows_visible == 0)
 	rows_visible = 1;
 
@@ -323,10 +311,10 @@ xbaeMakeRowVisible(XbaeMatrixWidget mw, int row)
      * Figure out the new value of the VSB to scroll this cell
      * onto the screen (the VSB uses row coordinates instead of pixels)
      */
-    if (rel_row < VERT_ORIGIN(mw))
-	vert_value = rel_row;
-    else if (rel_row >= rows_visible + VERT_ORIGIN(mw))
-	vert_value = rel_row - rows_visible + 1;
+    if (row < VERT_ORIGIN(mw))
+	vert_value = row;
+    else if (row >= rows_visible + VERT_ORIGIN(mw))
+	vert_value = row - rows_visible + 1;
     else
 	vert_value = VERT_ORIGIN(mw);
 
@@ -347,7 +335,9 @@ xbaeMakeRowVisible(XbaeMatrixWidget mw, int row)
  * Scroll a column so it is visible on the screen.
  */
 void
-xbaeMakeColumnVisible(XbaeMatrixWidget mw, int column)
+xbaeMakeColumnVisible(mw, column)
+XbaeMatrixWidget mw;
+int column;
 {
     int value, slider_size, increment, page_increment, x, horiz_value;
 
@@ -373,13 +363,13 @@ xbaeMakeColumnVisible(XbaeMatrixWidget mw, int column)
     else if (x + COLUMN_WIDTH(mw, column) >
 	     VISIBLE_WIDTH(mw) + HORIZ_ORIGIN(mw))
     {
-	int offs = (x + COLUMN_WIDTH(mw, column)) - (VISIBLE_WIDTH(mw) +
+	int off = (x + COLUMN_WIDTH(mw, column)) - (VISIBLE_WIDTH(mw) +
 						    HORIZ_ORIGIN(mw));
 
-	if (x - offs < HORIZ_ORIGIN(mw))
+	if (x - off < HORIZ_ORIGIN(mw))
 	    horiz_value = x;
 	else
-	    horiz_value = HORIZ_ORIGIN(mw) + offs;
+	    horiz_value = HORIZ_ORIGIN(mw) + off;
     }
     else
 	horiz_value = HORIZ_ORIGIN(mw);
@@ -401,7 +391,9 @@ xbaeMakeColumnVisible(XbaeMatrixWidget mw, int column)
  * Scrolls a fixed or non-fixed cell so it is visible on the screen.
  */
 void
-xbaeMakeCellVisible(XbaeMatrixWidget mw, int row, int column)
+xbaeMakeCellVisible(mw, row, column)
+XbaeMatrixWidget mw;
+int row, column;
 {
     if (!xbaeIsRowVisible(mw, row))
 	xbaeMakeRowVisible(mw, row);
@@ -414,7 +406,9 @@ xbaeMakeCellVisible(XbaeMatrixWidget mw, int row, int column)
  * drawing non-fixed column labels and fixed rows.
  */
 void
-xbaeSetClipMask(XbaeMatrixWidget mw, unsigned int clip_reason)
+xbaeSetClipMask(mw, clip_reason)
+XbaeMatrixWidget mw;
+unsigned int clip_reason;
 {
     XRectangle r[2];
     int n = 1;
@@ -494,11 +488,13 @@ xbaeSetClipMask(XbaeMatrixWidget mw, unsigned int clip_reason)
 		       0, 0, r, n, Unsorted);
 }
 
+
 /*
  * Get the total pixel width of the non-fixed cell area
  */
 void
-xbaeGetCellTotalWidth(XbaeMatrixWidget mw)
+xbaeGetCellTotalWidth(mw)
+XbaeMatrixWidget mw;
 {
     int i, columns;
 
@@ -516,7 +512,8 @@ xbaeGetCellTotalWidth(XbaeMatrixWidget mw)
  * Cache the pixel position of each column
  */
 void
-xbaeGetColumnPositions(XbaeMatrixWidget mw)
+xbaeGetColumnPositions(mw)
+XbaeMatrixWidget mw;
 {
     int i, x;
 
@@ -527,24 +524,20 @@ xbaeGetColumnPositions(XbaeMatrixWidget mw)
 }
 
 void
-xbaeGetRowPositions(XbaeMatrixWidget mw)
-{
-    int i, y;
-
-    for (i = 0, y = 0;
-	 i < mw->matrix.rows;
-	 y += SOME_ROW_HEIGHT(mw, i), i++)
-	ROW_POSITION(mw, i) = y;
-}
-
-void
+#if NeedFunctionPrototypes
 xbaeComputeSize(XbaeMatrixWidget mw, Boolean compute_width,
 		Boolean compute_height)
+#else
+xbaeComputeSize(mw, compute_width, compute_height)
+XbaeMatrixWidget mw;
+Boolean compute_width;
+Boolean compute_height;
+#endif
 {
     unsigned long full_width = NON_FIXED_TOTAL_WIDTH(mw) +
 	FIXED_COLUMN_WIDTH(mw) + TRAILING_FIXED_COLUMN_WIDTH(mw) +
 	ROW_LABEL_WIDTH(mw) + 2 * mw->manager.shadow_thickness;
-    unsigned long full_height = xbaeCellTotalHeight(mw) +
+    unsigned long full_height = CELL_TOTAL_HEIGHT(mw) +
 	FIXED_ROW_HEIGHT(mw) + TRAILING_FIXED_ROW_HEIGHT(mw) +
 	COLUMN_LABEL_HEIGHT(mw) + 2 * mw->manager.shadow_thickness;
     unsigned long width, height;
@@ -573,27 +566,14 @@ xbaeComputeSize(XbaeMatrixWidget mw, Boolean compute_width,
      * Otherwise, if the compute_height flag is set, then we are full height.
      * Otherwise we keep whatever height we are.
      */
-    if (mw->matrix.visible_rows) {
-#ifdef HAVE_ROW_HEIGHTS
-	int	i;
-	height = TRAILING_FIXED_ROW_HEIGHT(mw) + FIXED_ROW_HEIGHT(mw) +
-	    COLUMN_LABEL_HEIGHT(mw) + 2 * mw->manager.shadow_thickness;
-
-	for (i=0; i<mw->matrix.visible_rows; i++)
-		if (i < mw->matrix.rows)
-			height += SOME_ROW_HEIGHT(mw, i);
-		else
-			height += ROW_HEIGHT(mw);
-#else
+    if (mw->matrix.visible_rows)
 	height = mw->matrix.visible_rows * ROW_HEIGHT(mw) +
 	    TRAILING_FIXED_ROW_HEIGHT(mw) + FIXED_ROW_HEIGHT(mw) +
 	    COLUMN_LABEL_HEIGHT(mw) + 2 * mw->manager.shadow_thickness;
-#endif
-    } else if (compute_height) {
+    else if (compute_height)
 	height = full_height;
-    } else {
+    else
 	height = mw->core.height;
-    }
 
     /*
      * Store our calculated size.
@@ -632,18 +612,14 @@ xbaeComputeSize(XbaeMatrixWidget mw, Boolean compute_width,
      */
     mw->matrix.desired_width = mw->core.width;
     mw->matrix.desired_height = mw->core.height;
-
-#ifdef	XBAE_VERBOSE
-    fprintf(stderr, "xbaeComputeSize -> w %d h %d\n",
-	mw->matrix.desired_width, mw->matrix.desired_height);
-#endif
 }
 
 /*
  * Return the length of the longest row label
  */
 short
-xbaeMaxRowLabel(XbaeMatrixWidget mw)
+xbaeMaxRowLabel(mw)
+XbaeMatrixWidget mw;
 {
     int i;
     short max = 0, len;
@@ -661,7 +637,9 @@ xbaeMaxRowLabel(XbaeMatrixWidget mw)
 }
 
 void
-xbaeParseColumnLabel(String label, ColumnLabelLines lines)
+xbaeParseColumnLabel(label, lines)
+String label;
+ColumnLabelLines lines;
 {
     char *nl;
 
@@ -707,8 +685,6 @@ xbaeParseColumnLabel(String label, ColumnLabelLines lines)
     }
 }
 
-/* FIX ME : this function contains some as yet unfixed ROW_HEIGHT behaviour.
-   Danny 23/5/2000 */
 /*
  * Convert an x/y pixel position to the row/column cell position it picks.
  * 'cell' specifies whether the x/y coord is relative to the fixed cells
@@ -721,7 +697,11 @@ xbaeParseColumnLabel(String label, ColumnLabelLines lines)
  * may be useful nevertheless.
  */
 Boolean
-xbaeXYToRowCol(XbaeMatrixWidget mw, int *x, int *y, int *row, int *column, CellType cell)
+xbaeXYToRowCol(mw, x, y, row, column, cell)
+XbaeMatrixWidget mw;
+int *x, *y;
+int *row, *column;
+CellType cell;
 {
     Rectangle rect;
     unsigned int inBox = CLIP_NONE;
@@ -1015,7 +995,7 @@ xbaeXYToRowCol(XbaeMatrixWidget mw, int *x, int *y, int *row, int *column, CellT
 		*y += row_height;
 	    }
 	    else
-		*row = xbaeYtoRow(mw, *y) +
+		*row = YtoRow(mw, *y) +
 		    ((((CLIP_FIXED_COLUMNS & inBox) ||
 		       (CLIP_TRAILING_FIXED_COLUMNS & inBox))) &&
 		     !((CLIP_FIXED_ROWS & inBox) ||
@@ -1122,10 +1102,10 @@ xbaeXYToRowCol(XbaeMatrixWidget mw, int *x, int *y, int *row, int *column, CellT
 	if (CLIP_ROW_LABELS & inBox)
 	{
 	    *y -= row_label_offset;
-	    *row = xbaeYtoRow(mw, *y);
+	    *row = YtoRow(mw, *y);
 	    *row += (CLIP_FIXED_ROWS & inBox ? 0 : mw->matrix.top_row);
 	    *row += ((CLIP_TRAILING_FIXED_ROWS & inBox) ?
-		     (xbaeCellTotalHeight(mw) - VISIBLE_HEIGHT(mw)) /
+		     (CELL_TOTAL_HEIGHT(mw) - VISIBLE_HEIGHT(mw)) /
 		     row_height - mw->matrix.top_row: 0);
 	    	    
 	    *column = -1;
@@ -1225,7 +1205,7 @@ xbaeXYToRowCol(XbaeMatrixWidget mw, int *x, int *y, int *row, int *column, CellT
 	/*
 	 * Convert the new point to a row/column position
 	 */
-	*row = xbaeYtoRow(mw, *y + mw->matrix.first_row_offset) + VERT_ORIGIN(mw);
+	*row = YtoRow(mw, *y + mw->matrix.first_row_offset) + VERT_ORIGIN(mw);
 	*column = xbaeXtoCol(mw, *x + HORIZ_ORIGIN(mw));
 
 	/*
@@ -1356,39 +1336,6 @@ int x;
     return i - 1;
 }
 
-int
-xbaeYtoRow(XbaeMatrixWidget mw, int y)
-{
-#ifdef	HAVE_ROW_HEIGHTS
-	int	i, pos;
-
-	for (i=0, pos=0; i<mw->matrix.rows; i++) {
-		pos += mw->matrix.row_heights[i];
-		if (y <= pos)
-			return i;
-	}
-	return mw->matrix.rows;
-#else
-	return y / ROW_HEIGHT(mw);
-#endif
-
-#if 0
-    int i;
-
-    for (i = 0; i < mw->matrix.rows; i++)
-	if (ROW_POSITION(mw, i) > y)
-	    return i - 1;
-    /*
-     * I have seen cases where this function returned mw->matrix.columns
-     * causing a crash as array bounds are read - AL
-     */
-    if (i > mw->matrix.rows)
-	return mw->matrix.rows - 1;
-
-    return i - 1;
-#endif
-}
-
 /*
  * Convert a pixel position to the trailing
  * fixed column it is contained in
@@ -1416,90 +1363,13 @@ int x;
  * fixed cells, or the clip window for non-fixed).
  */
 void
-xbaeRowColToXY(XbaeMatrixWidget mw, int row, int column, int *x, int *y)
+xbaeRowColToXY(mw, row, column, x, y)
+XbaeMatrixWidget mw;
+int row;
+int column;
+int *x;
+int *y;
 {
-#ifdef	HAVE_ROW_HEIGHTS
-    int		i;
-
-    /*
-     * If we are in a fixed cell, calculate x/y relative to Matrixs
-     * window (take into account labels etc)
-     */
-    if (IS_FIXED(mw, row, column))
-    {
-	/*
-	 * Ignore horiz_origin if we are in a fixed column
-	 */
-	if (IS_LEADING_FIXED_COLUMN(mw, column))
-	{
-	    if (IS_FIXED_ROW(mw, row))
-		*x = COLUMN_LABEL_OFFSET(mw) + COLUMN_POSITION(mw, column);
-	    else
-		*x = COLUMN_POSITION(mw, column);	/* LeftClip */
-	}
-	else if (IS_TRAILING_FIXED_COLUMN(mw, column))
-	{
-	    int m;
-	    if (IS_FIXED_ROW(mw, row))
-		*x = TRAILING_FIXED_COLUMN_LABEL_OFFSET(mw);
-	    else
-		*x = 0;					/* RightClip */
-	    for (m = TRAILING_HORIZ_ORIGIN(mw); m < column; m++)
-		*x += COLUMN_WIDTH(mw, m);
-	}
-	else if (IS_FIXED_ROW(mw, row))
-	    *x = (COLUMN_POSITION(mw, column) -
-		  COLUMN_POSITION(mw, mw->matrix.fixed_columns)) -
-		HORIZ_ORIGIN(mw);
-	else
-	    *x = COLUMN_LABEL_OFFSET(mw) +
-		COLUMN_POSITION(mw, column) - HORIZ_ORIGIN(mw);
-
-	/*
-	 * Ignore vert_origin if we are in a fixed row
-	 */
-	if (IS_LEADING_FIXED_ROW(mw, row)) {
-	    if (IS_FIXED_COLUMN(mw, column)) {
-		*y = ROW_LABEL_OFFSET(mw);
-	    } else {
-		*y = 0;		/* TopClip */
-	    }
-
-	    for (i=0; i<row; i++)
-		*y += mw->matrix.row_heights[i];
-	} else if (IS_TRAILING_FIXED_ROW(mw, row)) {
-	    int m;
-	    if (IS_FIXED_COLUMN(mw, column))
-		*y = TRAILING_FIXED_ROW_LABEL_OFFSET(mw);
-	    else
-		*y = 0;				/* BottomClip */
-	    for (m = TRAILING_VERT_ORIGIN(mw); m < row; m++)
-		*y += ROW_HEIGHT(mw);
-	} else if (IS_FIXED_COLUMN(mw, column)) {
-	    *y = 0;
-	    for (i=mw->matrix.fixed_rows + VERT_ORIGIN(mw); i<row; i++)
-		*y += mw->matrix.row_heights[i];
-	} else {
-	    *y = ROW_LABEL_OFFSET(mw);
-	    for (i=VERT_ORIGIN(mw); i<row; i++)
-		*y += mw->matrix.row_heights[i];
-	}
-    }
-
-    /*
-     * If we are not fixed we must account for fixed rows/columns
-     * and scrolling origins.
-     */
-    else {
-	*x = (COLUMN_POSITION(mw, column) -
-	      COLUMN_POSITION(mw, mw->matrix.fixed_columns)) -
-	    HORIZ_ORIGIN(mw);
-	*y = 0;
-	for (i=mw->matrix.fixed_rows + VERT_ORIGIN(mw); i<row; i++)
-	    *y += mw->matrix.row_heights[i];
-	*y -= mw->matrix.first_row_offset;
-    }
-#else
     /*
      * If we are in a fixed cell, calculate x/y relative to Matrixs
      * window (take into account labels etc)
@@ -1576,7 +1446,6 @@ xbaeRowColToXY(XbaeMatrixWidget mw, int row, int column, int *x, int *y)
 			       VERT_ORIGIN(mw));
 	*y -= mw->matrix.first_row_offset;
     }
-#endif
 }
 
 #define FIXED_NONE	0
@@ -1596,7 +1465,10 @@ xbaeRowColToXY(XbaeMatrixWidget mw, int row, int column, int *x, int *y)
  * or one of the extra clips which handle the fixed row/col cells.
  */
 Window
-xbaeGetCellWindow(XbaeMatrixWidget mw, Widget *w, int row, int column)
+xbaeGetCellWindow(mw, w, row, column)
+XbaeMatrixWidget mw;
+Widget *w;
+int row, column;
 {
     int posn;
     Window win;
@@ -1662,8 +1534,17 @@ xbaeGetCellWindow(XbaeMatrixWidget mw, Widget *w, int row, int column)
 }
 
 void
-xbaeCalcVertFill(XbaeMatrixWidget mw, Window win, int x, int y, int row, int column,
-	int *ax, int *ay, int *width, int *height)
+xbaeCalcVertFill(mw, win, x, y, row, column, ax, ay, width, height)
+XbaeMatrixWidget mw;
+Window win;
+int x;
+int y;
+int row;
+int column;
+int *ax;
+int *ay;
+int *width;
+int *height;
 {
     *ax = x;
     *width = COLUMN_WIDTH(mw, column);
@@ -1743,11 +1624,20 @@ xbaeCalcVertFill(XbaeMatrixWidget mw, Window win, int x, int y, int row, int col
 }
     
 void
-xbaeCalcHorizFill(XbaeMatrixWidget mw, Window win, int x, int y, int row, int column,
-	int *ax, int *ay, int *width, int *height)
+xbaeCalcHorizFill(mw, win, x, y, row, column, ax, ay, width, height)
+XbaeMatrixWidget mw;
+Window win;
+int x;
+int y;
+int row;
+int column;
+int *ax;
+int *ay;
+int *width;
+int *height;
 {
     *ay = y;
-    *height = SOME_ROW_HEIGHT(mw, row);
+    *height = ROW_HEIGHT(mw);
 
     if (win == XtWindow(TopClip(mw)))
     {
@@ -1809,68 +1699,3 @@ xbaeCalcHorizFill(XbaeMatrixWidget mw, Window win, int x, int y, int row, int co
 		ClipChild(mw)->core.y - *ay;
     }
 }
-
-/*
- * Below are some functions to deal with a multi-threaded environment.
- * Use these instead of the Xt stuff, to ensure that we can still cope
- * with X11r5 where this stuff didn't exist.
- */
-#ifdef  XtSpecificationRelease
-#if     XtSpecificationRelease > 5
-#define R6plus
-#endif
-#endif
-
-void xbaeObjectLock(Widget w)
-{
-#ifdef  R6plus
-        if (XmIsGadget(w))
-                XtAppLock(XtWidgetToApplicationContext(
-                        XtParent(w)));
-        else
-                XtAppLock(XtWidgetToApplicationContext(w));
-#endif
-}
-
-void
-xbaeObjectUnlock(Widget w)
-{
-#ifdef  R6plus
-        if (XmIsGadget(w))
-                XtAppUnlock(XtWidgetToApplicationContext(
-                        XtParent(w)));
-        else
-                XtAppUnlock(XtWidgetToApplicationContext(w));
-#endif
-}
-
-/* The following 2 functions are here to provide information about the
-   version of this library - since we may often build it as a shared/dynamic
-   library it's important to have this builtin */
-const char *
-XbaeGetVersionTxt(void)
-{
-	return XbaeVersionTxt;
-}
-
-int
-XbaeGetVersionNum(void)
-{
-	return XbaeVersion;
-}
-
-/* The following 2 functions contain/return info about the
-   M*tif/LessTif version this library was built with.
-   Building against one toolkit and linking on runtime against
-   another is likely to fail! */
-const char *
-XbaeGetXmVersionTxt(void)
-{
-        return XmVERSION_STRING;
-}
-
-int
-XbaeGetXmVersionNum(void)
-{
-        return XmVersion;
-}
