@@ -1,6 +1,6 @@
 /**
  *
- * $Id: BubbleButton.c,v 1.12 2000/11/14 18:55:49 rwscott Exp $
+ * $Id: BubbleButton.c,v 1.5 1999/09/22 14:27:47 rwscott Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  *
@@ -21,8 +21,6 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  **/
-
-#include "../config.h"
 #include <unistd.h>
 #include <stdio.h>
 #include <X11/StringDefs.h>
@@ -33,24 +31,22 @@
 #include <Xm/LabelP.h>
 #include <Xm/DialogS.h>
 #include <Xm/MenuShell.h>
-#include <Xm/Display.h>
 #include <BubbleButtonP.h>
-#include "SlideC.h"
 
 #undef DEBUG
 
-static const char rcsid[] = "$Id: BubbleButton.c,v 1.12 2000/11/14 18:55:49 rwscott Exp $";
+static const char rcsid[] = "$Id: BubbleButton.c,v 1.5 1999/09/22 14:27:47 rwscott Exp $";
 
 /*
    Widget methods, forward declarations
  */
 
-static void class_initialize(void);
+static void class_initialize();
 static void class_part_initialize(WidgetClass widget_class);
 static void initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args);
 static void destroy(Widget w);
 static Boolean set_values(Widget old, Widget request, Widget new_w, ArgList args, Cardinal *num_args);
-static void _XmExportLabelString(Widget w, int offset, XtArgVal *value);
+void _XmExportLabelString(Widget w, int offset, XtArgVal *value);
 
 /*
    Helper functions, forward declarations
@@ -197,7 +193,7 @@ WidgetClass xrwsBubbleButtonWidgetClass = (WidgetClass)&xrwsBubbleButtonClassRec
  */
 
 static void
-class_initialize(void)
+class_initialize()
 {
     xrwsBubbleButtonClassRec.bubble_button_class.leave_time = 0;
 }
@@ -273,11 +269,6 @@ set_values(Widget old, Widget request, Widget new_w, ArgList args, Cardinal *num
     	XmStringFree(BubbleButton_MouseOverString(old));
     	BubbleButton_MouseOverString(new_w) = XmStringCopy(BubbleButton_MouseOverString(new_w));
     }
-    if (BubbleButton_BubbleString(new_w) != BubbleButton_BubbleString(old))
-    {
-    	XmStringFree(BubbleButton_BubbleString(old));
-    	BubbleButton_BubbleString(new_w) = XmStringCopy(BubbleButton_BubbleString(new_w));
-    }
     if (XtIsSensitive(old) != XtIsSensitive(new_w))
     {
 	if (!XtIsSensitive(new_w))
@@ -316,36 +307,14 @@ _XmExportLabelString(Widget w, int offset, XtArgVal *value)
     *value = (XtArgVal)ret;
 }
 
-static void
-fadeOutFinish(Widget slide, Widget w, XtPointer call_data)
-{
-    BubbleButton_Slider(w) = NULL;
-    XtPopdown(XtParent(BubbleButton_Label(w)));
-}
-
 static void
 UnpostIt(Widget w)
 {
     BubbleButton_DurationTimer(w) = (XtIntervalId)NULL;
-    BubbleButton_Slider(w) = XtVaCreateWidget("Slide", xltSlideContextWidgetClass,
-	XmGetXmDisplay(XtDisplay(w)),
-	XltNslideWidget, XtParent(BubbleButton_Label(w)),
-	XltNslideDestHeight, 1,
-	NULL);
-    XtAddCallback(BubbleButton_Slider(w), XltNslideFinishCallback, (XtCallbackProc)fadeOutFinish, w);
-}
-
-static void
-fadeInFinish(Widget slide, Widget w, XtPointer call_data)
-{
-    BubbleButton_Slider(w) = NULL;
-    if (BubbleButton_Duration(w) > 0)
-    {
-	BubbleButton_DurationTimer(w) = XtAppAddTimeOut(XtWidgetToApplicationContext(w),
-			BubbleButton_Duration(w),
-			(XtTimerCallbackProc)UnpostIt, 
-			w);
-    }
+    /*
+    BubbleButtonClass_LeaveTime(w) = event->xcrossing.time;
+    */
+    XtPopdown(XtParent(BubbleButton_Label(w)));
 }
 
 static void
@@ -363,32 +332,23 @@ Window root, child;
     			&rx, &ry,
     			&x, &y,
     			&key);
+    	XtVaSetValues(XtParent(BubbleButton_Label(w)),
+    		XmNx, rx - x + XtWidth(w) / 2,
+    		XmNy, ry - y + XtHeight(w),
+    		NULL);
+    	XtPopup(XtParent(BubbleButton_Label(w)), XtGrabNone);
     	if (BubbleButton_DurationTimer(w) != (XtIntervalId)NULL)
     	{
 	    XtRemoveTimeOut(BubbleButton_DurationTimer(w));
 	    BubbleButton_DurationTimer(w) = (XtIntervalId)NULL;
     	}
-	{
-	XtWidgetGeometry geo;
-
-	    XtQueryGeometry(BubbleButton_Label(w), NULL, &geo);
-	    XtVaSetValues(XtParent(BubbleButton_Label(w)),
-    		XmNx, rx + 1 /*- x + XtWidth(w) / 2*/,
-    		XmNy, ry + 1 /*- y + XtHeight(w)*/,
-    		XmNheight, 1,
-    		XmNwidth, 1 /*geo.width*/,
-    		NULL);
-	    XtPopup(XtParent(BubbleButton_Label(w)), XtGrabNone);
-	    BubbleButton_Slider(w) = XtVaCreateWidget("Slide", xltSlideContextWidgetClass,
-	    	XmGetXmDisplay(XtDisplay(w)),
-		XltNslideWidget, XtParent(BubbleButton_Label(w)),
-		XltNslideDestX, rx - x + XtWidth(w) / 2,
-		XltNslideDestY, ry - y + XtHeight(w),
-		XltNslideDestWidth, geo.width,
-		XltNslideDestHeight, geo.height,
-		NULL);
-	    XtAddCallback(BubbleButton_Slider(w), XltNslideFinishCallback, (XtCallbackProc)fadeInFinish, w);
-	}
+    	if (BubbleButton_Duration(w) > 0)
+    	{
+	    BubbleButton_DurationTimer(w) = XtAppAddTimeOut(XtWidgetToApplicationContext(w),
+					BubbleButton_Duration(w),
+					(XtTimerCallbackProc)UnpostIt, 
+					w);
+    	}
 }
 
 static void
@@ -476,11 +436,6 @@ LeaveWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
     }
     else
     {
-	if (BubbleButton_Slider(w) != NULL)
-	{
-	    XtDestroyWidget(BubbleButton_Slider(w));
-	    BubbleButton_Slider(w) = NULL;
-	}
 	XtPopdown(XtParent(BubbleButton_Label(w)));
 	if (event)
 	{
