@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Host.c,v 1.14 2000/12/18 19:41:48 amai Exp $
+ * $Id: Host.c,v 1.8 1999/09/22 14:27:48 rwscott Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  *
@@ -23,15 +23,11 @@
  **/
 
 #include "../config.h"
-
 #include <unistd.h>
-/* #include <fcntl.h> */
+#include <fcntl.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
-#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
-#endif
 #include <sys/socket.h>
 #include <sys/time.h>
 #ifdef HAVE_SYS_SELECT_H
@@ -39,20 +35,16 @@
 #endif
 #include <netinet/in.h>
 #include <netdb.h>
-
 #include <X11/StringDefs.h>
-
 #include <Xm/MessageB.h>
 #include <Xm/Form.h>
 #include <Xm/TextF.h>
 #include <Xm/Label.h>
-#include <Xm/RepType.h>
-
-#include "HostP.h"
+#include <HostP.h>
 
 #undef DEBUG
 
-static const char rcsid[] = "$Id: Host.c,v 1.14 2000/12/18 19:41:48 amai Exp $";
+static const char rcsid[] = "$Id: Host.c,v 1.8 1999/09/22 14:27:48 rwscott Exp $";
 
 typedef struct
 {
@@ -75,7 +67,7 @@ static char DefaultHelp[] = "\n"
    Widget methods, forward declarations
  */
 
-static void class_initialize(void);
+static void class_initialize();
 static void class_part_initialize(WidgetClass widget_class);
 static void initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args);
 static void destroy(Widget w);
@@ -89,7 +81,6 @@ static void get_values_hook(Widget w, ArgList args, Cardinal *num_args);
 static Boolean SendByte(Widget w);
 static Boolean Connect(Widget W);
 static int SockOpen(char *HostName, char *Service);
-static void InputHandler(Widget W, int *Fd, XtInputId *Id);
 
 /*
    Widget default resources
@@ -148,11 +139,6 @@ static XtResource resources[] =
 	sizeof(XtCallbackList), Offset(OutputCallback),
 	XtRCallback, NULL
     },
-    {
-	XltNhostType, XltCHostType, XltRHostType,
-	sizeof(unsigned char), Offset(type),
-	XtRImmediate, (XtPointer)XltHOST_CLIENT
-    },
 };
 #undef Offset
 
@@ -216,21 +202,9 @@ WidgetClass xrwsHostWidgetClass = (WidgetClass)&xrwsHostClassRec;
 static void
 Disconnect(Widget w)
 {
-int i;
-
 #ifdef DEBUG
     printf("Disconnect()\n");
 #endif
-    for (i = 0; i < Host_NumClients(w); i++)
-    {
-	close(Host_ClientList(w)[i].fd);
-    }
-    if (Host_ClientList(w))
-    {
-    	XtFree((char *)Host_ClientList(w));
-    	Host_ClientList(w) = NULL;
-    }
-    Host_NumClients(w) = 0;
     if (Host_InputId(w))
     {
 	XtRemoveInput(Host_InputId(w));
@@ -246,11 +220,6 @@ int i;
 	XtRemoveTimeOut(Host_OutputId(w));
 	Host_OutputId(w) = 0;
     }
-    if (Host_BinaryTimeOutId(w))
-    {
-	XtRemoveTimeOut(Host_BinaryTimeOutId(w));
-	Host_BinaryTimeOutId(w) = 0;
-    }
     Host_OutputSize(w) = 0;
     Host_InputSize(w) = 0;
     Host_OutputData(w)[0] = '\0';
@@ -300,9 +269,11 @@ TimeOut(Widget W)
 static void
 BinaryByte(Widget W, char byte)
 {
-    if (Host_BinaryTimeOutId(W) != (XtIntervalId)NULL)
+    static XtIntervalId Id = (XtIntervalId)NULL;
+
+    if (Id != (XtIntervalId)NULL)
     {
-	XtRemoveTimeOut(Host_BinaryTimeOutId(W));
+	XtRemoveTimeOut(Id);
     }
     Host_InputData(W)[Host_InputSize(W)] = byte;
     Host_InputSize(W)++;
@@ -360,7 +331,7 @@ BinaryByte(Widget W, char byte)
     }
     if (Host_Mode(W) == MODE_BINARY)
     {
-	Host_BinaryTimeOutId(W) = XtAppAddTimeOut(XtWidgetToApplicationContext(W),
+	Id = XtAppAddTimeOut(XtWidgetToApplicationContext(W),
 			     10000, (XtTimerCallbackProc)TimeOut, W);
     }
 }
@@ -390,62 +361,6 @@ Throttle(Widget W, Boolean state)
     }
 }
 
-static int
-Listen(char *Service)
-{
-int optval = 1;
-int ListenFd;
-struct sockaddr_in my_addr_in;
-struct servent *sp;
-
-    memset((char *)&my_addr_in, 0, sizeof(struct sockaddr_in));
-    my_addr_in.sin_family = AF_INET;
-    my_addr_in.sin_addr.s_addr = INADDR_ANY;
-    if (atoi(Service) != 0)
-    {
-    	my_addr_in.sin_port = htons(atoi(Service));
-    }
-    else
-    {
-#ifdef HAVE_GETSERVBYNAME
-    	sp = getservbyname(Service, "tcp");
-    	if (sp == NULL)
-#endif
-    	{
-	    fprintf(stderr, "Service >%s< not found\n", Service);
-	    ListenFd = -1;
-	    return(ListenFd);
-    	}
-	my_addr_in.sin_port = sp->s_port;
-    }
-    ListenFd = socket(AF_INET, SOCK_STREAM, 0);
-    if (ListenFd == -1)
-    {
-	fprintf(stderr, "socket error\n");
-	ListenFd = -1;
-	return(ListenFd);
-    }
-    if (setsockopt(ListenFd, SOL_SOCKET, SO_REUSEADDR, (void *)&optval, sizeof(optval)) == -1)
-    {
-	fprintf(stderr, "setsockopt error\n");
-	ListenFd = -1;
-	return(ListenFd);
-    }
-    if (bind(ListenFd, (void *)&my_addr_in, sizeof(struct sockaddr_in)) == -1)
-    {
-	fprintf(stderr, "bind error\n");
-	ListenFd = -1;
-	return(ListenFd);
-    }
-    if (listen(ListenFd, 5) == -1)
-    {
-	fprintf(stderr, "listen error\n");
-	ListenFd = -1;
-	return(ListenFd);
-    }
-    return(ListenFd);
-}
-
 static int
 SockOpen(char *HostName, char *Service)
 {
@@ -505,8 +420,6 @@ SockOpen(char *HostName, char *Service)
 static Boolean
 SendByte(Widget w)
 {
-int i;
-
     while ((XtAppPending(XtWidgetToApplicationContext(w)) & XtIMAlternateInput) == XtIMAlternateInput)
     {
 	XtAppProcessEvent(XtWidgetToApplicationContext(w), XtIMAlternateInput);
@@ -514,20 +427,7 @@ int i;
     Host_OutputId(w) = (XtIntervalId)NULL;
     if (!Host_Throttle(w))
     {
-	switch (Host_Type(w))
-	{
-	case XltHOST_CLIENT:
-	    write(Host_Fd(w), &(Host_OutputData(w)[0]), 1);
-	    break;
-	case XltHOST_SERVER:
-	    for (i = 0; i < Host_NumClients(w); i++)
-	    {
-	    	write(Host_ClientList(w)[i].fd, &(Host_OutputData(w)[0]), 1);
-	    }
-	    break;
-	default:
-	    break;
-	}
+	write(Host_Fd(w), &(Host_OutputData(w)[0]), 1);
 	memmove(&(Host_OutputData(w)[0]), &(Host_OutputData(w)[1]), Host_OutputSize(w));
 	Host_OutputSize(w)--;
 	if (Host_OutputCallback(w))
@@ -635,48 +535,6 @@ ProcessByte(Widget W, char byte)
 
 /* ******************** */
 
-static void
-ConnectionRequest(Widget W, int *Fd, XtInputId *Id)
-{
-int addrlen;
-
-    Host_NumClients(W)++;
-    Host_ClientList(W) = (XltClientInfo *)XtRealloc((char *)Host_ClientList(W), Host_NumClients(W) * sizeof(XltClientInfo));
-    addrlen = sizeof(struct sockaddr_in);
-    Host_ClientList(W)[Host_NumClients(W) - 1].fd = accept(Host_Fd(W), (void *)&(Host_ClientList(W)[Host_NumClients(W) - 1].addr), &addrlen);
-    Host_ClientList(W)[Host_NumClients(W) -1].id = XtAppAddInput(XtWidgetToApplicationContext(W),
-						Host_ClientList(W)[Host_NumClients(W) - 1].fd,
-						(XtPointer)XtInputReadMask,
-						(XtInputCallbackProc)InputHandler,
-						W);
-}
-
-/* ******************** */
-
-static void
-ReleaseClient(Widget w, int fd)
-{
-int i, j;
-
-    for (i = 0; i < Host_NumClients(w); i++)
-    {
-    	if (Host_ClientList(w)[i].fd == fd)
-    	{
-	    XtRemoveInput(Host_ClientList(w)[i].id);
-	    close(Host_ClientList(w)[i].fd);
-	    for (j = i + 1; j < Host_NumClients(w); j++)
-	    {
-	    	Host_ClientList(w)[j - 1] = Host_ClientList(w)[j];
-	    }
-	    Host_NumClients(w)--;
-	    Host_ClientList(w) = (XltClientInfo *)XtRealloc((char *)Host_ClientList(w), Host_NumClients(w) * sizeof(XltClientInfo));
-	    break;
-    	}
-    }
-}
-
-/* ******************** */
-
 static void
 InputHandler(Widget W, int *Fd, XtInputId *Id)
 {
@@ -717,17 +575,7 @@ InputHandler(Widget W, int *Fd, XtInputId *Id)
 	    case 0:
 		fprintf(stderr, "InputHandler(%s) - EOF while reading device\n", XtName(W));
 		DoCallback = True;
-		switch (Host_Type(W))
-		{
-		case XltHOST_CLIENT:
-		    Disconnect(W);
-		    break;
-		case XltHOST_SERVER:
-		    ReleaseClient(W, *Fd);
-		    break;
-		default:
-		    break;
-		}
+		Disconnect(W);
 		break;
 	    case -1:
 		perror("InputHandler");
@@ -790,57 +638,38 @@ Connect(Widget W)
 	{
 	    XtAppProcessEvent(XtWidgetToApplicationContext(XtParent(W)), XtIMAll);
 	}
-	switch (Host_Type(W))
+	Host_Fd(W) = SockOpen(Host_Name(W), Host_Port(W));
+	if (Host_Fd(W) > 0)
 	{
-	case XltHOST_CLIENT:
-	    Host_Fd(W) = SockOpen(Host_Name(W), Host_Port(W));
-	    if (Host_Fd(W) > 0)
-	    {
-		_XltHostCallbackStruct tmp;
-		String Name;
-		String Class;
-		FILE *xrdb;
-		String xrdb_command;
-		String base = "xrdb -merge -nocpp -display";
+	    _XltHostCallbackStruct tmp;
+	    String Name;
+	    String Class;
+	    FILE *xrdb;
+	    String xrdb_command;
+	    String base = "xrdb -merge -nocpp -display";
 
-		Host_InputId(W) = XtAppAddInput(XtWidgetToApplicationContext(W),
-						Host_Fd(W),
-						(XtPointer)XtInputReadMask,
-						(XtInputCallbackProc)InputHandler,
-						W);
-		xrdb_command = XtMalloc(strlen(base) + strlen(DisplayString(XtDisplay(XtParent(W)))) + 2);
-		sprintf(xrdb_command, "%s %s", base, DisplayString(XtDisplay(XtParent(W))));
-		xrdb = popen(xrdb_command, "w");
-		if (xrdb != NULL)
-		{
-		    XtGetApplicationNameAndClass(XtDisplay(XtParent(W)), &Name, &Class);
-		    fprintf(xrdb, "%s.Host: %s\n%s.Service: %s\n",
-			    Class,
-			    Host_Name(W),
-			    Class,
-			    Host_Port(W));
-		    pclose(xrdb);
-		}
-		XtFree(xrdb_command);
-		Host_Throttle(W) = False;
-		tmp.reason = XltCR_CONNECT;
-		XtCallCallbackList(W, Host_ConnectCallback(W), &tmp);
-	    }
-	    break;
-	case XltHOST_SERVER:
-	    Host_Fd(W) = Listen(Host_Port(W));
-	    if (Host_Fd(W) > 0)
+	    Host_InputId(W) = XtAppAddInput(XtWidgetToApplicationContext(W),
+					    Host_Fd(W),
+					    (XtPointer)XtInputReadMask,
+					    (XtInputCallbackProc)InputHandler,
+					    W);
+	    xrdb_command = XtMalloc(strlen(base) + strlen(DisplayString(XtDisplay(XtParent(W)))) + 2);
+	    sprintf(xrdb_command, "%s %s", base, DisplayString(XtDisplay(XtParent(W))));
+	    xrdb = popen(xrdb_command, "w");
+	    if (xrdb != NULL)
 	    {
-		Host_InputId(W) = XtAppAddInput(XtWidgetToApplicationContext(W),
-						Host_Fd(W),
-						(XtPointer)XtInputReadMask,
-						(XtInputCallbackProc)ConnectionRequest,
-						W);
+		XtGetApplicationNameAndClass(XtDisplay(XtParent(W)), &Name, &Class);
+		fprintf(xrdb, "%s.Host: %s\n%s.Service: %s\n",
+			Class,
+			Host_Name(W),
+			Class,
+			Host_Port(W));
+		pclose(xrdb);
 	    }
-	    break;
-	default:
-	    fprintf(stderr, "%s: Unknown host type\n", XtName(W));
-	    break;
+	    XtFree(xrdb_command);
+	    Host_Throttle(W) = False;
+	    tmp.reason = XltCR_CONNECT;
+	    XtCallCallbackList(W, Host_ConnectCallback(W), &tmp);
 	}
     }
     return (True);
@@ -881,23 +710,11 @@ OpenHost(Widget W, Widget w)
  */
 
 static void
-class_initialize(void)
+class_initialize()
 {
-static char *value_names[] =
-{
-    "client",
-    "server"
-};
-
-static unsigned char values[] =
-{
-    XltHOST_CLIENT,
-    XltHOST_SERVER
-};
     /*
        printf("class_initialize()\n");
      */
-     XmRepTypeRegister(XltRHostType, value_names, values, XtNumber(values));
 }
 
 static void
@@ -933,9 +750,6 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
     Host_InputData(new_w) = XtMalloc(Host_InputMaxSize(new_w));
     Host_Dialog(new_w) = NULL;
     Host_InputNeed(new_w) = 0;
-    Host_BinaryTimeOutId(new_w) = (XtIntervalId)NULL;
-    Host_NumClients(new_w) = 0;
-    Host_ClientList(new_w) = NULL;
     if (Host_Terminator(new_w) == NULL)
     {
 	Host_Terminator(new_w) = XtNewString("\r\n");
@@ -1002,10 +816,6 @@ set_values(Widget old, Widget request, Widget new_w, ArgList args, Cardinal *num
     {
 	ReConnect = True;
     }
-    if (Host_Type(old) != Host_Type(new_w))
-    {
-	ReConnect = True;
-    }
     if (ReConnect)
     {
 	Disconnect(new_w);
