@@ -1,6 +1,6 @@
 /**
  *
- * $Id: HostP.h,v 1.4 1999/11/26 21:52:54 rwscott Exp $
+ * $Id: HostP.h,v 1.2 1998/08/23 15:28:36 rwscott Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  *
@@ -29,11 +29,6 @@
 #include <X11/ObjectP.h>
 
 typedef enum { MODE_ASCII, MODE_BINARY } InputMode;
-typedef struct _xltClientInfo_struct {
-    int fd;
-    struct sockaddr_in addr;
-    XtInputId id;
-} XltClientInfo;
 
 typedef struct {
 	int Fd;
@@ -62,15 +57,8 @@ typedef struct {
 	Widget host_dialog;
 	int InputNeed;
 	XtCallbackList OutputCallback;
-	XtIntervalId BinaryTimeOutId;
-	unsigned char type;
-	int num_clients;
-	XltClientInfo *client_list;
 } XltHostPart;
 
-#define Host_ReadBuffer(w) (((XltHostWidget)w)->host.ReadBuffer)
-#define Host_BufferSize(w) (((XltHostWidget)w)->host.BufferSize)
-#define Host_BinaryTimeOutId(w) (((XltHostWidget)w)->host.BinaryTimeOutId)
 #define Host_Fd(w) (((XltHostWidget)w)->host.Fd)
 #define Host_Name(w) (((XltHostWidget)w)->host.Name)
 #define Host_Port(w) (((XltHostWidget)w)->host.Port)
@@ -97,9 +85,6 @@ typedef struct {
 #define Host_Delay(w) (((XltHostWidget)w)->host.Delay)
 #define Host_Dialog(w) (((XltHostWidget)w)->host.host_dialog)
 #define Host_InputNeed(w) (((XltHostWidget)w)->host.InputNeed)
-#define Host_Type(w) (((XltHostWidget)w)->host.type)
-#define Host_NumClients(w) (((XltHostWidget)w)->host.num_clients)
-#define Host_ClientList(w) (((XltHostWidget)w)->host.client_list)
 
 typedef struct _XltHostRec {
 	ObjectPart object;
