@@ -1,6 +1,6 @@
 /**
  *
- * $Id: NumEntry.c,v 1.11 2000/10/15 17:20:13 amai Exp $
+ * $Id: NumEntry.c,v 1.6 1999/09/22 14:27:49 rwscott Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  *
@@ -21,8 +21,6 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  **/
- 
-#include "../config.h"
 #include <stdio.h>
 #include <Xm/TextF.h>
 #include <Xm/Label.h>
@@ -39,7 +37,7 @@
 #include <stdio.h>
 #endif
 
-static const char rcsid[] = "$Id: NumEntry.c,v 1.11 2000/10/15 17:20:13 amai Exp $";
+static const char rcsid[] = "$Id: NumEntry.c,v 1.6 1999/09/22 14:27:49 rwscott Exp $";
 
 /*
    Widget methods, forward declarations
@@ -138,10 +136,8 @@ static XtActionsRec actions[] =
 };
 
 static char tm_table[] = "\
-	<Key>osfDown: Down()\n\
-	<Key>osfUp: Up()\n\
-	!<Btn4Down>: Up()\n\
-	!<Btn5Down>: Down()";
+	<Key>osfDown: Down() \n\
+	<Key>osfUp: Up()";
 
 /*
    Widget class record
@@ -197,7 +193,7 @@ XltNumEntryClassRec xrwsNumEntryClassRec = {
     /* subresource_count */ 0,
     /* constraint_size   */ sizeof(XmFormConstraintRec),
     /* initialize        */ NULL /*constraint_initialize*/,
-    /* destroy           */ NULL,
+    /* destroy           */ destroy /*NULL*/,
     /* set_values        */ NULL /*constraint_set_values*/,
     /* extension         */ NULL,
     },
@@ -299,7 +295,7 @@ DoMath(Widget W)
 #endif
     value = XmTextFieldGetString(NumEntry_TextField(W));
     Place = XmTextFieldGetInsertionPosition(NumEntry_TextField(W));
-    result = XltCalc(value);
+    result = Calc(value);
     if (result != NumEntry_Result(W))
     {
 	char buf[1024];
@@ -317,7 +313,6 @@ DoMath(Widget W)
 	{
 	    XtFree(NumEntry_Value(W));
 	    NumEntry_Value(W) = cbs.value;
-	    NumEntry_Result(W) = cbs.dvalue;
 	}
 	else
 	{
@@ -495,7 +490,6 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
     XtVaSetValues(NumEntry_Label(new_w),
 		  XmNlabelString, NumEntry_LabelString(new_w),
 		  NULL);
-    XtOverrideTranslations(NumEntry_Label(new_w), XtParseTranslationTable(tm_table));
     XtManageChild(NumEntry_Label(new_w));
     /*
        XtVaGetValues(NumEntry_Label(new_w),
@@ -523,7 +517,6 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 		  XmNorientation, XmHORIZONTAL,
 		  XmNnumColumns, 1,
 		  NULL);
-    XtOverrideTranslations(NumEntry_RowColumn(new_w), XtParseTranslationTable(tm_table));
     NumEntry_UpArrow(new_w) = XmCreateArrowButton(NumEntry_RowColumn(new_w), "UpArrow", NULL, 0);
     XtAddCallback(NumEntry_UpArrow(new_w), XmNactivateCallback, (XtCallbackProc)StepValue, (XtPointer)1);
     XtAddCallback(NumEntry_UpArrow(new_w), XmNarmCallback, (XtCallbackProc)AutoRepeat, (XtPointer)True);
