@@ -1,6 +1,4 @@
 /*
- * $Id: SciPlotUtil.c,v 1.5 2000/09/20 09:38:06 amai Exp $
- *
  * Copyright (C) 1996 by Rob McMullen
  *
  * This library is free software; you can redistribute it and/or
@@ -22,19 +20,15 @@
  *         http://www.ae.utexas.edu/~rwmcm
  */
 
-#include "../config.h"
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
 #include <unistd.h>
 #include <string.h>
 #include <time.h>
-
 #include <X11/Intrinsic.h>
 #include <X11/Shell.h>
 #include <X11/StringDefs.h>
-
 #include <Xm/Xm.h>
 #include <Xm/Label.h>
 #include <Xm/TextF.h>
@@ -46,7 +40,6 @@
 #include <Xm/PanedW.h>
 
 #include "SciPlot.h"
-#include "SciPlotUtil.h"
 
 /* Globals */
 static int DialogCount=0;		/* Number of dialogs on screen */
@@ -57,7 +50,7 @@ typedef struct {
   int num;
 } textnumpair;
 
-static textnumpair colors_list[] =
+textnumpair colors_list[] =
 {
   {"blue", 0},
   {"red", 0},
@@ -71,7 +64,7 @@ static textnumpair colors_list[] =
 
 #define NUM_COLORS 8
 
-static textnumpair marker_list[] =
+textnumpair marker_list[] =
 {
   {"XtMARKER_SQUARE", XtMARKER_SQUARE},
   {"XtMARKER_CIRCLE", XtMARKER_CIRCLE},
@@ -109,8 +102,8 @@ static textnumpair marker_list[] =
 #define MAXFIELD 40
 #define STRING_MAX 63
 
-static char  field[MAXFIELD][STRING_MAX+1];
-static float ffield[MAXFIELD];
+char	field[MAXFIELD][STRING_MAX+1];
+float	ffield[MAXFIELD];
 
 #define PARSE_SEPARATORS	",= \t\n"
 
@@ -315,7 +308,7 @@ reads(int fd, char *buf, int num)
  * Read a line (ended by \n) from the specified file and call sepfield() to
  * break the line up into fields.
  */
-static int
+int
 getfields(FILE *fd)
 {
   int count;
