@@ -1,6 +1,6 @@
 /**
  *
- * $Id: SelectDebugLevel.c,v 1.5 2000/01/25 11:54:24 amai Exp $
+ * $Id: SelectDebugLevel.c,v 1.2 1998/07/01 11:32:09 rwscott Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  *
@@ -22,14 +22,13 @@
  *
  **/
 
-#include "../config.h"
 #include <stdio.h>
 
 #include <Xm/ToggleB.h>
 #include <Xm/MessageB.h>
 #include <Xm/RowColumn.h>
 
-static const char rcsid[] = "$Id: SelectDebugLevel.c,v 1.5 2000/01/25 11:54:24 amai Exp $";
+static const char rcsid[] = "$Id: SelectDebugLevel.c,v 1.2 1998/07/01 11:32:09 rwscott Exp $";
 
 /* ******************** */
 
@@ -75,16 +74,12 @@ char name[10];
 				XmNradioBehavior,True,
 				XmNorientation,XmVERTICAL,
 				NULL);
+                for (i=0; i<10; i++)
                 {
-                int client_data;
-
-		    for (i = 0, client_data = 0; i < 10; i++, client_data++)
-		    {
-			sprintf(name, "Debug%i", i);
-			tb = XmCreateToggleButton(rc, name, NULL, 0);
-			XtManageChild(tb);
-			XtAddCallback(tb, XmNvalueChangedCallback, (XtCallbackProc)ChangeDebugLevel, (XtPointer)client_data);
-		    }
+                        sprintf(name,"Debug%i",i);
+                        tb = XmCreateToggleButton(rc,name,NULL,0);
+                        XtManageChild(tb);
+                        XtAddCallback(tb,XmNvalueChangedCallback,(XtCallbackProc)ChangeDebugLevel,(XtPointer)i);
                 }
                 XtManageChild(rc);
         }
