@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Sound.h,v 1.1 1998/06/03 21:55:07 rwscott Exp $
+ * $Id: Sound.h,v 1.2 1999/10/23 12:48:10 amai Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  *
@@ -27,9 +27,17 @@
 
 #include <X11/Intrinsic.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 Boolean *XltSoundInitialize(Widget W);
 void XltSoundEnable(Boolean State);
 void XltSoundSetup(Widget W);
 void XltHelpOnSound(Widget W);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
