@@ -1,5 +1,5 @@
 /*
-    $Id: Stroke.h,v 1.2 1998/06/19 09:36:55 rwscott Exp $
+    $Id: Stroke.h,v 1.3 1999/10/23 12:48:10 amai Exp $
 
     libStroke is a library to enable any X application to use Strokes.
     Copyright (C) 1997  Richard Scott <rwscott@magi.com>
@@ -23,6 +23,10 @@
 
 #include <X11/Intrinsic.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #define DEFAULT_STROKE_TRANSLATION "!<Btn3Motion>: Input()\\n\
 				    !<Btn3Down>: Input()\\n\
 				    !<Btn3Up>: Input()"
@@ -62,4 +66,9 @@ void StrokeSetMapping(Widget W, String Map);
 String StrokeGetMapping(Widget W);
 
 void XltHelpOnStrokes(Widget W);
+
+#ifdef __cplusplus
+}
+#endif
+
 #endif
