@@ -1,6 +1,6 @@
 /**
  *
- * $Id: ToolBar.c,v 1.6 1998/08/23 15:28:37 rwscott Exp $
+ * $Id: ToolBar.c,v 1.13 1999/09/23 21:18:50 rwscott Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  *
@@ -27,16 +27,17 @@
 #include <Xm/Xm.h>
 #include <Xm/MessageB.h>
 #include <Xm/RowColumn.h>
-#include <Xm/PushB.h>
 #include <Xm/ToggleB.h>
+#include <Xm/PushB.h>
 #include <Xm/Frame.h>
 #include <Xm/Form.h>
 #include <Xm/ArrowB.h>
 #include <Xm/ScrolledW.h>
 #include <X11/xpm.h>
 #include <BubbleButton.h>
+#include <FilePicker.h>
 
-static const char rcsid[] = "$Id: ToolBar.c,v 1.6 1998/08/23 15:28:37 rwscott Exp $";
+static const char rcsid[] = "$Id: ToolBar.c,v 1.13 1999/09/23 21:18:50 rwscott Exp $";
 
 /* ******************** */
 
@@ -122,6 +123,8 @@ ConfigureOk(Widget w, Widget ToolBar)
 	}
 	XtFree(xrdb_command);
     }
+#else
+printf("itemResource >%s<\n", itemResource);
 #endif
     XtFree(itemResource);
 
@@ -211,7 +214,7 @@ ConfigureAddItem(Widget RC, Widget Button)
     Frame = XmCreateFrame(RC, "ItemFrame", NULL, 0);
     Form = XmCreateForm(Frame, "Item", NULL, 0);
     Toggle = XmCreateToggleButton(Form, XtName(Button), NULL, 0);
-    XtAddCallback(Toggle, XmNvalueChangedCallback, (void *)ToggleItem, Button);
+    XtAddCallback(Toggle, XmNvalueChangedCallback, (XtCallbackProc)ToggleItem, Button);
     XmToggleButtonSetState(Toggle, XtIsManaged(Button), False);
     XtVaGetValues(Button,
 		  XmNlabelType, &labelType,
@@ -234,9 +237,9 @@ ConfigureAddItem(Widget RC, Widget Button)
 		  XmNleftAttachment, XmATTACH_WIDGET,
 		  XmNleftWidget, Toggle,
 		  NULL);
-    XtAddCallback(lArrow, XmNactivateCallback, (void *)ShiftLeft, Button);
+    XtAddCallback(lArrow, XmNactivateCallback, (XtCallbackProc)ShiftLeft, Button);
     XtManageChild(lArrow);
-    rArrow = XmCreateArrowButton(Form, "lArrow", NULL, 0);
+    rArrow = XmCreateArrowButton(Form, "rArrow", NULL, 0);
     XtVaSetValues(rArrow,
 		  XmNarrowDirection, XmARROW_RIGHT,
 		  XmNtopAttachment, XmATTACH_OPPOSITE_WIDGET,
@@ -246,9 +249,9 @@ ConfigureAddItem(Widget RC, Widget Button)
 		  XmNleftAttachment, XmATTACH_WIDGET,
 		  XmNleftWidget, lArrow,
 		  NULL);
-    XtAddCallback(rArrow, XmNactivateCallback, (void *)ShiftRight, Button);
+    XtAddCallback(rArrow, XmNactivateCallback, (XtCallbackProc)ShiftRight, Button);
     XtManageChild(rArrow);
-    Browse = XltCreateBubbleButton(Form, "Browse", NULL, 0);
+    Browse = XltCreateFilePicker(Form, XtName(Button), NULL, 0);
     XtVaSetValues(Browse,
 		  XmNtopAttachment, XmATTACH_OPPOSITE_WIDGET,
 		  XmNtopWidget, Toggle,
@@ -256,6 +259,7 @@ ConfigureAddItem(Widget RC, Widget Button)
 		  XmNbottomWidget, Toggle,
 		  XmNleftAttachment, XmATTACH_WIDGET,
 		  XmNleftWidget, rArrow,
+		  XmNrightAttachment, XmATTACH_FORM,
 		  NULL);
     XtManageChild(Browse);
 
@@ -274,6 +278,7 @@ void
 XltToolBarConfigure(Widget w, Widget ToolBar)
 {
     Cardinal numChildren;
+    Cardinal numManagedChildren = 0;
     WidgetList children;
     int i;
     Widget Shell = w;
@@ -287,11 +292,8 @@ XltToolBarConfigure(Widget w, Widget ToolBar)
     while (!XtIsTopLevelShell(Shell))
 	Shell = XtParent(Shell);
     Dialog = XmCreateMessageDialog(Shell, "ToolBarConfigure", NULL, 0);
-    XtVaSetValues(Dialog,
-		  XmNresizePolicy, XmRESIZE_NONE,
-		  NULL);
-    XtAddCallback(Dialog, XmNcancelCallback, (void *)ConfigureCancel, NULL);
-    XtAddCallback(Dialog, XmNokCallback, (void *)ConfigureOk, ToolBar);
+    XtAddCallback(Dialog, XmNcancelCallback, (XtCallbackProc)ConfigureCancel, NULL);
+    XtAddCallback(Dialog, XmNokCallback, (XtCallbackProc)ConfigureOk, ToolBar);
     XtVaGetValues(ToolBar,
 		  XmNmenuHelpWidget, &menuHelpWidget,
 		  NULL);
@@ -299,6 +301,9 @@ XltToolBarConfigure(Widget w, Widget ToolBar)
 		  XmNdeleteResponse, XmDESTROY,
 		  NULL);
     Form = XmCreateForm(Dialog, "TBCForm", NULL, 0);
+    XtVaSetValues(Form,
+		  XmNresizePolicy, XmRESIZE_GROW,
+		  NULL);
     FakeToolBar = XmCreateRowColumn(Form, "FakeToolBar", NULL, 0);
     XtVaSetValues(FakeToolBar,
 		  XmNtopAttachment, XmATTACH_FORM,
@@ -317,6 +322,11 @@ XltToolBarConfigure(Widget w, Widget ToolBar)
 		  XmNbottomAttachment, XmATTACH_FORM,
 		  NULL);
     RC = XmCreateRowColumn(SW, "TBCSWRC", NULL, 0);
+    XtVaSetValues(RC,
+    	XmNpacking, XmPACK_COLUMN,
+    	XmNorientation, XmVERTICAL,
+    	XmNnumColumns, 1,
+    	NULL);
     XtVaGetValues(ToolBar,
 		  XmNchildren, &children,
 		  XmNnumChildren, &numChildren,
@@ -347,6 +357,7 @@ XltToolBarConfigure(Widget w, Widget ToolBar)
 	if (XtIsManaged(children[i]))
 	{
 	    XtManageChild(Button);
+	    numManagedChildren++;
 	}
 	else
 	{
@@ -359,6 +370,30 @@ XltToolBarConfigure(Widget w, Widget ToolBar)
     XtManageChild(FakeToolBar);
     XtManageChild(Form);
     XtManageChild(Dialog);
+    {
+    Dimension width;
+    Dimension rc_width;
+    Dimension rc_height;
+    Dimension rc_margin_height;
+    int columns;
+
+    	XtVaGetValues(FakeToolBar,
+    		XmNwidth, &width,
+    		NULL);
+    	XtVaGetValues(RC,
+    		XmNwidth, &rc_width,
+    		XmNheight, &rc_height,
+    		XmNmarginHeight, &rc_margin_height,
+    		NULL);
+    	columns = (int)(width / rc_width);
+    	XtVaSetValues(RC,
+    		XmNorientation, XmHORIZONTAL,
+    		XmNnumColumns, (int)((double)((double)numChildren + .5 * (double)columns) / (double)columns),
+    		NULL);
+    	XtVaSetValues(SW,
+    		XmNheight, ((rc_height * 4) / numManagedChildren) + 2 * rc_margin_height,
+    		NULL);
+    }
 }
 
 /* ******************** */
@@ -369,12 +404,8 @@ XltToolBarAddItem(Widget ToolBar, char *Label, char **PixmapData)
     Widget Button;
     Pixmap pixmap;
     Pixmap pixmap_insens;
-/*
-   Pixmap mask;
- */
     XpmAttributes attrib;
     GC gc;
-    Pixel bg;
 
     Button = XltCreateBubbleButton(ToolBar, Label, NULL, 0);
 
@@ -383,11 +414,10 @@ XltToolBarAddItem(Widget ToolBar, char *Label, char **PixmapData)
 	XpmColorSymbol colors[1];
 
 	XtVaGetValues(Button,
-		      XmNbackground, &bg,
+		      XmNbackground, &colors[0].pixel /*bg*/,
 		      NULL);
 	colors[0].name = NULL;
 	colors[0].value = "None";
-	colors[0].pixel = bg;
 	attrib.valuemask = XpmCloseness | XpmColorSymbols;
 	attrib.closeness = 40000;
 	attrib.colorsymbols = colors;
@@ -396,7 +426,7 @@ XltToolBarAddItem(Widget ToolBar, char *Label, char **PixmapData)
 				XRootWindowOfScreen(XtScreen(ToolBar)),
 				PixmapData,
 				&pixmap,
-				NULL /*&mask */ ,
+				NULL,
 				&attrib);
 
 	pixmap_insens = XCreatePixmap(XtDisplay(ToolBar),
@@ -405,24 +435,7 @@ XltToolBarAddItem(Widget ToolBar, char *Label, char **PixmapData)
 				      attrib.height,
 				      DefaultDepthOfScreen(XtScreen(ToolBar)));
 	gc = XDefaultGCOfScreen(XtScreen(ToolBar));
-	/*
-	   if (mask != (Pixmap)NULL)
-	   {
-	   XtVaGetValues(Button,
-	   XmNbackground, &bg,
-	   NULL);
-	   XSetBackground(XtDisplay(ToolBar),gc,bg);
-	   XSetFunction(XtDisplay(ToolBar),gc,GXor);
-	   XCopyPlane(XtDisplay(ToolBar),
-	   mask,pixmap,
-	   gc,
-	   0,0,attrib.width,attrib.height,
-	   0,0,
-	   1);
-	   XFreePixmap(XtDisplay(ToolBar),mask);
-	   }
-	   XSetFunction(XtDisplay(ToolBar),gc,GXcopy);
-	 */
+	XSetFunction(XtDisplay(ToolBar),gc,GXcopy);
 	XCopyArea(XtDisplay(ToolBar),
 		  pixmap,
 		  pixmap_insens,
@@ -433,17 +446,24 @@ XltToolBarAddItem(Widget ToolBar, char *Label, char **PixmapData)
 	XSetFillStyle(XtDisplay(ToolBar), gc, FillStippled);
 	XSetStipple(XtDisplay(ToolBar), gc,
 		    XmGetPixmapByDepth(XtScreen(ToolBar),
-				       "50_foreground",
-				       WhitePixelOfScreen(XtScreen(ToolBar)),
-				       BlackPixelOfScreen(XtScreen(ToolBar)),
-				       1)
-	    );
+				       "25_foreground",
+				       1 /*WhitePixelOfScreen(XtScreen(ToolBar))*/,
+				       0 /*BlackPixelOfScreen(XtScreen(ToolBar))*/,
+				       1));
 	XFillRectangle(XtDisplay(ToolBar),
 		       pixmap_insens,
 		       gc,
 		       0, 0,
 		       attrib.width + 1, attrib.height + 1);
 
+	{
+	XImage *image;
+
+	    image = XGetImage(XtDisplay(Button), pixmap, 
+		0, 0, attrib.width, attrib.height,
+		(unsigned long)-1, ZPixmap);
+	    XmInstallImage(image, Label);
+	}
 	XpmFreeAttributes(&attrib);
 
 	XtVaSetValues(Button,
