@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Working.c,v 1.2 1998/09/12 12:43:39 rwscott Exp $
+ * $Id: Working.c,v 1.5 1999/09/22 14:27:49 rwscott Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  *
@@ -28,7 +28,7 @@
 #include <Xm/Frame.h>
 #include <Xm/Label.h>
 
-static const char rcsid[] = "$Id: Working.c,v 1.2 1998/09/12 12:43:39 rwscott Exp $";
+static const char rcsid[] = "$Id: Working.c,v 1.5 1999/09/22 14:27:49 rwscott Exp $";
 
 typedef struct {
 	XtIntervalId Id;
@@ -68,24 +68,31 @@ StructureNotifyHandler(Widget w, Boolean *mapped, XEvent *event, Boolean *cont)
 }
 
 void
-XltWaitTillMapped(Widget w)
+XltWaitTillMapped(Widget dialog)
 {
+XWindowAttributes window_attributes;
 Boolean mapped = False;
+Widget w = dialog;
 
-    XtAddEventHandler(w,
-		StructureNotifyMask,
-		False,
-		(void *)StructureNotifyHandler,
-		(XtPointer)&mapped);
-    while (XtIsManaged(w) && !mapped)
+    while (!XtIsShell(w)) w = XtParent(w);
+    XGetWindowAttributes(XtDisplay(w), XtWindow(w), &window_attributes);
+    if (window_attributes.map_state == IsUnmapped)
     {
-	XtAppProcessEvent(XtWidgetToApplicationContext(w), XtIMXEvent);
+	XtAddEventHandler(w,
+		    StructureNotifyMask,
+		    False,
+		    (XtEventHandler)StructureNotifyHandler,
+		    (XtPointer)&mapped);
+	while (/*XtIsManaged(w) &&*/ !mapped)
+	{
+	    XtAppProcessEvent(XtWidgetToApplicationContext(w), XtIMXEvent);
+	}
+	XtRemoveEventHandler(w,
+		    StructureNotifyMask,
+		    False,
+		    (XtEventHandler)StructureNotifyHandler,
+		    (XtPointer)&mapped);
     }
-    XtRemoveEventHandler(w,
-		StructureNotifyMask,
-		False,
-		(void *)StructureNotifyHandler,
-		(XtPointer)&mapped);
     XmUpdateDisplay(w);
 }
 
@@ -113,7 +120,7 @@ char buf[1024];
 		height);
 	XmUpdateDisplay(Data->Da);
 	Data->Id = XtAppAddTimeOut(XtWidgetToApplicationContext(Data->Da),
-			    1000, (XtPointer)UpdateGraph, Data);
+			    1000, (XtTimerCallbackProc)UpdateGraph, Data);
 }
 
 Boolean
@@ -138,12 +145,12 @@ XmString string;
 			NULL);
 		XtUnmanageChild(XmMessageBoxGetChild(Dialog, XmDIALOG_HELP_BUTTON));
 		XtUnmanageChild(XmMessageBoxGetChild(Dialog, XmDIALOG_CANCEL_BUTTON));
-		XtAddCallback(Dialog, XmNokCallback, (void *)callback, &abort);
-		XtAddCallback(Dialog, XmNunmapCallback, (void *)callback, &abort);
+		XtAddCallback(Dialog, XmNokCallback, (XtCallbackProc)callback, &abort);
+		XtAddCallback(Dialog, XmNunmapCallback, (XtCallbackProc)callback, &abort);
 		XtAddEventHandler(XtParent(Dialog),
 			StructureNotifyMask,
 			False,
-			(void *)StructureNotifyHandler,
+			(XtEventHandler)StructureNotifyHandler,
 			(XtPointer)&mapped);
 		mapped = False;
 		frame = XmCreateFrame(Dialog,"Frame",NULL,0);
@@ -173,7 +180,10 @@ XmString string;
 		    NULL);
 	    XmStringFree(string);
 	}
-	Data.percent = PercentDone;
+	if (PercentDone >= 0)
+	{
+	    Data.percent = PercentDone;
+	}
 	switch (PercentDone)
 	{
 	case 0:
@@ -185,7 +195,7 @@ XmString string;
 				XtWindow(Data.Da),
 				0, 0, 0, 0, False);
 			Data.Id = XtAppAddTimeOut(XtWidgetToApplicationContext(Dialog),
-				0, (XtPointer)UpdateGraph, &Data);
+				0, (XtTimerCallbackProc)UpdateGraph, &Data);
 		}
 		break;
 	case 100:
@@ -212,10 +222,14 @@ XmString string;
 	    {
 	    XtInputMask mask;
 
-	    while ((mask = (XtAppPending(XtWidgetToApplicationContext(Dialog)) & ~XtIMAlternateInput)))
-	    {
-		XtAppProcessEvent(XtWidgetToApplicationContext(Dialog), mask);
-	    }
+		while ((mask = (XtAppPending(XtWidgetToApplicationContext(Dialog)) & ~XtIMAlternateInput)))
+		{
+		    XtAppProcessEvent(XtWidgetToApplicationContext(Dialog), mask);
+		}
+		if (!XtIsManaged(Dialog))
+		{
+		    abort = True;
+		}
 	    }
 	    break;
 	}
