@@ -1,10 +1,23 @@
 #ifndef _XRWS_H
 #define _XRWS_H
 /*
-	$Id: Xlt.h,v 1.2 1998/06/29 14:50:26 rwscott Exp $
+	$Id: Xlt.h,v 1.4 1998/11/14 21:08:58 rwscott Exp $
 */
 
+#include <assert.h>
 #include <X11/IntrinsicP.h>
+#include <Xm/PushB.h>
+
+#define XltCheckArgSize(a,n) assert(sizeof(a)/sizeof(a[0]) <= n)
+
+#define	XltGetArgs(w,a,n) { \
+	XltCheckArgSize(a, n); \
+	XtGetValues(w, a, n); \
+}
+#define	XltSetArgs(w,a,n) { \
+	XltCheckArgSize(a, n); \
+	XtSetValues(w, a, n); \
+}
 
 #ifdef __cplusplus
 extern "C" {
