@@ -1,27 +1,19 @@
-/* $Id: calc.c,v 1.15 2000/12/18 13:24:57 amai Exp $ */
-
 /* calc.c - Floating-point calculator V1.00 (C) Richard K. Lloyd 1992
    Compile using cc +O3 -s -o calc calc.c -lm */
 
-/* amai: Everything not related to usage in XLT has been removed.
-         A version closer to the original will remain somewhere deep
-         inside CVS.
-	 Finally do not try to learn programming from this hack -
-	 it's ugly and error-prone ...
-	 Check the trigonometric functions WRT degree vs. radiant!
- */
-
 #include "../config.h"
-#include "calc.h"
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
 #include <limits.h>
+#include <stdlib.h>
+#include <signal.h>
 #include <string.h>
-#include <ctype.h>
 #include <time.h>
+#include <ctype.h>
 
+#define CALC_VERSION "1.00"
 #define MAXFACTOR  148  /* Get that lipstick out ! */
 #ifndef TRUE
 #define TRUE 1
@@ -33,46 +25,58 @@
 #define M_PI 3.14159265358979323846
 #endif
 
-
-static double
-calc_drand(void)
+#ifndef HAVE_DRAND48
+double drand48(void)
 {
-#ifdef HAVE_DRAND48
-	return drand48();
-#else
-	return((double)rand()/RAND_MAX);
-#endif
+	return(((double)rand()) / ((double)RAND_MAX));
 }
-
-
-static void
-calc_srand(long int seedval)
-{
-#ifdef HAVE_SRAND48
-	srand(seedval);
 #else
+double drand48(); /* Aaargh ! You shouldn't need this !! */
+#endif
+#ifndef HAVE_SRAND48
+void srand48(long int seedval)
+{
 	srand((unsigned int)seedval);
-#endif
 }
+#endif
 
+extern int optind;
+extern char *getenv();
+extern char *strrchr();
+static void level_0();
 
-static void level_0(void);
+#if 0
+char expr_line[255];
+#else
+char *expr_line;
+#endif
+char tempstr[255];
+int exp_len,hex_format;
+int exp_error;
+char err_string[255];
+char expression[255],answer_str[255];
+int scan,equals,interact,goteof,needCR;
+double facts[MAXFACTOR];
+double operand;
+char progname[255];
+char *envstr;
 
-static char *expr_line;
-static char tempstr[255];
-static char err_string[255];
-static char expression[255],answer_str[255];
-static int exp_len,hex_format;
-static int exp_error;
-static int scan,equals,goteof;
-static int interact=FALSE;
-static double facts[MAXFACTOR];
-static double operand;
-static char *envstr;
+#if 0
+basename(slash,fullname)
+char *slash,*fullname;
+{
+   char *slashptr;
+   if ((slashptr=strrchr(fullname,'/'))==NULL)
+      strcpy(slash,fullname);
+   else
+      strcpy(slash,&slashptr[1]);
+}
+#endif
 
-
-static char
-*substr(char *mainstr, int startpos, int length)
+char *substr(mainstr,startpos,length)
+char *mainstr;
+int startpos;
+int length;
 {
    int mainsize=strlen(mainstr);
    int newpos=0;
@@ -86,8 +90,9 @@ static char
    return(tempstr);
 }
 
-static int
-instr(char *mainstr, char slicechar)
+int instr(mainstr,slicechar)
+char *mainstr;
+char slicechar;
 {
    int mainlen=strlen(mainstr);
    int slicepos=0;
@@ -100,21 +105,22 @@ instr(char *mainstr, char slicechar)
 }
 
 static void
-randomize(long newseed)
+randomize(newseed)
+long newseed;
 {
-   calc_srand(newseed);
+   srand48(newseed);
 }
 
-static double
-randval(long upper)
+double randval(upper)
+long upper;
 {
    if (upper<0) { randomize(-upper); return(upper); }
-   if (upper<=1) return(calc_drand());
-   return((long)(calc_drand()*upper+1));
+   if (upper<=1) return(drand48());
+   return((long)(drand48()*upper+1));
 }
 
 static void
-strip_expression(void)
+strip_expression()
 {
    int copy1=0;
    int copy2=0;
@@ -131,7 +137,8 @@ strip_expression(void)
 }
 
 static void
-crash(const char *error_message)
+crash(error_message)
+char *error_message;
 {
    if (!exp_error)
    {
@@ -140,8 +147,8 @@ crash(const char *error_message)
    }
 }
 
-static int
-search(char *operator)
+int search(operator)
+char *operator;
 {
    int op_len=strlen(operator);
    int found_it=FALSE;
@@ -151,15 +158,13 @@ search(char *operator)
    return(found_it);
 }
 
-static char
-next(void)
+char next()
 {
    if (scan>=exp_len || exp_error) return('\0');
    return(expression[scan++]);
 }
 
-static double
-get_number(void)
+double get_number()
 {
    char the_number[255],the_var[255],conv_str[63];
    int num_len=0;
@@ -294,33 +299,26 @@ get_number(void)
 }
 
 static void
-bracket(void)
+bracket()
 {
    level_0();
    if (next()!=')') crash("Missing bracket");
 }
 
-static double
-compute_sin(double angle)
+double compute_sin(angle)
+double angle;
 {
    return(sin(M_PI*angle/180));
 }
 
-static double 
-compute_cos(double angle)
+double compute_cos(angle)
+double angle;
 {
    return(cos(M_PI*angle/180));
 }
 
-static double 
-compute_tan(double angle)
-{
-   return(tan(M_PI*angle/180));
-}
-
-
 static void
-eval_operand(void)
+eval_operand()
 {
    if (search("INT"))
    {
@@ -349,7 +347,9 @@ eval_operand(void)
    else
    if (search("TAN"))
    {
-      eval_operand(); operand=compute_tan(operand);
+      eval_operand();
+      if (compute_cos(operand)==0) crash("Bad tangent");
+         else operand=compute_sin(operand)/compute_cos(operand);
    }
    else
    if (search("ASN"))
@@ -417,15 +417,14 @@ eval_operand(void)
    if (search("(")) bracket(); else operand=get_number();
 }
 
-
 static void
-level_4(void)
+level_4()
 {
    double temp_operand;
    eval_operand();
    while (search("^"))
    {
-      if (operand<=0.)
+      if (operand<=0)
          crash("Cannot raise zero or less to the power of a value");
       else
       {
@@ -436,9 +435,8 @@ level_4(void)
    }
 }
 
-
 static void
-level_3(void)
+level_3()
 {
    double temp_operand;
    level_4();
@@ -446,7 +444,7 @@ level_3(void)
    {
       temp_operand=operand;
       level_4();
-      if (operand==0.) crash("Division by zero");
+      if (operand==0) crash("Division by zero");
       else
       {
          if (search("%")) operand=operand/100;
@@ -455,9 +453,8 @@ level_3(void)
    }
 }
 
-
 static void
-level_2(void)
+level_2()
 {
    double temp_operand;
    level_3();
@@ -470,9 +467,8 @@ level_2(void)
    }
 }
 
-
 static void
-level_1(void)
+level_1()
 {
    double temp_operand;
    level_2();
@@ -485,9 +481,8 @@ level_1(void)
    }
 }
 
-
 static void
-level_0(void)
+level_0()
 {
     double temp_operand;
     level_1();
@@ -500,9 +495,8 @@ level_0(void)
     }
 }
 
-
 static void
-eval_statement(void)
+eval_statement()
 {
    char signstr[10];
    int ans_len;
@@ -539,11 +533,10 @@ eval_statement(void)
    }
 }
 
-
 static void
-show_help(void)
+show_help()
 {
-   printf("This is a BASIC-style expression evaluator which understands the following\n");
+   printf("%s is a BASIC-style expression evaluator which understands the following\n",progname);
    printf("operators (all trigonometrical functions use degrees):\n");
    printf("+,-,*,/,^   Addition, subtraction, multiplication, division and power.\n");
    printf("()          Brackets (overrides operator precedence).\n");
@@ -572,9 +565,8 @@ show_help(void)
    printf("TIME        Returns the number of seconds since 1st January 1970.\n");
 }
 
-
 static void
-split_line(void)
+split_line()
 {
    char lhs[255];
    int comma;
@@ -643,38 +635,172 @@ split_line(void)
    }
 }
 
-
 static void
-init(void)
+init()
 {
    int i;
-
-   facts[0]=1.;
+   facts[0]=1;
    for (i=1;i<MAXFACTOR;i++)
    {
       facts[i]=facts[i-1]*i;
    }
    randomize(time(0)); /* Equivalent to RND(-TIME) */
+   needCR=FALSE;
+   interact=TRUE;
 }
 
+#if 0
+tidy_up()
+{
+   signal(SIGINT, SIG_IGN);
+   signal(SIGQUIT, SIG_IGN);
+   printf("%s interactive mode exited.\n",progname);
+}
+#endif
 
-extern double 
-XltCalc(const char *cmd)
+#if 0
+void aborted()
+{
+   printf("\n");
+   tidy_up();
+   exit(1);
+}
+#endif
+
+#if 0
+interactive()
+{
+   signal(SIGINT, aborted);
+   signal(SIGQUIT, aborted);
+   goteof=FALSE;
+   printf("%s V%s (C) Richard K. Lloyd 1992. Type HELP for further info.\n",progname,CALC_VERSION);
+   printf("Now in interactive mode. Type EXIT or QUIT to exit.\n");
+   
+   while (!goteof)
+   {
+#ifdef DEBUG
+      printf("A=%s,",getenv("A"));
+#endif
+      printf("%s> ",progname);
+      goteof=(gets(expr_line)==NULL);
+      if (goteof)
+         printf("\n");
+      else
+         if (expr_line[0]=='!')
+         {
+            system(substr(expr_line,2,strlen(expr_line)-1));
+         }
+         else
+         {
+            strip_expression();
+            split_line();
+         }
+   }
+   tidy_up();
+}
+#endif
+
+#if 0
+get_stdin()
+{
+   goteof=FALSE;
+   while (!goteof)
+   {
+       if (!(goteof=(gets(expr_line)==NULL)))
+       {
+          strip_expression();
+          split_line();
+       }
+   }
+}
+#endif
+
+#if 0
+static void
+command_line(argc,argv)
+int argc;
+char **argv;
+{
+   interact=FALSE;
+   strcpy(expr_line,"");
+   for (;optind<argc;optind++)
+   {
+      strcat(expr_line,argv[optind]);
+   }
+   strip_expression();
+   split_line();
+}
+#endif
+
+#if 0
+usage()
+{
+   fprintf(stderr,"Syntax: %s [options] [expression[,expression...]\n",progname);
+   fprintf(stderr,"All spaces are stripped from the expression prior to evaluation.\n");
+   fprintf(stderr,"If no expression is supplied, then an interactive mode is entered.\n");
+   fprintf(stderr,"Options currently supported with %s %s are as follows:\n",progname,CALC_VERSION);
+   fprintf(stderr,"-? : Displays this syntax message.\n");
+   fprintf(stderr,"-h : Displays the interactive help.\n");
+   fprintf(stderr,"-s : Reads from standard input without entering interactive mode.\n");
+   fprintf(stderr,"-v : Displays version information.\n");
+   exit(1);
+}
+
+get_options(argc,argv)
+int argc;
+char **argv;
+{
+   int param;
+   while ((param=getopt(argc,argv,"hsv?")) != EOF)
+   {
+       switch (param)
+       {
+          case 'h':
+             show_help();
+             exit(0);
+             break;
+          case 's':
+             interact=FALSE;
+             break;
+          case 'v':
+             printf("%s version %s\n",progname,CALC_VERSION);
+             exit(0);
+             break;
+          case '?':
+             usage(); /* Bad option */
+             break;
+       }
+   }
+}
+
+int main(argc,argv)
+int argc;
+char **argv;
+{
+   init();
+   basename(progname,argv[0]);
+   get_options(argc,argv);
+   if (optind==argc) /* No parameters */
+   {
+      if (interact)
+         interactive();
+      else
+         get_stdin();
+   }
+   else
+      command_line(argc,argv);
+   return(0);
+}
+#endif
+double Calc(char *cmd)
 {
 
-	static int IsInit = FALSE;
-	int cmdlen;
-
-	if (!IsInit) {
-		init();
-		IsInit=TRUE;
-	}
+	optind = 0;
+	init();
+	interact=FALSE;
 	answer_str[0] = '\0';
-	cmdlen=strlen(cmd);
-	expr_line = (char *)malloc(cmdlen+1);
-	strcpy(expr_line, cmd);
+	expr_line = cmd;
 	strip_expression();
 	split_line();
-	free(expr_line);
 	return(operand);
 }
