@@ -40,7 +40,9 @@ static void val_changed(Widget w, XtPointer client, XtPointer call)
   printf("EntrySB #%d now: %s\n",(int)client,(char *)call);
 }
 
-int main(int argc, char *argv[])
+int main(argc, argv)
+    int argc;
+    char *argv[];
 {
   Widget toplevel,tester,rowcol;
   XtAppContext app_context;
