@@ -1,3 +1,5 @@
+/* $Id: test1.c,v 1.5 1999/10/26 09:16:26 amai Exp $ */
+
 #include <stdio.h>
 #include <Host.h>
 #include <Stroke.h>
@@ -79,11 +81,11 @@ main(int argc, char **argv)
 
   XtManageChild(Connect);
   XtManageChild(form);
-  XtAddCallback(Host, XltNconnectCallback, (void *)Callback, NULL);
-  XtAddCallback(Host, XltNasciiInputCallback, (void *)AsciiInputCallback, one);
-  XtAddCallback(Host, XltNbinaryInputCallback, (void *)BinaryInputCallback, NULL);
-  XtAddCallback(Host, XltNinputCallback, (void *)InputCallback, NULL);
-  XtAddCallback(Connect, XmNactivateCallback, (void *)XltHostSelect, Host);
+  XtAddCallback(Host, XltNconnectCallback, (XtCallbackProc)Callback, NULL);
+  XtAddCallback(Host, XltNasciiInputCallback, (XtCallbackProc)AsciiInputCallback, one);
+  XtAddCallback(Host, XltNbinaryInputCallback, (XtCallbackProc)BinaryInputCallback, NULL);
+  XtAddCallback(Host, XltNinputCallback, (XtCallbackProc)InputCallback, NULL);
+  XtAddCallback(Connect, XmNactivateCallback, (XtCallbackProc)XltHostSelect, Host);
   XtRealizeWidget(toplevel);
   {
   String port;
