@@ -1,5 +1,5 @@
 /*
-    $Id: test1.c,v 1.4 2000/06/29 10:05:34 amai Exp $
+    $Id: test1.c,v 1.2 1998/09/12 14:30:35 rwscott Exp $
 
     stroke.c is a test program for the Stroke library.
     Copyright (C) 1997  Richard Scott
@@ -19,11 +19,10 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 #include <stdlib.h>
-#include <stdarg.h>
-#include <string.h>
 #include <unistd.h>
 #include <signal.h>
 #include <stdio.h>
+#include <varargs.h>
 #include <values.h>
 
 #include <Xm/RowColumn.h>
@@ -52,12 +51,12 @@
 #endif
 #include <Xlt.h>
 
+int getopt();
 
 char *Program;
-
 Widget AppShell;
 XtAppContext    Context;
-static char rcsid[]="$Id: test1.c,v 1.4 2000/06/29 10:05:34 amai Exp $";
+static char rcsid[]="$Id: test1.c,v 1.2 1998/09/12 14:30:35 rwscott Exp $";
 typedef struct {
 	Boolean Sounds;
 	String StartupSound;
@@ -89,18 +88,19 @@ static XrmOptionDescRec opTable[] = {
 	{"-debug",".debug",XrmoptionSepArg, NULL},
 };
 
-static void ClearDA(void);
+static void ClearDA();
 
-static void DisplayVersion(void);
-static void DisplayCopyright(void);
-static void DisplayLicense(void);
+static void DisplayVersion();
+static void DisplayCopyright();
+static void DisplayLicense();
 
 static XtActionsRec GlobalActions[] = {
-	{"DisplayVersion", (XtActionProc)DisplayVersion},
-	{"DisplayCopyright", (XtActionProc)DisplayCopyright},
-	{"DisplayLicense", (XtActionProc)DisplayLicense},
+	{"DisplayVersion", DisplayVersion},
+	{"DisplayCopyright", DisplayCopyright},
+	{"DisplayLicense", DisplayLicense},
 	{"Exit", (XtActionProc)exit},
-	{"ClearDA", (XtActionProc)ClearDA},
+
+	{"ClearDA", ClearDA},
 };
 
 static char *FallBack[] = {
@@ -139,13 +139,14 @@ static char *FallBack[] = {
 
 /* ******************** */
 
-void debug(int no, ...)
+void debug(va_alist)
+va_dcl
 {
 va_list args;
 char    *fmt;
 int     level;
 
-        va_start(args, no);
+        va_start(args);
         level = va_arg(args,int);
         if (level <= AppResources.debug)
         {
@@ -199,7 +200,7 @@ FILE *xrdb;
 
 /* ******************** */
 
-static void DoNothing(void)
+static void DoNothing()
 {
 	/*
 		This is necessary to ensure not more than 250 mS delay from
@@ -207,7 +208,7 @@ static void DoNothing(void)
 		be re-started and the WorkProc will not be noticed until
 		another Xevent is processed!
 	*/
-	XtAppAddTimeOut(Context,250,(XtTimerCallbackProc)DoNothing,NULL);
+	XtAppAddTimeOut(Context,250,DoNothing,NULL);
 }
 
 /* ******************** */
@@ -269,7 +270,10 @@ static void ToggleStrokeDebug(Widget W, Boolean *state)
 
 /* ******************** */
 
-static Widget CreateOptionPulldown(Widget parent, Arg *args_in, int n_in)
+static Widget CreateOptionPulldown(parent,args_in,n_in)
+Widget  parent;
+Arg     *args_in;
+int     n_in;
 {
 Widget  PulldownMenu,
         Button;
@@ -313,7 +317,7 @@ Widget  PulldownMenu,
 
 /* ******************** */
 
-static void DisplayLicense(void)
+static void DisplayLicense()
 {
 static Widget Dialog;
 String msg = "\n\
@@ -561,9 +565,9 @@ POSSIBILITY OF SUCH DAMAGES.\n\
 
 /* ******************** */
 
-static void DisplayCopyright(void)
+static void DisplayCopyright()
 {
-String msg = "stroke $Revision: 1.4 $\n\
+String msg = "stroke $Revision: 1.2 $\n\
 \n\
 Copyright (C) 1997 Richard Scott\n\
 \n\
@@ -580,14 +584,14 @@ click `Help->License' for details.\n\
 
 /* ******************** */
 
-static void DisplayVersion(void)
+static void DisplayVersion()
 {
 String msg = "stroke\n\
 A stroke test program for the X11\n\
 window system and Motif\n\
 \n\
 by Rick Scott <rwscott@magi.com>\n\
-$Revision: 1.4 $";
+$Revision: 1.2 $";
 
 	debug(5,"DisplayVersion(%s)\n",rcsid);
         Info(msg);
@@ -595,7 +599,10 @@ $Revision: 1.4 $";
 
 /* ******************** */
 
-static Widget CreateFilePulldown(Widget  parent, Arg *args_in, int n_in)
+static Widget CreateFilePulldown(parent,args_in,n_in)
+Widget  parent;
+Arg     *args_in;
+int     n_in;
 {
 Widget  PulldownMenu,
         Button;
@@ -618,7 +625,7 @@ Widget  PulldownMenu,
 
 /* ******************** */
 
-static void ClearDA(void)
+static void ClearDA()
 {
 Widget mainDA = XtNameToWidget(AppShell, "*mainDA");
 
@@ -629,7 +636,10 @@ Widget mainDA = XtNameToWidget(AppShell, "*mainDA");
 
 /* ******************** */
 
-static Widget CreateEditPulldown(Widget  parent, Arg *args_in, int n_in)
+static Widget CreateEditPulldown(parent,args_in,n_in)
+Widget  parent;
+Arg     *args_in;
+int     n_in;
 {
 Widget  PulldownMenu,
         Button;
@@ -650,7 +660,10 @@ Widget  PulldownMenu,
 
 /* ******************** */
 
-static Widget CreateHelpPulldown(Widget  parent, Arg *args_in, int n_in)
+static Widget CreateHelpPulldown(parent,args_in,n_in)
+Widget  parent;
+Arg     *args_in;
+int     n_in;
 {
 Widget  HelpMenu,
         Button;
@@ -682,7 +695,10 @@ Widget  HelpMenu,
 
 /* ******************** */
 
-static Widget CreateMenus(Widget parent, Arg *args_in, int n_in)
+static Widget CreateMenus(parent,args_in,n_in)
+Widget  parent;
+Arg     *args_in;
+int     n_in;
 {
 Widget  MenuBar;
 
@@ -707,25 +723,27 @@ static void GetApplicationResources(Widget W)
 
 /* ******************** */
 
-static void ExposeDA(void)
+static void ExposeDA()
 {
 }
 
 /* ******************** */
 
-static void ResizeDA(void)
+static void ResizeDA()
 {
 }
 
 /* ******************** */
 
-static void InputDA(void)
+static void InputDA()
 {
 }
 
 /* ******************** */
 
-int main(int	argc, char *argv[])
+int main(argc,argv)
+int	argc;
+char	*argv[];
 {
 Widget		Form,
 		Menus;
