@@ -1,4 +1,4 @@
-/* $Id: test1.c,v 1.4 2000/08/25 09:44:57 amai Exp $ */
+/* $Id: test1.c,v 1.3 1999/10/26 09:16:30 amai Exp $ */
 
 #include <Xm/PushB.h>
 #include <Xm/Label.h>
@@ -22,7 +22,7 @@
 #include "view_trans.xpm"
 
 void
-debug(void)
+debug()
 {
 }
 
