@@ -1,9 +1,8 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/ComboBox.c,v 1.48 2000/12/20 19:48:31 amai Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/ComboBox.c,v 1.40 1999/10/26 09:25:14 amai Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
- * Copyright (C) 1997-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,11 +22,12 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/ComboBox.c,v 1.48 2000/12/20 19:48:31 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/ComboBox.c,v 1.40 1999/10/26 09:25:14 amai Exp $";
+
 
 #include <LTconfig.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/ListP.h>
 #include <Xm/TextFP.h>
@@ -112,7 +112,7 @@ static void CheckMinimalSize(Widget w, XtWidgetGeometry *reply);
 #if 0
 static void CheckSetRenderTable(Widget w);
 #endif
-static void ClassInitialize(void);
+static void ClassInitialize();
 static void ClassPartInitialize(WidgetClass class);
 static void ComboBoxParentProcess(Widget w);
 static void ComputeSize(Widget w, XtWidgetGeometry *reply);
@@ -180,7 +180,6 @@ static void ComboBoxFocusMovedCB(Widget w, XtPointer client_data, XtPointer data
 static void _LTTranslateCoords(Widget w, Position x, Position y, Position *rootx, Position *rooty);
 static void _LTShellSmartPlacement(Widget w);
 static void __LTShellSmartPlacement(Widget w, int *ret_x, int *ret_y);
-static void GetValuesHook(Widget w, ArgList args, Cardinal *num_args);
 
 
 #define VALID(w) (w && XtIsManaged(w))
@@ -402,7 +401,7 @@ static XmSyntheticResource syn_resources[] = {
       Offset(arrow_spacing),
       _XmFromHorizontalPixels,
       _XmToHorizontalPixels
-   },
+   }
 
 };
 
@@ -456,7 +455,7 @@ XmComboBoxClassRec xmComboBoxClassRec = {
       SetValues,                              /* set_values */
       NULL,                                   /* set_values_hook */
       XtInheritSetValuesAlmost,               /* set_values_almost */
-      GetValuesHook,                          /* get_values_hook */
+      NULL,                                   /* get_values_hook */
       NULL,                                   /* accept_focus */
       XtVersion,                              /* version */
       NULL,                                   /* callback offsets */
@@ -560,7 +559,7 @@ CBActivate(
 {
    DEBUGOUT(XdbDebug(__FILE__, w, "%s:CBActivate ...\n",
    	__FILE__));
-#if 0
+   #if 0
    FindComboBox();
    CallSelectionCallbacks(); 
    if (CB_Type(w) == XmDROP_DOWN_COMBO_BOX ||
@@ -569,7 +568,7 @@ CBActivate(
    	PopdownList();
    }
    ComboBoxParentProcess();
-#endif
+   #endif
 }
 
 static void 
@@ -603,10 +602,10 @@ CBCancel(
    String *params, 
    Cardinal *num_params)
 {
-#if 0
+   #if 0
    FindComboBox();
    ComboBoxParentProcess();
-#endif
+   #endif
 }
 
 static void 
@@ -616,10 +615,10 @@ CBDisarm(
    String *params, 
    Cardinal *num_params)
 {
-#if 0
+   #if 0
    FindComboBox();
    DrawArrow();
-#endif
+   #endif
 }
 
 static void 
@@ -656,14 +655,14 @@ CBDropDownList(
    /* pop it up */
    _XmPopupSpringLoaded(CB_ListShell(w));
 
-#if 0
+   #if 0
    XtPopup(CB_ListShell(w), XtGrabNone);
-#endif
+   #endif
 
-#if 0
+   #if 0
    PopdownList();
    CBDisarm();
-#endif
+   #endif
 }
 
 static void 
@@ -693,9 +692,9 @@ CBFocusOut(Widget w, XEvent *event, String *params, Cardinal *num_params)
 
    UnhighlightBorder(w);
 
-#if 0
+   #if 0
    CallSelectionCallbacks(); 
-#endif
+   #endif
 }
 
 #if 0
@@ -706,9 +705,9 @@ CBGetSelectedItem(
    String *params, 
    Cardinal *num_params)
 {
-#if 0
+   #if 0
    GetEditBoxValue();
-#endif
+   #endif
 }
 #endif
 
@@ -767,19 +766,19 @@ CBListAction(
 
       XtVaGetValues(CB_List(w), XmNitemCount, &item_cnt,
                                 NULL);
-#if 0
+      #if 0
       /* FIXME: these resources need to be implemented in the list box */
       XtVaGetValues(CB_List(w), XmNselectedPositions, &selected_pos,
                                 XmNselectedPositionCount, &selected_pos_cnt,
                                 NULL);
 
-#else
+      #else
       if (XmListGetSelectedPos(CB_List(w), &selected_pos, &selected_pos_cnt) == FALSE)
       {
          selected_pos_cnt = 0;
       }
 
-#endif
+      #endif
       if(selected_pos_cnt <= 0)
       {
          pos = 1;
@@ -790,11 +789,11 @@ CBListAction(
          if (selected_pos)
          {
             pos = *selected_pos; /* pick first item */
-#if 0  /* FIXME: XmNselectedPositions is not implemented. */
-#else
+            #if 0  /* FIXME: XmNselectedPositions is not implemented. */
+            #else
             /* Free allocates memory by XmListGetSelectedPos for the selected_pos array */
             XtFree((char *)selected_pos);
-#endif
+            #endif
          }
          else
          {
@@ -831,10 +830,10 @@ CBSetSelectedItem(
    String *params, 
    Cardinal *num_params)
 {
-#if 0
+   #if 0
    GetEditBoxValue();
    SetEditBoxValue();
-#endif
+   #endif
 }
 #endif
 
@@ -946,7 +945,7 @@ CheckSetRenderTable(Widget w)
   END:
 */
 static void
-ClassInitialize(void)
+ClassInitialize()
 {
    /* parse translations */
    parsed_list_translations = XtParseTranslationTable(
@@ -975,12 +974,12 @@ ComboBoxParentProcess(Widget w)
    /* FIXTHIS: ComboBoxParentProcess needs to be implemented. */
    Unused(w);
 
-#if 0
+   #if 0
    PopdownList();
    CBDisarm();
    GetEditBoxValue();
    CallSelectionCallbacks();
-#endif
+   #endif
 }
 
 /*
@@ -1131,11 +1130,11 @@ ComputeSizeComboBox(Widget w, XtWidgetGeometry *reply)
    reply->width = e_pref.width;
    reply->height = e_pref.height;
 
-#if 0
+   #if 0
    /* start with the size of edit box */
    reply->width = CB_IdealEBWidth(w);
    reply->height = CB_IdealEBHeight(w);
-#endif
+   #endif
 
    /* add the height of scrolled window if type is XmCOMBO_BOX */
    /*
@@ -1175,11 +1174,11 @@ ComputeSizeDropDown(Widget w, XtWidgetGeometry *reply)
    reply->width = e_pref.width;
    reply->height = e_pref.height;
 
-#if 0
+   #if 0
    /* start with the size of edit box */
    reply->width = CB_IdealEBWidth(w);
    reply->height = CB_IdealEBHeight(w);
-#endif
+   #endif
 
    /*
       REMARK:
@@ -1360,22 +1359,22 @@ CreatePulldown(Widget w)
    {
       XtSetArg(args[n], XmNownerEvents, True); n++;
       
-#if 0
+      #if 0
       /* FIXTHIS: GrabModeSync handling is broken in the grab shell. */
       XtSetArg(args[n], XmNgrabStyle, GrabModeSync); n++;
-#endif
+      #endif
 
       /* Despite the function name a GrabShell widget is used */
       CB_ListShell(w) = XmCreateGrabShell(w,CB_LIST_SHELL_CN,args,n);
 
-#if 1
+      #if 1
       /* Why am I doing this? */
 
       /* Add focus handler */
       XmeAddFocusChangeCallback(CB_ListShell(w), 
                                 (XtCallbackProc) ShellFocusMovedCB, 
                                 (XtPointer) w);
-#endif
+      #endif
 
       XtAddCallback(CB_ListShell(w),
                     XmNpopdownCallback, 
@@ -1453,9 +1452,9 @@ CreateScrolledList(Widget w)
                  (XtCallbackProc) ListSelectionCB,
                  (XtPointer) w);
 
-#if 0
+   #if 0
    SetEditBoxValue();
-#endif
+   #endif
 }
 
 /*
@@ -1869,9 +1868,9 @@ GeometryManager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
        *reply = *request;
    return (XtGeometryResult) XtGeometryYes;
 
-#if 0
+   #if 0
    CheckMinimalSize();
-#endif
+   #endif
 }
 
 /*
@@ -2133,7 +2132,7 @@ PopupEH(Widget w, XtPointer udata, XEvent *xev, Boolean *pb)
    /* Call our action procedure */
    XtCallActionProc(w, "CBArmAndDropDownList", xev, NULL, 0);
    
-#if 0
+   #if 0
    /* Is the grab shell managed? */
    if (!XtIsManaged(CB_ListShell(w)))
    {
@@ -2154,7 +2153,7 @@ PopupEH(Widget w, XtPointer udata, XEvent *xev, Boolean *pb)
       CBDisarm(w,xev,NULL,NULL);
       */
    }
-#endif
+   #endif
 }
 
 /*
@@ -2452,10 +2451,10 @@ SetValues(Widget old,
           Cardinal *num_args)
 {
    Boolean need_refresh = False;
-#if 0
+   #if 0
    XmComboBoxWidget ow = (XmComboBoxWidget) old;
    XmComboBoxWidget nw = (XmComboBoxWidget) c_new;
-#endif
+   #endif
 
    /* FIXTHIS: */
 
@@ -2529,9 +2528,9 @@ ShellPopdownCB(Widget w, XtPointer client_data, XtPointer data)
    Unused(client_data);
    Unused(data);
 
-#if 0
+   #if 0
    CBFocusOut();
-#endif
+   #endif
 } 
 
 static void
@@ -2797,10 +2796,10 @@ AdjustKidsDropDown(Widget w)
    shell_width = edit_width + CB_ArrowSize(w) + CB_ArrowSpacing(w)
                  + (2*(MGR_ShadowThickness(w) + CB_MarginWidth(w)));
 
-#if 0
+   #if 0
    shell_width = XtWidth(w)
                  - (2*CB_HighlightThickness(w));
-#endif
+   #endif
 
    shell_height = XtHeight(CB_ListShell(w));
 
@@ -3099,9 +3098,8 @@ The text field widget is called "Text".
   END:
 */
 
-
-extern void
-XmComboBoxAddItem(Widget w, XmString xms, int a, Boolean unique)
+void
+XmComboBoxAddItem(Widget w, XmString xms, int a, int b)
 {
 	char    *s = NULL;
 	XmStringGetLtoR(xms, XmFONTLIST_DEFAULT_TAG, &s);
@@ -3109,7 +3107,7 @@ XmComboBoxAddItem(Widget w, XmString xms, int a, Boolean unique)
 	fprintf(stderr, "XmComboBoxAddItem(%s,%d,%d)\n", s, a, b);
 #endif
 	XtFree(s);
-      /* FIXME: what about 'unique' ?? */
+
 	XmListAddItemUnselected(CB_List(w), xms, a);
 }
 
@@ -3215,14 +3213,14 @@ _LTShellSmartPlacement(Widget w)
 {
     int x,y;
 
-#if 0
+    #if 0
     /* Is shell realized? */
     if(!XtIsRealized(w))
     {
         /* Force size calculation */
         XtRealizeWidget(w);
     }
-#endif
+    #endif
 
     __LTShellSmartPlacement(w, &x, &y);
 
@@ -3230,23 +3228,3 @@ _LTShellSmartPlacement(Widget w)
     if(XtX(w) != x || XtY(w) != y) XtVaSetValues(w, XmNx, x, XmNy, y, NULL);
 }
 
-static void
-GetValuesHook(Widget w, ArgList args, Cardinal *num_args)
-{
-	int	i;
-	XrmQuark	tf = XrmStringToQuark(XmNtextField), q,
-			l = XrmStringToQuark(XmNlist);
-	XtPointer	*p;
-
-	for (i=0; i<*num_args; i++) {
-		q = XrmStringToQuark(args[i].name);
-		if (q == tf) {	/* XmNtextField */
-			p = (XtPointer) args[i].value;
-			*p = (XtPointer)XtNameToWidget(w, "Text");
-		} else if (q == l) {	/* XmNlist */
-			p = (XtPointer) args[i].value;
-			*p = (XtPointer)CB_List(w);
-		} else {
-		}
-	}
-}
