@@ -1,9 +1,8 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/GrabShell.c,v 1.18 2000/09/23 15:05:26 amai Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/GrabShell.c,v 1.16 1999/01/28 21:03:17 pgw Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
- * Copyright (C) 1997-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,18 +22,20 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/GrabShell.c,v 1.18 2000/09/23 15:05:26 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/GrabShell.c,v 1.16 1999/01/28 21:03:17 pgw Exp $";
 
 
 #include <LTconfig.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/GrabShellP.h>
 #include <Xm/MwmUtil.h>
 #include <Xm/TransltnsP.h>
 #include <Xm/MenuUtilP.h>
+
 #include <XmI/PixConvI.h>
+
 #include <XmI/MessagesI.h>
 #include <XmI/DebugUtil.h>
 #include <XmI/PopupUtil.h>
@@ -855,22 +856,22 @@ MapNotifyHandler(Widget w, XtPointer cdata, XEvent *xev, Boolean *pb)
 
    ForceExpose(w);
 
-#if 1
-#if 1
+   #if 1
+   #if 1
    _XmGrabShellGrab(w, GS_PostTime(w));
-#else
+   #else
    _XmGrabShellGrab(w, CurrentTime);
-#endif
-#endif
+   #endif
+   #endif
 
    /* Only needed if using GrabModeSync..I think */
    event_mode = (GS_GrabStyle(w) == GrabModeSync) ? SyncBoth : AsyncBoth;
 
-#if 1
+   #if 1
    _XmAllowEvents(w, event_mode, GS_PostTime(w));
-#else
+   #else
    _XmAllowEvents(w, event_mode, CurrentTime);
-#endif
+   #endif
 
    /* The time parameter is ignored on a XmGRAB_SHELL_FOCUS_SAVE */
    _XmGrabShellFocus(w, XmGRAB_SHELL_FOCUS_SAVE, GS_PostTime(w));
