@@ -1,9 +1,10 @@
+#undef	CREATE_SCROLLER_IN_REALIZE
+#define	LARGE_PAGE
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Notebook.c,v 1.31 2000/11/06 09:40:18 amai Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Notebook.c,v 1.24 1999/09/19 16:34:13 rwscott Exp $
  *
  * Copyright (C) 1997-1998 Free Software Foundation, Inc.
- * Copyright (C) 1998-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +24,8 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Notebook.c,v 1.31 2000/11/06 09:40:18 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Notebook.c,v 1.24 1999/09/19 16:34:13 rwscott Exp $";
+
 
 /*
  * This is a widget whose main purpose is to do geometry management for its
@@ -49,19 +51,15 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Notebo
  * XmPushButton, XmPushButtonGadget, XmArrowButton, XmArrowButtonGadget,
  * XmText, XmTextField, XmScrollBar, XmDrawnButton; and all their subclasses.
  */
-
-/* definitions used below */
-#define	LARGE_PAGE
 #define	TRAIT_WORKAROUND
 
 #include <LTconfig.h>
-
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <XmI/DebugUtil.h>
 
 #include <Xm/NotebookP.h>
-#include <Xm/XpmP.h>
+#include <XmI/XmXpm.h>
 
 /*
  * Traits used by Notebook
@@ -88,10 +86,9 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Notebo
 #include <Xm/ScrollBar.h>
 #endif
 
-
 /* Forward Declarations */
 
-static void ClassInitialize(void);
+static void ClassInitialize();
 
 static void ClassPartInitialize(WidgetClass w_class);
 
@@ -510,7 +507,7 @@ XmNotebookClassRec xmNotebookClassRec = {
 WidgetClass xmNotebookWidgetClass = (WidgetClass)&xmNotebookClassRec;
 
 static void
-ClassInitialize(void)
+ClassInitialize()
 {
     _XmNotebookCoreClassExtRec.record_type = XmQmotif;
 
@@ -712,6 +709,7 @@ Initialize(Widget request, Widget nw,
 		      "Notebook initialize: w/h %d %d\n",
 		      XtWidth(nw), XtHeight(nw)));
 
+    NB_DynamicLastPageNum(nw) = False;
     NB_ScrollerChild(nw) = NULL;
 
     XtSetArg(al[0], XmNnotebookChildType, XmMINOR_TAB);
@@ -749,6 +747,7 @@ Initialize(Widget request, Widget nw,
     XtHeight(nw) = 100;
 #endif
 
+#ifndef CREATE_SCROLLER_IN_REALIZE
     /*
      * The spec says this should happen in Realize() but that's a really odd
      *	and inconvenient place.
@@ -767,29 +766,8 @@ Initialize(Widget request, Widget nw,
 		xmTextFieldWidgetClass, NB_Scroller(nw), al, 2);
 
 	XtManageChild(NB_Scroller(nw));
-
-    } else {
-	XmNavigatorTrait		t;
-	XmNavigatorDataRec		nd;
-	XmTwoDIntRec			ndmin, ndmax, ndval;
-	/*
-	 * Update the scroller for first/last page
-	 * This also happens in SetValues().
-	 */
-	t = XmeTraitGet(XtClass(NB_Scroller(nw)), XmQTnavigator);
-	if (t) {
-		nd.valueMask = NavValue | NavMinimum | NavMaximum;
-		nd.value = &ndval;
-		nd.minimum = &ndmin;
-		nd.maximum = &ndmax;
-
-		ndval.x = 0;	/* FIX ME */
-		ndmin.x = NB_FirstPageNumber(nw);
-		ndmax.x = NB_LastPageNumber(nw);
-
-		t->setValue(NB_Scroller(nw), &nd, True);
-	}
     }
+#endif
 }
 
 static void
@@ -834,32 +812,6 @@ SetValues(Widget old, Widget request, Widget nw,
 	need_refresh = True;
     }
 
-    if (NE(NB_LastPageNumber)) {
-	NB_DynamicLastPageNum(nw) = False;
-    }
-
-    if (NE(NB_FirstPageNumber) || NE(NB_LastPageNumber)) {
-	XmNavigatorTrait		t;
-	XmNavigatorDataRec		nd;
-	XmTwoDIntRec			ndmin, ndmax, ndval;
-	/*
-	 * Use trait method to update XmPAGE_SCROLLER
-	 */
-	if (NB_Scroller(nw)) {
-	    t = XmeTraitGet(XtClass(NB_Scroller(nw)), XmQTnavigator);
-	    if (t) {
-		nd.valueMask = NavMinimum | NavMaximum;
-		nd.minimum = &ndmin;
-		nd.maximum = &ndmax;
-
-		ndmin.x = NB_FirstPageNumber(nw);
-		ndmax.x = NB_LastPageNumber(nw);
-
-		t->setValue(NB_Scroller(nw), &nd, True);
-	    }
-	}
-    }
-
     need_refresh = True;	/* FIX ME */
 
     return need_refresh;
@@ -984,7 +936,7 @@ resize(Widget w)
 static void
 _XmNBTabCallback(Widget w, XtPointer client, XtPointer call)
 {
-	int			r = (int)(long)client;
+	int			r = (int)client;
 	XmAnyCallbackStruct	*cbp = (XmAnyCallbackStruct *)call;
 
 	DEBUGOUT(XdbDebug(__FILE__, w, "_XmNBTabCallback\n"));
@@ -1143,7 +1095,7 @@ ConstraintInitialize(Widget request, Widget nw,
 	t = XmeTraitGet(XtClass(nw), XmQTactivatable);
 	if (t)
 		((XmActivatableTrait)t)->changeCB(nw,
-			_XmNBTabCallback, (XtPointer)(long)rc,
+			_XmNBTabCallback, (XtPointer)rc,
 			True);	/* Add it */
 	else
 		_XmWarning(nw, "has no XmQTactivatable trait\n");
@@ -1181,11 +1133,9 @@ ConstraintInitialize(Widget request, Widget nw,
 	} else {
 	    /* FIX ME */
 
-	}
-	if (NB_FirstPageNumber(nb) > NBC_PageNumber(nw)) {
+	    if (NB_FirstPageNumber(nb) > NBC_PageNumber(nw))
 		NB_FirstPageNumber(nb) = NBC_PageNumber(nw);
-	}
-	if (NB_DynamicLastPageNum(nb) && (NB_LastPageNumber(nb) < NBC_PageNumber(nw))) {
+	    if (NB_LastPageNumber(nb) < NBC_PageNumber(nw))
 		NB_LastPageNumber(nb) = NBC_PageNumber(nw);
 	}
 
@@ -1626,12 +1576,12 @@ _XmNBDefaultLastPageNumber(Widget w, int offset, XrmValue *val)
 static void
 _XmNBCreateSpiralPixmap(Widget w)
 {
-	XpmAttributes   attrib; 
+	_LtXpmAttributes   attrib; 
         Pixmap          mask;
 
 	attrib.valuemask = 0;
 
-	XpmCreatePixmapFromData(XtDisplay(w),
+	_LtXpmCreatePixmapFromData(XtDisplay(w),
                 XRootWindowOfScreen(XtScreen(w)),
                 spiral,
                 &NB_SpiralPixmap(w),
@@ -1706,6 +1656,26 @@ Realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
     (*superclass->core_class.realize) (w, value_mask, attributes);
 #undef superclass
 
+#ifdef	CREATE_SCROLLER_IN_REALIZE
+    /*
+     * This is an odd place to do this, but that's what the spec says.
+     */
+    if (NB_Scroller(w) == NULL) {
+	Arg	al[1];
+
+	NB_Scroller(w) = XtCreateWidget("PageScroller",
+		xmSpinBoxWidgetClass, w, NULL, 0);
+
+	/* FIX ME should we add a child to it ? */
+	XtSetArg(al[0], XmNspinBoxChildType, XmNUMERIC);
+
+	(void) XtCreateManagedWidget("TextField",
+		xmTextFieldWidgetClass, NB_Scroller(w), al, 1);
+
+	XtManageChild(NB_Scroller(w));
+    }
+#endif
+
     if (NB_SpiralPixmap(w) == XmUNSPECIFIED_PIXMAP)
 	   _XmNBCreateSpiralPixmap(w);
 
