@@ -1,9 +1,8 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.39 2001/08/06 15:50:11 dannybackx Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/SpinBox.c,v 1.23 1999/01/21 22:36:04 danny Exp $
  *
  * Copyright (C) 1997-1998 Free Software Foundation, Inc.
- * Copyright  1998, 1999, 2000, 2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,27 +22,27 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.39 2001/08/06 15:50:11 dannybackx Exp $";
-
-#include <LTconfig.h>
+static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/SpinBox.c,v 1.23 1999/01/21 22:36:04 danny Exp $";
 
 #include <stdio.h>
-
+#include <LTconfig.h>
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
+#include <XmI/DebugUtil.h>
+
 #include <Xm/SpinBP.h>
+
 #include <Xm/Text.h>
 #include <Xm/TextF.h>
+
 #include <Xm/TraitP.h>
 #include <Xm/AccTextT.h>
 #include <Xm/NavigatorT.h>
 #include <Xm/ScrollFrameT.h>
 
-#include <XmI/DebugUtil.h>
-
 /* Forward Declarations */
 
-static void class_initialize(void);
+static void class_initialize();
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -113,11 +112,6 @@ static XtResource resources[] =
 	sizeof(unsigned char), Offset(arrow_layout),
 	XmRImmediate, (XtPointer)XmARROWS_END
     },
-    {
-	XmNarrowOrientation, XmCArrowOrientation, XmRArrowOrientation,
-	sizeof(unsigned char), Offset(arrow_orientation),
-	XmRImmediate, (XtPointer)XmARROWS_VERTICAL
-    },
     {
 	XmNarrowSize, XmCArrowSize, XmRArrowSize,
 	sizeof(Dimension), Offset(arrow_size),
@@ -204,9 +198,6 @@ static XtActionsRec actions[] =
 	{"SpinBoxFocusOut",	SpinBoxFocusOut}
 };
 
-/*
- * Constraint resources, i.e. resources magically added to all XmSpinBox children.
- */
 #define Offset(field) XtOffsetOf(XmSpinBoxConstraintRec, spinBox.field)
 static XtResource ConstraintResources[] = {
     {
@@ -244,11 +235,6 @@ static XtResource ConstraintResources[] = {
 	sizeof(int), Offset(position),
 	XmRImmediate, (XtPointer)0
     },
-    {
-	XmNpositionType, XmCPositionType, XmRChar,
-	sizeof(unsigned char), Offset(position_type),
-	XmRImmediate, (XtPointer)XmPOSITION_VALUE
-    },
     {
 	XmNspinBoxChildType, XmCSpinBoxChildType, XmRSpinBoxChildType,
 	sizeof(unsigned char), Offset(sb_child_type),
@@ -258,12 +244,7 @@ static XtResource ConstraintResources[] = {
 	XmNvalues, XmCValues, XmRXmStringTable,
 	sizeof(XmStringTable), Offset(values),
 	XmRImmediate, (XtPointer)NULL
-    },
-    {
-	XmNpositionType, XmCPositionType, XmRChar,
-	sizeof(unsigned char), Offset(position_type),
-	XmRImmediate, (XtPointer)XmPOSITION_INDEX
-    },
+    }
 };
 
 /* FIX ME - this should go in other files */
@@ -299,6 +280,7 @@ char _XmSpinBox_ChildAccelerators[] =
 	"<Key>osfBeginData:		SpinBFirst()\n"
 	"<Key>osfEndData:		SpinBLast()\n";
 
+/* *INDENT-OFF* */
 static XmBaseClassExtRec _XmSpinBoxCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -414,6 +396,7 @@ XmSpinBoxClassRec xmSpinBoxClassRec = {
 	/* extension */ NULL,
     },
 };
+/* *INDENT-ON* */
 
 
 WidgetClass xmSpinBoxWidgetClass = (WidgetClass)&xmSpinBoxClassRec;
@@ -426,14 +409,12 @@ XmNavigatorTraitRec _XmSPBNavigatorTraitRec = {
 };
 
 static void
-class_initialize(void)
+class_initialize()
 {
     _XmSpinBoxCoreClassExtRec.record_type = XmQmotif;
 
-    XmeTraitSet((XtPointer)xmSpinBoxWidgetClass, XmQTnavigator,
-                (XtPointer)&_XmSPBNavigatorTraitRec);
-    XmeTraitSet((XtPointer)xmSpinBoxWidgetClass, XmQTnavigator,
-                (XtPointer)&_XmSPBNavigatorTraitRec);
+    XmeTraitSet(xmSpinBoxWidgetClass, XmQTnavigator, &_XmSPBNavigatorTraitRec);
+    XmeTraitSet(xmSpinBoxWidgetClass, XmQTnavigator, &_XmSPBNavigatorTraitRec);
 }
 
 static void
@@ -472,11 +453,11 @@ initialize(Widget request, Widget nw,
 {
 	XmScrollFrameTrait	t;
 
-	DEBUGOUT(_LtDebug(__FILE__, nw,
+	DEBUGOUT(XdbDebug(__FILE__, nw,
 		      "SpinBox initialize: w/h %d %d\n",
 		      XtWidth(nw), XtHeight(nw)));
 #if 0
-	DEBUGOUT(_LtDebugPrintArgList(__FILE__, nw, args, *num_args, False));
+	DEBUGOUT(XdbPrintArgList(__FILE__, nw, args, *num_args, False));
 #endif
 
 	SPB_TextW(nw) = NULL;
@@ -490,7 +471,7 @@ initialize(Widget request, Widget nw,
 	}
 
 	/* Find out if our parent is a ScrollFrame */
-	t = (XmScrollFrameTrait) XmeTraitGet((XtPointer)XtClass(XtParent(nw)),
+	t = (XmScrollFrameTrait) XmeTraitGet(XtClass(XtParent(nw)),
 					XmQTscrollFrame);
 	if (t) {
 		t->init(XtParent(nw), _XmSPBTraitMoveCB, nw);	/* ??? FIX ME */
@@ -509,7 +490,7 @@ SetValues(Widget old, Widget request, Widget nw,
     Boolean	need_refresh = False,
 		need_layout = False;
 
-    DEBUGOUT(_LtDebug(__FILE__, nw, "SetValues()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, nw, "SetValues()\n"));
 
 #define	NE(x)	(x(old) != x(nw))
 
@@ -525,8 +506,8 @@ SetValues(Widget old, Widget request, Widget nw,
     if (NE(SPB_UpX) || NE(SPB_UpY)
      || NE(SPB_UpWidth) || NE(SPB_UpHeight)
      || NE(SPB_DownX) || NE(SPB_DownY)
-     || NE(SPB_DownWidth) || NE(SPB_DownHeight)) {
-    }
+     || NE(SPB_DownWidth) || NE(SPB_DownHeight))
+		;
 
     if (need_layout) {
 	Layout(nw, NULL);
@@ -540,8 +521,7 @@ SetValues(Widget old, Widget request, Widget nw,
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-	DEBUGOUT(_LtDebug(__FILE__, w, "Expose up %d %d down %d %d\n",
-		SPB_UpX(w), SPB_UpY(w), SPB_DownX(w), SPB_DownY(w)));
+	DEBUGOUT(XdbDebug(__FILE__, w, "Expose\n"));
 
 	_XmRedisplayGadgets(w, event, region);
 
@@ -554,7 +534,7 @@ expose(Widget w, XEvent *event, Region region)
 			SPB_UpWidth(w),
 			SPB_UpHeight(w),
 			SPB_DetailShadowThickness(w),
-			(SPB_ArrowOrientation(w) == XmARROWS_HORIZONTAL) ? XmARROW_RIGHT : XmARROW_UP);
+			XmARROW_RIGHT);
 	XmeDrawArrow(XtDisplay(w), XtWindow(w),
 			MGR_BottomShadowGC(w),
 			MGR_TopShadowGC(w),
@@ -564,13 +544,13 @@ expose(Widget w, XEvent *event, Region region)
 			SPB_DownWidth(w),
 			SPB_DownHeight(w),
 			SPB_DetailShadowThickness(w),
-			(SPB_ArrowOrientation(w) == XmARROWS_HORIZONTAL) ? XmARROW_LEFT : XmARROW_DOWN);
+			XmARROW_LEFT);
 }
 
 static void
 resize(Widget w)
 {
-	DEBUGOUT(_LtDebug(__FILE__, w, "Resize\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "Resize\n"));
 }
 
 /*
@@ -584,28 +564,26 @@ ConstraintInitialize(Widget request, Widget nw,
 {
     Widget sb = XtParent(nw);
 
-	DEBUGOUT(_LtDebug2(__FILE__, sb, nw, "ConstraintInitialize\n"));
+	DEBUGOUT(XdbDebug2(__FILE__, sb, nw, "ConstraintInitialize\n"));
 #if 0
-	DEBUGOUT(_LtDebugPrintArgList(__FILE__, nw, args, *num_args, False));
+	DEBUGOUT(XdbPrintArgList(__FILE__, nw, args, *num_args, False));
 #endif
 
-		if (SPBC_Numeric(nw)) {
-			DEBUGOUT(_LtDebug(__FILE__, nw,
+		if (SPBC_Numeric(nw))
+			DEBUGOUT(XdbDebug(__FILE__, nw,
 				"ConstraintInitialize(XmNUMERIC) min %d max %d inc %d\n",
 				SPBC_Minimum(nw),
 				SPBC_Maximum(nw),
 				SPBC_Increment(nw) ));
-		}
-		else {
-			DEBUGOUT(_LtDebug(__FILE__, nw,
+		else
+			DEBUGOUT(XdbDebug(__FILE__, nw,
 				"ConstraintInitialize(XmSTRING) num_values %d\n",
 				SPBC_NumValues(nw)));
-		}
 
 	if (SPBC_ArrowSensitivity(nw) == XmARROWS_DEFAULT_SENSITIVITY)
 		SPBC_ArrowSensitivity(nw) = SPB_DefaultSensitivity(sb);
 
-	if (XmeTraitGet((XtPointer)XtClass(nw), XmQTaccessTextual))
+	if (XmeTraitGet(XtClass(nw), XmQTaccessTextual))
 		_XmSpinBoxShowValue(sb, nw);
 }
 
@@ -616,9 +594,9 @@ ConstraintSetValues(Widget curr, Widget req, Widget nw,
 	Widget	sb = XtParent(nw);
 	Boolean	r = False;
 
-	DEBUGOUT(_LtDebug2(__FILE__, sb, nw, "ConstraintSetValues\n"));
+	DEBUGOUT(XdbDebug2(__FILE__, sb, nw, "ConstraintSetValues\n"));
 #if 0
-	DEBUGOUT(_LtDebugPrintArgList(__FILE__, nw, args, *num_args, False));
+	DEBUGOUT(XdbPrintArgList(__FILE__, nw, args, *num_args, False));
 #endif
 
 #define	NE(x)	(x(curr) != x(nw))
@@ -650,7 +628,7 @@ static void
 PreferredSize(	Widget w, Widget instig, XtWidgetGeometry *ig,
 				Dimension *wid, Dimension *ht)
 {
-	Cardinal i;
+	int		i;
 	Position	xx, yy;
 	Dimension	hh = 0;
 
@@ -665,18 +643,28 @@ PreferredSize(	Widget w, Widget instig, XtWidgetGeometry *ig,
 				hh = XtHeight(child);
 
 			xx += XtWidth(child) + SPB_Spacing(w);
-			DEBUGOUT(_LtDebug2(__FILE__, w, child,
+			DEBUGOUT(XdbDebug2(__FILE__, w, child,
 				"PreferredSize: add width %d\n",
 				XtWidth(child)));
 	}
 
+	SPB_DownX(w) = xx;
+	SPB_DownY(w) = yy;
+	SPB_DownWidth(w) = SPB_ArrowSize(w);
+	SPB_DownHeight(w) = SPB_ArrowSize(w);
+
 	xx += SPB_DownWidth(w) + SPB_Spacing(w);
+
+	SPB_UpX(w) = xx;
+	SPB_UpY(w) = yy;
+	SPB_UpWidth(w) = SPB_ArrowSize(w);
+	SPB_UpHeight(w) = SPB_ArrowSize(w);
 	xx += SPB_UpWidth(w) + SPB_MarginWidth(w);
 
 	*wid = xx;
 	*ht = hh + 2 * SPB_MarginHeight(w);;
 
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 	"PreferredSize => %d %d (ArrowSize %d MarginWidth %d"
 	" MarginHeight %d Spacing %d)\n",
 		*wid, *ht,
@@ -688,26 +676,15 @@ PreferredSize(	Widget w, Widget instig, XtWidgetGeometry *ig,
 /*
  * Layout is primarily influenced by
  *	SPB_ArrowLayout (XmARROWS_BEGINNING, XmARROWS_END, XmARROWS_SPLIT).
- *
- * FIX ME
- *	XmNarrowOrientation (XmARROWS_VERTICAL, XmARROWS_HORIZONTAL).
- *	ArrowLayout XmARROWS_FLAT_BEGINNING, XmARROWS_FLAT_END missing.
  */
 static void
 Layout(Widget w, Widget instig)
 {
-	Cardinal i;
+	int		i;
 	Position	xx, yy;
 	Dimension	hh = 0;
 
-	DEBUGOUT(_LtDebug(__FILE__, w, "XmSpinBox Layout %s\n",
-		(SPB_ArrowLayout(w) == XmARROWS_BEGINNING) ? "XmARROWS_BEGINNING" :
-		(SPB_ArrowLayout(w) == XmARROWS_END) ? "XmARROWS_END" :
-		(SPB_ArrowLayout(w) == XmARROWS_SPLIT) ? "XmARROWS_SPLIT" :
-		(SPB_ArrowLayout(w) == XmARROWS_FLAT_BEGINNING) ? "XmARROWS_FLAT_BEGINNING" :
-		(SPB_ArrowLayout(w) == XmARROWS_FLAT_END) ? "XmARROWS_FLAT_END" :
-		"??"
-	));
+	DEBUGOUT(XdbDebug(__FILE__, w, "XmSpinBox Layout\n"));
 
 	for (i=0; i<MGR_NumChildren(w); i++)
 	    if (XtHeight(MGR_Children(w)[i]) > hh)
@@ -736,11 +713,10 @@ Layout(Widget w, Widget instig)
 		if (XtIsManaged(MGR_Children(w)[i])) {
 			Widget	child = MGR_Children(w)[i];
 
-			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
-				XtWidth(child), XtHeight(child),
-				XtBorderWidth(child));
+				XtX(child) = xx;
+				XtY(child) = SPB_MarginHeight(w);
 
-			xx += XtWidth(child) + SPB_Spacing(w);
+				xx += XtWidth(child) + SPB_Spacing(w);
 		}
 
 		break;
@@ -752,11 +728,10 @@ Layout(Widget w, Widget instig)
 		if (XtIsManaged(MGR_Children(w)[i])) {
 			Widget	child = MGR_Children(w)[i];
 
-			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
-				XtWidth(child), XtHeight(child),
-				XtBorderWidth(child));
+				XtX(child) = xx;
+				XtY(child) = SPB_MarginHeight(w);
 
-			xx += XtWidth(child) + SPB_Spacing(w);
+				xx += XtWidth(child) + SPB_Spacing(w);
 		}
 
 	    SPB_DownX(w) = xx;
@@ -783,84 +758,22 @@ Layout(Widget w, Widget instig)
 		if (XtIsManaged(MGR_Children(w)[i])) {
 			Widget	child = MGR_Children(w)[i];
 
-			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
-				XtWidth(child), XtHeight(child),
-				XtBorderWidth(child));
+				XtX(child) = xx;
+				XtY(child) = SPB_MarginHeight(w);
 
-			xx += XtWidth(child) + SPB_Spacing(w);
+				xx += XtWidth(child) + SPB_Spacing(w);
 		}
 
 	    SPB_UpX(w) = xx;
 	    SPB_UpY(w) = yy;
 	    SPB_UpWidth(w) = SPB_ArrowSize(w);
 	    SPB_UpHeight(w) = SPB_ArrowSize(w);
-	    break;
-	case XmARROWS_FLAT_BEGINNING:				/* FIX ME */
-	    SPB_DownX(w) = SPB_MarginWidth(w);
-	    SPB_DownY(w) = yy;
-	    SPB_DownWidth(w) = SPB_ArrowSize(w);
-	    SPB_DownHeight(w) = SPB_ArrowSize(w);
-
-	    xx = SPB_MarginWidth(w) + SPB_Spacing(w) + SPB_DownWidth(w);
-
-	    SPB_UpX(w) = xx;
-	    SPB_UpY(w) = yy;
-	    SPB_UpWidth(w) = SPB_ArrowSize(w);
-	    SPB_UpHeight(w) = SPB_ArrowSize(w);
-
-	    xx += SPB_MarginWidth(w) + SPB_Spacing(w) + SPB_UpWidth(w) + SPB_ArrowSize(w);
-
-	    for (i=0; i<MGR_NumChildren(w); i++)
-		if (XtIsManaged(MGR_Children(w)[i])) {
-			Widget	child = MGR_Children(w)[i];
-
-			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
-				XtWidth(child), XtHeight(child),
-				XtBorderWidth(child));
-
-			xx += XtWidth(child) + SPB_Spacing(w);
-		}
-
-	    break;
-	case XmARROWS_FLAT_END:				/* FIX ME */
-	    xx = SPB_MarginWidth(w);
-
-	    for (i=0; i<MGR_NumChildren(w); i++)
-		if (XtIsManaged(MGR_Children(w)[i])) {
-			Widget	child = MGR_Children(w)[i];
-
-			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
-				XtWidth(child), XtHeight(child),
-				XtBorderWidth(child));
-
-			xx += XtWidth(child) + SPB_Spacing(w);
-		}
-
-	    SPB_DownX(w) = xx;
-	    SPB_DownY(w) = yy;
-	    SPB_DownWidth(w) = SPB_ArrowSize(w);
-	    SPB_DownHeight(w) = SPB_ArrowSize(w);
-
-	    xx += SPB_MarginWidth(w) + SPB_ArrowSize(w) + SPB_Spacing(w);
-
-	    SPB_UpX(w) = xx;
-	    SPB_UpY(w) = yy;
-	    SPB_UpWidth(w) = SPB_ArrowSize(w);
-	    SPB_UpHeight(w) = SPB_ArrowSize(w);
-	    break;
 	}
 
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 	    "SpinBoxLayout: down at %d %d up at %d %d, spb size %d %d\n",
 	    SPB_DownX(w), SPB_DownY(w), SPB_UpX(w), SPB_UpY(w),
 	    XtWidth(w), XtHeight(w)));
-	 for (i=0; i<MGR_NumChildren(w); i++) {
-		if (XtIsManaged(MGR_Children(w)[i])) {
-			Widget	child = MGR_Children(w)[i];
-			DEBUGOUT(_LtDebug2(__FILE__, w, child, "x %d y %d sz %d %d\n",
-				XtX(child), XtY(child), XtWidth(child), XtHeight(child)));
-		}
-	}
 }
 
 static XtGeometryResult
@@ -871,7 +784,7 @@ QueryGeometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 
 #define	Wants(x)	((geo.request_mode & x) == x)
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "QueryGeometry\n"));
 
     geo = *proposed;
 
@@ -885,16 +798,16 @@ QueryGeometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 
     if (Wants(CWHeight) && (geo.height != answer->height))
     {
-	DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry => No.\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "QueryGeometry => No.\n"));
 	return XtGeometryNo;
     }
     if (Wants(CWWidth) && (geo.width != answer->width))
     {
-	DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry => No.\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "QueryGeometry => No.\n"));
 	return XtGeometryNo;
     }
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry => Yes.\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "QueryGeometry => Yes.\n"));
     return XtGeometryYes;
 }
 
@@ -903,7 +816,7 @@ GeometryManager(Widget w,
 		 XtWidgetGeometry *request,
 		 XtWidgetGeometry *reply)
 {
-	DEBUGOUT(_LtDebug(__FILE__, w, "GeometryManager\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "GeometryManager\n"));
 
 	/* FIX ME */
 
@@ -917,17 +830,17 @@ ChangeManaged(Widget w)
 	XtWidgetGeometry	geo;
 	XtGeometryResult	r;
 
-	DEBUGOUT(_LtDebug(__FILE__, w, "ChangeManaged\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "ChangeManaged\n"));
 
 	/* Make sure that our size is right */
 	PreferredSize(w, NULL, NULL, &geo.width, &geo.height);
 	geo.request_mode = CWWidth | CWHeight;
 
 	r = _XmMakeGeometryRequest(w, &geo);
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 		"ChangeManaged Geometry Request %s -> %s\n",
-		_LtDebugWidgetGeometry2String(&geo),
-		_LtDebugGeometryResult2String(r)));
+		XdbWidgetGeometry2String(&geo),
+		XdbGeometryResult2String(r)));
 
 	if (r == XtGeometryYes) {
 		/* FIX ME */
@@ -971,7 +884,7 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 	tw = SPB_TextW(w);
 
 	if (tw == NULL) {
-		DEBUGOUT(_LtDebug(__FILE__, w, "SpinBModify: no text widget\n"));
+		DEBUGOUT(XdbDebug(__FILE__, w, "SpinBModify: no text widget\n"));
 		return;
 	}
 
@@ -1013,7 +926,7 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 		s = _XmSpinBoxNumericString(tw);
 		xms = XmStringCreateSimple(s);
 
-		DEBUGOUT(_LtDebug(__FILE__, w,
+		DEBUGOUT(XdbDebug(__FILE__, w,
 			"SpinBModify(NUMERIC) %d [%d,%d]\n",
 			SPBC_Position(tw), SPBC_Minimum(tw), SPBC_Maximum(tw)));
 	} else {
@@ -1041,7 +954,7 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 
 		xms = XmStringCopy(SPBC_Values(tw)[SPBC_Position(tw)]);
 
-		DEBUGOUT(_LtDebug(__FILE__, w,
+		DEBUGOUT(XdbDebug(__FILE__, w,
 			"SpinBModify(STRING) %d [%d,%d]\n",
 			SPBC_Position(tw), 0, SPBC_NumValues(tw)));
 	}
@@ -1079,7 +992,7 @@ _XmSpinBoxTimer(XtPointer client, XtIntervalId *timerid)
 {
 	Widget	spb = (Widget)client;
 
-	DEBUGOUT(_LtDebug(__FILE__, spb, "_XmSpinBoxTimer\n"));
+	DEBUGOUT(XdbDebug(__FILE__, spb, "_XmSpinBoxTimer\n"));
 
 	if (SPB_UpArrowPressed(spb))
 			SpinBModify(spb, NULL, XmCR_SPIN_NEXT);
@@ -1095,7 +1008,7 @@ SpinBArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
 	Widget	tw;
 
-	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBArm at %d %d\n",
+	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBArm at %d %d\n",
 		event->xbutton.x, event->xbutton.y));
 
 	if ((tw = SPB_TextW(w)) == NULL)
@@ -1156,7 +1069,7 @@ SpinBArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 SpinBDisarm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBDisarm\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBDisarm\n"));
 
 	if (SPB_TimerId(w))
 		XtRemoveTimeOut(SPB_TimerId(w));
@@ -1169,37 +1082,37 @@ SpinBDisarm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 SpinBFirst(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBFirst\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBFirst\n"));
 }
 
 static void
 SpinBLast(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBLast\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBLast\n"));
 }
 
 static void
 SpinBLeft(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBLeft\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBLeft\n"));
 }
 
 static void
 SpinBRight(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBRight\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBRight\n"));
 }
 
 static void
 SpinBNext(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBNext\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBNext\n"));
 }
 
 static void
 SpinBPrior(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBPrior\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBPrior\n"));
 }
 
 static void
@@ -1207,7 +1120,7 @@ _XmSpinBoxChildFocus(Widget w, XtPointer client, XtPointer call)
 {
 	Widget	spb = (Widget)client;
 
-	DEBUGOUT(_LtDebug2(__FILE__, spb, w, "_XmSpinBoxChildFocus\n"));
+	DEBUGOUT(XdbDebug2(__FILE__, spb, w, "_XmSpinBoxChildFocus\n"));
 
 	SPB_TextW(spb) = w;
 }
@@ -1217,17 +1130,17 @@ InsertChild(Widget w)
 {
     Widget	spb = XtParent(w);
 
-    DEBUGOUT(_LtDebug2(__FILE__, (Widget)spb, w, "SpinBox InsertChild\n"));
+    DEBUGOUT(XdbDebug2(__FILE__, (Widget)spb, w, "SpinBox InsertChild\n"));
 
 #define superclass (&xmManagerClassRec)
     (*superclass->composite_class.insert_child) (w);
 #undef superclass
 
-	if (XmeTraitGet((XtPointer)XtClass(w), XmQTaccessTextual)) {
+	if (XmeTraitGet(XtClass(w), XmQTaccessTextual)) {
 #if 0
 		Arg		a;
 
-		DEBUGOUT(_LtDebug2(__FILE__, spb, w,
+		DEBUGOUT(XdbDebug2(__FILE__, spb, w,
 			"Adding accelerators to child\n"));
 
 		XtSetArg(a, XmNtranslations,
@@ -1277,13 +1190,12 @@ _XmSpinBoxShowValue(Widget spb, Widget t)
 	XmString	xms;
 	XmAccessTextualTrait	trait;
 
-	DEBUGOUT(_LtDebug(__FILE__, spb, "_XmSpinBoxShowValue\n"));
+	DEBUGOUT(XdbDebug(__FILE__, spb, "_XmSpinBoxShowValue\n"));
 
 	if (spb == NULL || t == NULL)
 		return;
 
-	trait = (XmAccessTextualTrait)XmeTraitGet((XtPointer)XtClass(t),
-	                                           XmQTaccessTextual);
+	trait = (XmAccessTextualTrait)XmeTraitGet(XtClass(t), XmQTaccessTextual);
 
 	if (trait == NULL) {
 	    _XmError(t, "_XmSpinBoxShowValue: no trait XmQTaccessTextual\n");
@@ -1312,7 +1224,7 @@ _XmSpinBoxShowValue(Widget spb, Widget t)
 			XmTextSetString(t, s);
 			XtFree(s);
 		} else
-			trait->setValue(t, (XtPointer)xms, XmFORMAT_XmSTRING);
+			trait->setValue(t, xms, XmFORMAT_XmSTRING);
 		/* Do *not* free xms */
 	}
 
@@ -1321,19 +1233,19 @@ _XmSpinBoxShowValue(Widget spb, Widget t)
 static void
 SpinBoxEnter(Widget w, XEvent *evp, String *par, Cardinal *npar)
 {
-	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBoxEnter\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBoxEnter\n"));
 }
 
 static void
 SpinBoxFocusIn(Widget w, XEvent *evp, String *par, Cardinal *npar)
 {
-	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBoxFocusIn\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBoxFocusIn\n"));
 }
 
 static void
 SpinBoxFocusOut(Widget w, XEvent *evp, String *par, Cardinal *npar)
 {
-	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBoxFocusOut\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBoxFocusOut\n"));
 }
 
 /*
@@ -1345,7 +1257,7 @@ _XmSPBTraitChangeMoveCB(Widget nav,
 			XtPointer closure,
 			Boolean setUnset)
 {
-	DEBUGOUT(_LtDebug(__FILE__, nav,
+	DEBUGOUT(XdbDebug(__FILE__, nav,
 		"_XmSPBTraitChangeMoveCB (%s)\n",
 		setUnset ? "set" : "unset"));
 
@@ -1360,7 +1272,7 @@ _XmSPBTraitSetValue(Widget nav, XmNavigatorData navigatorData, Boolean notify)
 {
 	Widget	tw;
 
-	DEBUGOUT(_LtDebug(__FILE__, nav, "_XmSPBTraitSetValue\n"));
+	DEBUGOUT(XdbDebug(__FILE__, nav, "_XmSPBTraitSetValue\n"));
 
 	tw = SPB_TextW(nav);
 	if (tw == NULL)
@@ -1369,18 +1281,6 @@ _XmSPBTraitSetValue(Widget nav, XmNavigatorData navigatorData, Boolean notify)
 	if (navigatorData == NULL)
 		return;
 
-	if (navigatorData->valueMask & NavMinimum) {
-		SPBC_Minimum(tw) = navigatorData->minimum->x;
-	}
-
-	if (navigatorData->valueMask & NavMaximum) {
-		SPBC_Maximum(tw) = navigatorData->maximum->x;
-	}
-
-	if (navigatorData->valueMask & NavValue) {
-		/* FIX ME */
-	}
-
 	SPBC_Position(tw) = navigatorData->value->x;
 
 	_XmSpinBoxShowValue(nav, tw);
@@ -1389,7 +1289,7 @@ _XmSPBTraitSetValue(Widget nav, XmNavigatorData navigatorData, Boolean notify)
 static int
 _XmSPBTraitGetValue(Widget nav, XmNavigatorData navigatorData)
 {
-	DEBUGOUT(_LtDebug(__FILE__, nav, "_XmSPBTraitGetValue\n"));
+	DEBUGOUT(XdbDebug(__FILE__, nav, "_XmSPBTraitGetValue\n"));
 	return 0;
 }
 
@@ -1399,7 +1299,7 @@ _XmSPBTraitGetValue(Widget nav, XmNavigatorData navigatorData)
 static void
 _XmSPBTraitMoveCB(Widget nav, XtPointer client, XtPointer call)
 {
-	DEBUGOUT(_LtDebug(__FILE__, nav, "_XmSPBTraitMoveCB\n"));
+	DEBUGOUT(XdbDebug(__FILE__, nav, "_XmSPBTraitMoveCB\n"));
 
 	/*
 	 * This gets called when a navigator (e.g. Notebook) that we're
@@ -1408,24 +1308,3 @@ _XmSPBTraitMoveCB(Widget nav, XtPointer client, XtPointer call)
 	 * By getting this call we can change our appearance (e.g. page number).
 	 */
 }
-
-
-extern int
-XmSpinBoxValidatePosition(Widget textfield,
-                          int *position)
-{
-   int oldpos;
-
-   if (SPBC_Numeric(textfield)) {
-	oldpos = SPBC_Position(textfield);
-	*position = oldpos;
-        _XmWarning(NULL, "XmSpinBoxValidatePosition(): not yet implemented!");
-        return XmCURRENT_VALUE;
-   }
-   else {
-        /* non-numeric */
-	oldpos = SPBC_Position(textfield);
-	*position = oldpos;
-	return XmCURRENT_VALUE;
-   }
-}
