@@ -1,9 +1,8 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/XmStrDefs.c,v 1.6 2000/11/09 15:16:42 amai Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/XmStrDefs.c,v 1.3 1998/09/24 15:37:41 pgw Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
- * Copyright (C) 1997-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,23 +22,25 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/XmStrDefs.c,v 1.6 2000/11/09 15:16:42 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/XmStrDefs.c,v 1.3 1998/09/24 15:37:41 pgw Exp $";
 
 /*
- * This file contains the _XmStrings array for Motif 2.0 libXm
+ * This file contains the _XmStrings array
  */
 
 #include <LTconfig.h>
-
-/*
 #include <XmI/XmI.h>
-*/
+
+#include <Xm/XmP.h>
+#if XtSpecificationRelease < 6
+#include <X11/IntrinsicP.h>
+#endif
 
 /*
  * The missing commas are intentional.  Let the compiler
  * concatenate the strings
  */
-const char _XmStrings[] =
+_XmConst char _XmStrings[] =
 /* 0     */ "\0"
 /* 1     */ "Accelerator\0"
 /* 13    */ "AcceleratorText\0"
