@@ -1,9 +1,8 @@
 /**
  *
- * $Id: ArrowBG.c,v 1.29 2000/09/23 15:05:23 amai Exp $
+ * $Id: ArrowBG.c,v 1.25 1999/03/06 05:26:17 gritton Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,11 +22,11 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ArrowBG.c,v 1.29 2000/09/23 15:05:23 amai Exp $";
+static const char rcsid[] = "$Id: ArrowBG.c,v 1.25 1999/03/06 05:26:17 gritton Exp $";
 
 #include <LTconfig.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/ArrowBGP.h>
 #include <Xm/RepType.h>
@@ -65,7 +64,7 @@ static XmActivatableTraitRec _XmArrowBGTraitRec = {
 
 
 #if XmVERSION > 1
-static void class_initialize(void);
+static void class_initialize();
 #endif
 
 static void class_part_initialize(WidgetClass w_class);
@@ -268,7 +267,7 @@ WidgetClass xmArrowButtonGadgetClass =
 
 #if XmVERSION > 1
 static void
-class_initialize(void)
+class_initialize()
 {
 #if 0
     _XmArrowBGRectClassExtRec.record_type = XmQmotif;
@@ -381,7 +380,6 @@ destroy(Widget w)
     if (ABG_Timer(w) != 0)
     {
 	XtRemoveTimeOut(ABG_Timer(w));
-	ABG_Timer(w) = 0;
     }
 
     XtReleaseGC(w, ABG_ArrowGC(w));
@@ -715,7 +713,6 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     if (ABG_Timer(w) != 0)
     {
 	XtRemoveTimeOut(ABG_Timer(w));
-	ABG_Timer(w) = 0;
     }
 
     ABG_Timer(w) = XtAppAddTimeOut(XtWidgetToApplicationContext(w),
