@@ -1,9 +1,8 @@
 /**
  *
- * $Id: BulletinBoard.c,v 1.57 2000/10/23 07:57:45 amai Exp $
+ * $Id: BulletinBoard.c,v 1.49 1999/07/28 17:45:29 danny Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,10 +22,9 @@
  *
  **/
 
-static const char rcsid[] = "$Id: BulletinBoard.c,v 1.57 2000/10/23 07:57:45 amai Exp $";
+static const char rcsid[] = "$Id: BulletinBoard.c,v 1.49 1999/07/28 17:45:29 danny Exp $";
 
 #include <LTconfig.h>
-
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -41,25 +39,9 @@ static const char rcsid[] = "$Id: BulletinBoard.c,v 1.57 2000/10/23 07:57:45 ama
 #include <Xm/PushB.h>
 #include <Xm/PushBG.h>
 #include <Xm/MwmUtil.h>
-#include <Xm/VendorSEP.h>
 
 #include <XmI/DebugUtil.h>
 
-/* #defines being used in this file:
-      #ifdef USE_WIDGETS
-*/
-
-
-/* We use a 'private', i.e. non-declared but actually
-   exported call from OpenGroup's Intrinsic sources
-   (lib/Xt/Callback.c) in this file.
-   Note that we don't give the precise type here ...
- */
-extern void 
-_XtRemoveAllCallbacks(
-  /* InternalCallbackList *callbacks; */
- void *callbacks);
-
 /* Forward Declarations */
 
 static void class_initialize(void);
@@ -251,7 +233,7 @@ static XtActionsRec actions[] =
 
 static XtTranslations mapTrans;
 static XtTranslations defTrans;
-
+/* *INDENT-OFF* */
 #if 0
 static XmBaseClassExtRec _XmBulletinBCoreClassExtRec = {
     /* next_extension            */ NULL,
@@ -372,6 +354,7 @@ XmBulletinBoardClassRec xmBulletinBoardClassRec = {
 	/* extension			*/ NULL,
     },
 };
+/* *INDENT-ON* */
 
 
 WidgetClass xmBulletinBoardWidgetClass = (WidgetClass)&xmBulletinBoardClassRec;
@@ -481,11 +464,8 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 	BB_TextFontList(bb) = XmFontListCopy(BB_TextFontList(new_w));
     }
 
-    if (((XmBulletinBoardWidgetClass)XtClass(new_w))->bulletin_board_class.always_install_accelerators)
-    {
-	XtAugmentTranslations(new_w, mapTrans);
-	XtAugmentTranslations(new_w, defTrans);
-    }
+    XtAugmentTranslations(new_w, mapTrans);
+    XtAugmentTranslations(new_w, defTrans);
     /* rws 30 Aug 1998
        We seem to loose a few hundred bytes every time we parse a translation
        table, so like mapTrans lets parse it in class_initialize and use the
@@ -573,12 +553,8 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 
 	if ((ve = _LtFindVendorExt(new_w)) != NULL)
 	{
-    	    extern void _XtAddCallback(XtCallbackList *,
-				       XtCallbackProc, XtPointer);
-
-	    _XtAddCallback(&VSEP_FocusMovedCallback(ve),
-			   bbclass->bulletin_board_class.focus_moved_proc,
-                           new_w);
+	    XtAddCallback(ve, XmNfocusMovedCallback,
+			bbclass->bulletin_board_class.focus_moved_proc, new_w);
 	}
     }
 
@@ -587,7 +563,6 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
     BB_OldHeight(new_w) = -1;
 
     BB_GeoCache(new_w) = NULL;
-    MGR_InitialFocus(new_w) = BB_DefaultButton(new_w);
     BB_InSetValues(new_w) = False;
 }
 
@@ -599,18 +574,12 @@ destroy(Widget w)
     DEBUGOUT(XdbDebug("RWS", w,"%s:destroy(%d)\n",
     	__FILE__, __LINE__
     	));
-
-    if (BB_DialogTitle(w))
-        XmStringFree(BB_DialogTitle(w));
     XmFontListFree(BB_LabelFontList(w));
     XmFontListFree(BB_ButtonFontList(w));
     XmFontListFree(BB_TextFontList(w));
     if ((ve = _LtFindVendorExt(w)) != NULL)
       {
-	_XtRemoveAllCallbacks(&VSEP_FocusMovedCallback(ve));
-	/* mitch
 	XtRemoveAllCallbacks(ve,XmNfocusMovedCallback);
-	*/
       }
     
 
@@ -658,7 +627,6 @@ set_values(Widget old,
 
 	_XmBBUpdateDynDefaultButton(new_w);
 
-	MGR_InitialFocus(new_w) = BB_DefaultButton(nw);
 	need_refresh = True;	/* do we need to ? */
     }
 
@@ -680,11 +648,6 @@ set_values(Widget old,
 		BB_DialogTitle(new_w) = XmStringCopy(BB_DialogTitle(new_w));
 	    }
 
-            XmStringFree(BB_DialogTitle(old));
-        }
-        else if (BB_DialogTitle(old) != BB_DialogTitle(new_w))
-        {
-            BB_DialogTitle(new_w) = XmStringCopy(BB_DialogTitle(new_w));
 	    XmStringFree(BB_DialogTitle(old));
 	}
 
@@ -1448,19 +1411,6 @@ delete_child(Widget w)
     {
 	BB_CancelButton(bb) = NULL;
     }
-    if (w == BB_DynamicCancelButton(bb))
-    {
-	BB_DynamicCancelButton(bb) = NULL;
-    }
-    if (w == BB_DynamicDefaultButton(bb))
-    {
-	BB_DynamicDefaultButton(bb) = NULL;
-    }
-    if (w == BB_DefaultButton(bb))
-    {
-	BB_DefaultButton(bb) = NULL;
-	MGR_InitialFocus(bb) = NULL;
-    }
 }
 
 static Boolean
@@ -1617,11 +1567,7 @@ _XmBulletinBoardFocusMoved(Widget wid, XtPointer client_data, XtPointer data)
     Widget default_button = NULL;
     Widget par;
 
-    DEBUGOUT(XdbDebug(__FILE__, wid, "%s:%d - %s %s %s\n",
-    	__FILE__, __LINE__,
-    	cbs->cont ? "True" : "False",
-    	cbs->old_focus ? XtName(cbs->old_focus) : "NULL",
-    	cbs->new_focus ? XtName(cbs->new_focus) : "NULL"));
+    DEBUGOUT(XdbDebug(__FILE__, wid, "_XmBulletinBoardFocusMoved\n"));
 
     if (!cbs->cont)
     {
@@ -1832,10 +1778,6 @@ _XmBulletinBoardSetDynDefaultButton(Widget wid, Widget newDefaultButton)
 {
     Arg argl[2];
 
-    DEBUGOUT(XdbDebug(__FILE__, wid, "%s:%d - %s\n",
-    	__FILE__, __LINE__,
-    	newDefaultButton ? XtName(newDefaultButton) : "NULL"));
-
     if (newDefaultButton && wid != XtParent(newDefaultButton))
     {
     	return;
@@ -1870,14 +1812,7 @@ _XmBulletinBoardSetDynDefaultButton(Widget wid, Widget newDefaultButton)
 void
 _XmBBUpdateDynDefaultButton(Widget bb)
 {
-    DEBUGOUT(XdbDebug(__FILE__, bb, "%s:_XmBBUpdateDynDefault(%d) - %s(%smanaged) %s\n",
-    	__FILE__, __LINE__,
-    	BB_DynamicDefaultButton(bb) ? XtName(BB_DynamicDefaultButton(bb)) : "NULL",
-    	BB_DynamicDefaultButton(bb) ? XtIsManaged(BB_DynamicDefaultButton(bb)) ? "" : "not " : "not ",
-    	BB_DefaultButton(bb) ? XtName(BB_DefaultButton(bb)) : "NULL"));
-
-    if (BB_DynamicDefaultButton(bb) &&
-        XtIsManaged(BB_DynamicDefaultButton(bb)))
+    if (BB_DynamicDefaultButton(bb))
     {
 	_XmBulletinBoardSetDynDefaultButton(bb, BB_DynamicDefaultButton(bb));
     }
