@@ -1,9 +1,8 @@
 /**
  *
- * $Id: CascadeB.c,v 1.154 2000/10/19 13:51:59 amai Exp $
+ * $Id: CascadeB.c,v 1.146 1999/09/29 22:20:06 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,14 +22,12 @@
  *
  **/
 
-static const char rcsid[] = "$Id: CascadeB.c,v 1.154 2000/10/19 13:51:59 amai Exp $";
+static const char rcsid[] = "$Id: CascadeB.c,v 1.146 1999/09/29 22:20:06 rwscott Exp $";
 
 #include <LTconfig.h>
-
-#include <stdarg.h>
-
 #include <XmI/XmI.h>
 #include <XmI/MacrosI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/CascadeBP.h>
 #include <Xm/CascadeBGP.h>
@@ -41,8 +38,15 @@ static const char rcsid[] = "$Id: CascadeB.c,v 1.154 2000/10/19 13:51:59 amai Ex
 #include <Xm/MenuUtilP.h>
 #include <Xm/ScreenP.h>
 
+#ifndef __STDC__
+#include <varargs.h>
+#else
+#include <stdarg.h>
+#endif
+
 #include <XmI/DebugUtil.h>
 
+#include <stdio.h>
 
 #ifndef XmUNSPECIFIED
 #define XmUNSPECIFIED	(~0)
@@ -100,7 +104,7 @@ static void CheckDisarm(Widget, XEvent *, String *, Cardinal *);
 static void ArmAndPost(Widget, XEvent *, String *, Cardinal *);
 #endif
 
-static void MenuProcEntry(int proc, Widget rc, ...);
+static void MenuProcEntry(int proc, Widget rc,...);
 
 /*
  * Resources for the cascade button class
@@ -482,10 +486,7 @@ resize(Widget w)
     (*superclass->core_class.resize) (w);
 #undef superclass
 
-    if (Lab_MenuType(w) != XmMENU_BAR)
-    {
-	place_cascade(w);
-    }
+    place_cascade(w);
 }
 
 static void
@@ -496,7 +497,6 @@ destroy(Widget w)
     if (CB_Timer(w) != 0)
     {
 	XtRemoveTimeOut(CB_Timer(w));
-	CB_Timer(w) = 0;
     }
 
     if (CB_ArmedPixmap(w))
@@ -560,13 +560,11 @@ set_values(Widget old, Widget request, Widget new_w,
 	{
 	    if (CB_CascadePixmap(new_w) == XmUNSPECIFIED_PIXMAP &&
 		CB_Submenu(new_w))
-	    {
 		_XmCreateArrowPixmaps(new_w);
-	    }
 	    size_cascade(new_w);
-	    refresh_needed = True;
 	}
 
+	refresh_needed = True;
     }
 
     if (XtSensitive(new_w) != XtSensitive(old))
@@ -767,10 +765,7 @@ _XmCascadingPopup(Widget w, XEvent *event, Boolean doCascade)
     Widget sub_pane;
     Boolean was_torn;
 
-	if (XmIsGadget(w))
-	    sub_pane = CBG_Submenu(w);
-	else
-	    sub_pane = CB_Submenu(w);
+	sub_pane = XmIsGadget(w) ?  CBG_Submenu(w) : CB_Submenu(w);
 	if (sub_pane)
 	{
 	    RCClass_MenuProcs(XtClass(sub_pane))(XmMENU_RESTORE_TEAROFF_TO_MENUSHELL,
@@ -783,10 +778,11 @@ _XmCascadingPopup(Widget w, XEvent *event, Boolean doCascade)
 
     XFlush(XtDisplay(w));
 
-    if(XmIsGadget(w))
-          XtCallCallbackList(w, CBG_CascadeCall(w), &cbs);
-    else
-          XtCallCallbackList(w, CB_CascadeCall(w),  &cbs);
+    XtCallCallbackList(w,
+		       (XmIsGadget(w)
+			? CBG_CascadeCall(w)
+			: CB_CascadeCall(w)),
+		       &cbs);
 
     if (doCascade)
     {
@@ -1270,12 +1266,29 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 }
 
 
+#ifdef __STDC__
 static void
-MenuProcEntry(int proc, Widget w, ...)
+MenuProcEntry(int proc, Widget w,...)
 {
     va_list arg_list;
+    /*
+    XEvent *event;
+    */
 
     va_start(arg_list, w);
+#else
+MenuProcEntry(proc, w, va_alist)
+     int proc;
+     Widget w;
+     va_dcl
+{
+    va_list arglist;
+    /*
+    XEvent *event;
+    */
+
+    va_start(arglist);
+#endif
 
     switch (proc)
     {
