@@ -1,9 +1,8 @@
 /**
  *
- * $Id: CascadeBG.c,v 1.145 2001/07/27 18:51:55 dannybackx Exp $
+ * $Id: CascadeBG.c,v 1.130 1999/10/19 20:25:59 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,14 +22,11 @@
  *
  **/
 
-static const char rcsid[] = "$Id: CascadeBG.c,v 1.145 2001/07/27 18:51:55 dannybackx Exp $";
+static const char rcsid[] = "$Id: CascadeBG.c,v 1.130 1999/10/19 20:25:59 rwscott Exp $";
 
 #include <LTconfig.h>
-
-#include <stdarg.h>
-#include <string.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/CacheP.h>
 #include <Xm/CascadeB.h>	/* For XmCascadeButtonHighlight */
@@ -41,6 +37,13 @@ static const char rcsid[] = "$Id: CascadeBG.c,v 1.145 2001/07/27 18:51:55 dannyb
 #include <Xm/RowColumnP.h>
 #include <Xm/ScreenP.h>
 #include <Xm/MenuUtilP.h>
+#include <X11/Xfuncs.h>
+
+#ifndef __STDC__
+#include <varargs.h>
+#else
+#include <stdarg.h>
+#endif
 
 #include <XmI/DebugUtil.h>
 
@@ -102,8 +105,6 @@ static void ArmAndActivate(Widget w, XEvent *event,
 
 static void MenuProcEntry(int proc, Widget rc,...);
 
-static void CascadePopupHandler(XtPointer clientData, XtIntervalId *id);
-
 /*
  * cache resources
  */
@@ -123,6 +124,7 @@ static XtResource cache_resources[] =
     }
 };
 
+/* *INDENT-OFF* */
 XmCascadeButtonGCacheObjClassRec xmCascadeButtonGCacheObjClassRec = {
     /* Object class part */
     {
@@ -335,6 +337,7 @@ XmCascadeButtonGadgetClassRec xmCascadeButtonGadgetClassRec = {
 	/* extension */ NULL
     },
 };
+/* *INDENT-ON* */
 
 
 WidgetClass xmCascadeButtonGadgetClass =
@@ -348,9 +351,9 @@ secondary_object_create(Widget request, Widget new_w,
     XmBaseClassExt *bce;
     XtPointer nsec, rsec;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "CascadeButtonGCacheRec %s being initialized.\n",
 		      XtName(new_w)));
 
@@ -380,7 +383,7 @@ secondary_object_create(Widget request, Widget new_w,
     ed->widget = (Widget)nsec;
     ed->reqWidget = (Widget)rsec;
 
-    memcpy(rsec, nsec, size);
+    bcopy(nsec, rsec, size);
 
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
@@ -398,7 +401,7 @@ secondary_object_create(Widget request, Widget new_w,
 int
 _XmCascadeBCacheCompare(XtPointer A, XtPointer B)
 {
-    return !memcmp(((XmCascadeButtonGCacheObjPart *)A),
+    return !bcmp(((XmCascadeButtonGCacheObjPart *)A),
 		 ((XmCascadeButtonGCacheObjPart *)B),
 		 sizeof(XmCascadeButtonGCacheObjPart));
 }
@@ -414,7 +417,7 @@ _XmArrowPixmapCacheCompare(XtPointer A, XtPointer B)
      * different shadow thicknesses imply different pixmap sizes (at least
      * for the same size font).
      */
-    return !memcmp(A, B, XtOffsetOf(XmArrowPixmap, pixmap));
+    return !bcmp(A, B, XtOffsetOf(XmArrowPixmap, pixmap));
 }
 
 void
@@ -437,7 +440,7 @@ _XmArrowPixmapCacheDelete(XtPointer data)
 			(Pixmap)data);
 		    list->prev->next = list->next;
 		    list->next->prev = list->prev;
-		    XtFree((char *)list);
+		    XtFree((XtPointer)list);
 		}
 		return;
 	    }
@@ -509,12 +512,12 @@ _XmCreateArrowPixmaps(Widget w)
     cpart.top_shadow_color = ts;
     cpart.bottom_shadow_color = bs;
     cp = (XmArrowPixmap *)
-	_XmCachePart(&arrow_pixmap_cache, (XtPointer)&cpart, sizeof cpart);
+	_XmCachePart(&arrow_pixmap_cache, &cpart, sizeof cpart);
 
     cpart.top_shadow_color = bs;
     cpart.bottom_shadow_color = ts;
     acp = (XmArrowPixmap *)
-	_XmCachePart(&arrow_pixmap_cache, (XtPointer)&cpart, sizeof cpart);
+	_XmCachePart(&arrow_pixmap_cache, &cpart, sizeof cpart);
 
     /* If the cached pixmaps don't exist, create them */
     if (cp->pixmap == XmUNSPECIFIED_PIXMAP
@@ -599,10 +602,10 @@ class_initialize(void)
 
     combined = (XtResourceList)XtMalloc(sizeof(XtResource) * ncom);
 
-    memcpy(combined, labels, nlabels * sizeof(XtResource));
-    memcpy(&combined[nlabels],
-           cache_resources,
- 	   XtNumber(cache_resources) * sizeof(XtResource));
+    bcopy(labels, combined, nlabels * sizeof(XtResource));
+    bcopy(cache_resources,
+	  &combined[nlabels],
+	  XtNumber(cache_resources) * sizeof(XtResource));
 
     XtFree((char *)labels);
 
@@ -622,7 +625,7 @@ initialize_posthook(Widget request, Widget new_w,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w, "CascadeBG InitializePosthook\n"));
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "CascadeBG InitializePosthook\n"));
 
     /* don't let the null fool you */
     LabG_Cache(new_w) = (XmLabelGCacheObjPart *)
@@ -844,19 +847,16 @@ resize(Widget w)
     (*superclass->rect_class.resize) (w);
 #undef superclass
 
-    if (LabG_MenuType(w) != XmMENU_BAR)
-    {
-	place_cascade(w);
-    }
+    place_cascade(w);
 }
 
 static void
 destroy(Widget w)
 {
+    _XmCacheDelete((XtPointer)CBG_Cache(w));
     if (CBG_Timer(w) != 0)
     {
 	XtRemoveTimeOut(CBG_Timer(w));
-	CBG_Timer(w) = 0;
     }
 
     if (CBG_ArmedPixmap(w))
@@ -864,8 +864,6 @@ destroy(Widget w)
 	_XmArrowPixmapCacheDelete((XtPointer)CBG_ArmedPixmap(w));
 	_XmArrowPixmapCacheDelete((XtPointer)CBG_CascadePixmap(w));
     }
-
-   _XmCacheDelete((XtPointer)CBG_Cache(w));
 }
 
 static Boolean
@@ -874,7 +872,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
     XtPointer nsec, rsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -894,12 +892,12 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
     ExtObj_LogicalParent(nsec) = new_w;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
-	  LabG_Cache(new_w),
+    bcopy(LabG_Cache(new_w),
+	  &((XmLabelGCacheObject)nsec)->label_cache,
 	  sizeof(XmLabelGCacheObjPart));
-    memcpy(&((XmCascadeButtonGCacheObject)nsec)->cascade_button_cache,
-           CBG_Cache(new_w),
-	   sizeof(XmCascadeButtonGCacheObjPart));
+    bcopy(CBG_Cache(new_w),
+	  &((XmCascadeButtonGCacheObject)nsec)->cascade_button_cache,
+	  sizeof(XmCascadeButtonGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
 
@@ -915,7 +913,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 		   (*bce)->secondaryObjectClass->core_class.num_resources,
 		   args, *num_args);
 
-    memcpy(rsec, nsec, size);
+    bcopy(nsec, rsec, size);
 
     LabG_Cache(new_w) = &(((XmCascadeButtonGCacheObject)nsec)->label_cache);
     LabG_Cache(request) = &(((XmCascadeButtonGCacheObject)rsec)->label_cache);
@@ -983,7 +981,7 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Boolean refresh_needed = False;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w, "set_values()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "set_values()\n"));
 
     if (CBG_MapDelay(new_w) < 0)
     {
@@ -1024,12 +1022,11 @@ set_values(Widget old, Widget request, Widget new_w,
 	    if (LabG_MenuType(new_w) != XmMENU_OPTION &&
 		CBG_CascadePixmap(new_w) == XmUNSPECIFIED_PIXMAP &&
 		CBG_Submenu(new_w))
-	    {
 		_XmCreateArrowPixmaps(new_w);
-	    }
 	    size_cascade(new_w);
-	    refresh_needed = True;
 	}
+
+	refresh_needed = True;
     }
 
     if (XtSensitive(new_w) != XtSensitive(old))
@@ -1142,7 +1139,7 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
     XtPointer nsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -1150,12 +1147,12 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 
     nsec = _XmExtObjAlloc(size);
 
-    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
-           LabG_Cache(new_w),
-	   sizeof(XmLabelGCacheObjPart));
-    memcpy(&((XmCascadeButtonGCacheObject)nsec)->cascade_button_cache,
-           CBG_Cache(new_w),
-	   sizeof(XmCascadeButtonGCacheObjPart));
+    bcopy(LabG_Cache(new_w),
+	  &((XmLabelGCacheObject)nsec)->label_cache,
+	  sizeof(XmLabelGCacheObjPart));
+    bcopy(CBG_Cache(new_w),
+	  &((XmCascadeButtonGCacheObject)nsec)->cascade_button_cache,
+	  sizeof(XmCascadeButtonGCacheObjPart));
 
     /*
      * don't do this and ResInd will blow up.
@@ -1262,8 +1259,8 @@ expose(Widget w,
        XEvent *event,
        Region region)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "expose() Armed(%d) type %s\n",
-		      CBG_IsArmed(w), _LtDebugMenuType2String(LabG_MenuType(w))));
+    DEBUGOUT(XdbDebug(__FILE__, w, "expose() Armed(%d) type %s\n",
+		      CBG_IsArmed(w), XdbMenuType2String(LabG_MenuType(w))));
 
     draw_cascade(w);
 
@@ -1286,16 +1283,16 @@ DoSelect(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
 Boolean validButton;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:DoSelect(%d)\n\t%s posted mine %s\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:DoSelect(%d)\n\t%s posted mine %s\n",
 	__FILE__, __LINE__,
 	RC_PopupPosted(XtParent(w)) ? XtName(RC_PopupPosted(XtParent(w))) : "nothing",
 	CBG_Submenu(w) ? XtName(CBG_Submenu(w)) : "none"
 	));
-    DEBUGOUT(_LtDebug("MENU", w, "%s:DoSelect(%d)\n\t%s posted mine %s %s\n",
+    DEBUGOUT(XdbDebug("MENU", w, "%s:DoSelect(%d)\n\t%s posted mine %s %s\n",
 	__FILE__, __LINE__,
 	RC_PopupPosted(XtParent(w)) ? XtName(RC_PopupPosted(XtParent(w))) : "nothing",
 	CBG_Submenu(w) ? XtName(CBG_Submenu(w)) : "none",
-	event ? _LtDebugEventType2String(event->xany.type) : "no-event"
+	event ? XdbEventType2String(event->xany.type) : "no-event"
 	));
     if (event && event->xany.type == ButtonRelease)
     {
@@ -1352,12 +1349,12 @@ MenuBarSelect(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     Boolean validButton;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:MenuBarSelect(%d)\n\t%s posted mine %s\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:MenuBarSelect(%d)\n\t%s posted mine %s\n",
 	__FILE__, __LINE__,
 	RC_PopupPosted(XtParent(w)) ? XtName(RC_PopupPosted(XtParent(w))) : "nothing",
 	CBG_Submenu(w) ? XtName(CBG_Submenu(w)) : "none"
 	));
-    DEBUGOUT(_LtDebug("MENU", w, "%s:MenuBarSelect(%d)\n\t%s posted mine %s\n",
+    DEBUGOUT(XdbDebug("MENU", w, "%s:MenuBarSelect(%d)\n\t%s posted mine %s\n",
 	__FILE__, __LINE__,
 	RC_PopupPosted(XtParent(w)) ? XtName(RC_PopupPosted(XtParent(w))) : "nothing",
 	CBG_Submenu(w) ? XtName(CBG_Submenu(w)) : "none"
@@ -1376,7 +1373,7 @@ MenuBarSelect(Widget w, XEvent *event, String *params, Cardinal *num_params)
 	XmProcessTraversal(w, XmTRAVERSE_CURRENT);
 	if (RC_PopupPosted(XtParent(w)))
 	{
-	Cardinal i;
+	int i;
 
 	    for (i = 0; i < MGR_NumChildren(RC_PopupPosted(XtParent(w))); i++)
 	    {
@@ -1413,8 +1410,8 @@ MenuBarSelect(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 ArmAndPost(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "ArmAndPost(): %p %p\n", w, CBG_Submenu(w)));
-    DEBUGOUT(_LtDebug("MENU", w, "%s:ArmAndPost(%d)\n\t%s posted mine %s\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "ArmAndPost(): %p %p\n", w, CBG_Submenu(w)));
+    DEBUGOUT(XdbDebug("MENU", w, "%s:ArmAndPost(%d)\n\t%s posted mine %s\n",
 	__FILE__, __LINE__,
 	RC_PopupPosted(XtParent(w)) ? XtName(RC_PopupPosted(XtParent(w))) : "nothing",
 	CBG_Submenu(w) ? XtName(CBG_Submenu(w)) : "none"
@@ -1425,7 +1422,7 @@ ArmAndPost(Widget w, XEvent *event, String *params, Cardinal *num_params)
 #if 0
     if (!RC_IsArmed(CBG_Submenu(w)))
     {
-	DEBUGOUT(_LtDebug(__FILE__, w, "MENU_ARM\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "MENU_ARM\n"));
 
 	RCClass_MenuProcs(XtClass(XtParent(w)))(XmMENU_ARM, XtParent(w), NULL);
     }
@@ -1444,16 +1441,16 @@ ArmAndPost(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 MenuBarEnter(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "MenuBarEnter\n\t%s %s %s %s posted posting %s\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "MenuBarEnter\n\t%s %s %s %s posted posting %s\n",
 	_XmGetInDragMode(w) ? "Dragging" : "Not Dragging",
-	_LtDebugRcType2String(LabG_MenuType(w)),
+	XdbRcType2String(LabG_MenuType(w)),
 	RC_IsArmed(XtParent(w)) ? "Armed" : "Not Armed",
 	RC_PopupPosted(XtParent(w)) ? XtName(RC_PopupPosted(XtParent(w))) : "nothing",
 	CBG_Submenu(w) ? XtName(CBG_Submenu(w)) : "nothing"
 	));
-    DEBUGOUT(_LtDebug("MENU", w, "MenuBarEnter\n\t%s %s %s %s posted posting %s\n",
+    DEBUGOUT(XdbDebug("MENU", w, "MenuBarEnter\n\t%s %s %s %s posted posting %s\n",
 	_XmGetInDragMode(w) ? "Dragging" : "Not Dragging",
-	_LtDebugRcType2String(LabG_MenuType(w)),
+	XdbRcType2String(LabG_MenuType(w)),
 	RC_IsArmed(XtParent(w)) ? "Armed" : "Not Armed",
 	RC_PopupPosted(XtParent(w)) ? XtName(RC_PopupPosted(XtParent(w))) : "nothing",
 	CBG_Submenu(w) ? XtName(CBG_Submenu(w)) : "nothing"
@@ -1533,7 +1530,7 @@ StartDrag(Widget w, XEvent *event, String *params, Cardinal *num_params)
     Boolean validButton;
     Boolean poppedUp;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "StartDrag()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "StartDrag()\n"));
 
     XAllowEvents(XtDisplay(w), SyncPointer, CurrentTime);
 
@@ -1551,7 +1548,7 @@ StartDrag(Widget w, XEvent *event, String *params, Cardinal *num_params)
     /* Was it the right button? */
     RC_MenuButton(w, event, &validButton);
 
-    DEBUGOUT(_LtDebug("MENU", w, "%s:StartDrag(%d) - %s posted mine %s\n",
+    DEBUGOUT(XdbDebug("MENU", w, "%s:StartDrag(%d) - %s posted mine %s\n",
 	__FILE__, __LINE__,
 	RC_PopupPosted(XtParent(w)) ? XtName(RC_PopupPosted(XtParent(w))) : "None",
 	CBG_Submenu(w) ? XtName(CBG_Submenu(w)) : "None"
@@ -1560,7 +1557,7 @@ StartDrag(Widget w, XEvent *event, String *params, Cardinal *num_params)
     {
 	if (CBG_Submenu(w) && RC_PopupPosted(XtParent(w)) == CBG_Submenu(w))
 	{
-	Cardinal i;
+	int i;
 
 	    for (i = 0; i < MGR_NumChildren(CBG_Submenu(w)); i++)
 	    {
@@ -1572,7 +1569,7 @@ StartDrag(Widget w, XEvent *event, String *params, Cardinal *num_params)
 	    RC_MenuShellPopdown(w, event, &poppedUp);
 	    _XmCascadingPopup(w, event, True);
 	    {
-	    Cardinal i;
+	    int i;
 	    Widget menu = XtParent(w);
 
 		for (i = 0; i < MGR_NumChildren(menu); i++)
@@ -1594,7 +1591,7 @@ CascadePopupHandler(XtPointer clientData, XtIntervalId *id)
 
     CBG_Timer(w) = 0;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "CascadePopupHandler()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "CascadePopupHandler()\n"));
 
     _XmCascadingPopup(w, NULL, True);	/* FIX ME: NULL? */
 }
@@ -1603,7 +1600,7 @@ CascadePopupHandler(XtPointer clientData, XtIntervalId *id)
 static void
 DelayedArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "DelayedArm()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "DelayedArm()\n"));
 
     XAllowEvents(XtDisplay(w), SyncPointer, CurrentTime);
 
@@ -1634,7 +1631,7 @@ CheckDisarm(Widget w, XEvent *event, String *params, Cardinal *num_params)
     int y = ((XLeaveWindowEvent *)event)->y_root;
     Widget subpane;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "CheckDisarm() - %i %i %i\n", x, y, XtHeight(w)));
+    DEBUGOUT(XdbDebug(__FILE__, w, "CheckDisarm() - %i %i %i\n", x, y, XtHeight(w)));
 
     XAllowEvents(XtDisplay(w), SyncPointer, CurrentTime);
 
@@ -1690,7 +1687,7 @@ Help(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "ArmAndActivate\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "ArmAndActivate\n"));
 
     MGR_ActiveChild(XtParent(w)) = w;
     if (LabG_MenuType(w) == XmMENU_BAR)
@@ -1711,17 +1708,17 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 
 	if (CBG_Submenu(w) && !RC_IsArmed(CBG_Submenu(w)))
 	{
-	    DEBUGOUT(_LtDebug(__FILE__, w, "MENU_ARM\n"));
+	    DEBUGOUT(XdbDebug(__FILE__, w, "MENU_ARM\n"));
 
 	    RCClass_MenuProcs(XtClass(XtParent(w)))(XmMENU_ARM,
 						    XtParent(w), NULL);
 	}
 
-	CascadePopupHandler((XtPointer)w, NULL);
+	CascadePopupHandler(w, NULL);
     }
     else /* pullright */
     {
-	CascadePopupHandler((XtPointer)w, NULL);
+	CascadePopupHandler(w, NULL);
     }
 }
 
@@ -1802,6 +1799,7 @@ visual_change(Widget w,
     return False;
 }
 
+#ifdef __STDC__
 static void
 MenuProcEntry(int proc, Widget w,...)
 {
@@ -1811,6 +1809,19 @@ MenuProcEntry(int proc, Widget w,...)
     */
 
     va_start(arg_list, w);
+#else
+MenuProcEntry(proc, w, va_alist)
+     int proc;
+     Widget w;
+     va_dcl
+{
+    va_list arglist;
+    /*
+    XEvent *event = NULL;
+    */
+
+    va_start(arglist);
+#endif
 
     switch (proc)
     {
@@ -1848,14 +1859,14 @@ MenuProcEntry(int proc, Widget w,...)
 void
 XmCascadeButtonGadgetHighlight(Widget w, Boolean highlight)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w,
+    DEBUGOUT(XdbDebug(__FILE__, w,
 		      "XmCascadeButtonGadgetHighlight(hl %d, armed %d,"
 		      " apm 0x%X, cpm 0x%X), %s, geo %d %d %dx%d\n",
 		      highlight,
 		      XmIsPrimitive(w) ? CB_IsArmed(w) : CBG_IsArmed(w),
 		  XmIsPrimitive(w) ? CB_ArmedPixmap(w) : CBG_ArmedPixmap(w),
 	      XmIsPrimitive(w) ? CB_CascadePixmap(w) : CBG_CascadePixmap(w),
-		      _LtDebugMenuType2String(LabG_MenuType(w)),
+		      XdbMenuType2String(LabG_MenuType(w)),
 		      XtX(w), XtY(w), XtWidth(w), XtHeight(w)
 	     ));
 
