@@ -1,9 +1,8 @@
 /**
  *
- * $Id: CutPaste.c,v 1.16 2000/10/23 14:58:08 amai Exp $
+ * $Id: CutPaste.c,v 1.10 1999/10/28 18:33:43 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,24 +22,22 @@
  *
  **/
 
-static const char rcsid[] = "$Id: CutPaste.c,v 1.16 2000/10/23 14:58:08 amai Exp $";
+static const char rcsid[] = "$Id: CutPaste.c,v 1.10 1999/10/28 18:33:43 amai Exp $";
 
 #include <LTconfig.h>
-
-#include <stdio.h>
-#include <string.h>
-
 #include <XmI/XmI.h>
 
+#include <X11/Xfuncs.h>
+
 #include <Xm/XmP.h>
 #include <Xm/AtomMgr.h>
 #include <Xm/CutPaste.h>
 #include <XmI/CutPasteI.h>
 #include <XmI/AtomMgrI.h>
+#include <stdio.h>
 
 #include <XmI/DebugUtil.h>
 
-
 #define UNLOCKED	0
 #define LOCKED		1
 
@@ -156,6 +153,12 @@ static Window _XmClipboardInitializeSelection(Display *display,
 
 static Boolean _XmClipboardWeOwnSelection(Display *display, XmClipboard * clip);
 
+/* And one external function for the prototype police */
+
+extern int XmClipboardWithdrawFormat(Display *display, Window window,
+				     int data_id);
+
+
 
 /******************************* low level ******************************/
 
@@ -416,7 +419,6 @@ _XmClipboardDeleteFormats(Display *display, Window window, int id)
     XtFree((char *)data);
 }
 
-
 static void
 _XmClipboardDeleteItem(Display *display, Window window,
 		       XmClipboard * clip, unsigned item)
@@ -526,7 +528,6 @@ _XmClipboardDeleteItem(Display *display, Window window,
     _XmClipboardDeleteId(display, item);
 }
 
-
 static void
 _XmClipboardDeleteMarked(Display *display, Window window, XmClipboard * clip)
 {
@@ -545,14 +546,13 @@ _XmClipboardDeleteMarked(Display *display, Window window, XmClipboard * clip)
     }
 }
 
-
 static int
 _XmClipboardGetWindowProperty(Display *display, Window win, Atom item,
 			      unsigned **data, int *len,
 			      int *type_return, int *format_return,
 			      Boolean delete)
 {
-    long transfersize;
+    int transfersize;
     long offset;
     Atom actual_type;
     int actual_format;
@@ -560,20 +560,19 @@ _XmClipboardGetWindowProperty(Display *display, Window win, Atom item,
     unsigned long bytes_after = 1;
     unsigned char *prop;
     unsigned *ret_buf;
-    Bool req_delete=False;
 
     transfersize = XMaxRequestSize(display);
     *data = NULL;
     *len = 0;
 
-    ret_buf = (unsigned *)XtMalloc(8); /* minimum size */
+    ret_buf = (unsigned *)XtMalloc(8);		/* FIX ME : 8 : what's this ? */
     ret_buf[0] = 0;
     offset = 0;
     alloc_size = 0;
 
     while (bytes_after)
     {
-	if (XGetWindowProperty(display, win, item, offset, transfersize, req_delete,
+	if (XGetWindowProperty(display, win, item, offset, transfersize, False,
 			       AnyPropertyType, &actual_type, &actual_format,
 			       &nitems, &bytes_after, &prop) != Success)
 	{
@@ -619,7 +618,7 @@ _XmClipboardGetWindowProperty(Display *display, Window win, Atom item,
 
 	ret_buf = (unsigned *)XtRealloc((char *)ret_buf,
 					alloc_size + alloc_incr + 1);
-	memcpy(&ret_buf[offset], prop, alloc_incr);
+	bcopy(prop, &ret_buf[offset], alloc_incr);
 	alloc_size += alloc_incr;
 
 	switch (actual_format)
@@ -667,7 +666,6 @@ _XmClipboardGetWindowProperty(Display *display, Window win, Atom item,
     return XmClipboardSuccess;
 }
 
-
 static Boolean
 _XmClipboardSearchForWindow(Display *display, Window root, Window window)
 {
@@ -709,7 +707,6 @@ _XmClipboardSearchForWindow(Display *display, Window root, Window window)
     return found;
 }
 
-
 static Time
 _XmClipboardGetCurrentTime(Display *display)
 {
@@ -731,7 +728,6 @@ _XmClipboardGetCurrentTime(Display *display)
     return event.xproperty.time;
 }
 
-
 static Bool
 _XmClipboardDataIsReady(Display *display, XEvent *event, XPointer arg)
 {
@@ -762,7 +758,6 @@ _XmClipboardDataIsReady(Display *display, XEvent *event, XPointer arg)
     return False;
 }
 
-
 static Boolean
 _XmClipboardRequestDataAndWait(Display *display, Window win,
 			       XmClipboardFormat * format)
@@ -812,7 +807,6 @@ _XmClipboardRequestDataAndWait(Display *display, Window win,
     return True;
 }
 
-
 static Boolean
 _XmClipboardWindowExists(Display *display, Window window)
 {
@@ -855,7 +849,6 @@ _XmClipboardWindowExists(Display *display, Window window)
     return found;
 }
 
-
 static int
 _XmClipboardFindItem(Display *display, int id, unsigned **data, int *len,
 		     int *format_return, unsigned prop_id)
@@ -896,7 +889,6 @@ _XmClipboardFindItem(Display *display, int id, unsigned **data, int *len,
     return XmClipboardFail;
 }
 
-
 static XmClipboardFormat *
 _XmClipboardFindFormat(Display *display, XmClipboard * clip,
 		       char *format_name, long item_id, int index,
@@ -1050,7 +1042,6 @@ _XmClipboardFindFormat(Display *display, XmClipboard * clip,
     return format;
 }
 
-
 static void
 _XmClipboardReplaceItem(Display *display, int id, unsigned *data, int len,
 			int mode, int format, Boolean free)
@@ -1111,7 +1102,6 @@ _XmClipboardReplaceItem(Display *display, int id, unsigned *data, int len,
     }
 }
 
-
 static int
 _XmClipboardRetrieveItem(Display *display, int id, int extra_size, int size,
 			 unsigned **data, int *len, int *format_return,
@@ -1141,7 +1131,7 @@ _XmClipboardRetrieveItem(Display *display, int id, int extra_size, int size,
 
     if (status == XmClipboardSuccess)
     {
-	memcpy(buf, ldata, *len);
+	bcopy(ldata, buf, *len);
     }
 
     *data = buf;
@@ -1155,7 +1145,6 @@ _XmClipboardRetrieveItem(Display *display, int id, int extra_size, int size,
     return status;
 }
 
-
 static unsigned
 _XmClipboardGetNewItemId(Display *display)
 {
@@ -1173,7 +1162,6 @@ _XmClipboardGetNewItemId(Display *display)
     return ret;
 }
 
-
 static Atom
 _XmClipboardGetAtomFromFormat(Display *display, char *format_name)
 {
@@ -1191,7 +1179,6 @@ _XmClipboardGetAtomFromFormat(Display *display, char *format_name)
     return atom;
 }
 
-
 static Boolean
 _XmClipboardGetLenFromFormat(Display *display, char *format_name, int *format)
 {
@@ -1228,7 +1215,6 @@ _XmClipboardGetLenFromFormat(Display *display, char *format_name, int *format)
     return ret;
 }
 
-
 static Window
 _XmClipboardInitializeSelection(Display *display, XmClipboard * clip,
 				Window window, Time locktime)
@@ -1257,7 +1243,6 @@ _XmClipboardInitializeSelection(Display *display, XmClipboard * clip,
     return clipowner;
 }
 
-
 static Boolean
 _XmClipboardWeOwnSelection(Display *display, XmClipboard * clip)
 {
@@ -1276,7 +1261,6 @@ _XmClipboardWeOwnSelection(Display *display, XmClipboard * clip)
     return False;
 }
 
-
 static void
 _XmAssertClipboardSelection(Display *display, Window window,
 			    XmClipboard * clip, Time locktime)
@@ -1306,7 +1290,6 @@ _XmAssertClipboardSelection(Display *display, Window window,
     XtAddEventHandler(w, None, True, _XmClipboardEventHandler, NULL);
 }
 
-
 static Bool
 _XmClipboardSelectionIsReady(Display *display, XEvent *event, XPointer arg)
 {
@@ -1370,13 +1353,13 @@ _XmClipboardSelectionIsReady(Display *display, XEvent *event, XPointer arg)
 
     buf = (unsigned *)XtMalloc(len + match->len);
 
-    memcpy(buf, match->data, match->len);
+    bcopy(match->data, buf, match->len);
 
     XtFree((char *)match->data);
 
     match->data = buf;
 
-    memcpy((char *)buf + match->len, data, len);
+    bcopy(data, (char *)buf + match->len, len);
 
     XtFree((char *)data);
 
@@ -1390,7 +1373,6 @@ _XmClipboardSelectionIsReady(Display *display, XEvent *event, XPointer arg)
     return True;
 }
 
-
 static Boolean
 _XmClipboardGetSelection(Display *display, Window window, char *format_name,
 			 XmClipboard * clip, unsigned **data, int *len)
@@ -1474,7 +1456,6 @@ _XmClipboardGetSelection(Display *display, Window window, char *format_name,
     return False;
 }
 
-
 static void
 _XmClipboardSetNextItemId(Display *display, int item_id)
 {
@@ -1524,7 +1505,6 @@ _XmClipboardSetNextItemId(Display *display, int item_id)
 			    PropModeReplace, 32, True);
 }
 
-
 static void
 _XmClipboardMarkItem(Display *display, XmClipboard * clip,
 		     unsigned id, Boolean delete_on)
@@ -1558,7 +1538,6 @@ _XmClipboardMarkItem(Display *display, XmClipboard * clip,
 
 }
 
-
 static void
 _XmClipboardSetAccess(Display *display, Window window)
 {
@@ -1572,7 +1551,6 @@ _XmClipboardSetAccess(Display *display, Window window)
 		    PropModeReplace, (unsigned char *)"yes", 3);
 }
 
-
 static XmClipboard *
 _XmClipboardOpen(Display *display, int extra_size)
 {
@@ -1634,7 +1612,6 @@ _XmClipboardOpen(Display *display, int extra_size)
     return clip;
 }
 
-
 static void
 _XmClipboardClose(Display *display, XmClipboard * clip)
 {
@@ -1644,7 +1621,6 @@ _XmClipboardClose(Display *display, XmClipboard * clip)
 			    PropModeReplace, 32, True);
 }
 
-
 static int
 _XmClipboardLock(Display *display, Window window)
 {
@@ -1754,7 +1730,6 @@ _XmClipboardLock(Display *display, Window window)
     return XmClipboardSuccess;
 }
 
-
 static int
 _XmClipboardUnlock(Display *display, Window window, Boolean remove_all_locks)
 {
@@ -1820,7 +1795,6 @@ _XmClipboardUnlock(Display *display, Window window, Boolean remove_all_locks)
     return XmClipboardSuccess;
 }
 
-
 static void
 _XmClipboardEventHandler(Widget widget, XtPointer client_data,
 			 XEvent *ev, Boolean *dontSwallow)
@@ -1911,7 +1885,6 @@ _XmClipboardEventHandler(Widget widget, XtPointer client_data,
 			    PropModeReplace, 32, True);
 }
 
-
 static Boolean
 _XmClipboardSendMessage(Display *display, Window window,
 			XmClipboardFormat * format, int id)
@@ -1978,7 +1951,7 @@ _XmClipboardSendMessage(Display *display, Window window,
 
 /*************************** public functions **************************/
 
-extern int
+int
 XmClipboardBeginCopy(Display *display,
 		     Window window,
 		     XmString clip_label,
@@ -1990,8 +1963,7 @@ XmClipboardBeginCopy(Display *display,
 				widget, callback, item_id);
 }
 
-
-extern int
+int
 XmClipboardCancelCopy(Display *display,
 		      Window window,
 		      long item_id)
@@ -2033,8 +2005,7 @@ XmClipboardCancelCopy(Display *display,
     return XmClipboardSuccess;
 }
 
-
-extern int
+int
 XmClipboardCopy(Display *display,
 		Window window,
 		long item_id,
@@ -2170,7 +2141,7 @@ XmClipboardCopy(Display *display,
 
     if (buffer)
     {
-	memcpy(nbuf, buffer, length);
+	bcopy(buffer, nbuf, length);
     }
 
     format->length += length;
@@ -2193,8 +2164,7 @@ XmClipboardCopy(Display *display,
     return XmClipboardSuccess;
 }
 
-
-extern int
+int
 XmClipboardCopyByName(Display *display,
 		      Window window,
 		      long data_id,
@@ -2260,7 +2230,7 @@ XmClipboardCopyByName(Display *display,
 
 	bufstart = (unsigned char *)idata + ilen - length;
 
-	memcpy(bufstart, buffer, length);
+	bcopy(buffer, bufstart, length);
 
 	_XmClipboardReplaceItem(display, format->data_id, idata, ilen,
 				PropModeReplace, fmt, True);
@@ -2279,8 +2249,7 @@ XmClipboardCopyByName(Display *display,
     return XmClipboardSuccess;
 }
 
-
-extern int
+int
 XmClipboardEndCopy(Display *display,
 		   Window window,
 		   long item_id)
@@ -2362,8 +2331,7 @@ XmClipboardEndCopy(Display *display,
     return XmClipboardSuccess;
 }
 
-
-extern int
+int
 XmClipboardEndRetrieve(Display *display,
 		       Window window)
 {
@@ -2381,7 +2349,7 @@ XmClipboardEndRetrieve(Display *display,
     return XmClipboardSuccess;
 }
 
-extern int
+int
 XmClipboardInquireCount(Display *display,
 			Window window,
 			int *count,
@@ -2431,7 +2399,7 @@ XmClipboardInquireCount(Display *display,
 	    return XmClipboardFail;
 	}
 
-	/* FIX ME:  This is supposed to be the ICCCM way */
+	/* FIX ME */
     }
 
     if (max_length != NULL)
@@ -2456,8 +2424,7 @@ XmClipboardInquireCount(Display *display,
     return XmClipboardSuccess;
 }
 
-
-extern int
+int
 XmClipboardInquireFormat(Display *display,
 			 Window window,
 			 int index,
@@ -2507,7 +2474,7 @@ XmClipboardInquireFormat(Display *display,
 	    return XmClipboardFail;
 	}
 
-	/* FIX ME: This is supposed to be the ICCCM way of things */
+	/* FIX ME */
     }
 
     if (name)
@@ -2537,8 +2504,7 @@ XmClipboardInquireFormat(Display *display,
     return XmClipboardSuccess;
 }
 
-
-extern int
+int
 XmClipboardInquireLength(Display *display,
 			 Window window,
 			 char *format_name,
@@ -2604,8 +2570,7 @@ XmClipboardInquireLength(Display *display,
     return XmClipboardSuccess;
 }
 
-
-extern int
+int
 XmClipboardInquirePendingItems(Display *display,
 			       Window window,
 			       char *format_name,
@@ -2686,16 +2651,14 @@ XmClipboardInquirePendingItems(Display *display,
     return XmClipboardSuccess;
 }
 
-
-extern int
+int
 XmClipboardLock(Display *display,
 		Window window)
 {
     return _XmClipboardLock(display, window);
 }
 
-
-extern int
+int
 XmClipboardRegisterFormat(Display *display,
 			  char *format_name,
 			  int format_length)
@@ -2756,8 +2719,7 @@ XmClipboardRegisterFormat(Display *display,
     return XmClipboardFail;
 }
 
-
-extern int
+int
 XmClipboardRetrieve(Display *display,
 		    Window window,
 		    char *format_name,
@@ -2771,7 +2733,7 @@ XmClipboardRetrieve(Display *display,
     int fetchlen = 0;
     XmClipboardFormat *format;
     Boolean got_format = False;
-    unsigned *data=NULL;
+    unsigned *data;
     unsigned char *bufstart = NULL;
     Boolean partial_copy = False, got_data = False;
 
@@ -2886,43 +2848,40 @@ XmClipboardRetrieve(Display *display,
 	DEBUGOUT(XdbDebug(__FILE__, XtWindowToWidget(display, window),
 	    "XmClipboardRetrieve: we don't own selection !!\n"));
 
-/* amai-20001018: at least when clipboard is messed up from remaining LT bugs
-   I got data==NULL here ...
-*/
-	if (got_data = _XmClipboardGetSelection(display, window,
-	                                        format_name, clip,
-  				  		&data, &dlen)) {
+	_XmClipboardGetSelection(display, window, format_name, clip,
+				 &data, &dlen);
 
-		bufstart = (unsigned char *)data + clip->offset;
-		if (dlen - clip->offset > length)
-		{
-		    partial_copy = True;
-		    fetchlen = length;
-		}
-		else
-		{
-		    fetchlen = dlen - clip->offset;
-		}
-	
-		if (clip->retrieve_locked)
-		{
-	
-		    if (partial_copy)
-		    {
-			clip->offset += fetchlen;
-		    }
-		    else
-		    {
-			clip->offset = 0;
-		    }
-		}
-	} /* got_data */
+	bufstart = (unsigned char *)data + clip->offset;
 
+	if (dlen - clip->offset > length)
+	{
+	    partial_copy = True;
+	    fetchlen = length;
+	}
+	else
+	{
+	    fetchlen = dlen - clip->offset;
+	}
+
+	if (clip->retrieve_locked)
+	{
+
+	    if (partial_copy)
+	    {
+		clip->offset += fetchlen;
+	    }
+	    else
+	    {
+		clip->offset = 0;
+	    }
+	}
+
+	got_data = True;
     }
 
     if (got_data)
     {
-	memcpy(buffer, bufstart, fetchlen);
+	bcopy(bufstart, buffer, fetchlen);
 
 	XtFree((char *)data);
     }
@@ -2954,8 +2913,7 @@ XmClipboardRetrieve(Display *display,
     return XmClipboardSuccess;
 }
 
-
-extern int
+int
 XmClipboardStartCopy(Display *display,
 		     Window window,
 		     XmString clip_label,
@@ -3033,7 +2991,6 @@ XmClipboardStartCopy(Display *display,
     return XmClipboardSuccess;
 }
 
-
 int
 XmClipboardStartRetrieve(Display *display,
 			 Window window,
@@ -3057,7 +3014,6 @@ XmClipboardStartRetrieve(Display *display,
     return XmClipboardSuccess;
 }
 
-
 int
 XmClipboardUndoCopy(Display *display, Window window)
 {
@@ -3116,15 +3072,13 @@ XmClipboardUndoCopy(Display *display, Window window)
     return XmClipboardSuccess;
 }
 
-
-extern int
+int
 XmClipboardUnlock(Display *display, Window window, Boolean remove_all_locks)
 {
     return _XmClipboardUnlock(display, window, remove_all_locks);
 }
 
-
-extern int
+int
 XmClipboardWithdrawFormat(Display *display,
 			  Window window,
 			  int data_id)
