@@ -1,9 +1,8 @@
 /**
  *
- * $Id: Display.c,v 1.23 2001/07/27 18:51:55 dannybackx Exp $
+ * $Id: Display.c,v 1.14 1999/02/02 18:23:05 gritton Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,10 +22,9 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Display.c,v 1.23 2001/07/27 18:51:55 dannybackx Exp $";
+static const char rcsid[] = "$Id: Display.c,v 1.14 1999/02/02 18:23:05 gritton Exp $";
 
 #include <LTconfig.h>
-
 #include <XmI/XmI.h>
 #include <XmI/MacrosI.h>
 #include <XmI/AtomMgrI.h>
@@ -40,7 +38,6 @@ static const char rcsid[] = "$Id: Display.c,v 1.23 2001/07/27 18:51:55 dannyback
 
 #include <XmI/DebugUtil.h>
 
-
 #define Offset(field) XtOffsetOf(XmDisplayRec, display.field)
 
 static XtResource resources[] =
@@ -88,7 +85,7 @@ static void initialize(Widget request, Widget new_w,
 
 static void destroy(Widget w);
 
-#if 1
+#if 0
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
 #endif
@@ -151,23 +148,23 @@ XmDisplayClassRec xmDisplayClassRec = {
 	/* class_part_initialize */ class_part_initialize,
 	/* class_inited          */ False,
 	/* initialize            */ initialize,
-	/* initialize_hook       */ NULL, /* Motif has one */
+	/* initialize_hook       */ NULL,
 	/* realize               */ XtInheritRealize,
-	/* actions               */ NULL,
-	/* num_actions           */ 0,
+	/* actions               */ NULL /*actions*/,
+	/* num_actions           */ 0 /*XtNumber(actions)*/,
 	/* resources             */ resources,
 	/* num_resources         */ XtNumber(resources),
 	/* xrm_class             */ NULLQUARK,
-	/* compress_motion       */ False,
-	/* compress_exposure     */ XtExposeNoCompress,
-	/* compress_enterleave   */ False,
+	/* compress_motion       */ False /*True*/,
+	/* compress_exposure     */ XtExposeNoCompress /*XtExposeCompressMultiple*/,
+	/* compress_enterleave   */ False /*True*/,
 	/* visible_interest      */ False,
 	/* destroy               */ destroy,
 	/* resize                */ NULL,
 	/* expose                */ NULL,
-	/* set_values            */ set_values, /* Motif doesn't have this */
+	/* set_values            */ NULL /*set_values*/,
 	/* set_values_hook       */ NULL,
-	/* set_values_almost     */ NULL,
+	/* set_values_almost     */ NULL /*XtInheritSetValuesAlmost*/,
 	/* get_values_hook       */ NULL,
 	/* accept_focus          */ NULL,
 	/* version               */ XtVersion,
@@ -181,8 +178,8 @@ XmDisplayClassRec xmDisplayClassRec = {
     {
 	/* geometry manager */ NULL,
         /* change_managed   */ NULL,
-        /* insert_child     */ XtInheritInsertChild, /* Motif has one */
-        /* delete_child     */ XtInheritDeleteChild, /* Motif has one */
+        /* insert_child     */ XtInheritInsertChild,
+        /* delete_child     */ XtInheritDeleteChild,
         /* extension        */ NULL,	
     },
     /* Shell class part */
@@ -245,7 +242,7 @@ DisplaySuicide(Widget w, XtPointer ClientData, XtPointer CallData)
 {
     Display *Dsp;
 
-    DEBUGOUT(_LtDebug(__FILE__, (Widget)ClientData,
+    DEBUGOUT(XdbDebug(__FILE__, (Widget)ClientData,
 		      "XmDisplay Connection Close-Down\n"));
 
     Dsp = XtDisplay((Widget)ClientData);
@@ -309,17 +306,7 @@ initialize(Widget request, Widget new_w,
     XPointer FirstDisplayWidget;
     XmDisplay dpy = (XmDisplay)new_w;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
-		      "%s:initialize(%d) - %i args\n"
-		      "\trequest X %5i Y %5i W %5i H %5i\n"
-		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
-		      __FILE__, __LINE__,
-		      *num_args,
-		      XtX(request), XtY(request),
-		      XtWidth(request), XtHeight(request),
-		      XtX(new_w), XtY(new_w),
-		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "XmDisplay initialize\n"));
 
     dpy->display.shellCount = 0;
     dpy->display.numModals = 0;
@@ -350,7 +337,7 @@ initialize(Widget request, Widget new_w,
     else
     {
 	XSaveContext(XtDisplay(new_w), PDWC_RID_DisplayWidget,
-		     PerDisplayWidgetContext, (XPointer)new_w);
+		     PerDisplayWidgetContext, (_Xconst char *)new_w);
     }
 
     /*
@@ -399,9 +386,9 @@ destroy(Widget w)
 {
 
     if (CoreBeingDestroyed(w))
-	DEBUGOUT(_LtDebug(__FILE__, w, "Destroy(being_destroyed)\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "Destroy(being_destroyed)\n"));
     else {
-	DEBUGOUT(_LtDebug(__FILE__, w, "Destroy\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "Destroy\n"));
 
 	/* Hack */
 	return;
@@ -417,7 +404,7 @@ destroy(Widget w)
     _XmFlushAtomsForDisplay(XtDisplay(w));
 }
 
-#if 1
+#if 0
 /*
  * There is almost nothing dto do -- yet.
  */
@@ -425,21 +412,6 @@ static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
-		      "%s:set_values(%d) - %i args\n"
-		      "\t    old X %5i Y %5i W %5i H %5i\n"
-		      "\trequest X %5i Y %5i W %5i H %5i\n"
-		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
-		      __FILE__, __LINE__,
-		      *num_args,
-		      XtX(old), XtY(old),
-		      XtWidth(old), XtHeight(old),
-		      XtX(request), XtY(request),
-		      XtWidth(request), XtHeight(request),
-		      XtX(new_w), XtY(new_w),
-		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
-
     return False;
 }
 #endif
@@ -461,7 +433,7 @@ RefreshMapping(Widget w, XEvent *event,
      * look up the offending display widget and refresh the virtual
      * key bindings. Happy refreshing...
      */
-    DEBUGOUT(_LtDebug(__FILE__, w, "Refreshing virtual key bindings.\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "Refreshing virtual key bindings.\n"));
 
     _XmRefreshVirtKeys(XmGetXmDisplay(event->xmapping.display));
 }
@@ -530,34 +502,17 @@ _XmGetDropSiteManagerObject(XmDisplay xmDisplay)
 {
     XmDropSiteManagerObject dsm = NULL;
 
-    DEBUGOUT(_LtDebug(__FILE__, (Widget)xmDisplay, "%s:_XmGetDropSiteManagerObject(%d) - %s 0x%p\n",
-    	__FILE__, __LINE__,
-    	Display_DSM(xmDisplay) ? "Old" : "New", Display_DSM(xmDisplay)));
-    if (!XmIsDisplay(xmDisplay))
+    if (Display_DSM(xmDisplay) == NULL)
     {
-    	_XmWarning((Widget)xmDisplay, "%s:_XmGetDropSiteManagerObject(%d) called without an XmDisplay",
-    		__FILE__, __LINE__);
+	dsm = (XmDropSiteManagerObject)XtCreateWidget("DropSiteManager",
+				       Display_DropSiteManagerClass(xmDisplay),
+						   (Widget)xmDisplay, NULL, 0);
+
+	Display_DSM(xmDisplay) = dsm;
     }
     else
     {
-	if (Display_DSM(xmDisplay) == NULL)
-	{
-	    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmGetDropSiteManagerObject(%d) - creating\n",
-		__FILE__, __LINE__
-		));
-	    dsm = (XmDropSiteManagerObject)XtCreateWidget("DropSiteManager",
-					   Display_DropSiteManagerClass(xmDisplay),
-						       (Widget)xmDisplay, NULL, 0);
-	    DEBUGOUT(_LtDebug2(__FILE__, (Widget)xmDisplay, (Widget)dsm, "%s:_XmGetDropSiteManagerObject(%d) - created 0x%p\n",
-		__FILE__, __LINE__, dsm
-		));
-
-	    Display_DSM(xmDisplay) = dsm;
-	}
-	else
-	{
-	    dsm = Display_DSM(xmDisplay);
-	}
+	dsm = Display_DSM(xmDisplay);
     }
 
     return dsm;
@@ -568,8 +523,6 @@ _XmGetDragProtocolStyle(Widget w)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(w));
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:_XmGetDragProtocolStyle(%d)\n",
-    	__FILE__, __LINE__));
     switch (Display_DragReceiverProtocolStyle(disp))
     {
     case XmDRAG_NONE:
@@ -597,8 +550,6 @@ _XmGetDragProtocolStyle(Widget w)
 unsigned char
 _XmGetDragTrackingMode(Widget w)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:_XmGetDragTrackingMode(%d)\n",
-    	__FILE__, __LINE__));
     return 0;
 }
 
@@ -606,14 +557,12 @@ Widget
 _XmGetDragContextFromHandle(Widget w, Atom iccHandle)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(w)), dc;
-    Cardinal c;
+    int i;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:_XmGetDragContextFromHandle(%d)\n",
-    	__FILE__, __LINE__));
-    for (c = 0; c < MGR_NumChildren(disp); c++)
+    for (i = 0; i < MGR_NumChildren(disp); i++)
     {
 
-	dc = MGR_Children(disp)[c];
+	dc = MGR_Children(disp)[i];
 
 	if (XmIsDragContext(dc))
 	{
@@ -637,8 +586,6 @@ _XmGetXmDisplayClass(void)
 {
     if (__XmDisplayClass == NULL)
     {
-	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmGetXmDisplayClass(%d)\n",
-	    __FILE__, __LINE__));
 	__XmDisplayClass = (WidgetClass)&xmDisplayClassRec;
     }
 
@@ -656,8 +603,6 @@ _XmSetXmDisplayClass(WidgetClass wc)
 {
     WidgetClass OldDisplayClass, SuperClass;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmSetXmDisplayClass(%d)\n",
-    	__FILE__, __LINE__));
     OldDisplayClass = __XmDisplayClass;
     SuperClass = wc;
 
@@ -684,10 +629,8 @@ Widget
 XmGetDragContext(Widget w, Time time)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(w)), dc = NULL;
-    Cardinal i;
+    int i;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:XmGetDragContext(%d)\n",
-    	__FILE__, __LINE__));
     for (i = 0; i < MGR_NumChildren(disp); i++)
     {
 	if (XmIsDragContext(MGR_Children(disp)[i]))
