@@ -1,9 +1,8 @@
 /**
  *
- * $Id: DragBS.c,v 1.40 2001/07/27 18:51:55 dannybackx Exp $
+ * $Id: DragBS.c,v 1.17 1999/08/03 23:21:51 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,18 +22,18 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DragBS.c,v 1.40 2001/07/27 18:51:55 dannybackx Exp $";
-
-#include <LTconfig.h>
+static const char rcsid[] = "$Id: DragBS.c,v 1.17 1999/08/03 23:21:51 rwscott Exp $";
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 
+#include <LTconfig.h>
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/DisplayP.h>
 #include <Xm/AtomMgr.h>
+#include <X11/Xfuncs.h>
 #include <XmI/AtomMgrI.h>
 #include <XmI/DragDropI.h>
 #include <XmI/CutPasteI.h>
@@ -58,12 +57,6 @@ static const char rcsid[] = "$Id: DragBS.c,v 1.40 2001/07/27 18:51:55 dannybackx
  * have access to the X server.
  */
 
-/* amai: Hmm, well for now it's just for convenience to help on debugging.
- * it used to be 100000L 
- */
-#define PROP_LENGTH 200000L
-
-
 /*
  * these are used for protected sections
  */
@@ -84,7 +77,6 @@ static XContext displayToDW = None;
 static XContext displayToAtoms = None;
 static XContext displayToTargets = None;
 
-
 /*
  * basic atoms that must be agreed on
  */
@@ -137,7 +129,6 @@ static char *motifAtoms[] =
     _XA_XM_TEXT_I_S_PROP
 };
 
-
 static int
 DWError(Display *display, XErrorEvent *event)
 {
@@ -146,7 +137,6 @@ DWError(Display *display, XErrorEvent *event)
     return 0;
 }
 
-
 /*
  * create the drag window
  */
@@ -157,7 +147,7 @@ create_drag_window(Display *display)
     XSetWindowAttributes attr;
 
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:create_drag_window(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:create_drag_window(%d)\n",
 		      __FILE__, __LINE__));
 
     attr.override_redirect = True;
@@ -174,7 +164,6 @@ create_drag_window(Display *display)
     return win;
 }
 
-
 /*
  * see if the drag window property can be found on the root window
  */
@@ -189,7 +178,7 @@ read_drag_window(Display *display)
     Window win = None;
 
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_drag_window(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_drag_window(%d)\n",
 		      __FILE__, __LINE__));
 
     old_handler = XSetErrorHandler(DWError);
@@ -199,15 +188,14 @@ read_drag_window(Display *display)
     mw = XmInternAtom(display, _XA_MOTIF_DRAG_WINDOW, False);
 
     if (XGetWindowProperty(display, DefaultRootWindow(display),
-			   mw, 0L, PROP_LENGTH,
+			   mw, 0L, 100000L,
 			   False, AnyPropertyType,
 			   &atype, &aformat, &nitems, &bafter, &prop)
 	== Success && atype == XA_WINDOW && aformat == 32 && nitems == 1)
     {
 	win = *((Window *)prop);
     }
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_drag_window(%d) - bafter=%i\n",
-		      __FILE__, __LINE__, bafter));
+
     if (prop)
     {
 	XFree((char *)prop);
@@ -217,19 +205,18 @@ read_drag_window(Display *display)
 
     if (error_flag)
     {
-	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_drag_window(%d) - None\n",
+	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_drag_window(%d) - None\n",
 		      __FILE__, __LINE__));
 
 	return None;
     }
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_drag_window(%d) - %p\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_drag_window(%d) - %p\n",
 		      __FILE__, __LINE__, win));
 
     return win;
 }
 
-
 /*
  * set the drag window property on the root window
  */
@@ -238,7 +225,7 @@ write_drag_window(Display *display, Window *win)
 {
     Atom mw;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:write_drag_window(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:write_drag_window(%d)\n",
 		      __FILE__, __LINE__));
 
     mw = XmInternAtom(display, _XA_MOTIF_DRAG_WINDOW, False);
@@ -247,7 +234,6 @@ write_drag_window(Display *display, Window *win)
 		    XA_WINDOW, 32, PropModeReplace, (unsigned char *)win, 1);
 }
 
-
 /*
  * lookup (program local) the value of the drag window
  */
@@ -256,7 +242,7 @@ get_drag_window(Display *display)
 {
     Window win;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:get_drag_window(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:get_drag_window(%d)\n",
 		      __FILE__, __LINE__));
 
     if (displayToDW == None)
@@ -267,26 +253,25 @@ get_drag_window(Display *display)
     if (XFindContext(display, DefaultRootWindow(display),
 		     displayToDW, (XPointer *)&win) == XCSUCCESS)
     {
-	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:get_drag_window(%d) - %p\n",
+	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:get_drag_window(%d) - %p\n",
 		      __FILE__, __LINE__, win));
 
 	return win;
     }
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:get_drag_window(%d) - None\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:get_drag_window(%d) - None\n",
 		      __FILE__, __LINE__));
 
     return None;
 }
 
-
 /*
  * cache (program local) the value of the drag window
  */
 static void
 set_drag_window(Display *display, Window win)
 {
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:set_drag_window(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:set_drag_window(%d)\n",
 		      __FILE__, __LINE__));
 
     if (displayToDW == None)
@@ -302,17 +287,16 @@ set_drag_window(Display *display, Window win)
     }
 
     XSaveContext(display, DefaultRootWindow(display),
-		 displayToDW, (XPointer)win);
+		 displayToDW, (_Xconst char *)win);
 }
 
-
 /*
  * catch window errors when fetching or setting the DRAG_WINDOW properties
  */
 static int
 protect_handler(Display *display, XErrorEvent *event)
 {
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:protect_handler(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:protect_handler(%d)\n",
 		      __FILE__, __LINE__));
 
     if (event->error_code == BadWindow &&
@@ -332,14 +316,13 @@ protect_handler(Display *display, XErrorEvent *event)
     return (*oldErrorHandler) (display, event);
 }
 
-
 /*
  * begin catching window errors
  */
 static void
 begin_protection(Display *display, Window win)
 {
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:begin_protection(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:begin_protection(%d)\n",
 		      __FILE__, __LINE__));
 
     bad_window = False;
@@ -351,14 +334,13 @@ begin_protection(Display *display, Window win)
     errorWindow = win;
 }
 
-
 /*
  * end catching window errors
  */
 static void
 end_protection(Display *display)
 {
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:end_protection(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:end_protection(%d)\n",
 		      __FILE__, __LINE__));
 
     XSync(display, False);
@@ -368,101 +350,78 @@ end_protection(Display *display)
     oldErrorHandler = NULL;
 }
 
-
 /*
  * read from a drag buffer (sort of)
- * probably for Motif BC (binary compatibility?!)
  */
-extern int
+short
 _XmReadDragBuffer(XmDndBufMgr bmgr, Boolean read_string,
-		  char *retbuf, int bufsize)
+		  char *retbuf, short size)
 {
     int rsize, eaten;
-    int size;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmReadDragBuffer(%d) - read_string %s size %i\n",
+    /*
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmReadDragBuffer(%d) - read_string %s\n",
 		      __FILE__, __LINE__,
-		      read_string ? "True" : "False",
-		      bufsize));
+		      read_string ? "True" : "False"));
+    */
 
     if (read_string)
     {
 	rsize = bmgr->name_size;
+
 	eaten = bmgr->name_start - bmgr->names;
 
-	if (eaten>rsize) {
-	  /* amai: in my understanding this is a major problem and
-	     should never happen */
-	  _XmWarning(NULL, "%s(%i): eaten=%i > rsize=%i\n",
-	             __FILE__, __LINE__, eaten, rsize);
-          /* abort(); */
-          size=0;
+	if (rsize <= eaten)
+	{
+	    size = rsize - eaten;
 	}
-	else {
-	   size = rsize-eaten;
-  	   if (size > bufsize)
-              size = bufsize;
-        }
-	memcpy(retbuf, bmgr->name_start, size);
+
+	bcopy(bmgr->name_start, retbuf, size);
+
 	bmgr->name_start += size;
+
 	return size;
     }
     else
     {
 	rsize = bmgr->atom_size;
-	eaten = (int)(bmgr->atom_start - bmgr->atoms);
 
-	if (eaten>rsize) {
-	  /* amai: in my understanding this is a major problem and
-	     should never happen */
-	  _XmWarning(NULL, "%s(%i): eaten=%i > rsize=%i\n",
-	             __FILE__, __LINE__, eaten, rsize);
-          /* abort(); */
-          size=0;
+	eaten = bmgr->atom_start - bmgr->atoms;
+
+	if (rsize <= eaten)
+	{
+	    size = rsize - eaten;
 	}
-	else {
-	   size = rsize-eaten;
-	   if (size > bufsize)
-              size = bufsize;
-        }
-        /* fprintf(stderr, "rsize=%i, eaten=%i, bufsize=%i, size=%i\n",
-                rsize, eaten, bufsize, size); */
-	memcpy(retbuf, bmgr->atom_start, size);
+
+	bcopy(bmgr->atom_start, retbuf, size);
+
 	bmgr->atom_start += size;
+
 	return size;
     }
 }
 
-
 /*
  * write to a drag buffer (sort of)
- * probably for Motif BC (binary compatibility?!)
  */
-extern int
+short
 _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
-		   char *data, int size)
+		   char *data, short size)
 {
-    int increase_needed;
-
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmWriteDragBuffer(%d) write_string %s size %i\n",
-		      __FILE__, __LINE__,
-		      write_string ? "True" : "False",
-		      size));
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmWriteDragBuffer(%d)\n",
+		      __FILE__, __LINE__));
 
     if (write_string)
     {
-	increase_needed = (bmgr->name_size + size) - bmgr->name_avail;
-	if (increase_needed > 0)
+	if ((bmgr->name_size + size) > bmgr->name_avail)
 	{
-	    increase_needed /= 1000;
-            increase_needed++;
-            increase_needed *= 1000;
-	    bmgr->name_avail += increase_needed;
+	    bmgr->name_avail += 1000;
 
 	    if (bmgr->names == bmgr->name_ptr)
 	    {
 		bmgr->names = XtMalloc(bmgr->name_avail);
-		memcpy(bmgr->names, bmgr->name_ptr, bmgr->name_size);
+
+		bcopy(bmgr->name_ptr, bmgr->names, bmgr->name_size);
 	    }
 	    else
 	    {
@@ -470,24 +429,23 @@ _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
 	    }
 	}
 
-	memcpy(bmgr->names + bmgr->name_size, data, size);
+	bcopy(data, bmgr->names + bmgr->name_size, size);
+
 	bmgr->name_size += size;
 
 	return size;
     }
     else
     {
-	increase_needed = (bmgr->atom_size + size) - bmgr->atom_avail;
-	if (increase_needed)
+	if ((bmgr->atom_size + size) > bmgr->atom_avail)
 	{
-	    increase_needed /= 1000;
-            increase_needed++;
-            increase_needed *= 1000;		
-	    bmgr->atom_avail += increase_needed;
+	    bmgr->atom_avail += 1000;
+
 	    if (bmgr->atoms == bmgr->atom_ptr)
 	    {
 		bmgr->atoms = XtMalloc(bmgr->atom_avail);
-		memcpy(bmgr->atoms, bmgr->atom_ptr, bmgr->atom_size);
+
+		bcopy(bmgr->atom_ptr, bmgr->atoms, bmgr->atom_size);
 	    }
 	    else
 	    {
@@ -495,14 +453,14 @@ _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
 	    }
 	}
 
-	memcpy(bmgr->atoms + bmgr->atom_size, data, size);
+	bcopy(data, bmgr->atoms + bmgr->atom_size, size);
+
 	bmgr->atom_size += size;
 
 	return size;
     }
 }
 
-
 /*
  * get the ATOM_PAIRS.  They may or may not already exist
  */
@@ -521,7 +479,7 @@ read_atom_pairs(Display *display)
     unsigned long nitems, bafter;
     unsigned char *prop = NULL;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d)\n",
 		      __FILE__, __LINE__));
 
     pa = XmInternAtom(display, _XA_MOTIF_DRAG_ATOM_PAIRS, False);
@@ -530,18 +488,18 @@ read_atom_pairs(Display *display)
 
     begin_protection(display, win);
 
-    if (XGetWindowProperty(display, win, pa, 0L, PROP_LENGTH,
+    if (XGetWindowProperty(display, win, pa, 0L, 100000L,
 			   False, pa,
 			   &atype, &aformat, &nitems, &bafter,
 			   (unsigned char **)&pairs) == Success &&
 	nitems >= 8 && pairs != NULL)
     {
-	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - got property, bafter=%i\n",
-		      __FILE__, __LINE__, bafter));
+	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - got property\n",
+		      __FILE__, __LINE__));
 
 	gotit = True;
-	prop = (unsigned char *)pairs;
     }
+
     end_protection(display);
 
     if (bad_window)
@@ -562,7 +520,7 @@ read_atom_pairs(Display *display)
 	    XFree((char *)prop);
 	}
 
-	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - did not get property\n",
+	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - did not get property\n",
 		      __FILE__, __LINE__));
 
 	return False;
@@ -580,7 +538,7 @@ read_atom_pairs(Display *display)
 	SWAP4BYTES(pairs->data_size);
     }
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - %i pairs\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - %i pairs\n",
 		      __FILE__, __LINE__,
 		      pairs->num_pairs));
 
@@ -606,7 +564,7 @@ read_atom_pairs(Display *display)
 
 	    _XmReadDragBuffer(&bmgr, True, buf, pair.namelen);
 
-	    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - intern %s\n",
+	    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - intern %s\n",
 		      __FILE__, __LINE__,
 		      buf));
 
@@ -622,7 +580,6 @@ read_atom_pairs(Display *display)
     return gotit;
 }
 
-
 /*
  * if the ATOM_PAIRS didn't exist, put them on the drag window
  */
@@ -638,7 +595,7 @@ write_atom_pairs(Display *display)
     int i;
     Window win;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:write_atom_pairs(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:write_atom_pairs(%d)\n",
 		      __FILE__, __LINE__));
 
     pair_rec.byte_order = _XmByteOrder();
@@ -706,7 +663,6 @@ write_atom_pairs(Display *display)
     }
 }
 
-
 /*
  * fetch the cached atoms table
  */
@@ -715,7 +671,7 @@ get_atoms_table(Display *display)
 {
     XmDndAtomsTable tbl = NULL;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:get_atoms_table(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:get_atoms_table(%d)\n",
 		      __FILE__, __LINE__));
 
     if (displayToAtoms == (XContext)0)
@@ -732,7 +688,6 @@ get_atoms_table(Display *display)
     return tbl;
 }
 
-
 /*
  * cache the atoms table
  */
@@ -741,7 +696,7 @@ set_atoms_table(Display *display, XmDndAtomsTable table)
 {
     XmDndAtomsTable atoms;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:set_atoms_table(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:set_atoms_table(%d)\n",
 		      __FILE__, __LINE__));
 
     if (displayToAtoms == (XContext)0)
@@ -760,16 +715,15 @@ set_atoms_table(Display *display, XmDndAtomsTable table)
     }
 
     XSaveContext(display, DefaultRootWindow(display),
-		 displayToAtoms, (XPointer)table);
+		 displayToAtoms, (_Xconst char *)table);
 }
 
-
 static XmDndAtomsTable
 create_default_atoms_table(Display *display)
 {
     XmDndAtomsTable tbl;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:create_default_atoms_table(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:create_default_atoms_table(%d)\n",
 		      __FILE__, __LINE__));
 
     tbl = (XmDndAtomsTable) XtMalloc(sizeof(XmDndAtomsTableRec));
@@ -786,7 +740,6 @@ create_default_atoms_table(Display *display)
     return tbl;
 }
 
-
 static Boolean
 read_atoms_table(Display *display, XmDndAtomsTable tbl)
 {
@@ -799,7 +752,7 @@ read_atoms_table(Display *display, XmDndAtomsTable tbl)
     XmDndAtomsTableEntryRec atom_ent;
     XmDndBufMgrRec bmgr;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_atoms_table(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_atoms_table(%d)\n",
 		      __FILE__, __LINE__));
 
     da = XmInternAtom(display, _XA_MOTIF_DRAG_ATOMS, False);
@@ -808,14 +761,12 @@ read_atoms_table(Display *display, XmDndAtomsTable tbl)
 
     begin_protection(display, win);
 
-    if (XGetWindowProperty(display, win, da, 0L, PROP_LENGTH,
+    if (XGetWindowProperty(display, win, da, 0L, 100000L,
 			   False, da,
 			   &atype, &aformat, &nitems, &bafter,
 			   (unsigned char **)&atoms) == Success &&
 	nitems >= 8)
     {
-        DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - got property, bafter=%i\n",
-		      __FILE__, __LINE__, bafter));    
 	got_it = True;
     }
 
@@ -892,7 +843,6 @@ read_atoms_table(Display *display, XmDndAtomsTable tbl)
     return True;
 }
 
-
 /*
  * write the atoms table out to the drag window
  */
@@ -906,7 +856,7 @@ write_atoms_table(Display *display, XmDndAtomsTable tbl)
     int i;
     Window win;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:write_atoms_table(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:write_atoms_table(%d)\n",
 		      __FILE__, __LINE__));
 
     if (tbl == NULL)
@@ -961,7 +911,6 @@ write_atoms_table(Display *display, XmDndAtomsTable tbl)
     }
 }
 
-
 /*
  * fetch the cached atoms table
  */
@@ -970,7 +919,7 @@ get_targets_table(Display *display)
 {
     XmDndTargetsTable targets = NULL;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:get_targets_table(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:get_targets_table(%d)\n",
 		      __FILE__, __LINE__));
 
     if (displayToTargets == (XContext)0)
@@ -981,19 +930,18 @@ get_targets_table(Display *display)
     if (XFindContext(display, DefaultRootWindow(display),
 		     displayToTargets, (XPointer *)&targets) != XCSUCCESS)
     {
-	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:get_targets_table(%d) - NULL\n",
+	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:get_targets_table(%d) - NULL\n",
 		      __FILE__, __LINE__));
 
 	return NULL;
     }
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:get_targets_table(%d) - %p\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:get_targets_table(%d) - %p\n",
 		      __FILE__, __LINE__, targets));
 
     return targets;
 }
 
-
 /*
  * cache the atoms table
  */
@@ -1002,7 +950,7 @@ set_targets_table(Display *display, XmDndTargetsTable table)
 {
     XmDndTargetsTable targets;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:set_targets_table(%d) - %p\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:set_targets_table(%d) - %p\n",
 		      __FILE__, __LINE__, table));
 
     if (displayToTargets == (XContext)0)
@@ -1024,10 +972,9 @@ set_targets_table(Display *display, XmDndTargetsTable table)
     }
 
     XSaveContext(display, DefaultRootWindow(display),
-		 displayToTargets, (XPointer)table);
+		 displayToTargets, (_Xconst char *)table);
 }
 
-
 /*
  * create the default target table
  */
@@ -1036,7 +983,7 @@ create_default_targets_table(Display *display)
 {
     XmDndTargetsTable tbl;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:create_default_targets_table(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:create_default_targets_table(%d)\n",
 		      __FILE__, __LINE__));
 
     tbl = (XmDndTargetsTable)XtMalloc(sizeof(XmDndTargetsTableRec));
@@ -1057,7 +1004,6 @@ create_default_targets_table(Display *display)
     return tbl;
 }
 
-
 static Boolean
 read_targets_table(Display *display, XmDndTargetsTable tbl)
 {
@@ -1070,7 +1016,7 @@ read_targets_table(Display *display, XmDndTargetsTable tbl)
     XmDndBufMgrRec bmgr;
     CARD16 nents;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_targets_table(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_targets_table(%d)\n",
 		      __FILE__, __LINE__));
 
     ta = XmInternAtom(display, _XA_MOTIF_DRAG_TARGETS, False);
@@ -1079,15 +1025,12 @@ read_targets_table(Display *display, XmDndTargetsTable tbl)
 
     begin_protection(display, win);
 
-    if (XGetWindowProperty(display, win, ta, 0L, PROP_LENGTH,
+    if (XGetWindowProperty(display, win, ta, 0L, 100000L,
 			   False, ta,
 			   &atype, &aformat, &nitems, &bafter,
 			   (unsigned char **)&targets) == Success &&
 	nitems >= 8)
     {
-        DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_targets_table(%d) bafter=%i\n",
-		      __FILE__, __LINE__, bafter));
-
 	got_it = True;
     }
 
@@ -1106,7 +1049,7 @@ read_targets_table(Display *display, XmDndTargetsTable tbl)
 	    XFree((XPointer)targets);
 	}
 
-	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_targets_table(%d) - False\n",
+	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_targets_table(%d) - False\n",
 		      __FILE__, __LINE__));
 
 	return False;
@@ -1178,17 +1121,12 @@ read_targets_table(Display *display, XmDndTargetsTable tbl)
 	}
     }
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_targets_table(%d) - True %p\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_targets_table(%d) - True %p\n",
 		      __FILE__, __LINE__, tbl));
 
-    if (targets)
-     {
-         XFree((XPointer)targets);
-     }
     return True;
 }
 
-
 static void
 write_targets_table(Display *display, XmDndTargetsTable tbl)
 {
@@ -1200,7 +1138,7 @@ write_targets_table(Display *display, XmDndTargetsTable tbl)
     Window win;
     CARD16 nents;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:write_targets_table(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:write_targets_table(%d)\n",
 		      __FILE__, __LINE__));
 
     if (tbl == NULL)
@@ -1258,19 +1196,18 @@ write_targets_table(Display *display, XmDndTargetsTable tbl)
     }
 }
 
-
 /*
  * fetch and/or set the ATOM_PAIRS.  This is triggered at least once
  * by the first call to XmInternAtom().
  */
-extern void
+void
 _XmInitAtomPairs(Display *display)
 {
     Window win;
     char *dstr;
     Display *d;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmInitAtomPairs(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmInitAtomPairs(%d)\n",
 		      __FILE__, __LINE__));
 
     if ((win = read_drag_window(display)) == None)
@@ -1318,11 +1255,10 @@ _XmInitAtomPairs(Display *display)
     }
 }
 
-
 /*
  * intialize the DRAG_TARGETS table, and the DRAG_ATOMS table
  */
-extern void
+void
 _XmInitTargetsTable(Display *display)
 {
     Window win;
@@ -1331,7 +1267,7 @@ _XmInitTargetsTable(Display *display)
     XmDndAtomsTable atoms;
     XmDndTargetsTable targets;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmInitTargetsTable(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmInitTargetsTable(%d)\n",
 		      __FILE__, __LINE__));
 
     if ((win = read_drag_window(display)) == None)
@@ -1405,17 +1341,16 @@ _XmInitTargetsTable(Display *display)
     }
 }
 
-
 /*
  * called from DropSMgr's CreateInfo method.
  */
-extern Cardinal
+Cardinal
 _XmIndexToTargets(Widget shell, Cardinal t_index, Atom **targetsRtn)
 {
     Display *dpy = XtDisplay(shell);
     XmDndTargetsTable targets;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmIndexToTargets(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmIndexToTargets(%d)\n",
 		      __FILE__, __LINE__));
 
     if ((targets = get_targets_table(dpy)) == NULL)
@@ -1450,7 +1385,6 @@ _XmIndexToTargets(Widget shell, Cardinal t_index, Atom **targetsRtn)
     return targets->entries[t_index].num_targets;
 }
 
-
 /*
  * minimize duplicates in the targets table by sorting compound entries
  */
@@ -1459,7 +1393,7 @@ acompare(XmConst void *a, XmConst void *b)
 {
     Atom *pa = (Atom *)a, *pb = (Atom *)b;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:acompare(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:acompare(%d)\n",
 		      __FILE__, __LINE__));
 
     return *pa - *pb;
@@ -1474,10 +1408,10 @@ _XmTargetsToIndex(Widget shell, Atom *tlist, Cardinal numTargets)
 {
     Display *dpy = XtDisplay(shell);
     XmDndTargetsTable targets;
-    Cardinal i;
+    int i;
     Atom *atoms;
 
-    DEBUGOUT(_LtDebug(__FILE__, shell,
+    DEBUGOUT(XdbDebug(__FILE__, shell,
 		      "%s:_XmTargetsToIndex(%d) - %p 0x%x targets %p\n", 
 		      __FILE__, __LINE__,
 		      tlist,
@@ -1498,7 +1432,7 @@ _XmTargetsToIndex(Widget shell, Atom *tlist, Cardinal numTargets)
 
 	targets = get_targets_table(dpy);
     }
-    DEBUGOUT(_LtDebug(__FILE__, shell,
+    DEBUGOUT(XdbDebug(__FILE__, shell,
 		      "%s:_XmTargetsToIndex(%d) - targets->num_entries %i\n", 
 		      __FILE__, __LINE__,
 		      targets->num_entries
@@ -1534,7 +1468,7 @@ _XmTargetsToIndex(Widget shell, Atom *tlist, Cardinal numTargets)
     for (i = 0; i < targets->num_entries; i++)
     {
 	if (numTargets == targets->entries[i].num_targets &&
-	    memcmp(atoms, targets->entries[i].targets,
+	    bcmp(atoms, targets->entries[i].targets,
 		 sizeof(Atom) * numTargets) == 0)
 	{
 	    XtFree((char *)atoms);
@@ -1561,7 +1495,7 @@ _XmTargetsToIndex(Widget shell, Atom *tlist, Cardinal numTargets)
     for (i = 0; i < targets->num_entries; i++)
     {
 	if (numTargets == targets->entries[i].num_targets &&
-	    memcmp(atoms, targets->entries[i].targets,
+	    bcmp(atoms, targets->entries[i].targets,
 		 sizeof(Atom) * numTargets) == 0)
 	{
 	    XtFree((char *)atoms);
@@ -1591,11 +1525,10 @@ _XmTargetsToIndex(Widget shell, Atom *tlist, Cardinal numTargets)
     return i;
 }
 
-
 /*
  * called when a drag starts, to allocate an Atom for the DragContext
  */
-extern Atom
+Atom
 _XmAllocMotifAtom(Widget shell, Time time)
 {
     XmDndAtomsTable atoms;
@@ -1604,9 +1537,7 @@ _XmAllocMotifAtom(Widget shell, Time time)
     int i;
     char buf[32];
 
-    DEBUGOUT(_LtDebug(__FILE__, shell, "%s:_XmAllocMotifAtom(%d)\n",
-		      __FILE__, __LINE__));
-    DEBUGOUT(_LtDebug("DRAGSOURCE", shell, "%s:_XmAllocMotifAtom(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmAllocMotifAtom(%d)\n",
 		      __FILE__, __LINE__));
 
     if ((atoms = get_atoms_table(dpy)) == NULL)
@@ -1653,7 +1584,7 @@ _XmAllocMotifAtom(Widget shell, Time time)
 	    (XmDndAtomsTableEntry) XtRealloc((char *)atoms->entries,
 			 atoms->num_entries * sizeof(XmDndAtomsTableEntryRec));
 
-	sprintf(buf, _XA_MOTIF_ATOM_FORMAT, i);
+	sprintf(buf, _XA_MOTIF_ATOM_FORMAT, atoms->num_entries);
 	alloc = XmInternAtom(dpy, buf, False);
 
 	atoms->entries[i].atom = alloc;
@@ -1666,29 +1597,20 @@ _XmAllocMotifAtom(Widget shell, Time time)
 
     XFlush(dpy);
 
-    if (_LtDebugInDebug("DRAGSOURCE", shell))
-    {
-    char *AtomName = XGetAtomName(dpy, alloc);
-
-	DEBUGOUT(_LtDebug0("DRAGSOURCE", shell, "\t%s - 0x%x\n", AtomName, time));
-    	XFree(AtomName);
-    }
-
     return alloc;
 }
 
-
 /*
  * Free the atom.
  */
-extern void
+void
 _XmFreeMotifAtom(Widget shell, Atom atom)
 {
     XmDndAtomsTable atoms;
     Display *dpy = XtDisplay(shell);
     int i;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmFreeMotifAtom(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmFreeMotifAtom(%d)\n",
 		      __FILE__, __LINE__));
 
     if (atom == None)
@@ -1736,17 +1658,16 @@ _XmFreeMotifAtom(Widget shell, Atom atom)
     XFlush(dpy);
 }
 
-
 /*
  * I understand what it does, by why would you want to do it?
  */
-extern void
+void
 _XmDestroyMotifWindow(Display *dpy)
 {
     Atom dw;
     Window win;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmDestroyMotifWindow(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmDestroyMotifWindow(%d)\n",
 		      __FILE__, __LINE__));
 
     win = read_drag_window(dpy);
@@ -1762,7 +1683,6 @@ _XmDestroyMotifWindow(Display *dpy)
     XDestroyWindow(dpy, win);
 }
 
-
 /*
  * get the drag proxy window.  XmDisplay uses this to initialize
  * the proxy instance variable.
@@ -1776,7 +1696,7 @@ _XmGetDragProxyWindow(Display *display)
     unsigned long nitems, bafter;
     unsigned char *prop = NULL;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmGetDragProxyWindow(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmGetDragProxyWindow(%d)\n",
 		      __FILE__, __LINE__));
 
     if ((win = read_drag_window(display)) == None)
@@ -1786,27 +1706,25 @@ _XmGetDragProxyWindow(Display *display)
 
     pw = XmInternAtom(display, _XA_MOTIF_DRAG_PROXY_WINDOW, False);
 
-    if (XGetWindowProperty(display, win, pw, 0L, PROP_LENGTH,
+    if (XGetWindowProperty(display, win, pw, 0L, 100000L,
 			   False, AnyPropertyType,
 			   &atype, &aformat, &nitems, &bafter, &prop)
 	== Success && atype == XA_WINDOW && aformat == 32 && nitems == 1)
     {
-        DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmGetDragProxyWindow(%d) - bafter=%i\n",
-		      __FILE__, __LINE__, bafter));
 	win = *((Window *)prop);
     }
+
     if (prop)
     {
 	XFree((XPointer)prop);
     }
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmGetDragProxyWindow(%d) - %p\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmGetDragProxyWindow(%d) - %p\n",
 		      __FILE__, __LINE__, win));
 
     return win;
 }
 
-
 /*
  * get the drag receiver info property from the target
  *
@@ -1814,7 +1732,7 @@ _XmGetDragProxyWindow(Display *display)
  * application's window.  There's a lot more there than what Daniel
  * talks about.  Must be due to PREREGISTER, yes?
  */
-extern Boolean
+Boolean
 _XmGetDragReceiverInfo(Display *display, Window win, XmDragReceiverInfo ri)
 {
     Atom dri;
@@ -1825,19 +1743,15 @@ _XmGetDragReceiverInfo(Display *display, Window win, XmDragReceiverInfo ri)
     unsigned long bafter, length;
     Window root;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmGetDragReceiverInfo(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmGetDragReceiverInfo(%d)\n",
 		      __FILE__, __LINE__));
-    DEBUGOUT(_LtDebug0("DRAGSOURCE", NULL, "%s:_XmGetDragReceiverInfo(%d) - %p\n",
-		      __FILE__, __LINE__, win));
 
     dri = XmInternAtom(display, _XA_MOTIF_DRAG_RECEIVER_INFO, False);
 
-    if (XGetWindowProperty(display, win, dri, 0L, PROP_LENGTH, False,
+    if (XGetWindowProperty(display, win, dri, 0L, 100000L, False,
 			   dri, &type, &format, &length, &bafter,
 			   (unsigned char **)&receiver) != Success)
     {
-	DEBUGOUT(_LtDebug0("DRAGSOURCE", NULL, "%s:_XmGetDragReceiverInfo(%d) - getting prop failed\n",
-		      __FILE__, __LINE__));
 	return False;
     }
 
@@ -1845,8 +1759,6 @@ _XmGetDragReceiverInfo(Display *display, Window win, XmDragReceiverInfo ri)
     {
 	ri->dragProtocolStyle = XmDRAG_NONE;
 	XFree((char *)receiver);
-	DEBUGOUT(_LtDebug0("DRAGSOURCE", NULL, "%s:_XmGetDragReceiverInfo(%d) - None available\n",
-		      __FILE__, __LINE__));
 	return False;
     }
 
@@ -1886,20 +1798,18 @@ _XmGetDragReceiverInfo(Display *display, Window win, XmDragReceiverInfo ri)
     return True;
 }
 
-
-extern void
+void
 _XmSetDragReceiverInfo(Widget w, Widget widget)
 {
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmSetDragReceiverInfo(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmSetDragReceiverInfo(%d)\n",
 		      __FILE__, __LINE__));
 
 }
 
-
-extern void
+void
 _XmClearDragReceiverInfo(Widget shell)
 {
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmClearDragReceiverInfo(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmClearDragReceiverInfo(%d)\n",
 		      __FILE__, __LINE__));
 
 }
@@ -1907,10 +1817,10 @@ _XmClearDragReceiverInfo(Widget shell)
 /*
  * free up the dropsite info
  */
-extern void
+void
 _XmFreeDragReceiverInfo(XmShellDropSiteInfo di)
 {
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmFreeDragReceiverInfo(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmFreeDragReceiverInfo(%d)\n",
 		      __FILE__, __LINE__));
 
     if (di)
@@ -1924,14 +1834,13 @@ _XmFreeDragReceiverInfo(XmShellDropSiteInfo di)
     }
 }
 
-
-extern unsigned char
+unsigned char
 _XmByteOrder(void)
 {
     static unsigned char byte_order = 0;
 
     /*
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmByteOrder(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmByteOrder(%d)\n",
 		      __FILE__, __LINE__));
     */
 
@@ -1944,3 +1853,4 @@ _XmByteOrder(void)
 
     return byte_order;
 }
+
