@@ -1,9 +1,8 @@
 /**
  *
- * $Id: DragC.c,v 1.35 2001/07/27 18:51:55 dannybackx Exp $
+ * $Id: DragC.c,v 1.24 1999/08/15 23:39:07 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -41,13 +40,11 @@
  * provided "as is" without express or implied warranty.
  */
 
-static const char rcsid[] = "$Id: DragC.c,v 1.35 2001/07/27 18:51:55 dannybackx Exp $";
+static const char rcsid[] = "$Id: DragC.c,v 1.24 1999/08/15 23:39:07 rwscott Exp $";
 
 #include <LTconfig.h>
-
-#include <string.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/DragCP.h>
 #include <Xm/DropSMgrP.h>
@@ -56,10 +53,10 @@ static const char rcsid[] = "$Id: DragC.c,v 1.35 2001/07/27 18:51:55 dannybackx
 #include <Xm/DisplayP.h>
 #include <Xm/AtomMgr.h>
 #include <Xm/MenuUtilP.h>	/* for the _XmGrab stuff */
+#include <X11/Xfuncs.h>
 
 #include <XmI/DebugUtil.h>
 
-
 /* Forward Declarations */
 
 static void class_initialize(void);
@@ -358,8 +355,6 @@ WidgetClass xmDragContextClass = (WidgetClass)&xmDragContextClassRec;
 static void
 class_initialize(void)
 {
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:class_initialize(%d)\n",
-    	__FILE__, __LINE__));
 #if 0
     _XmDragCCoreClassExtRec.record_type = XmQmotif;
 #endif
@@ -370,8 +365,6 @@ class_part_initialize(WidgetClass widget_class)
 {
     WidgetClass sc;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:class_part_initialize(%d)\n",
-    	__FILE__, __LINE__));
     _XmFastSubclassInit(widget_class, XmDRAG_CONTEXT_BIT);
 
     sc = widget_class->core_class.superclass;
@@ -395,7 +388,7 @@ initialize(Widget request, Widget new_w,
     XmDropSiteManagerObject dsm;
     Arg argl[2];
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "%s:initialize(%d) - %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -405,7 +398,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     DC_InDropSite(new_w) = False;
     DC_DragTimerId(new_w) = None;
@@ -424,11 +417,7 @@ initialize(Widget request, Widget new_w,
     DC_OrigDragOver(new_w) = NULL;
 
     /* setup the notify cb */
-#if 0
     dsm = _XmGetDropSiteManagerObject(_XmDCtoDD(new_w));
-#else
-    dsm = _XmGetDropSiteManagerObject((XmDisplay)XmGetXmDisplay(XtDisplay(new_w)));
-#endif
     XtSetArg(argl[0], XmNclientData, (XtPointer)new_w);
     if (DC_SourceIsExternal(new_w))
     {
@@ -445,7 +434,7 @@ initialize(Widget request, Widget new_w,
     {
 	exports = (Atom *)XtMalloc(DC_NumExportTargets(new_w) * sizeof(Atom));
 
-	memcpy(exports, DC_ExportTargets(new_w),
+	bcopy(DC_ExportTargets(new_w), exports,
 	      DC_NumExportTargets(new_w) * sizeof(Atom));
 
 	DC_ExportTargets(new_w) = exports;
@@ -460,12 +449,9 @@ initialize(Widget request, Widget new_w,
     DC_NumReceiverInfos(new_w) = 0;
     DC_MaxReceiverInfos(new_w) = 0;
 
-    if (XtIsRealized(XtParent(new_w)))
-    {
-	XtRealizeWidget(new_w);
-    }
+    XtRealizeWidget(new_w);
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "Initialize: Parent %s window 0x%X us 0x%X\n",
 		      XtName(XtParent(new_w)), XtWindow(XtParent(new_w)),
 		      XtWindow(new_w)));
@@ -474,7 +460,7 @@ initialize(Widget request, Widget new_w,
 static void
 destroy(Widget w)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:destroy(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:destroy(%d)\n",
     	__FILE__, __LINE__));
 
     if (DC_ExportTargets(w))
@@ -501,7 +487,7 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Atom *exports;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "%s:set_values(%d) - %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -514,10 +500,11 @@ set_values(Widget old, Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     if (DC_ExportTargets(old) != DC_ExportTargets(new_w))
     {
+
 	if (DC_ExportTargets(old))
 	{
 	    XtFree((char *)DC_ExportTargets(old));
@@ -525,7 +512,7 @@ set_values(Widget old, Widget request, Widget new_w,
 
 	exports = (Atom *)XtMalloc(DC_NumExportTargets(new_w) * sizeof(Atom));
 
-	memcpy(exports, DC_ExportTargets(new_w),
+	bcopy(DC_ExportTargets(new_w), exports,
 	      DC_NumExportTargets(new_w) * sizeof(Atom));
 
 	DC_ExportTargets(new_w) = exports;
@@ -542,14 +529,8 @@ send_drag_message(Widget dc, Window win, XmDragDropCallbackStruct * cbs,
     XmDndMessage *dnd_message = (XmDndMessage *) & cmsg.data.b[0];
     Atom msg;
 
-    DEBUGOUT(_LtDebug(__FILE__, dc, "%s:send_drag_message(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, dc, "%s:send_drag_message(%d)\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(_LtDebug("DRAGSOURCE", dc, "%s:send_drag_message(%d) - %s to %p\n",
-    	__FILE__, __LINE__,
-    	_LtDebugDragAndDropMessageType2String(cbs->any.reason), win));
-    DEBUGOUT(_LtDebug("DRAGSINK", dc, "%s:send_drag_message(%d) - %s to %p\n",
-    	__FILE__, __LINE__,
-    	_LtDebugDragAndDropMessageType2String(cbs->any.reason), win));
 
     msg = XmInternAtom(XtDisplay(dc), _XA_MOTIF_DRAG_AND_DROP_MESSAGE, False);
 
@@ -615,16 +596,11 @@ receive_drag_message(Widget dc, XEvent *event, XmDragDropCallbackStruct * cbs)
     XmDndMessage *dnd_message = (XmDndMessage *) & cm->data.b[0];
     Atom msg;
 
-    DEBUGOUT(_LtDebug(__FILE__, dc, "%s:receive_drag_message(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, dc, "%s:receive_drag_message(%d)\n",
     	__FILE__, __LINE__));
 
     msg = XmInternAtom(XtDisplay(dc), _XA_MOTIF_DRAG_AND_DROP_MESSAGE, False);
 
-    DEBUGOUT(_LtDebug("DRAGSOURCE", dc, "%s:receive_drag_message(%d) - %s %i %s\n",
-    	__FILE__, __LINE__,
-    	_LtDebugDragAndDropMessageType2String(dnd_message->reason & DND_CLEAR_EVENT_TYPE), dnd_message->reason & DND_CLEAR_EVENT_TYPE,
-    	cm->message_type == msg ? "Valid DnD message" : "Invalid DnD message"));
-
     if (cm->message_type != msg)
     {
 	_XmWarning(dc, "Invalid Drag/Drop message.\n");
@@ -736,7 +712,7 @@ maybe_send_drag_message(Widget dc, Window win, int reason)
     XmDragTopLevelClientDataStruct tld;
     XmDragMotionClientDataStruct md;
 
-    DEBUGOUT(_LtDebug(__FILE__, dc, "%s:maybe_send_drag_message(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, dc, "%s:maybe_send_drag_message(%d)\n",
     	__FILE__, __LINE__));
 
     if (DC_ActiveProtocolStyle(dc) == XmDRAG_DROP_ONLY)
@@ -871,11 +847,8 @@ invoke_initiator_callback(Widget dc, int cr_reason)
     XmDragDropCallbackStruct cbs;
     XtCallbackList cb = NULL;
 
-    DEBUGOUT(_LtDebug(__FILE__, dc, "%s:invoke_initiator_callback(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, dc, "%s:invoke_initiator_callback(%d)\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(_LtDebug("DRAGSOURCE", dc, "%s:invoke_initiator_callback(%d) %s\n",
-    	__FILE__, __LINE__,
-    	_LtDebugDragAndDropMessageType2String(cr_reason)));
 
     switch (cr_reason)
     {
@@ -1035,11 +1008,8 @@ invoke_receiver_callback(Widget dc, XmDragDropCallbackStruct * cbs)
     XtCallbackList cb = NULL;
     int state;
 
-    DEBUGOUT(_LtDebug(__FILE__, dc, "%s:invoke_receiver_callback(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, dc, "%s:invoke_receiver_callback(%d)\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(_LtDebug("DRAGSOURCE", dc, "%s:invoke_receiver_callback(%d) - %s\n",
-    	__FILE__, __LINE__,
-    	_LtDebugDragAndDropMessageType2String(cbs->any.reason)));
 
     switch (cbs->any.reason)
     {
@@ -1161,7 +1131,7 @@ internal_notify(Widget w, XtPointer cd, XtPointer cbs)
     XmDragDropCallbackStruct *cb = (XmDragDropCallbackStruct *) cbs;
     Widget dc = (Widget)cd;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:internal_notify(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:internal_notify(%d)\n",
     	__FILE__, __LINE__));
 
     invoke_receiver_callback(dc, cb);
@@ -1173,9 +1143,7 @@ external_notify(Widget w, XtPointer cd, XtPointer cbs)
     XmDragDropCallbackStruct *cb = (XmDragDropCallbackStruct *) cbs;
     Widget dc = (Widget)cd;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:external_notify(%d)\n",
-    	__FILE__, __LINE__));
-    DEBUGOUT(_LtDebug("DRAGSINK", w, "%s:external_notify(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:external_notify(%d)\n",
     	__FILE__, __LINE__));
 
     switch (cb->any.reason)
@@ -1202,9 +1170,7 @@ external_msg_handler(Widget widget, XtPointer client_data, XEvent *event,
     Widget dc = (Widget)client_data;
     XmDragDropCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebug(__FILE__, widget, "%s:external_msg_handler(%d)\n",
-    	__FILE__, __LINE__));
-    DEBUGOUT(_LtDebug("DRAG_SOURCE", widget, "%s:external_msg_handler(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, widget, "%s:external_msg_handler(%d)\n",
     	__FILE__, __LINE__));
 
     if (dc != NULL && event->type != ClientMessage)
@@ -1241,7 +1207,7 @@ drop_convert_incr_callback(Widget w, Atom *selection, Atom *target,
     Atom ok, fail, drop;
     Widget dc;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:drop_convert_incr_callback(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:drop_convert_incr_callback(%d)\n",
     	__FILE__, __LINE__));
 
     sev = XtGetSelectionRequest(w, *selection, NULL);
@@ -1318,7 +1284,7 @@ drop_convert_callback(Widget w, Atom *selection, Atom *target,
     Atom ok, fail, drop;
     Widget dc;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "DropConvertCallback\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "DropConvertCallback\n"));
 
     sev = XtGetSelectionRequest(w, *selection, NULL);
 
@@ -1390,7 +1356,7 @@ drop_lose_incr_callback(Widget w, Atom *selection, XtPointer cd)
 {
     Widget dc;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:drop_lose_incr_callback(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:drop_lose_incr_callback(%d)\n",
     	__FILE__, __LINE__));
 
     if ((dc = _XmGetDragContextFromHandle(w, *selection)) == NULL)
@@ -1409,7 +1375,7 @@ drop_lose_callback(Widget w, Atom *selection)
 {
     Widget dc;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:drop_lose_callback(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:drop_lose_callback(%d)\n",
     	__FILE__, __LINE__));
 
     if ((dc = _XmGetDragContextFromHandle(w, *selection)) == NULL)
@@ -1428,7 +1394,7 @@ drop_timeout(XtPointer data, XtIntervalId *id)
 {
     Widget dc = (Widget)data;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:drop_timeout(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:drop_timeout(%d)\n",
     	__FILE__, __LINE__));
 
     DC_DragCompletionStatus(dc) = XmDROP_CANCEL;
@@ -1469,9 +1435,7 @@ create_root_info(Widget w)
     XmDragReceiverInfo ri;
     Display *disp = XtDisplay(w);
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:create_root_info(%d)\n",
-    	__FILE__, __LINE__));
-    DEBUGOUT(_LtDebug("DRAGSOURCE", w, "%s:create_root_info(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:create_root_info(%d)\n",
     	__FILE__, __LINE__));
 
     if (DC_NumReceiverInfos(w) == 0)
@@ -1496,15 +1460,9 @@ create_root_info(Widget w)
 
     if (!_XmGetDragReceiverInfo(disp, ri->window, ri))
     {
-	DEBUGOUT(_LtDebug("DRAGSOURCE", w, "%s:create_root_info(%d) - couldn't get receiver info\n",
-	    __FILE__, __LINE__));
 	return;
     }
 
-    DEBUGOUT(_LtDebug("DRAGSOURCE", w, "%s:create_root_info(%d) - protocol %s\n",
-    	__FILE__, __LINE__,
-    	_LtDebugDragType2String(ri->dragProtocolStyle)));
-
     if (ri->dragProtocolStyle == XmDRAG_NONE ||
 	ri->dragProtocolStyle == XmDRAG_DROP_ONLY ||
 	ri->dragProtocolStyle == XmDRAG_DYNAMIC)
@@ -1525,7 +1483,7 @@ new_root(Widget dc, Window root)
     Cursor cursor;
     Arg args[10];
 
-    DEBUGOUT(_LtDebug(__FILE__, dc, "%s:new_root(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, dc, "%s:new_root(%d)\n",
     	__FILE__, __LINE__));
 
     dos = DC_CurDragOver(dc);
@@ -1612,7 +1570,7 @@ write_initiator(Widget dc)
     XmDndSourceProp src_prop;
     Atom init;
 
-    DEBUGOUT(_LtDebug(__FILE__, dc, "%s:write_initiator(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, dc, "%s:write_initiator(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -1647,7 +1605,7 @@ find_shell_child(Display *display, Window win)
     Window root, parent, *children;
     Atom state;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:find_shell_child(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:find_shell_child(%d)\n",
     	__FILE__, __LINE__));
 
     state = XmInternAtom(display, _XA_WM_STATE, True);
@@ -1658,7 +1616,7 @@ find_shell_child(Display *display, Window win)
 
     if (type != 0)
     {
-	DEBUGOUT(_LtDebug(__FILE__, NULL, "find_shell_child: %08x\n", win));
+	DEBUGOUT(XdbDebug(__FILE__, NULL, "find_shell_child: %08x\n", win));
 	return win;
     }
 
@@ -1680,7 +1638,7 @@ find_shell_child(Display *display, Window win)
 	{
 	    XFree((char *)children);
 
-	    DEBUGOUT(_LtDebug(__FILE__, NULL,
+	    DEBUGOUT(XdbDebug(__FILE__, NULL,
 			      "find_shell_child 2: %08x\n", win));
 
 	    return win;
@@ -1701,10 +1659,10 @@ find_shell_child(Display *display, Window win)
 static XmDragReceiverInfo
 find_receiver_info(Widget dc, Window win)
 {
-    Cardinal i;
+    int i;
     XmDragReceiverInfo ri;
 
-    DEBUGOUT(_LtDebug(__FILE__, dc, "%s:find_receiver_info(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, dc, "%s:find_receiver_info(%d)\n",
     	__FILE__, __LINE__));
 
     /* maybe there's a match */
@@ -1742,9 +1700,7 @@ get_current_receiver(Widget dc, Window root, Window win)
     Position deltax, deltay;
     int rootx, rooty;
 
-    DEBUGOUT(_LtDebug(__FILE__, dc, "%s:get_current_receiver(%d)\n",
-    	__FILE__, __LINE__));
-    DEBUGOUT(_LtDebug("DRAGSOURCE", dc, "%s:get_current_receiver(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, dc, "%s:get_current_receiver(%d)\n",
     	__FILE__, __LINE__));
 
     DC_CrossingTime(dc) = DC_LastChangeTime(dc);
@@ -1850,7 +1806,7 @@ drag_main_loop(XtPointer data, XtIntervalId *id)
     XtAppContext app;
     XEvent event;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:drag_main_loop(%d)\n",
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:drag_main_loop(%d)\n",
     	__FILE__, __LINE__));
 
     if (dc == NULL)
@@ -1860,27 +1816,27 @@ drag_main_loop(XtPointer data, XtIntervalId *id)
 
     fw = XmGetFocusWidget(DC_SrcShell(dc));
 
-    /* T. Straumann: avoid dereferencing NULL fw */
-    if (fw)
+	/* T. Straumann: avoid dereferencing NULL fw */
+	if (fw)
+	{
+    if (_XmGetFocusPolicy(DC_SrcShell(dc)) != XmEXPLICIT)
     {
-	if (_XmGetFocusPolicy(DC_SrcShell(dc)) != XmEXPLICIT)
-	{
-	    WidgetClass wc = XtClass(fw);
+	WidgetClass wc = XtClass(fw);
 
-	    if (XmIsPrimitive(fw) && PrimC_BorderUnhighlight(wc) != NULL)
-	    {
-		PrimC_BorderUnhighlight(wc) (fw);
-	    }
-	    else if (XmIsGadget(fw) && GC_BorderUnhighlight(wc) != NULL)
-	    {
-		GC_BorderUnhighlight(wc) (fw);
-	    }
-	}
-	else
+	if (XmIsPrimitive(fw) && PrimC_BorderUnhighlight(wc) != NULL)
 	{
-	    XtSetKeyboardFocus(DC_SrcShell(dc), NULL);
+	    PrimC_BorderUnhighlight(wc) (fw);
+	}
+	else if (XmIsGadget(fw) && GC_BorderUnhighlight(wc) != NULL)
+	{
+	    GC_BorderUnhighlight(wc) (fw);
 	}
     }
+    else
+    {
+	XtSetKeyboardFocus(DC_SrcShell(dc), NULL);
+    }
+	}
 
     write_initiator(dc);
 
@@ -1912,10 +1868,10 @@ drag_main_loop(XtPointer data, XtIntervalId *id)
 	    case MotionNotify:
 	    case EnterNotify:
 	    case LeaveNotify:
-		DEBUGOUT(_LtDebug(__FILE__, dc,
-				  "Type: %s Window: %08x swindow: %08x "
+		DEBUGOUT(XdbDebug(__FILE__, dc,
+				  "Type: %d Window: %08x swindow: %08x "
 				  "root: %08x\n",
-				  _LtDebugEventType2String(event.type), event.xbutton.subwindow,
+				  event.type, event.xbutton.subwindow,
 				  event.xbutton.window, event.xbutton.root));
 
 		/* so that the event gets delivered to the right widget (us) */
@@ -1928,7 +1884,7 @@ drag_main_loop(XtPointer data, XtIntervalId *id)
 		break;
 	    }
 
-	    DEBUGOUT(_LtDebug(__FILE__, dc,
+	    DEBUGOUT(XdbDebug(__FILE__, dc,
 			      "Dispatch event: state: %d last %d send: %d\n",
 			      event.xmotion.state, DC_LastEventState(dc),
 			      event.xany.send_event));
@@ -1949,7 +1905,7 @@ add_motion(Widget w, XmMotionBuffer * mb, XEvent *event)
 {
     XmDragReceiverInfo ri;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:add_motion(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:add_motion(%d)\n",
     	__FILE__, __LINE__));
 
     ri = DC_CurrReceiverInfo(w);
@@ -2004,7 +1960,7 @@ motion_message(Widget w, Window root, Window win)
 {
     Boolean left_drop = False;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:motion_message(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:motion_message(%d)\n",
     	__FILE__, __LINE__));
 
     if (root != DC_CurrWmRoot(w) ||
@@ -2079,7 +2035,7 @@ maybe_operation_changed(Widget w, unsigned int state)
 {
     unsigned char ops, op;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:maybe_operation_changed(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:maybe_operation_changed(%d)\n",
     	__FILE__, __LINE__));
 
     DC_LastEventState(w) = state;
@@ -2153,7 +2109,7 @@ motion_hysteresis(Widget w, XmMotionBuffer * mb)
     int i, grain_size, box_count, box_offset;
     Window sw = None;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:motion_hysteresis(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:motion_hysteresis(%d)\n",
     	__FILE__, __LINE__));
 
     grain_size = mb->num_motions / OPTIMAL_GRANULARITY;
@@ -2216,7 +2172,7 @@ drag_finish(Widget w, XEvent *event)
     Arg al[5];
     XtAppContext app;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:drag_finish(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:drag_finish(%d)\n",
     	__FILE__, __LINE__));
 
     /* NOTE: This is how we stop the main loop */
@@ -2352,8 +2308,7 @@ _XmDCStartDrag(XmDragContext dc,
     XWindowAttributes attr;
     Window win;
 
-    DEBUGOUT(_LtDebug(__FILE__, srcW, "_XmDCStartDrag\n"));
-    DEBUGOUT(_LtDebug("DRAGSOURCE", srcW, "_XmDCStartDrag\n"));
+    DEBUGOUT(XdbDebug(__FILE__, srcW, "_XmDCStartDrag\n"));
 
     disp = _XmDCtoDD((Widget)dc);
 
@@ -2399,9 +2354,6 @@ _XmDCStartDrag(XmDragContext dc,
 
     DC_ActiveProtocolStyle(dc) = _XmGetActiveProtocolStyle((Widget)dc);
 
-    DEBUGOUT(_LtDebug("DRAGSOURCE", srcW, "_XmDCStartDrag - Protocol %s (%d)\n",
-    	_LtDebugDragType2String(DC_ActiveProtocolStyle(dc)), DC_ActiveProtocolStyle(dc)));
-
     /* the protocol gotten from _XmGetActiveProtocolStyle() needs to be
      * filtered for reasonable values for the initiator. */
     switch (DC_ActiveProtocolStyle(dc))
@@ -2506,7 +2458,7 @@ _XmDCStartDrag(XmDragContext dc,
 static void
 _XmDCCancelDrag(XmDragContext dc)
 {
-    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmDCCancelDrag\n"));
+    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmDCCancelDrag\n"));
 
     DC_DragCompletionStatus(dc) = XmDROP_CANCEL;
 
@@ -2522,7 +2474,7 @@ _XmDCCancel(Widget w,
 	    String *params,
 	    Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "_XmDCCancel\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "_XmDCCancel\n"));
 
     /* make sure we don't cancel if already finished dragging */
     if (DC_DragFinishTime(w) == CurrentTime)
@@ -2548,23 +2500,23 @@ _XmDCMotion(Widget w,
     Boolean done = False;
     XmMotionBuffer mb;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:_XmDCMotion(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:_XmDCMotion(%d)\n",
     	__FILE__, __LINE__));
 
     if (event->type == MotionNotify)
     {
-	DEBUGOUT(_LtDebug(__FILE__, w, "_XmDCMotion: Motion\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "_XmDCMotion: Motion\n"));
     }
     else if (event->type == EnterNotify)
     {
-	DEBUGOUT(_LtDebug(__FILE__, w, "_XmDCMotion: Enter\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "_XmDCMotion: Enter\n"));
     }
     else if (event->type == LeaveNotify)
     {
-	DEBUGOUT(_LtDebug(__FILE__, w, "_XmDCMotion: Leave\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "_XmDCMotion: Leave\n"));
     }
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "DCMotion: w: %08x sw: %08x\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "DCMotion: w: %08x sw: %08x\n",
 		      event->xbutton.window, event->xbutton.subwindow));
 
     root = DC_CurrWmRoot(w);
@@ -2579,7 +2531,7 @@ _XmDCMotion(Widget w,
 
     while (!done && XCheckMaskEvent(XtDisplay(w), mask, event))
     {
-	DEBUGOUT(_LtDebug(__FILE__, w, "DCMotionLoop 1\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "DCMotionLoop 1\n"));
 
 	switch (event->type)
 	{
@@ -2600,7 +2552,7 @@ _XmDCMotion(Widget w,
 	}
 	else
 	{
-	    DEBUGOUT(_LtDebug(__FILE__, w,
+	    DEBUGOUT(XdbDebug(__FILE__, w,
 			      "Put back button or key event: 1.\n"));
 
 	    XPutBackEvent(XtDisplay(w), event);
@@ -2614,7 +2566,7 @@ _XmDCMotion(Widget w,
     while (!done && XCheckMaskEvent(XtDisplay(w), mask, event))
     {
 
-	DEBUGOUT(_LtDebug(__FILE__, w, "DCMotionLoop 2\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "DCMotionLoop 2\n"));
 
 	switch (event->type)
 	{
@@ -2635,7 +2587,7 @@ _XmDCMotion(Widget w,
 	}
 	else
 	{
-	    DEBUGOUT(_LtDebug(__FILE__, w,
+	    DEBUGOUT(XdbDebug(__FILE__, w,
 			      "Put back button or key event: 1.\n"));
 	    XPutBackEvent(XtDisplay(w), event);
 	}
@@ -2656,7 +2608,7 @@ _XmDCFinish(Widget w,
 	    String *params,
 	    Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "_XmDCFinish\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "_XmDCFinish\n"));
 
     DC_DragCompletionStatus(w) = XmDROP;
 
@@ -2672,7 +2624,7 @@ _XmDCHelp(Widget w,
 	  String *params,
 	  Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "_XmDCHelp\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "_XmDCHelp\n"));
 
     DC_DragCompletionStatus(w) = XmDROP_HELP;
 
@@ -2689,7 +2641,7 @@ _XmDCIgnore(Widget w,
 	    String *params,
 	    Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "_XmDCIgnore\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "_XmDCIgnore\n"));
 
     XAllowEvents(XtDisplay(w), SyncPointer, event->xbutton.time);
 }
@@ -2743,7 +2695,7 @@ _XmGetActiveProtocolStyle(Widget w)
 {
     unsigned char dis, drs;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetActiveProtocolStyle\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "_XmGetActiveProtocolStyle\n"));
 
     dis = Display_DragInitiatorProtocolStyle(_XmDCtoDD(w));
     drs = Display_DragReceiverProtocolStyle(_XmDCtoDD(w));
@@ -2782,7 +2734,7 @@ _XmAllocReceiverInfo(XmDragContext dc)
 {
     XmDragReceiverInfo ri;
 
-    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmAllocReceiverInfo\n"));
+    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmAllocReceiverInfo\n"));
 
     if (DC_CurrReceiverInfo(dc) == NULL)
     {
@@ -2796,7 +2748,7 @@ _XmAllocReceiverInfo(XmDragContext dc)
     {
 	DC_MaxReceiverInfos(dc) <<= 1;
 	DC_ReceiverInfos(dc) =
-	    (XmDragReceiverInfo)XtRealloc((char *)DC_ReceiverInfos(dc),
+	    (XmDragReceiverInfo)XtRealloc((XtPointer)DC_ReceiverInfos(dc),
 					  sizeof(XmDragReceiverInfoStruct)
 					  * DC_MaxReceiverInfos(dc));
     }
@@ -2818,14 +2770,7 @@ XmDragStart(Widget widget,
     Arg arg[1];
     ArgList merged;
 
-    DEBUGOUT(_LtDebug(__FILE__, widget, "%s:XmDragStart(%d) - %s\n",
-    	__FILE__, __LINE__,
-    	_LtDebugDragType2String(Display_DragInitiatorProtocolStyle(disp))));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, widget, arglist, argcount, False));
-    DEBUGOUT(_LtDebug("DRAGSOURCE", widget, "%s:XmDragStart(%d) - %s\n",
-    	__FILE__, __LINE__,
-    	_LtDebugDragType2String(Display_DragInitiatorProtocolStyle(disp))));
-    DEBUGOUT(_LtDebugPrintArgList("DRAGSOURCE", widget, arglist, argcount, False));
+    DEBUGOUT(XdbDebug(__FILE__, widget, "XmDragStart()\n"));
 
     if (Display_DragInitiatorProtocolStyle(disp) != XmDRAG_NONE)
     {
@@ -2859,7 +2804,7 @@ XmDragStart(Widget widget,
 void
 XmDragCancel(Widget dragcontext)
 {
-    DEBUGOUT(_LtDebug(__FILE__, dragcontext, "XmDragCancel()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, dragcontext, "XmDragCancel()\n"));
 
     _XmDragCancel((XmDragContext)dragcontext);
 }
@@ -2869,9 +2814,9 @@ XmTargetsAreCompatible(Display *dpy,
 		       Atom *exportTargets, Cardinal numExportTargets,
 		       Atom *importTargets, Cardinal numImportTargets)
 {
-    Cardinal i, j;
+    int i, j;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "XmTargetsAreCompatible()\n"));
+    DEBUGOUT(XdbDebug0(__FILE__, NULL, "XmTargetsAreCompatible()\n"));
 
     /* if ANY import targets matches any export target, they're compat */
     for (i = 0; i < numExportTargets; i++)
