@@ -1,10 +1,9 @@
-/**
+/** -*- Mode: C; tab-width: 8; indent-tabs-mode: nil -*-
  *
- * $Id: DragOverS.c,v 1.21 2000/10/04 18:30:33 amai Exp $
+ * $Id: DragOverS.c,v 1.16 1999/07/27 23:37:31 rwscott Exp $
  *
  * derived from Xt Vendor class.c 
  *
- * Copyright (C) 1995-2000 LessTif Development Team 
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright 1989 Massachusetts Institute of Technology
  *
@@ -26,13 +25,11 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DragOverS.c,v 1.21 2000/10/04 18:30:33 amai Exp $";
+static const char rcsid[] = "$Id: DragOverS.c,v 1.16 1999/07/27 23:37:31 rwscott Exp $";
 
 #include <LTconfig.h>
-
-#include <stdlib.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/XmosP.h>
 #include <Xm/VendorSP.h>
@@ -203,8 +200,6 @@ class_initialize()
 static void 
 class_part_initialize(WidgetClass widget_class)
 {
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:class_part_initialize(%d)\n",
-    	__FILE__, __LINE__));
     _XmFastSubclassInit(widget_class, XmDRAG_OVER_SHELL_BIT);
 }
 
@@ -213,18 +208,6 @@ static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
-		      "%s:initialize(%d) - %i args\n"
-		      "\trequest X %5i Y %5i W %5i H %5i\n"
-		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
-		      __FILE__, __LINE__,
-		      *num_args,
-		      XtX(request), XtY(request),
-		      XtWidth(request), XtHeight(request),
-		      XtX(new_w), XtY(new_w),
-		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
-
     XtWidth(new_w) = 0;
     XtHeight(new_w) = 0;
 
@@ -268,8 +251,6 @@ initialize(Widget request, Widget new_w,
 static void
 destroy(Widget w)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:destroy(%d)\n",
-    	__FILE__, __LINE__));
 }
 
 static Boolean
@@ -278,21 +259,6 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Widget dc = XtParent(new_w);	/* this had BETTER be a DragContext */
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
-		      "%s:set_values(%d) - %i args\n"
-		      "\t    old X %5i Y %5i W %5i H %5i\n"
-		      "\trequest X %5i Y %5i W %5i H %5i\n"
-		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
-		      __FILE__, __LINE__,
-		      *num_args,
-		      XtX(old), XtY(old),
-		      XtWidth(old), XtHeight(old),
-		      XtX(request), XtY(request),
-		      XtWidth(request), XtHeight(request),
-		      XtX(new_w), XtY(new_w),
-		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
-
     if (DO_Mode(new_w) != DO_Mode(old))
     {
 
@@ -317,8 +283,6 @@ set_values(Widget old, Widget request, Widget new_w,
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:expose(%d)\n",
-    	__FILE__, __LINE__));
 }
 
 /*
@@ -1453,7 +1417,7 @@ zap_cursor(Widget w)
     adjust_h = (DO_InitialY(w) - (XtY(w) + (XtHeight(w)>>1))) / ZAP_EFFECT2;
     adjust_w = (DO_InitialX(w) - (XtX(w) + (XtWidth(w)>>1))) / ZAP_EFFECT2;
 
-    gc_values.foreground = (~0);
+    gc_values.foreground = 1;
     gc_values.function = GXxor;
     gc_values.clip_mask = (Pixmap)NULL;
     XChangeGC( DisplayOfScreen(screen), gc,
@@ -1512,7 +1476,7 @@ zap_cursor(Widget w)
     	    RootWindowOfScreen(screen),
 	    segments[0].x2, segments[0].y2 );
 
-    	gc_values.foreground = (~0);
+    	gc_values.foreground = 1;
     	gc_values.function = GXxor;
     	XChangeGC( DisplayOfScreen(screen), gc,
 	    	GCFunction | GCForeground,
@@ -1535,8 +1499,6 @@ _XmDragOverHide(Widget w, Position clipOriginX, Position clipOriginY,
     Widget dc = XtParent(w);	/* this had BETTER be a DragContext */
     Boolean clip_on = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:_XmDragOverHide(%d)\n",
-    	__FILE__, __LINE__));
     if (!DO_IsVisible(w) || DC_BlendModel(dc) == XmBLEND_NONE ||
 	DO_ActiveMode(w) == XmCURSOR)
     {
@@ -1584,8 +1546,6 @@ _XmDragOverShow(Widget w, Position clipOriginX, Position clipOriginY,
     Widget dc = XtParent(w);	/* this had BETTER be a DragContext */
     Boolean clip_on = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:_XmDragOverShow(%d)\n",
-    	__FILE__, __LINE__));
     if (!DO_IsVisible(w) || DC_BlendModel(dc) == XmBLEND_NONE ||
 	DO_ActiveMode(w) == XmCURSOR)
     {
@@ -1731,8 +1691,6 @@ _XmDragOverChange(Widget w, unsigned char dropSiteStatus)
     XmDragIconObject src_icon = NULL, op_icon = NULL, state_icon = NULL;
     Boolean src_pix = True, dirty, change;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:_XmDragOverChange(%d)\n",
-    	__FILE__, __LINE__));
     DO_CursorState(w) = dropSiteStatus;
 
     if (DO_Mode(w) == XmWINDOW)
@@ -1912,8 +1870,6 @@ _XmDragOverFinish(Widget w, unsigned char completionStatus)
     Widget dc = XtParent(w);	/* this had BETTER be a drag context */
     Display *disp = XtDisplay(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:_XmDragOverFinish(%d)\n",
-    	__FILE__, __LINE__));
     if (DC_BlendModel(dc) == XmBLEND_NONE)
     {
 	return;
@@ -1942,16 +1898,12 @@ _XmDragOverFinish(Widget w, unsigned char completionStatus)
 Cursor
 _XmDragOverGetActiveCursor(Widget w)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:_XmDragOverGetActiveCursor(%d)\n",
-    	__FILE__, __LINE__));
     return DO_ActiveCursor(w);
 }
 
 void
 _XmDragOverSetInitialPosition(Widget w, Position initialX, Position initialY)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:_XmDragOverSetInitialPosition(%d)\n",
-    	__FILE__, __LINE__));
     DO_InitialX(w) = initialX;
     DO_InitialY(w) = initialY;
 }
