@@ -1,9 +1,8 @@
 /**
  *
- * $Id: DragUnder.c,v 1.5 2000/09/23 15:05:23 amai Exp $
+ * $Id: DragUnder.c,v 1.3 1998/09/12 15:05:25 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,20 +22,17 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DragUnder.c,v 1.5 2000/09/23 15:05:23 amai Exp $";
+static const char rcsid[] = "$Id: DragUnder.c,v 1.3 1998/09/12 15:05:25 rwscott Exp $";
 
 #include <LTconfig.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <XmI/DragDropI.h>
 
 #include <XmI/DebugUtil.h>
 
-
 void
 _XmDragUnderAnimation(Widget w, XtPointer clientData, XtPointer callData)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:_XmDragUnderAnimation(%d)\n",
-    	__FILE__, __LINE__));
 }
