@@ -1,9 +1,8 @@
 /**
  *
- * $Id: DropTrans.c,v 1.14 2000/09/22 20:35:11 amai Exp $
+ * $Id: DropTrans.c,v 1.10 1999/08/15 23:39:10 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,13 +22,13 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DropTrans.c,v 1.14 2000/09/22 20:35:11 amai Exp $";
+static const char rcsid[] = "$Id: DropTrans.c,v 1.10 1999/08/15 23:39:10 rwscott Exp $";
 
 #include <LTconfig.h>
-
-#include <string.h>
-
 #include <XmI/XmI.h>
+
+#include <X11/Xfuncs.h>
+
 #include <Xm/XmP.h>
 #include <Xm/AtomMgr.h>
 #include <Xm/DropTransP.h>
@@ -37,6 +36,7 @@ static const char rcsid[] = "$Id: DropTrans.c,v 1.14 2000/09/22 20:35:11 amai Ex
 #include <XmI/DragDropI.h>
 #include <XmI/AtomMgrI.h>
 #include <Xm/DisplayP.h>
+#include <string.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -214,17 +214,7 @@ initialize(Widget request, Widget new_w,
 {
     XmDropTransferEntry entries;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
-		      "%s:initialize(%d) - %i args\n"
-		      "\trequest X %5i Y %5i W %5i H %5i\n"
-		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
-		      __FILE__, __LINE__,
-		      *num_args,
-		      XtX(request), XtY(request),
-		      XtWidth(request), XtHeight(request),
-		      XtX(new_w), XtY(new_w),
-		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "DropTransfer initialize\n"));
 
     if (DT_NumDropTransfers(new_w) != 0)
     {
@@ -238,7 +228,7 @@ initialize(Widget request, Widget new_w,
 	entries = (XmDropTransferEntry)XtMalloc(DT_NumDropTransfers(new_w) *
 						sizeof(XmDropTransferEntryRec));
 
-	memcpy(entries, DT_DropTransfers(new_w),
+	bcopy(DT_DropTransfers(new_w), entries,
 	      DT_NumDropTransfers(new_w) * sizeof(XmDropTransferEntryRec));
 
 	DT_DropTransferLists(new_w)[0].transfer_list = entries;
@@ -291,20 +281,7 @@ static Boolean
 set_values(Widget current, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
-		      "%s:set_values(%d) - %i args\n"
-		      "\t    old X %5i Y %5i W %5i H %5i\n"
-		      "\trequest X %5i Y %5i W %5i H %5i\n"
-		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
-		      __FILE__, __LINE__,
-		      *num_args,
-		      XtX(current), XtY(current),
-		      XtWidth(current), XtHeight(current),
-		      XtX(request), XtY(request),
-		      XtWidth(request), XtHeight(request),
-		      XtX(new_w), XtY(new_w),
-		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "DropTransfer set_values\n"));
 
     return True;
 }
@@ -316,9 +293,6 @@ entry_transfer(Widget dt, int which)
     Widget dc = DT_DragContext(dt);
     int i;
 
-    DEBUGOUT(XdbDebug(__FILE__, dt, "%s:entry_transfer(%d)",
-    	__FILE__, __LINE__));
-
     DT_CurDropTransferList(dt) = which;
     DT_CurTargets(dt) = (Atom *)XtMalloc(lst->num_transfers * sizeof(Atom));
     DT_CurClientData(dt) = (XtPointer *)XtMalloc(lst->num_transfers *
@@ -356,9 +330,6 @@ static void
 notified_callback(Widget w, XtPointer cd, Atom *select, Atom *type,
 		  XtPointer value, unsigned long *len, int *fmt)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:notified_callback(%d)\n",
-    	__FILE__, __LINE__));
-
     if (value != NULL)
     {
 	XtFree((char *)value);
@@ -372,13 +343,6 @@ terminate_transfer(Widget dt, Atom *select)
 {
     Atom how;
 
-    DEBUGOUT(XdbDebug(__FILE__, dt, "%s:terminate_transfer(%d) - drag context %s receiver info %s %s\n",
-    	__FILE__, __LINE__,
-    	DT_DragContext(dt) ? "Yes" : "No",
-    	DC_CurrReceiverInfo(DT_DragContext(dt)) ?  "Yes" : "No",
-    	XGetAtomName(XtDisplay(dt), *select)
-    	));
-
     if (DT_TransferStatus(dt) == XmTRANSFER_SUCCESS)
     {
 	how = XmInternAtom(XtDisplay(dt), _XA_XmTRANSFER_SUCCESS, False);
@@ -388,12 +352,9 @@ terminate_transfer(Widget dt, Atom *select)
 	how = XmInternAtom(XtDisplay(dt), _XA_XmTRANSFER_FAILURE, False);
     }
 
-    if (DT_DragContext(dt) && DC_CurrReceiverInfo(DT_DragContext(dt)) && DC_CurrReceiverInfo(DT_DragContext(dt))->shell)
-    {
-	XtGetSelectionValue(DC_CurrReceiverInfo(DT_DragContext(dt))->shell,
+    XtGetSelectionValue(DC_CurrReceiverInfo(DT_DragContext(dt))->shell,
 			*select, how, notified_callback, (XtPointer)dt,
 			DT_Timestamp(dt));
-    }
 }
 
 static void
@@ -403,9 +364,6 @@ select_callback(Widget w, XtPointer cd, Atom *select, Atom *type,
     Widget dt = (Widget)cd;
     XmDropTransferList lst;
 
-    DEBUGOUT(XdbDebug(__FILE__, dt, "%s:select_callback(%d)",
-    	__FILE__, __LINE__));
-
     lst = &DT_DropTransferLists(dt)[DT_CurDropTransferList(dt)];
 
     if (DT_TransferCallback(dt))
@@ -449,9 +407,6 @@ drop_timer(XtPointer cd, XtIntervalId *id)
     Widget dt = (Widget)cd;
     Atom select;
 
-    DEBUGOUT(XdbDebug(__FILE__, dt, "%s:drop_timer(%d)\n",
-    	__FILE__, __LINE__));
-
     if (DT_NumDropTransferLists(dt))
     {
 	entry_transfer(dt, 0);
@@ -470,9 +425,6 @@ start_drop_transfer(Widget refWidget,
 {
     Widget disp = XmGetXmDisplay(XtDisplay(refWidget)), dt;
 
-    DEBUGOUT(XdbDebug(__FILE__, refWidget, "%s:start_drop_transfer(%d)\n",
-    	__FILE__, __LINE__));
-
     dt = XtCreateWidget("drop_transfer",
 			Display_DropTransferClass(disp),
 			disp, args, argCount);
@@ -494,9 +446,6 @@ add_drop_transfer(Widget widget,
     XmDropTransferEntry entries;
     int idx;
 
-    DEBUGOUT(XdbDebug(__FILE__, widget, "%s:add_drop_transfer(%d)",
-    	__FILE__, __LINE__));
-
     idx = DT_NumDropTransferLists(widget);
     DT_NumDropTransferLists(widget)++;
 
@@ -507,7 +456,7 @@ add_drop_transfer(Widget widget,
 
     entries = (XmDropTransferEntry)XtMalloc(num_transfers *
 					    sizeof(XmDropTransferEntryRec));
-    memcpy(entries, transfers, num_transfers * sizeof(XmDropTransferEntryRec));
+    bcopy(transfers, entries, num_transfers * sizeof(XmDropTransferEntryRec));
 
     DT_DropTransferLists(widget)[idx].transfer_list = entries;
     DT_DropTransferLists(widget)[idx].num_transfers = num_transfers;
@@ -518,8 +467,7 @@ XmDropTransferAdd(Widget drop_transfer,
 		  XmDropTransferEntryRec *transfers,
 		  Cardinal num_transfers)
 {
-    DEBUGOUT(XdbDebug(__FILE__, drop_transfer, "%s:XmDropTransferAdd(%d)",
-    	__FILE__, __LINE__));
+    DEBUGOUT(XdbDebug(__FILE__, drop_transfer, "XmDropTransferAdd()\n"));
 
     DTC_AddTransferProc(XtClass(drop_transfer)) (drop_transfer,
 						 transfers,
@@ -533,10 +481,7 @@ XmDropTransferStart(Widget widget,
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
 
-    DEBUGOUT(XdbDebug(__FILE__, widget, "%s:XmDropTransferStart(%d)\n",
-    	__FILE__, __LINE__));
-    DEBUGOUT(XdbPrintArgList(__FILE__, widget, arglist, argcount, False));
-
+    DEBUGOUT(XdbDebug(__FILE__, widget, "XmDropTransferStart()\n"));
 
     return DTC_StartTransferProc(Display_DropTransferClass(disp)) (widget,
 								   arglist,
