@@ -1,9 +1,11 @@
+#define MOZILLA
+#undef PATTERN_DANNY
+#undef	SAVE_PATTERN
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/FileSB.c,v 1.100 2000/10/09 11:56:32 amai Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm/FileSB.c,v 1.81 1999/09/26 16:37:13 rwscott Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
- * Copyright (C) 1997-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,21 +25,14 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/FileSB.c,v 1.100 2000/10/09 11:56:32 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/FileSB.c,v 1.81 1999/09/26 16:37:13 rwscott Exp $";
 
 #include <LTconfig.h>
-
-#include <stdlib.h>
-#include <string.h>
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#ifdef HAVE_LIBGEN_H
-#include <libgen.h>    /* for basename() */
-#endif
-
 #include <XmI/XmI.h>
 #include <XmI/MacrosI.h>
+
+#include <stdlib.h>
+#include <unistd.h>
 #include <Xm/XmP.h>
 #include <Xm/List.h>
 #include <Xm/SelectioBP.h>
@@ -50,17 +45,10 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/FileSB.c,v
 #include <Xm/TextF.h>
 #include <Xm/DialogS.h>
 #include <Xm/TransltnsP.h>
-
-#include "LTmisc.h"   /* for basename() */
+#include <X11/Xfuncs.h>
 
 #include <XmI/DebugUtil.h>
 
-
-/* #defines being used: */
-
-/* see below for more info */
-#define MOZILLA
-
 /* Forward Declarations */
 
 static void class_initialize(void);
@@ -213,33 +201,29 @@ static XtResource resources[] =
 	XmNfileListItemCount, XmCItemCount, XmRInt,
 	sizeof(int), SBOffset(list_item_count),
 	XmRImmediate, (XtPointer)XmUNSPECIFIED
-    },
-#if XmVERSION > 1
-    {
-	XmNpathMode, XmCPathMode, XmRPathMode,
-	sizeof(XtEnum), Offset(path_mode),
-	XmRImmediate, (XtPointer)XmPATH_MODE_FULL
-    },
-    {
-	XmNfileFilterStyle, XmCFileFilterStyle, XmRFileFilterStyle,
-	sizeof(XtEnum), Offset(file_filter_style),
-	XmRImmediate, (XtPointer)XmFILTER_NONE
-    },
-#endif
+    }
 };
 
 /* Synthetic resources */
-static void FSBGetDirListItemCount(Widget wid, int resource_offset, XtArgVal *value);
-static void FSBGetDirListItems(Widget wid, int resource_offset, XtArgVal *value);
-static void FSBGetDirListLabelString(Widget wid, int resource_offset, XtArgVal *value);
-static void FSBGetDirMask(Widget wid, int resource_offset, XtArgVal *value);
-static void FSBGetDirectory(Widget wid, int resource_offset, XtArgVal *value);
-static void FSBGetFilterLabelString(Widget wid, int resource_offset, XtArgVal *value);
-static void FSBGetListItemCount(Widget wid, int resource_offset, XtArgVal *value);
-static void FSBGetListItems(Widget wid, int resource_offset, XtArgVal *value);
-static void FSBGetNoMatchString(Widget wid, int resource_offset, XtArgVal *value);
-static void FSBGetPattern(Widget wid, int resource_offset, XtArgVal *value);
+void FSBGetDirListItemCount(Widget wid, int resource_offset, XtArgVal *value);
 
+void FSBGetDirListItems(Widget wid, int resource_offset, XtArgVal *value);
+
+void FSBGetDirListLabelString(Widget wid, int resource_offset, XtArgVal *value);
+
+void FSBGetDirMask(Widget wid, int resource_offset, XtArgVal *value);
+
+void FSBGetDirectory(Widget wid, int resource_offset, XtArgVal *value);
+
+void FSBGetFilterLabelString(Widget wid, int resource_offset, XtArgVal *value);
+
+void FSBGetListItemCount(Widget wid, int resource_offset, XtArgVal *value);
+
+void FSBGetListItems(Widget wid, int resource_offset, XtArgVal *value);
+
+void FSBGetNoMatchString(Widget wid, int resource_offset, XtArgVal *value);
+
+void FSBGetPattern(Widget wid, int resource_offset, XtArgVal *value);
 
 static XmSyntheticResource syn_resources[] =
 {
@@ -315,6 +299,7 @@ static XtActionsRec actions[] =
 	{"SelectionBoxRestore", FileSelectionBoxRestore},
 };
 
+/* *INDENT-OFF* */
 #if 0
 static XmBaseClassExtRec _XmFileSBCoreClassExtRec = {
     /* next_extension            */ NULL,
@@ -417,14 +402,14 @@ XmFileSelectionBoxClassRec xmFileSelectionBoxClassRec = {
     /* XmSelectionBox part */
     {
 	/* Motif has something called a list_callback here */
-	/* list_callback                */ NULL,
-	/* extension                    */ NULL,
+	/* extension */ NULL,
     },
     /* XmFileSelectionBox part */
     {
-	/* extension                    */ NULL,
+	/* extension */ NULL,
     }
 };
+/* *INDENT-ON* */
 
 
 WidgetClass xmFileSelectionBoxWidgetClass = (WidgetClass)&xmFileSelectionBoxClassRec;
@@ -460,7 +445,6 @@ initialize(Widget request, Widget new_w,
     int argc;
     XmString files = NULL;
     XtTranslations save_acc;
-    int dir_set_flag;
 
     DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "initialize: %i args\n"
@@ -703,7 +687,6 @@ initialize(Widget request, Widget new_w,
      *
      *		--mu@trends.net, 1998.07.04
      */
-    dir_set_flag = 0;
     if (_XmStringIsSpecified(FS_DirMask(new_w)))
     {
 	String mask;
@@ -713,6 +696,12 @@ initialize(Widget request, Widget new_w,
             String pat = _XmOSFindPatternPart(mask);
 	    if (!_XmStringIsSpecified(FS_Pattern(new_w))) {
 		FS_Pattern(new_w) = XmStringCreateLocalized(pat);
+#ifdef PATTERN_DANNY
+		fprintf(stderr,
+			"FileSB Initialize() pattern uninitialised, "
+			"take mask '%s'\n",
+			mask);
+#endif
 	    }
 
             if (pat > mask && !_XmStringIsSpecified(FS_Directory(new_w)))
@@ -725,21 +714,10 @@ initialize(Widget request, Widget new_w,
         	 */
         	*pat = '\0';
         	FS_Directory(new_w) = XmStringCreateLocalized(mask);
-                dir_set_flag = 1;
             }
 
             XtFree(mask);
         }
-
-        FS_DirMask(new_w) = XmStringCopy(FS_DirMask(new_w));
-    }
-
-    if (dir_set_flag == 0) { /* FS_Directory was not set above */
-        if (_XmStringIsSpecified(FS_Directory(new_w))) {
-            FS_Directory(new_w) = XmStringCopy(FS_Directory(new_w));
-        }
-        else
-            FS_Directory(new_w) = NULL;
     }
 
     _XmFileSelectionSearch(new_w);
@@ -753,25 +731,27 @@ destroy(Widget w)
     DEBUGOUT(XdbDebug("RWS", w,"%s:destroy(%d)\n",
     	__FILE__, __LINE__
     	));
-
+    DEBUGOUT(XdbDebug("NEDIT", w,"%s:destroy(%d)\n",
+    	__FILE__, __LINE__
+    	));
     XmStringFree(FS_DirListLabelString(w));
     XmStringFree(FS_FileListLabelString(w));
     XmStringFree(FS_FilterLabelString(w));
     XmStringFree(FS_NoMatchString(w));
 	/* T. Straumann: don't forget to free these */
-    XmStringFree(FS_DirMask(w));
-    XmStringFree(FS_Pattern(w));
-    XmStringFree(FS_Directory(w));
+	XmStringFree(FS_DirMask(w));
+	XmStringFree(FS_Pattern(w));
+	XmStringFree(FS_Directory(w));
 }
 
 static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    Arg al[6];
+    Arg al[10];
     int ac;
     Boolean refresh = False;
-    Boolean reSearch;
+	Boolean reSearch;
 
     DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
@@ -886,6 +866,26 @@ set_values(Widget old, Widget request, Widget new_w,
 
     }
 
+#ifdef PATTERN_DANNY
+{
+  int r;
+     r = XmStringCompare(FS_Pattern(new_w), FS_Pattern(old));
+     if (! r) {
+	fprintf(stderr, "FileSB: SetValues: Pattern differs (r %d), old %p '%s'"
+		r,
+		FS_Pattern(old), XdbXmString2String(FS_Pattern(old)));
+	fprintf(stderr,", new %p '%s'\n",
+		FS_Pattern(new_w), XdbXmString2String(FS_Pattern(new_w)));
+    } else {
+	fprintf(stderr, "FileSB: SetValues: Pattern equal (r %d) %p '%s',",
+		r,
+		FS_Pattern(old), XdbXmString2String(FS_Pattern(old)));
+	fprintf(stderr," %p '%s'\n",
+		FS_Pattern(new_w), XdbXmString2String(FS_Pattern(new_w)));
+    }
+}
+#endif
+
 	/* T. Straumann: if any new string is supplied, we must 
 	 *				 free the old one and make a copy of the user
 	 *				 supplied value.
@@ -940,6 +940,9 @@ set_values(Widget old, Widget request, Widget new_w,
 
 	if ( reSearch || (FS_FileTypeMask(new_w) != FS_FileTypeMask(old)))
     {
+#ifdef PATTERN_DANNY
+	fprintf(stderr, "FileSB: SetValues requires another Search()\n");
+#endif
 	_XmFileSelectionSearch(new_w);
     }
 
@@ -1696,44 +1699,22 @@ geoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
 	layoutPtr->fit_mode = XmGEO_WRAP;
 	if (LabG_RecomputeSize(SB_HelpButton(_w)))
 	{
-#if 1
-	    /* rws 8 Jul 2000
-	       filesb/test6
-	     */
 	    if (SB_List(_w) && XtIsManaged(XtParent(SB_List(_w))))
 	    {
-		layoutPtr->even_width = 6;
-		layoutPtr->even_height = 6;
+	    layoutPtr->even_width = 6;
+	    layoutPtr->even_height = 6;
 	    }
 	    else
 	    {
-		layoutPtr->even_width = 4;
-		layoutPtr->even_height = 4;
+	    layoutPtr->even_width = 4;
+	    layoutPtr->even_height = 4;
 	    }
-#endif
 	}
 	else
 	{
 	    layoutPtr->even_width = 1;
 	    layoutPtr->even_height = 1;
 	}
-#if 1
-	/* rws 8 Jul 2000
-	   filesb/test15 when pressing Filter
-	 */
-	if (SB_OkButton(_w) && !LabG_RecomputeSize(SB_OkButton(_w)))
-	{
-	    layoutPtr->even_width = 1;
-	    if (XtIsRealized(_w))
-	    {
-		layoutPtr->even_height = 1;
-	    }
-	    else
-	    {
-		layoutPtr->even_height = 4;
-	    }
-	}
-#endif
 	layoutPtr->space_above = BB_MarginHeight(_w);
 	newRow = True;
     }
@@ -1814,31 +1795,6 @@ noGeoRequest(XmGeoMatrix _geoSpec)
 
 /******************************* SEARCHING **********************************/
 
-
-#if XmVERSION > 1
-/* Keep it short and simple - make it a function (instead of a macro)
-   for easier debugging purposes but give it a more than reasonable chance
-   to be optimized out (or inlined in :-)  ... */
-static Boolean
-FileIsHidden(String name) {
-
-  const char *ptr;
-  
-  ptr=basename(name);
-  if (*ptr=='.') {
-     ptr++;
-     if ( (*ptr=='\0') || ((*ptr=='.')&&(*(ptr+1)=='\0')) )
-       /* keep special entries visible */
-        return False;
-     else
-        return True;
-  }
-  else
-     return False;
-}
-#endif
-
-
 static void
 defaultDirSearchProc(Widget widget,
 		     XtPointer data)
@@ -1846,7 +1802,7 @@ defaultDirSearchProc(Widget widget,
     String *entries, dir, pat;
     XmFileSelectionBoxCallbackStruct *cbs = (XmFileSelectionBoxCallbackStruct *)data;
     unsigned int numents, numalloc, argc, i, max;
-    Arg argl[3];
+    Arg argl[5];
     XmString *table;
 
     if (!XmStringGetLtoR(cbs->dir, XmFONTLIST_DEFAULT_TAG, &dir))
@@ -1854,9 +1810,8 @@ defaultDirSearchProc(Widget widget,
 	dir = XtNewString("");
     }
 
-    entries  = NULL;
-    numents  = 0;
-    numalloc = 0;
+    entries = NULL;
+    numents = numalloc = 0;
 
     /*
      * I think pattern should always be "*" for directories.
@@ -1875,33 +1830,6 @@ defaultDirSearchProc(Widget widget,
 
     max = 64;
     table = (XmString *)XtCalloc(max, sizeof(XmString));
-   
-#if XmVERSION > 1
-    /* we use two versions of this loop for better performance */
-    if (FS_FileFilterStyle(widget)==XmFILTER_HIDDEN_FILES) {
-
-        int visible=0;
-    
-        for (i = 0; i < numents; i++)
-         {
-	 if (FileIsHidden(entries[i])) {
-	    XtFree(entries[i]);
-	 }
-	 else {
-	   if (i == max)
-	    {
-	    max *= 2;
-	    table = (XmString *)XtRealloc((char *)table, max * sizeof(XmString));
-	    }
-	    table[visible] = XmStringCreateLtoR(entries[i], XmFONTLIST_DEFAULT_TAG);
-	    visible++;
-	    XtFree(entries[i]);
-         } /* not hidden */
-        } /* for */
-	numents = visible;
-    }  /* XmFILTER_HIDDEN_FILES */
-    else
-#endif
     for (i = 0; i < numents; i++)
     {
 	if (i == max)
@@ -1909,10 +1837,11 @@ defaultDirSearchProc(Widget widget,
 	    max *= 2;
 	    table = (XmString *)XtRealloc((char *)table, max * sizeof(XmString));
 	}
+
 	table[i] = XmStringCreateLtoR(entries[i], XmFONTLIST_DEFAULT_TAG);
+
 	XtFree(entries[i]);
     }
-
     if (entries)
     {
 	XtFree((char *)entries);
@@ -1939,7 +1868,7 @@ defaultFileSearchProc(Widget widget, XtPointer data)
     XmFileSelectionBoxCallbackStruct *cbs =
 	(XmFileSelectionBoxCallbackStruct *)data;
     unsigned int numents, numalloc, argc, i, max;
-    Arg argl[3];
+    Arg argl[5];
     XmString *table;
 
     DEBUGOUT(XdbDebug(__FILE__, widget, "defaultFileSearchProc\n"));
@@ -1968,9 +1897,8 @@ defaultFileSearchProc(Widget widget, XtPointer data)
 			  "defaultFileSearchProc: pattern '%s'\n", pat));
     }
 
-    entries  = NULL;
-    numents  = 0;
-    numalloc = 0;
+    entries = NULL;
+    numents = numalloc = 0;
 
     _XmOSBuildFileList(dir, pat, FS_FileTypeMask(widget),  /* FIX ME: leaks */
 		       &entries, &numents, &numalloc);
@@ -1983,45 +1911,17 @@ defaultFileSearchProc(Widget widget, XtPointer data)
     max = 64;
     table = (XmString *)XtCalloc(max, sizeof(XmString));
 
-#if XmVERSION > 1
-    /* we use two versions of this loop for better performance */
-    if (FS_FileFilterStyle(widget)==XmFILTER_HIDDEN_FILES) {
-
-        int visible=0;
-
-        for (i = 0; i < numents; i++)
-        {
-	 if (FileIsHidden(entries[i])) {
-	    XtFree(entries[i]);
-	 } else {
-   	   if (i == max)
- 	    {
-	     max *= 2;
-	     table = (XmString *)XtRealloc((char *)table,
+    for (i = 0; i < numents; i++)
+    {
+	if (i == max)
+	{
+	    max *= 2;
+	    table = (XmString *)XtRealloc((char *)table,
 					  max * sizeof(XmString));
- 	    }
-	    table[visible] = XmStringCreateLtoR(entries[i], XmFONTLIST_DEFAULT_TAG);
-	    visible++;
-	    XtFree(entries[i]);
-         } /* not hidden */
-	 } /* for */
-    numents = visible;
-    } /* XmFILTER_HIDDEN_FILES */
-    else
-#endif
-     for (i = 0; i < numents; i++)
-        {
-   	 if (i == max)
- 	{
-	     max *= 2;
-	     table = (XmString *)XtRealloc((char *)table,
-					  max * sizeof(XmString));
- 	  }
-	  table[i] = XmStringCreateLtoR(entries[i], XmFONTLIST_DEFAULT_TAG);
-	  XtFree(entries[i]);
-        }
-
-
+	}
+	table[i] = XmStringCreateLtoR(entries[i], XmFONTLIST_DEFAULT_TAG);
+	XtFree(entries[i]);
+    }
     if (entries)
     {
 	XtFree((char *)entries);
@@ -2197,6 +2097,9 @@ _XmFileSelectionSearch(Widget w)
     Arg argl[5];
     int argc;
     char *value;
+#ifdef	SAVE_PATTERN
+    XmString	x;
+#endif
 
     DEBUGOUT(XdbDebug(__FILE__, w, "_XmFileSelectionSearch()\n"));
 
@@ -2231,9 +2134,22 @@ _XmFileSelectionSearch(Widget w)
     DEBUGOUT(XdbDebug(__FILE__, w, "\tdirectory %s (%i)\n", 
     		XdbXmString2String(FS_Directory(w)),in.dir_length));
 
+#ifdef	SAVE_PATTERN
+    /*
+     * Too many strange things are happening
+     * Play it safe, only pass a copy
+     * Leak for now ...
+     */
+    x = FS_Pattern(w);
+    in.pattern = XmStringCopy(FS_Pattern(w));
+#else
     in.pattern = FS_Pattern(w);
+#endif
     if (!_XmStringIsSpecified(in.pattern))
     {
+#ifdef PATTERN_DANNY
+	fprintf(stderr, "FileSB _XmFileSelectionSearch: set pattern to ''\n");
+#endif
     	FS_Pattern(w) = XmStringCreateSimple("");
 	in.pattern = FS_Pattern(w);
     }
@@ -2247,6 +2163,10 @@ _XmFileSelectionSearch(Widget w)
     DEBUGOUT(XdbDebug(__FILE__, w, "_XmFileSelectionSearch() - Calling Qualify\n"));
     (*FS_QualifySearchDataProc(w)) (w, (XtPointer)&in, (XtPointer)&out);
 
+#ifdef	SAVE_PATTERN
+    FS_Pattern(w) = x;
+#endif
+
 #ifdef MOZILLA
     /* rws 21 Jun 1998
        Mozilla installs its own dir search proc.  The first thing it does is
@@ -2366,9 +2286,16 @@ _XmFileSelectionSearch(Widget w)
     FS_Directory(w) = XmStringCopy(out.dir);
     if (FS_Pattern(w))
     {
+#ifdef PATTERN_DANNY
+	fprintf(stderr, "FileSB _XmFileSelectionSearch: free pattern\n");
+#endif
 	XmStringFree(FS_Pattern(w));
     }
     FS_Pattern(w) = XmStringCopy(out.pattern);
+#ifdef PATTERN_DANNY
+    fprintf(stderr, "FileSB _XmFileSelectionSearch: change pattern (%s)\n",
+	XdbXmString2String(FS_Pattern(w)));
+#endif
 
     if (out.value)
     {
@@ -2557,6 +2484,10 @@ XmFileSelectionDoSearch(Widget w, XmString dirmask)
 	XmStringFree(FS_Directory(w));
 	FS_DirMask(w) = out.mask;
 	FS_Pattern(w) = out.pattern;
+#ifdef PATTERN_DANNY
+	fprintf(stderr, "XmFileSelectionDoSearch: change pattern (%s)\n",
+		XdbXmString2String(FS_Pattern(w)));
+#endif
 	FS_Directory(w) = out.dir;
 	if (out.value)
 	{
@@ -2702,6 +2633,10 @@ _XmFsbButton(Widget w, XtPointer client, XtPointer call)
 	XmStringFree(FS_Directory(sb));
 	FS_DirMask(sb) = out.mask;
 	FS_Pattern(sb) = out.pattern;
+#ifdef PATTERN_DANNY
+	fprintf(stderr, "_XmFsbButton: change pattern (%s)\n",
+		XdbXmString2String(FS_Pattern(w)));
+#endif
 	FS_Directory(sb) = out.dir;
 
 	if (XmStringGetLtoR(out.mask, XmFONTLIST_DEFAULT_TAG, &mask))
@@ -2747,6 +2682,10 @@ _XmFsbButton(Widget w, XtPointer client, XtPointer call)
 	XmStringFree(FS_Directory(sb));
 	FS_DirMask(sb) = out.mask;
 	FS_Pattern(sb) = out.pattern;
+#ifdef PATTERN_DANNY
+	fprintf(stderr, "_XmFsbButton: change pattern (%s)\n",
+		XdbXmString2String(FS_Pattern(w)));
+#endif
 	FS_Directory(sb) = out.dir;
 #endif
 
@@ -2770,6 +2709,10 @@ _XmFsbButton(Widget w, XtPointer client, XtPointer call)
 	    XmStringFree(FS_Directory(sb));
 	    FS_DirMask(sb) = out.mask;
 	    FS_Pattern(sb) = out.pattern;
+#ifdef PATTERN_DANNY
+	fprintf(stderr, "_XmFsbButton: change pattern (%s)\n",
+		XdbXmString2String(FS_Pattern(w)));
+#endif
 	    FS_Directory(sb) = out.dir;
 #endif
 	    _XmFileSelectionSearch((Widget)sb);
@@ -2979,16 +2922,14 @@ FSBGetListItems(Widget wid, int resource_offset, XtArgVal *value)
 void 
 FSBGetNoMatchString(Widget wid, int resource_offset, XtArgVal *value)
 {
-    /* Return a copy of the internal string because the */
-    /* application expects to be able to free the returned string. */
-    *value = (XtArgVal)XmStringCopy(FS_NoMatchString(wid));
+    /* FIX ME : a copy or the real thing ? */
+    *value = (XtArgVal)FS_NoMatchString(wid);
 }
 
 void 
 FSBGetPattern(Widget wid, int resource_offset, XtArgVal *value)
 {
-    /* Return a copy of the internal string because the */
-    /* application expects to be able to free the returned string. */
+    /* FIX ME : a copy or the real thing ? */
     *value = (XtArgVal)XmStringCopy(FS_Pattern(wid));
 }
 
@@ -3108,6 +3049,7 @@ FileSelectionBoxUpOrDown(Widget w, XEvent *event, String *params, Cardinal *num_
 static void
 FileSelectionBoxRestore(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
+    /* Arg args[2]; */
     Widget text, list, focus;
     /* XmStringTable items; */
     /* int item_count, *position_list, position_count; */
