@@ -1,9 +1,8 @@
 /**
  *
- * $Id: GadgetUtil.c,v 1.12 2001/07/27 18:51:56 dannybackx Exp $
+ * $Id: GadgetUtil.c,v 1.8 1998/09/12 15:05:29 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,26 +22,25 @@
  *
  **/
 
-static const char rcsid[] = "$Id: GadgetUtil.c,v 1.12 2001/07/27 18:51:56 dannybackx Exp $";
+static const char rcsid[] = "$Id: GadgetUtil.c,v 1.8 1998/09/12 15:05:29 rwscott Exp $";
 
 #include <LTconfig.h>
-
 #include <XmI/XmI.h>
 #include <XmI/MacrosI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/DropSMgr.h>
 
 #include <XmI/DebugUtil.h>
 
-
 XmGadget
 _XmInputInGadget(Widget cw,
 		 int x,
 		 int y)
 {
-    Cardinal i;
+    int i;
 
-    DEBUGOUT(_LtDebug(__FILE__, cw, "_XmInputInGadget(%d,%d)\n", x, y));
+    DEBUGOUT(XdbDebug(__FILE__, cw, "_XmInputInGadget(%d,%d)\n", x, y));
 
     for (i = 0; i < MGR_NumChildren(cw); i++)
     {
@@ -108,7 +106,7 @@ _XmConfigureObject(Widget g,
 		   Dimension height,
 		   Dimension border_width)
 {
-    DEBUGOUT(_LtDebug(__FILE__, g,
+    DEBUGOUT(XdbDebug(__FILE__, g,
 		      "_XmConfigureObject X %d Y %d W %d H %d BW %d\n",
 		      x, y, width, height, border_width));
 
@@ -185,7 +183,7 @@ _XmResizeObject(Widget g,
 		Dimension height,
 		Dimension border_width)
 {
-    DEBUGOUT(_LtDebug(__FILE__, g,
+    DEBUGOUT(XdbDebug(__FILE__, g,
 		      "_XmResizeObject W %d H %d\n", width, height));
 
     XmDropSiteStartUpdate(g);
@@ -207,7 +205,7 @@ _XmMoveObject(Widget g,
 	      Position x,
 	      Position y)
 {
-    DEBUGOUT(_LtDebug(__FILE__, g,
+    DEBUGOUT(XdbDebug(__FILE__, g,
 		      "_XmMoveObject X %d Y %d\n", x, y));
 
     XmDropSiteStartUpdate(g);
@@ -230,7 +228,7 @@ _XmRedisplayGadgets(Widget w,
 		    Region region)
 {
     XExposeEvent *ev = (XExposeEvent *)event;
-    Cardinal i;
+    int i;
 
     for (i = 0; i < MGR_NumChildren(w); i++)
     {
@@ -268,7 +266,7 @@ _XmDispatchGadgetInput(Widget w,
     XmGadgetClass gc = (XmGadgetClass)w->core.widget_class;
 
     if (w->core.being_destroyed) return;
-    DEBUGOUT(_LtDebug(__FILE__, w,
+    DEBUGOUT(XdbDebug(__FILE__, w,
 	  "_XmDispatchGadgetInput: mask 0x%X, FocusIn %s, Parent %s Manager\n",
 		      mask,
 		      (XmFOCUS_IN_EVENT & mask) ? "True" : "False",
@@ -276,7 +274,7 @@ _XmDispatchGadgetInput(Widget w,
 
     if (XmIsGadget(w) && (G_EventMask(g) & mask))
     {
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 			  "_XmDispatchGadgetInput() dispatching..\n"));
 
 	(*gc->gadget_class.input_dispatch) (w, event, mask);
