@@ -1,9 +1,8 @@
 /**
  *
- * $Id: GeoUtils.c,v 1.50 2000/09/22 20:35:11 amai Exp $
+ * $Id: GeoUtils.c,v 1.47 1999/07/27 23:37:31 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,19 +22,18 @@
  *
  **/
 
-static const char rcsid[] = "$Id: GeoUtils.c,v 1.50 2000/09/22 20:35:11 amai Exp $";
+static const char rcsid[] = "$Id: GeoUtils.c,v 1.47 1999/07/27 23:37:31 rwscott Exp $";
 
 #include <LTconfig.h>
-
-#include <stdlib.h>		/* for qsort */
-#include <string.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/BulletinBP.h>
 #include <Xm/SeparatorP.h>
 #include <Xm/SeparatoGP.h>
 #include <Xm/RowColumnP.h>
+#include <X11/Xfuncs.h>
+#include <stdlib.h>		/* for qsort */
 
 #include <XmI/DebugUtil.h>
 
@@ -1555,7 +1553,7 @@ _XmGeometryEqual(Widget wid,
     	XdbWidgetGeometry2String(geoA),
     	XdbWidgetGeometry2String(geoB)));
 
-    return (memcmp(geoA, geoB, sizeof(XtWidgetGeometry)) == 0);
+    return (bcmp(geoA, geoB, sizeof(XtWidgetGeometry)) == 0);
 }
 
 /*
@@ -1951,7 +1949,7 @@ _XmHandleGeometryManager(Widget w,
     DEBUGOUT(XdbDebug2(__FILE__, w, instigator, "_XmHandleGeometryManager (%s)\n",
     	XdbWidgetGeometry2String(desired)));
 
-    memset((void *)&want, 0, sizeof(XtWidgetGeometry));
+    bzero((void *)&want, sizeof(XtWidgetGeometry));
 
     if (cachePtr && *cachePtr)
     {
@@ -2149,7 +2147,7 @@ _XmMakeGeometryRequest(Widget w,
 	 * as we can (hoping no one has set the sink to /dev/null...)
 	 */
 	/*
-	memcpy(desired, &response, sizeof(XtWidgetGeometry));
+	bcopy(&response, desired, sizeof(XtWidgetGeometry));
 	*/
 	*desired = response;
 
