@@ -32,11 +32,8 @@
  */
 
 #include <LTconfig.h>
-
-#include <stdio.h>
-#include <string.h>
-
 #include <XmI/DebugUtil.h>
+#include <X11/Xfuncproto.h>
 #include <X11/IntrinsicP.h>	/* To get into the composite and core widget
 				   structures. */
 #include <X11/ObjectP.h>	/* For XtIs<Classname> macros. */
@@ -44,26 +41,12 @@
 #include <X11/ShellP.h>		/* for Application Shell Widget class. */
 
 #include <X11/Xatom.h>
+#include <X11/Xos.h>		/* for strcpy declaration */
+#include <XmI/LTV6EditresP.h>
 #include <X11/Xmd.h>
 #include <Xm/XmP.h>
-#include <XmI/LTV6EditresP.h>
-
-
-/* local prototypes */
-static void _LesstifEditResPutString8(ProtocolStream *stream, char *str);
-static void _LesstifEditResPut8(ProtocolStream *stream, unsigned int value);
-static void _LesstifEditResPut16(ProtocolStream *stream, unsigned int value);
-static void _LesstifEditResPut32(ProtocolStream *stream, unsigned long value);
-static void _LesstifEditResPutWidgetInfo(ProtocolStream *stream, WidgetInfo *info);
-static void _LesstifEditResResetStream(ProtocolStream *stream);
-
-static Boolean _LesstifEditResGet8(ProtocolStream *stream, unsigned char *val);
-static Boolean _LesstifEditResGet16(ProtocolStream *stream, unsigned short *val);
-static Boolean _LesstifEditResGetSigned16(ProtocolStream *stream, short *val);
-static Boolean _LesstifEditResGet32(ProtocolStream *stream, unsigned long *val);
-static Boolean _LesstifEditResGetString8(ProtocolStream *stream, char **str);
-static Boolean _LesstifEditResGetWidgetInfo(ProtocolStream *stream, WidgetInfo *info);
 
+#include <stdio.h>
 
 #define _LesstifEditResPutBool _LesstifEditResPut8
 #define _LesstifEditResPutResourceType _LesstifEditResPut8
@@ -262,11 +245,9 @@ XmuCopyISOLatin1Lowered(char *dst, XmConst char *src)
  */
 
 /* ARGSUSED */
-extern void
-_XmNSEEditResCheckMessages(Widget w,
-                           XtPointer data, 
-                           XEvent *event,
-                           Boolean *cont)
+void
+_XmNSEEditResCheckMessages(Widget w, XtPointer data, XEvent *event,
+			   Boolean *cont)
 {
     Time time;
     ResIdent ident;
@@ -937,7 +918,7 @@ HandleToolkitErrors(String name, String type, String class, String msg,
 	sprintf(buf, msg, params[0]);
     else if (streq(name, "conversionFailed") || streq(name, "conversionError"))
     {
-	if (streq((char *)info->event->value, XtRString))
+	if (streq(info->event->value, XtRString))
 	    sprintf(buf,
 		    "Could not convert the string '%s' for the `%s' resource.",
 		    (char *)info->event->value, info->event->name);
@@ -1266,11 +1247,6 @@ PositionInChild(Widget child, int x, int y)
     XtSetArg(args[num], XtNy, &child_y); num++;
     XtSetArg(args[num], XtNborderWidth, &border_width); num++;
     XtGetValues(child, args, num);
-    if (XmIsVendorShell(XtParent(child)))
-    {
-    	child_x = -border_width;
-    	child_y = -border_width;
-    }
 
     /*
      * The only way we will know of the widget is mapped is to see if
@@ -1566,7 +1542,7 @@ InsertWidget(ProtocolStream * stream, Widget w)
  *    Returns: none.
  */
 
-static void
+void
 _LesstifEditResPutString8(ProtocolStream *stream, char *str)
 {
     int i, len = strlen(str);
@@ -1583,7 +1559,7 @@ _LesstifEditResPutString8(ProtocolStream *stream, char *str)
  *    Returns: none
  */
 
-static void
+void
 _LesstifEditResPut8(ProtocolStream *stream, unsigned int value)
 {
     unsigned char temp;
@@ -1610,7 +1586,7 @@ _LesstifEditResPut8(ProtocolStream *stream, unsigned int value)
  *    Returns: void
  */
 
-static void
+void
 _LesstifEditResPut16(ProtocolStream *stream, unsigned int value)
 {
     _LesstifEditResPut8(stream, (value >> XER_NBBY) & BYTE_MASK);
@@ -1624,7 +1600,7 @@ _LesstifEditResPut16(ProtocolStream *stream, unsigned int value)
  *    Returns: void
  */
 
-static void
+void
 _LesstifEditResPut32(ProtocolStream *stream, unsigned long value)
 {
     int i;
@@ -1640,7 +1616,7 @@ _LesstifEditResPut32(ProtocolStream *stream, unsigned long value)
  *    Returns: none
  */
 
-static void
+void
 _LesstifEditResPutWidgetInfo(ProtocolStream *stream, WidgetInfo *info)
 {
     unsigned int i;
@@ -1662,7 +1638,7 @@ _LesstifEditResPutWidgetInfo(ProtocolStream *stream, WidgetInfo *info)
  *    Returns: none.
  */
 
-static void
+void
 _LesstifEditResResetStream(ProtocolStream *stream)
 {
     stream->current = stream->top;
@@ -1694,7 +1670,7 @@ _LesstifEditResResetStream(ProtocolStream *stream)
  *    Returns: True if sucessful.
  */
 
-static Boolean
+Boolean
 _LesstifEditResGet8(ProtocolStream *stream, unsigned char *val)
 {
     if (stream->size < (stream->current - stream->top))
@@ -1712,7 +1688,7 @@ _LesstifEditResGet8(ProtocolStream *stream, unsigned char *val)
  *    Returns: True if sucessful.
  */
 
-static Boolean
+Boolean
 _LesstifEditResGet16(ProtocolStream *stream, unsigned short *val)
 {
     unsigned char temp1, temp2;
@@ -1732,7 +1708,7 @@ _LesstifEditResGet16(ProtocolStream *stream, unsigned short *val)
  *      Returns: True if sucessful.
  */
 
-static Boolean
+Boolean
 _LesstifEditResGetSigned16(ProtocolStream *stream, short *val)
 {
     unsigned char temp1, temp2;
@@ -1761,7 +1737,7 @@ _LesstifEditResGetSigned16(ProtocolStream *stream, short *val)
  *    Returns: True if sucessful.
  */
 
-static Boolean
+Boolean
 _LesstifEditResGet32(ProtocolStream *stream, unsigned long *val)
 {
     unsigned short temp1, temp2;
@@ -1782,7 +1758,7 @@ _LesstifEditResGet32(ProtocolStream *stream, unsigned long *val)
  *    Returns: True if retrieval was successful.
  */
 
-static Boolean
+Boolean
 _LesstifEditResGetString8(ProtocolStream *stream, char **str)
 {
     unsigned short len;
@@ -1816,7 +1792,7 @@ _LesstifEditResGetString8(ProtocolStream *stream, char **str)
  *    Returns: True if retrieval was successful.
  */
 
-static Boolean
+Boolean
 _LesstifEditResGetWidgetInfo(ProtocolStream *stream, WidgetInfo *info)
 {
     unsigned int i;
