@@ -1,11 +1,10 @@
 /**
- * $Id: LTfnmatch.c,v 1.4 2000/09/22 20:35:12 amai Exp $
+ * $Id: LTfnmatch.c,v 1.3 1998/09/12 15:05:32 rwscott Exp $
  *
  * derived from GNU libc fnmatch.c
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1991, 1992, 1993 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -25,14 +24,18 @@
  *
  **/
 
-static const char rcsid[] = "$Id: LTfnmatch.c,v 1.4 2000/09/22 20:35:12 amai Exp $";
+static const char rcsid[] = "$Id: LTfnmatch.c,v 1.3 1998/09/12 15:05:32 rwscott Exp $";
 
 #include <LTconfig.h>
 
+#include <errno.h>
+#include <LTfnmatch.h>
 #include <ctype.h>
 
-#include <LTfnmatch.h>
 
+#ifndef errno
+extern int errno;
+#endif
 
 /* Match STRING against the filename pattern PATTERN, returning zero if
    it matches, nonzero if not.  */
