@@ -1,9 +1,8 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/Label.c,v 1.116 2000/09/23 15:05:24 amai Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm/Label.c,v 1.106 1999/09/11 04:28:34 gritton Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,13 +22,11 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/Label.c,v 1.116 2000/09/23 15:05:24 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/Label.c,v 1.106 1999/09/11 04:28:34 gritton Exp $";
 
 #include <LTconfig.h>
-
-#include <stdio.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/XmosP.h>
 #include <Xm/AtomMgr.h>
@@ -45,6 +42,8 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/Label.c,v
 #include <XmI/AtomMgrI.h>
 #include <XmI/DragDropI.h>
 
+#include <assert.h>
+
 #include <XmI/DebugUtil.h>
 
 /* Forward Declarations */
@@ -518,7 +517,7 @@ CreateInsensitiveGC(Widget w)
     values.graphics_exposures = False;
     values.foreground = Prim_Foreground(w);
     values.background = XtBackground(w);
-    values.fill_style = FillStippled;
+    values.fill_style = FillOpaqueStippled;
     values.ts_x_origin = values.ts_y_origin = 0;
     values.stipple = XmGetPixmapByDepth(XtScreen(w), "50_foreground", 1, 0, 1);
 
@@ -1175,12 +1174,6 @@ expose(Widget w, XEvent *event, Region region)
 	mypm = XtSensitive(w)
 	    ? Lab_Pixmap(w)
 	    : Lab_PixmapInsensitive(w);
-#if XmVERSION > 1
-	if (mypm == XmUNSPECIFIED_PIXMAP)
-	{
-	    mypm = Lab_Pixmap(w);
-	}
-#endif
 	if (mypm > XmUNSPECIFIED_PIXMAP &&
 	    cliprect.x + cliprect.width > Lab_TextRect_x(w) &&
 	    cliprect.x < Lab_TextRect_x(w) + Lab_TextRect_width(w) &&
@@ -1209,105 +1202,14 @@ expose(Widget w, XEvent *event, Region region)
 		cliprect.height =
 		    (Lab_TextRect_y(w) + Lab_TextRect_height(w)) - cliprect.y;
 	    }
-#if XmVERSION > 1
-	    {
-		unsigned int tmp, tmpw, tmph;
-		int tmpx, tmpy;
-		int Depth;
-		Window tmpwin;
-
-		/* rws 4 Mar 2000
-		   According to the comments in label/test12, this does not
-		   happen. We should be adding the pixmap to our pixmap
-		   cache, and getting the info from there instead of a
-		   round trip server query.
-		 */
-		/* rws 10 Mar 2000
-		   Apparently a Motif 2 thing.
-		 */
-		/*
-		   eaf 3 Apr 2000 use the cache for this.  Tests indicate
-		   that Motif does this in set_values, but I like waiting
-		   until we actually need the information.
-		 */
-		{
-		  char *name ;
-		  Pixel fg, bg ;
-		  int hotx, hoty ;
-		  u_int wid, hgt ;
-
-		  if( !_XmGetPixmapData(XtScreen(w), mypm, &name,
-		  	&Depth, &fg, &bg, &hotx, &hoty, &wid, &hgt) )
-		  {
-		    /* This pixmap has never been seen before.  Generate
-		     * a unique name and add it to the cache.  The cache
-		     * mechanism will obtain the depth.  Then we can try
-		     * again.
-		     */
-		    char newname[40] ;
-		    sprintf(newname, "--anon pixmap %x-%x",
-		      (unsigned)XtScreen(w), (unsigned)mypm) ;
-		    (void) _XmInstallPixmap(mypm, XtScreen(w), newname,
-			  Prim_Foreground(w), XtBackground(w)) ;
-
-		    /* Ok, let's try again. */
-		    if( !_XmGetPixmapData(XtScreen(w), mypm, &name,
-			  &Depth, &fg, &bg, &hotx, &hoty, &wid, &hgt) )
-		    {
-		      /* Still not found?
-		       * Don't panic, ask the server directly.
-		       */
-		      unsigned uDepth;
-		      XGetGeometry(XtDisplayOfObject(w), mypm, &tmpwin,
-				&tmpx, &tmpy, &tmpw, &tmph, &tmp, &uDepth);
-		      Depth=uDepth;
-		    }
-		  }
-		}
-
-		if (Depth == 1)
-		{
-		    XCopyPlane(XtDisplay(w),
-			  mypm,
-			  XtWindow(w),
-			  myGC,
-			  cliprect.x - Lab_TextRect_x(w),
-			  cliprect.y - Lab_TextRect_y(w),
-			  cliprect.width, cliprect.height,
-			  cliprect.x, cliprect.y,
-			  1);
-		}
-		else if (Depth > 1)
-		{
-		    XCopyArea(XtDisplay(w),
-			  mypm,
-			  XtWindow(w),
-			  myGC,
-			  cliprect.x - Lab_TextRect_x(w),
-			  cliprect.y - Lab_TextRect_y(w),
-			  cliprect.width, cliprect.height,
-			  cliprect.x, cliprect.y);
-		}
-	    }
-	    if (!XtSensitive(w) && Lab_PixmapInsensitive(w) == XmUNSPECIFIED_PIXMAP)
-	    {
-	    	/* label/test14 */
-	    	XFillRectangle(XtDisplay(w), XtWindow(w),
-	    		myGC,
-		  cliprect.x,
-		  cliprect.y,
-		  cliprect.width, cliprect.height);
-	    }
-#else
 	    XCopyArea(XtDisplay(w),
-		  mypm,
-		  XtWindow(w),
-		  myGC,
-		  cliprect.x - Lab_TextRect_x(w),
-		  cliprect.y - Lab_TextRect_y(w),
-		  cliprect.width, cliprect.height,
-		  cliprect.x, cliprect.y);
-#endif
+		      mypm,
+		      XtWindow(w),
+		      myGC,
+		      cliprect.x - Lab_TextRect_x(w),
+		      cliprect.y - Lab_TextRect_y(w),
+		      cliprect.width, cliprect.height,
+		      cliprect.x, cliprect.y);
 	}
     }
 }
@@ -1630,15 +1532,12 @@ drag_convert_proc(Widget w, Atom *selection,
 {
     Atom COMPOUND_TEXT;
     Atom MOTIF_DROP;
-    Widget source;
-    char *ct, *text;
-    XmString label;
 
     _XmObjectLock(w);
     COMPOUND_TEXT = XmInternAtom(XtDisplay(w), _XA_COMPOUND_TEXT, False);
     MOTIF_DROP = XmInternAtom(XtDisplay(w), _XA_MOTIF_DROP, False);
 
-    if (*selection != MOTIF_DROP || *target != COMPOUND_TEXT)
+    if (*selection != MOTIF_DROP)
     {
 	_XmObjectUnlock(w);
 	return False;
@@ -1646,32 +1545,13 @@ drag_convert_proc(Widget w, Atom *selection,
 
     DEBUGOUT(XdbDebug(__FILE__, w, "We're dealing with a motif drop\n"));
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "We're dealing with compound text\n"));
-
-    XtVaGetValues(w,
-    	XmNsourceWidget, &source,
-    	NULL);
-    XtVaGetValues(source,
-    	XmNlabelString, &label,
-    	NULL);
-
-    ct = XmCvtXmStringToCT(label);
-    XmStringFree(label);
-    text = XtNewString(ct);
-    *type_return = COMPOUND_TEXT;
-    *value_return = (XtPointer)text;
-    *length_return = strlen(text);
-    *format_return = 8;
-
     _XmObjectUnlock(w);
-    return True;
+    return False;
 }
 
 static void
 drag_drop_finish(Widget w, XtPointer client_data, XtPointer call_data)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:drag_drop_finish(%d)\n",
-    	__FILE__, __LINE__));
 }
 
 static void
@@ -1778,17 +1658,9 @@ _XmCalcLabelDimensions(Widget w)
     }
     else
     {
-    Pixmap mypm;
-
-	mypm = XtIsSensitive(w) ? Lab_Pixmap(w) : Lab_PixmapInsensitive(w);
-#if XmVERSION > 1
-	if (mypm == XmUNSPECIFIED_PIXMAP)
-	{
-	    mypm = Lab_Pixmap(w);
-	}
-#endif
-
-	_XmLabelGetPixmapSize(w, mypm,
+	_XmLabelGetPixmapSize(w, (XtIsSensitive(w)
+				  ? Lab_Pixmap(w)
+				  : Lab_PixmapInsensitive(w)),
 			      &Lab_TextRect_width(w),
 			      &Lab_TextRect_height(w));
     }
@@ -1810,6 +1682,10 @@ Widget
 XmCreateLabel(Widget parent, char *name,
 	      Arg *arglist, Cardinal argcount)
 {
-	return XtCreateWidget(name, xmLabelWidgetClass, parent,
+	Widget	w;
+	_XmObjectLock(parent);
+	w = XtCreateWidget(name, xmLabelWidgetClass, parent,
 			  arglist, argcount);
+	_XmObjectUnlock(parent);
+	return w;
 }
