@@ -1,9 +1,8 @@
 /**
  *
- * $Id: LabelG.c,v 1.100 2001/07/27 18:51:56 dannybackx Exp $
+ * $Id: LabelG.c,v 1.90 1999/09/19 16:34:11 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,12 +22,9 @@
  *
  **/
 
-static const char rcsid[] = "$Id: LabelG.c,v 1.100 2001/07/27 18:51:56 dannybackx Exp $";
+static const char rcsid[] = "$Id: LabelG.c,v 1.90 1999/09/19 16:34:11 rwscott Exp $";
 
 #include <LTconfig.h>
-
-#include <string.h>
-
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -44,6 +40,7 @@ static const char rcsid[] = "$Id: LabelG.c,v 1.100 2001/07/27 18:51:56 dannyback
 #include <Xm/ScreenP.h>
 #include <Xm/DragIconP.h>
 #include <XmI/AtomMgrI.h>
+#include <X11/Xfuncs.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -473,9 +470,9 @@ secondary_object_create(Widget request,
     XmBaseClassExt *bce;
     XtPointer nsec, rsec;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "LabelGCacheRec %s being initialized.\n", XtName(new_w)));
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -504,7 +501,7 @@ secondary_object_create(Widget request,
     ed->widget = (Widget)nsec;
     ed->reqWidget = (Widget)rsec;
 
-    memcpy(rsec, nsec, size);
+    bcopy(nsec, rsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     _XmPushWidgetExtData(new_w, ed, XmCACHE_EXTENSION);
@@ -516,7 +513,7 @@ secondary_object_create(Widget request,
 int
 _XmLabelCacheCompare(XtPointer A, XtPointer B)
 {
-    return !memcmp(((XmLabelGCacheObjPart *)A),
+    return !bcmp(((XmLabelGCacheObjPart *)A),
 		 ((XmLabelGCacheObjPart *)B),
 		 sizeof(XmLabelGCacheObjPart));
 }
@@ -537,17 +534,9 @@ _XmCalcLabelGDimensions(Widget w)
     }
     else
     {
-    Pixmap mypm;
-
-	mypm = XtIsSensitive(w) ? LabG_Pixmap(w) : LabG_PixmapInsensitive(w);
-#if XmVERSION > 1
-	if (mypm == XmUNSPECIFIED_PIXMAP)
-	{
-	    mypm = LabG_Pixmap(w);
-	}
-#endif
-
-	_XmLabelGetPixmapSize(w, mypm,
+	_XmLabelGetPixmapSize(w, (XtIsSensitive(w)
+				  ? LabG_Pixmap(w)
+				  : LabG_PixmapInsensitive(w)),
 			      &LabG_TextRect_width(w),
 			      &LabG_TextRect_height(w));
     }
@@ -586,7 +575,7 @@ _XmAssignLabG_MarginHeight(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -610,9 +599,9 @@ _XmAssignLabG_MarginHeight(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
-           LabG_Cache((Widget)lw),
-	   sizeof(XmLabelGCacheObjPart));
+    bcopy(LabG_Cache((Widget)lw),
+	  &((XmLabelGCacheObject)nsec)->label_cache,
+	  sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -631,7 +620,7 @@ _XmAssignLabG_MarginWidth(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -655,9 +644,9 @@ _XmAssignLabG_MarginWidth(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
-           LabG_Cache((Widget)lw),
-	   sizeof(XmLabelGCacheObjPart));
+    bcopy(LabG_Cache((Widget)lw),
+	  &((XmLabelGCacheObject)nsec)->label_cache,
+	  sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -674,7 +663,7 @@ _XmAssignLabG_MarginLeft(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -698,9 +687,9 @@ _XmAssignLabG_MarginLeft(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
-           LabG_Cache((Widget)lw),
-	   sizeof(XmLabelGCacheObjPart));
+    bcopy(LabG_Cache((Widget)lw),
+	  &((XmLabelGCacheObject)nsec)->label_cache,
+	  sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -717,7 +706,7 @@ _XmAssignLabG_MarginRight(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -741,9 +730,9 @@ _XmAssignLabG_MarginRight(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
-           LabG_Cache((Widget)lw),
-	   sizeof(XmLabelGCacheObjPart));
+    bcopy(LabG_Cache((Widget)lw),
+	  &((XmLabelGCacheObject)nsec)->label_cache,
+	  sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -760,7 +749,7 @@ _XmAssignLabG_MarginTop(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -784,9 +773,9 @@ _XmAssignLabG_MarginTop(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
-           LabG_Cache((Widget)lw),
-	   sizeof(XmLabelGCacheObjPart));
+    bcopy(LabG_Cache((Widget)lw),
+	  &((XmLabelGCacheObject)nsec)->label_cache,
+	  sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -803,7 +792,7 @@ _XmAssignLabG_MarginBottom(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -827,9 +816,9 @@ _XmAssignLabG_MarginBottom(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
-           LabG_Cache((Widget)lw),
-	   sizeof(XmLabelGCacheObjPart));
+    bcopy(LabG_Cache((Widget)lw),
+	  &((XmLabelGCacheObject)nsec)->label_cache,
+	  sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -850,77 +839,17 @@ drag_convert_proc(Widget w, Atom *selection,
 {
     Atom COMPOUND_TEXT;
     Atom MOTIF_DROP;
-    Widget source;
-    char *ct, *text;
-    XmString label;
-    Atom TEXT;
-    int len;
 
-    _XmObjectLock(w);
     COMPOUND_TEXT = XmInternAtom(XtDisplay(w), _XA_COMPOUND_TEXT, False);
     MOTIF_DROP = XmInternAtom(XtDisplay(w), _XA_MOTIF_DROP, False);
-    TEXT = XmInternAtom(XtDisplay(w), _XA_TEXT, False);
 
     if (*selection != MOTIF_DROP)
     {
-	_XmObjectUnlock(w);
 	return False;
     }
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "We're dealing with a motif drop\n"));
-
-    XtVaGetValues(w,
-    	XmNsourceWidget, &source,
-    	NULL);
-    XtVaGetValues(source,
-    	XmNlabelString, &label,
-    	NULL);
-
-    ct = XmCvtXmStringToCT(label);
-    XmStringFree(label);
-    text = XtNewString(ct);
-    len = strlen(text);
-
-    if (*target == XA_STRING){
-        *length_return = len;
-        *value_return = text;
-        *type_return = XA_STRING;
-    }
-    else if (*target == COMPOUND_TEXT || *target == TEXT){
-
-	    XTextProperty prop;
-	    char *buf;
-	    int ret;
-
-	    buf = XtMalloc(len + 1);
-            strncpy(buf, text, len);
-	    buf[len] = '\0';
-
-	    ret = XmbTextListToTextProperty(XtDisplay(w), &buf, 1,
-	    			XCompoundTextStyle, &prop);
-		
-	    XtFree(buf);
-	    if (ret != 0){
-	    	*length_return = 0;
-	    	*value_return  = NULL;
-	    }
-	    else{
-	    	buf = XtMalloc(prop.nitems + 1);
-		strncpy(buf, prop.value, prop.nitems);
-		buf[prop.nitems] = '\0';
-	    	*length_return = prop.nitems;
-	    	*value_return  = buf;
-	    }
-	   *type_return = COMPOUND_TEXT;
-
-    }
-    else
-	return False;
-
-    *format_return = 8;
-
-    _XmObjectUnlock(w);
-    return True;
+    DEBUGOUT(XdbDebug(__FILE__, w, "We're dealing with a motif drop\n"));
+    return False;
 }
 
 static void
@@ -932,30 +861,28 @@ void
 _XmProcessDrag(Widget w, XEvent *event,
 	       String *params, Cardinal *num_params)
 {
-    Atom export_target[3];
+    Atom export_target;
     Arg args[10];
     int n = 0;
     Widget dc;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "Processing a drag-drop request\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "Processing a drag-drop request\n"));
 
     if (LabG_IsPixmap(w))
     {
-	export_target[0] = XmInternAtom(XtDisplay(w),
+	export_target = XmInternAtom(XtDisplay(w),
 				     _XA_PIXMAP,
 				     False);
-        XtSetArg(args[n], XmNexportTargets, export_target); n++;
-        XtSetArg(args[n], XmNnumExportTargets, 1); n++;
     }
     else
     {
-	export_target[0] = XmInternAtom(XtDisplay(w), _XA_COMPOUND_TEXT, False);
-	export_target[1] = XmInternAtom(XtDisplay(w), _XA_TEXT, False);
-	export_target[2] = XA_STRING;
-        XtSetArg(args[n], XmNexportTargets, export_target); n++;
-        XtSetArg(args[n], XmNnumExportTargets, 3); n++;
+	export_target = XmInternAtom(XtDisplay(w),
+				     _XA_COMPOUND_TEXT,
+				     False);
     }
 
+    XtSetArg(args[n], XmNexportTargets, &export_target); n++;
+    XtSetArg(args[n], XmNnumExportTargets, 1); n++;
     XtSetArg(args[n], XmNdragOperations, XmDROP_COPY); n++;
     XtSetArg(args[n], XmNconvertProc, drag_convert_proc); n++;
     XtSetArg(args[n], XmNclientData, w); n++;
@@ -1073,7 +1000,7 @@ CreateInsensitiveGC(Widget w)
     values.graphics_exposures = False;
     values.foreground = XmParentForeground(w);
     values.background = XmParentBackground(w);
-    values.fill_style = FillStippled;
+    values.fill_style = FillOpaqueStippled;
     values.ts_x_origin = values.ts_y_origin = 0;
     values.stipple = XmGetPixmapByDepth(XtScreen(w), "50_foreground", 1, 0, 1);
 
@@ -1085,7 +1012,7 @@ static void
 initialize_prehook(Widget request, Widget new_w,
 		   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebug(__FILE__, new_w, "LabelG InitializePrehook\n"));
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "LabelG InitializePrehook\n"));
 }
 #endif
 
@@ -1097,7 +1024,7 @@ initialize_posthook(Widget request,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w, "LabelG InitializePosthook\n"));
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "LabelG InitializePosthook\n"));
 
     /* don't let the null fool you */
     LabG_Cache(new_w) = (XmLabelGCacheObjPart *)
@@ -1117,7 +1044,7 @@ initialize(Widget request, Widget new_w,
 {
     XmString xmstring;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "%s:initialize(%d) - %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -1127,7 +1054,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     LabG_SkipCallback(new_w) = False;
 
@@ -1310,7 +1237,7 @@ resize(Widget w)
 	    {
 		_XmAssignLabG_MarginRight((XmLabelGadget)w,
 		    LABEL_ACC_PAD + LabG_AccTextRect(w).width);
-		DEBUGOUT(_LtDebug(__FILE__, w,
+		DEBUGOUT(XdbDebug(__FILE__, w,
 				  "resize: set right margin to %d\n",
 				  LabG_MarginRight(w)));
 		_XmReCacheLabG(w);
@@ -1323,7 +1250,7 @@ resize(Widget w)
 	    {
 		_XmAssignLabG_MarginLeft((XmLabelGadget)w,
 		    LABEL_ACC_PAD + LabG_AccTextRect(w).width);
-		DEBUGOUT(_LtDebug(__FILE__, w,
+		DEBUGOUT(XdbDebug(__FILE__, w,
 				  "resize: set left margin to %d\n",
 				  LabG_MarginLeft(w)));
 		_XmReCacheLabG(w);
@@ -1407,7 +1334,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
     XtPointer nsec, rsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -1427,9 +1354,9 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
     ExtObj_LogicalParent(nsec) = new_w;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
-           LabG_Cache(new_w),
-	   sizeof(XmLabelGCacheObjPart));
+    bcopy(LabG_Cache(new_w),
+	  &((XmLabelGCacheObject)nsec)->label_cache,
+	  sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -1444,7 +1371,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 		   (*bce)->secondaryObjectClass->core_class.num_resources,
 		   args, *num_args);
 
-    memcpy(rsec, nsec, size);
+    bcopy(nsec, rsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     LabG_Cache(new_w) = &(((XmLabelGCacheObject)nsec)->label_cache);
@@ -1498,7 +1425,7 @@ set_values(Widget old, Widget request, Widget new_w,
     Boolean refresh_needed = False, relayout_needed = False,
 	recalc_needed = False;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w, "LabelGadget SetValues %d %d\n",
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "LabelGadget SetValues %d %d\n",
 		      LabG_MarginRight(new_w), LabG_MarginRight(old)));
 
     /* Silently discard accelerator for non-menu labels and cascades */
@@ -1759,7 +1686,7 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
     XtPointer nsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -1767,9 +1694,9 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 
     nsec = _XmExtObjAlloc(size);
 
-    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
-           LabG_Cache(new_w),
-	   sizeof(XmLabelGCacheObjPart));
+    bcopy(LabG_Cache(new_w),
+	  &((XmLabelGCacheObject)nsec)->label_cache,
+	  sizeof(XmLabelGCacheObjPart));
 
     /*
      * don't do this and ResInd will blow up.
@@ -1814,7 +1741,7 @@ get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args)
 static void
 get_values_hook(Widget w, ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "LabelG: GetValuesHook\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "LabelG: GetValuesHook\n"));
 }
 #endif
 
@@ -1895,11 +1822,11 @@ expose(Widget w,
 	- ((G_ShadowThickness(w) + G_HighlightThickness(w)) << 1)
 	- LabG_MarginTop(w) - LabG_MarginBottom(w);
 
-    DEBUGOUT(_LtDebug(__FILE__, w,
+    DEBUGOUT(XdbDebug(__FILE__, w,
              "Expose: cliprect %d %d %dx%d\n",
             cliprect.x, cliprect.y,
              cliprect.width, cliprect.height));
-    DEBUGOUT(_LtDebug(__FILE__, w,
+    DEBUGOUT(XdbDebug(__FILE__, w,
              "Expose: acctextrect %d %d %dx%d\n",
             LabG_AccTextRect(w).x, LabG_AccTextRect(w).y,
              LabG_AccTextRect(w).width, LabG_AccTextRect(w).height));
@@ -1946,12 +1873,6 @@ expose(Widget w,
 	mypm = XtSensitive(w)
 	    ? LabG_Pixmap(w)
 	    : LabG_PixmapInsensitive(w);
-#if XmVERSION > 1
-	if (mypm == XmUNSPECIFIED_PIXMAP)
-	{
-	    mypm = LabG_Pixmap(w);
-	}
-#endif
 	cliprect.x -= XtX(w);
 	cliprect.y -= XtY(w);
 	if (mypm > XmUNSPECIFIED_PIXMAP &&
@@ -1982,63 +1903,6 @@ expose(Widget w,
 		cliprect.height = (LabG_TextRect_y(w)
 				   + LabG_TextRect_height(w)) - cliprect.y;
 	    }
-#if XmVERSION > 1
-	    {
-		unsigned int tmp, tmpw, tmph;
-		int tmpx, tmpy;
-		unsigned Depth;
-		Window tmpwin;
-
-		/* rws 4 Mar 2000
-		   According to the comments in label/test12, this does not
-		   happen. We should be adding the pixmap to our pixmap
-		   cache, and getting the info from there instead of a
-		   round trip server query.
-		 */
-		/* rws 10 Mar 2000
-		   Apparently a Motif 2 thing.
-		 */
-		XGetGeometry(XtDisplayOfObject(w),
-			     mypm,
-			     &tmpwin,
-			     &tmpx, &tmpy,
-			     &tmpw, &tmph,
-			     &tmp, &Depth);
-
-		if (Depth == 1)
-		{
-		    XCopyPlane(XtDisplay(w),
-			  mypm,
-			  XtWindow(w),
-			  myGC,
-			  cliprect.x - LabG_TextRect_x(w),
-			  cliprect.y - LabG_TextRect_y(w),
-			  cliprect.width, cliprect.height,
-			  cliprect.x + XtX(w), cliprect.y + XtY(w),
-			  1);
-		}
-		else if (Depth > 1)
-		{
-		    XCopyArea(XtDisplay(w),
-			  mypm,
-			  XtWindow(w),
-			  myGC,
-			  cliprect.x - LabG_TextRect_x(w),
-			  cliprect.y - LabG_TextRect_y(w),
-			  cliprect.width, cliprect.height,
-			  cliprect.x + XtX(w), cliprect.y + XtY(w));
-		}
-	    }
-	    if (!XtSensitive(w) && LabG_PixmapInsensitive(w) == XmUNSPECIFIED_PIXMAP)
-	    {
-	    	/* label/test14 */
-	    	XFillRectangle(XtDisplay(w), XtWindow(w),
-	    		myGC,
-		  cliprect.x,
-		  cliprect.y,
-		  cliprect.width, cliprect.height);
-	    }
-#else
 	    XCopyArea(XtDisplay(w),
 		      mypm,
 		      XtWindow(w),
@@ -2047,7 +1911,6 @@ expose(Widget w,
 		      cliprect.y - LabG_TextRect_y(w),
 		      cliprect.width, cliprect.height,
 		      cliprect.x + XtX(w), cliprect.y + XtY(w));
-#endif
 	}
     }
 }
@@ -2120,7 +1983,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
     a.width = XtWidth(w);
     a.height = XtHeight(w);
     a.request_mode = CWWidth | CWHeight;
-    DEBUGOUT(_LtDebug(__FILE__, w,
+    DEBUGOUT(XdbDebug(__FILE__, w,
 		      "LabelGadget queried for size: reporting %d %d %08x\n",
 		      XtWidth(w), XtHeight(w), answer));
 
@@ -2241,11 +2104,11 @@ input_dispatch(Widget gadget,
     switch (event_mask)
     {
     case XmHELP_EVENT:
-	DEBUGOUT(_LtDebug(__FILE__, gadget, "LabelGadget got help event\n"));
+	DEBUGOUT(XdbDebug(__FILE__, gadget, "LabelGadget got help event\n"));
 	break;
 
     case XmBDRAG_EVENT:
-	DEBUGOUT(_LtDebug(__FILE__, gadget, "LabelGadget got bdrag event\n"));
+	DEBUGOUT(XdbDebug(__FILE__, gadget, "LabelGadget got bdrag event\n"));
 	_XmProcessDrag(gadget, event, NULL, NULL);
 	break;
     }
