@@ -1,9 +1,8 @@
 /**
  *
- * $Id: Manager.c,v 1.96 2001/07/27 18:51:56 dannybackx Exp $
+ * $Id: Manager.c,v 1.76 1999/09/18 16:04:48 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,13 +22,15 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Manager.c,v 1.96 2001/07/27 18:51:56 dannybackx Exp $";
+static const char rcsid[] = "$Id: Manager.c,v 1.76 1999/09/18 16:04:48 rwscott Exp $";
 
 #include <LTconfig.h>
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
 
 #include <XmI/XmI.h>
 #include <XmI/TraversalI.h>
@@ -41,8 +42,11 @@ static const char rcsid[] = "$Id: Manager.c,v 1.96 2001/07/27 18:51:56 dannyback
 #include <Xm/RepType.h>
 #include <Xm/TransltnsP.h>
 #include <X11/keysym.h>
+#include <X11/Xfuncs.h>
 #include <Xm/VirtKeysP.h>
 
+#include <XmI/DebugUtil.h>
+
 /* For determining class type */
 #include <Xm/CascadeBP.h>
 #include <Xm/CascadeBGP.h>
@@ -64,16 +68,12 @@ static const char rcsid[] = "$Id: Manager.c,v 1.96 2001/07/27 18:51:56 dannyback
 
 static XmDirection get_direction(Widget w);
 
-static XmSpecifyLayoutDirectionTraitRec _XmManagerLayoutTraitRec =
-{
-    0,				/* version */
-    get_direction		/* getValue */
+static XmSpecifyLayoutDirectionTraitRec _XmManagerLayoutTraitRec = {
+    0, /* version */
+    get_direction /* getValue */
 };
 
-#endif
-
-#include <XmI/DebugUtil.h>
-
+#endif 
 
 /* Forward Declarations */
 
@@ -93,12 +93,12 @@ static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
 
 /*
-   static XtGeometryResult geometry_manager(Widget w,
-   XtWidgetGeometry *request,
-   XtWidgetGeometry *reply);
+static XtGeometryResult geometry_manager(Widget w,
+					 XtWidgetGeometry *request,
+					 XtWidgetGeometry *reply);
 
-   static void changed_managed(Widget w);
- */
+static void changed_managed(Widget w);
+*/
 
 static void constraint_initialize(Widget request, Widget new_w,
 				  ArgList args, Cardinal *num_args);
@@ -335,17 +335,18 @@ static XtResource resources[] =
     }
 
 #if XmVERSION > 1
-    ,
-    {
+#if LESSTIF_BACK_COMPAT
+#else
+    ,{
 	XmNpopupHandlerCallback, XmCCallback, XmRCallback,
 	sizeof(XtCallbackList), Offset(popup_handler_callback),
 	XtRPointer, (XtPointer)NULL
     }
-    ,
-    {
+#endif
+    ,{
 	XmNlayoutDirection, XmCLayoutDirection, XmRDirection,
 	sizeof(XmDirection), Offset(string_direction),
-	XmRImmediate, (XtPointer)((XmDirection) NULL)	/* dynamic how? */
+	XmRImmediate, (XtPointer)((XmDirection)NULL) /* dynamic how? */
     }
 #endif
 };
@@ -389,13 +390,13 @@ static XmSyntheticResource syn_resources[] =
     },
 #if XmVERSION > 1
     {
-	XmNstringDirection,
+	XmNstringDirection, 
 	sizeof(XmStringDirection), MOffset(string_direction),
-	_XmFromLayoutDirection, _XmToLayoutDirection
+        _XmFromLayoutDirection, _XmToLayoutDirection
     },
 #endif
 };
-
+/* *INDENT-OFF* */
 static XmBaseClassExtRec _XmManagerCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -507,8 +508,7 @@ XmManagerClassRec xmManagerClassRec = {
 	/* extension                    */ (XtPointer)&_XmManagerClassExtRec
     },
 };
-
-
+/* *INDENT-ON* */
 
 
 WidgetClass xmManagerWidgetClass = (WidgetClass)&xmManagerClassRec;
@@ -565,11 +565,11 @@ class_part_initialize(WidgetClass widget_class)
 	}
     }
     /*
-       else
-       {
-       (*extptr)->accepts_objects = True;
-       }
-     */
+    else
+    {
+    	(*extptr)->accepts_objects = True;
+    }
+    */
 
 
     if (widget_class != xmManagerWidgetClass)
@@ -582,7 +582,7 @@ class_part_initialize(WidgetClass widget_class)
 	if (mce && !*mce && sce && *sce)
 	{
 	    *mce =
-		(XmManagerClassExtRec *)XtCalloc(1, sizeof(XmManagerClassExtRec));
+	      (XmManagerClassExtRec *)XtCalloc(1, sizeof(XmManagerClassExtRec));
 	    (*mce)->next_extension = NULL;
 	    (*mce)->record_type = NULLQUARK;
 	    (*mce)->version = XmManagerClassExtVersion;
@@ -612,7 +612,7 @@ class_part_initialize(WidgetClass widget_class)
     _XmInitializeSyntheticResources(mwc->manager_class.syn_resources,
 				    mwc->manager_class.num_syn_resources);
     _XmInitializeSyntheticResources(mwc->manager_class.syn_constraint_resources,
-			      mwc->manager_class.num_syn_constraint_resources);
+				    mwc->manager_class.num_syn_constraint_resources);
 
     if (widget_class != xmManagerWidgetClass)
     {
@@ -630,22 +630,22 @@ class_part_initialize(WidgetClass widget_class)
 			  msc->manager_class.num_syn_constraint_resources);
     }
 
-#if XmVERSION > 1
+    #if XmVERSION > 1
     /* FIX ME: do I need to worry about subclasses */
     /* initialize traits */
-    if (!XmeTraitSet((XtPointer)xmManagerWidgetClass, XmQTspecifyLayoutDirection,
-		     (XtPointer)&_XmManagerLayoutTraitRec))
+    if (! XmeTraitSet(xmManagerWidgetClass, XmQTspecifyLayoutDirection, 
+                &_XmManagerLayoutTraitRec))
     {
-	_XmWarning(NULL, "XmManager ClassInitialize: XmeTraitSet failed\n");
+        _XmWarning(NULL, "XmManager ClassInitialize: XmeTraitSet failed\n");
     }
-#endif
+    #endif
 }
 
 static void
 CreateHighlightGC(Widget mw)
 {
     XGCValues values;
-    unsigned long mask,dynamic,unused;
+    unsigned long mask;
 
     mask = GCForeground | GCBackground;
     values.foreground = MGR_HighlightColor(mw);
@@ -667,15 +667,7 @@ CreateHighlightGC(Widget mw)
     values.join_style = JoinMiter;
     values.cap_style = CapButt;
 
-    /* these may be changed in _XmDrawHighlight() called from
-     * gadget_border_highlight() */
-    dynamic = GCLineWidth | GCLineStyle | GCJoinStyle | GCDashList;
-
-    /* have no idea ! */
-    unused = 0;
-
     MGR_HighlightGC(mw) = XtGetGC((Widget)mw, mask, &values);
-
 }
 
 static void
@@ -762,7 +754,7 @@ initialize(Widget request,
 	   Cardinal *num_args)
 {
     XmManagerWidgetClass mwc = (XmManagerWidgetClass)new_w->core.widget_class;
-    /*XmManagerWidget   mw = (XmManagerWidget)new_w; */
+    /*XmManagerWidget	mw = (XmManagerWidget)new_w;*/
 
     MGR_EventHandlerAdded(new_w) = False;
     MGR_HighlightedWidget(new_w) = NULL;
@@ -809,7 +801,7 @@ initialize(Widget request,
     {
 	XtOverrideTranslations(new_w,
 			       (XtTranslations)mwc->
-			       manager_class.translations);
+					manager_class.translations);
     }
 
     /*
@@ -828,13 +820,13 @@ initialize(Widget request,
      */
     if (_XmGetBGPixmapName() != NULL)
     {
-	CoreBackgroundPixmap(new_w) =
-	    XmGetPixmapByDepth(XtScreen(new_w),
-			       _XmGetBGPixmapName(),
-			       MGR_Foreground(new_w),
-			       XtBackground(new_w),
-			       CoreDepth(new_w));
-	_XmClearBGPixmap();
+        CoreBackgroundPixmap(new_w) =
+                XmGetPixmapByDepth(XtScreen(new_w),
+                                            _XmGetBGPixmapName(),
+                                            MGR_Foreground(new_w),
+                                            XtBackground(new_w),
+                                            CoreDepth(new_w));
+        _XmClearBGPixmap();
     }
 
     CreateTopShadowGC(new_w);
@@ -849,17 +841,13 @@ initialize(Widget request,
 static void
 destroy(Widget w)
 {
-    DEBUGOUT(_LtDebug("RWS", w, "%s:destroy(%d)\n",
-		      __FILE__, __LINE__
-	     ));
+    DEBUGOUT(XdbDebug("RWS", w,"%s:destroy(%d)\n",
+    	__FILE__, __LINE__
+    	));
     XtReleaseGC(w, MGR_TopShadowGC(w));
     XtReleaseGC(w, MGR_BottomShadowGC(w));
     XtReleaseGC(w, MGR_HighlightGC(w));
     XtReleaseGC(w, MGR_BackgroundGC(w));
-    if (MGR_KeyboardList(w))
-    {
-        XtFree((char *)MGR_KeyboardList(w));
-    }
 
     if (MGR_EventHandlerAdded(w))
     {
@@ -877,11 +865,11 @@ realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
 {
     /* rws 13 Nov 1998
        This causes a parse error with gcc on AIX???
-       Boolean wz = False, hz = False; */
+    Boolean wz = False, hz = False; */
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
-		      __FILE__, __LINE__,
-		      XtWidth(w), XtHeight(w)));
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
+    	__FILE__, __LINE__,
+    	XtWidth(w), XtHeight(w)));
 
     /*
      * MLM 960524 - if you get an XError: widget has zero width or height.
@@ -897,9 +885,9 @@ realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
 	XtHeight(w) = 1;
     }
 
-    *value_mask |= CWDontPropagate | CWBitGravity;
+    *value_mask |= CWDontPropagate|CWBitGravity;
     attributes->do_not_propagate_mask =
-	(KeyPressMask | KeyReleaseMask | ButtonPressMask | ButtonReleaseMask |
+	(KeyPressMask|KeyReleaseMask|ButtonPressMask|ButtonReleaseMask|
 	 PointerMotionMask);
     attributes->bit_gravity = NorthWestGravity;
 
@@ -908,15 +896,15 @@ realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
 
     /* rws 7 Oct 1998
        drawingarea/test7 shows that this does not happen
-       if (wz)
-       {
-       XtWidth(w) = 0;
-       }
-       if (hz)
-       {
-       XtHeight(w) = 0;
-       }
-     */
+    if (wz)
+    {
+	XtWidth(w) = 0;
+    }
+    if (hz)
+    {
+	XtHeight(w) = 0;
+    }
+    */
 }
 
 static Boolean
@@ -928,21 +916,19 @@ set_values(Widget old,
 {
     Boolean need_refresh = False;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w, "SetValues()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "SetValues()\n"));
 
 #if 0
-    if (XtWidth(new_w) != XtWidth(old) && XtWidth(new_w) == 0)
-    {
+    if (XtWidth(new_w) != XtWidth(old) && XtWidth(new_w) == 0) {
 	_XmWarning(new_w,
-	 "XmManager SetValues: won't set width of widget to 0 (previous %d)\n",
-		   XtWidth(old));
+		"XmManager SetValues: won't set width of widget to 0 (previous %d)\n",
+		XtWidth(old));
 	XtWidth(new_w) = XtWidth(old);
     }
-    if (XtHeight(new_w) != XtHeight(old) && XtHeight(new_w) == 0)
-    {
+    if (XtHeight(new_w) != XtHeight(old) && XtHeight(new_w) == 0) {
 	_XmWarning(new_w,
-	"XmManager SetValues: won't set height of widget to 0 (previous %d)\n",
-		   XtHeight(old));
+		"XmManager SetValues: won't set height of widget to 0 (previous %d)\n",
+		XtHeight(old));
 	XtHeight(new_w) = XtHeight(old);
     }
 #endif
@@ -951,18 +937,18 @@ set_values(Widget old,
     {
 	XSetWindowAttributes attr;
 
-	CoreBackgroundPixmap(new_w) =
-	    XmGetPixmapByDepth(XtScreen(new_w),
-			       _XmGetBGPixmapName(),
-			       MGR_Foreground(new_w),
-			       XtBackground(new_w),
-			       CoreDepth(new_w));
+        CoreBackgroundPixmap(new_w) =
+                XmGetPixmapByDepth(XtScreen(new_w),
+                                            _XmGetBGPixmapName(),
+                                            MGR_Foreground(new_w),
+                                            XtBackground(new_w),
+                                            CoreDepth(new_w));
 
 	attr.background_pixmap = CoreBackgroundPixmap(new_w);
 	XChangeWindowAttributes(XtDisplay(new_w), XtWindow(new_w),
-				CWBackPixmap, &attr);
+			        CWBackPixmap, &attr);
 
-	_XmClearBGPixmap();
+        _XmClearBGPixmap();
     }
 
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRUnitType),
@@ -1033,7 +1019,7 @@ geometry_manager(Widget w,
 		 XtWidgetGeometry *reply)
 {
     /* Motif does not have this method */
-    DEBUGOUT(_LtDebug(__FILE__, w, "geometry_manager()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "geometry_manager()\n"));
 
     if (reply)
     {
@@ -1069,7 +1055,7 @@ changed_managed(Widget w)
 {
     /* Motif does not have this method */
     /* FIX ME */
-    DEBUGOUT(_LtDebug(__FILE__, w, "ChangeManaged()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "ChangeManaged()\n"));
 
 
     _XmNavigChangeManaged(w);
@@ -1097,7 +1083,7 @@ constraint_initialize(Widget request,
 		|| G_EventMask(new_w) & XmENTER_EVENT
 		|| G_EventMask(new_w) & XmLEAVE_EVENT)
 	    {
-		DEBUGOUT(_LtDebug(__FILE__, manager, "adding event handler\n"));
+		DEBUGOUT(XdbDebug(__FILE__, manager, "adding event handler\n"));
 
 		XtAddEventHandler(manager,
 				  PointerMotionMask | EnterWindowMask |
@@ -1120,7 +1106,7 @@ _XmGadgetArm(Widget w,
     XButtonEvent *ev = (XButtonEvent *)event;
     Widget g = (Widget)_XmInputForGadget(w, ev->x, ev->y);
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetArm()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "Inside _XmGadgetArm()\n"));
 
     if (g)
     {
@@ -1128,12 +1114,12 @@ _XmGadgetArm(Widget w,
 	_XmDispatchGadgetInput(g,
 			       event,
 			       XmARM_EVENT);
-
+	
 	MGR_SelectedGadget(w) = (XmGadget)g;
     }
     else
     {
-	if (_XmIsNavigable(w))
+	if (_XmIsNavigable(w)) 
 	{
 	    XmProcessTraversal(w, XmTRAVERSE_CURRENT);
 	}
@@ -1149,7 +1135,7 @@ _XmGadgetActivate(Widget w,
 {
     Widget g = (Widget)MGR_SelectedGadget(w);
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetActivate()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "Inside _XmGadgetActivate()\n"));
 
     if (g)
     {
@@ -1170,7 +1156,7 @@ _XmGadgetMultiArm(Widget w,
     XButtonEvent *ev = (XButtonEvent *)event;
     Widget g = (Widget)_XmInputForGadget(w, ev->x, ev->y);
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetMultiArm()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "Inside _XmGadgetMultiArm()\n"));
 
     if (g)
     {
@@ -1196,7 +1182,7 @@ _XmGadgetMultiArm(Widget w,
     }
     else
     {
-	if (_XmIsNavigable(w))
+	if (_XmIsNavigable(w)) 
 	{
 	    XmProcessTraversal(w, XmTRAVERSE_CURRENT);
 	}
@@ -1212,7 +1198,7 @@ _XmGadgetMultiActivate(Widget w,
 {
     Widget g = (Widget)MGR_SelectedGadget(w);
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetMultiActivate()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "Inside _XmGadgetMultiActivate()\n"));
 
     if (g)
     {
@@ -1247,7 +1233,7 @@ _XmGadgetDrag(Widget w,
     XButtonEvent *ev = (XButtonEvent *)event;
     Widget g = (Widget)_XmInputForGadget(w, ev->x, ev->y);
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetDrag()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "Inside _XmGadgetDrag()\n"));
 
     if (g)
     {
@@ -1265,7 +1251,7 @@ _XmGadgetSelect(Widget w,
 {
     Widget g = MGR_ActiveChild(w);
 
-    DEBUGOUT(_LtDebug2(__FILE__, w, g, "Inside _XmGadgetSelect()\n"));
+    DEBUGOUT(XdbDebug2(__FILE__, w, g, "Inside _XmGadgetSelect()\n"));
 
     if (g && XmIsGadget(g))
     {
@@ -1287,7 +1273,7 @@ _XmManagerParentActivate(Widget w,
     XmParentProcessDataRec data;
     XmManagerWidgetClass mwc = (XmManagerWidgetClass)w->core.widget_class;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "Inside ManagerParentActivate()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "Inside ManagerParentActivate()\n"));
 
     data.input_action.process_type = XmINPUT_ACTION;
     data.input_action.event = event;
@@ -1367,7 +1353,7 @@ _XmGadgetTraverseRight(Widget w,
 {
     Widget g = MGR_ActiveChild(w);
 
-    DEBUGOUT(_LtDebug(__FILE__, g,
+    DEBUGOUT(XdbDebug(__FILE__, g,
 		      "Manager XmProcessTraversal(TRAVERSE_RIGHT)\n"));
 
     XmProcessTraversal(g, XmTRAVERSE_RIGHT);
@@ -1394,7 +1380,7 @@ _XmGadgetHelp(Widget w,
     Widget cur;
     XmAnyCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetHelp()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "Inside _XmGadgetHelp()\n"));
 
     if (g)
     {
@@ -1424,11 +1410,11 @@ _XmGadgetHelp(Widget w,
 
 void
 _XmManagerHelp(Widget w,
-	       XEvent *event,
-	       String *params,
-	       Cardinal *num_params)
+	      XEvent *event,
+	      String *params,
+	      Cardinal *num_params)
 {
-    _XmGadgetHelp(w, event, params, num_params);
+	_XmGadgetHelp(w, event, params, num_params);
 }
 
 void
@@ -1439,8 +1425,8 @@ _XmGadgetKeyInput(Widget w,
 {
     Widget g = MGR_ActiveChild(w);
 
-    DEBUGOUT(_LtDebug2(__FILE__, w, g, "Inside _XmGadgetKeyInput()\n"));
-    DEBUGOUT(_LtDebug2(__FILE__, w, g,
+    DEBUGOUT(XdbDebug2(__FILE__, w, g, "Inside _XmGadgetKeyInput()\n"));
+    DEBUGOUT(XdbDebug2(__FILE__, w, g,
 		       "event type: %d code %08x\n",
 		       event->type, event->xkey.keycode));
 
@@ -1460,7 +1446,7 @@ _XmGadgetButtonMotion(Widget w,
 {
     Widget g = MGR_ActiveChild(w);
 
-    DEBUGOUT(_LtDebug(__FILE__, w,
+    DEBUGOUT(XdbDebug(__FILE__, w,
 		      "Inside _XmGadgetButtonMotion(), gadget %s\n",
 		      g ? XtName(g) : "(null)"));
 
@@ -1481,7 +1467,7 @@ _XmManagerParentCancel(Widget w,
     XmParentProcessDataRec data;
     XmManagerWidgetClass mwc = (XmManagerWidgetClass)w->core.widget_class;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "ManagerParentCancel\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "ManagerParentCancel\n"));
 
     data.input_action.process_type = XmINPUT_ACTION;
     data.input_action.event = event;
@@ -1526,7 +1512,7 @@ _XmSocorro(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmAnyCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmSocorro()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "Inside _XmSocorro()\n"));
 
     cbs.reason = XmCR_HELP;
     cbs.event = event;
@@ -1575,12 +1561,12 @@ _XmManagerEventHandler(Widget w,
     g = _XmInputForGadget(w, event->xmotion.x, event->xmotion.y);
     if (g == NULL)
     {
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 			  "### _XmManagerEventHandler(gadget NULL)\n"));
     }
     else
     {
-	DEBUGOUT(_LtDebug2(__FILE__, w,
+	DEBUGOUT(XdbDebug2(__FILE__, w,
 			   (Widget)g, "### _XmManagerEventHandler()\n"));
     }
 
@@ -1620,7 +1606,7 @@ _XmManagerEventHandler(Widget w,
 
 	if (MGR_HighlightedWidget(w) != NULL)
 	{
-	    DEBUGOUT(_LtDebug(__FILE__, w, "Sending LEAVE event to gadget\n"));
+	    DEBUGOUT(XdbDebug(__FILE__, w, "Sending LEAVE event to gadget\n"));
 	    _XmDispatchGadgetInput(MGR_HighlightedWidget(w),
 				   event,
 				   XmLEAVE_EVENT);
@@ -1643,7 +1629,7 @@ _XmManagerEventHandler(Widget w,
 
 	if (MGR_HighlightedWidget(w) == NULL)
 	{
-	    DEBUGOUT(_LtDebug(__FILE__, w, "Sending ENTER event to gadget\n"));
+	    DEBUGOUT(XdbDebug(__FILE__, w, "Sending ENTER event to gadget\n"));
 
 	    _XmDispatchGadgetInput((Widget)g,
 				   event,
@@ -1656,14 +1642,14 @@ _XmManagerEventHandler(Widget w,
 	    if (MGR_HighlightedWidget(w) != (Widget)g)
 	    {
 
-		DEBUGOUT(_LtDebug(__FILE__, w,
+		DEBUGOUT(XdbDebug(__FILE__, w,
 				  "Sending LEAVE event to old gadget\n"));
 
 		_XmDispatchGadgetInput(MGR_HighlightedWidget(w),
 				       event,
 				       XmLEAVE_EVENT);
 
-		DEBUGOUT(_LtDebug(__FILE__, w,
+		DEBUGOUT(XdbDebug(__FILE__, w,
 				  "Sending ENTER event to new gadget\n"));
 
 		_XmDispatchGadgetInput((Widget)g,
@@ -1679,9 +1665,9 @@ _XmManagerEventHandler(Widget w,
 void
 _XmDestroyParentCallback(Widget w, XtPointer client, XtPointer call)
 {
-    DEBUGOUT(_LtDebug2("NEDIT", XtParent(w), w,
-		       "%s:_XmDestroyParentCallback(%d)\n",
-		       __FILE__, __LINE__));
+    DEBUGOUT(XdbDebug2("NEDIT", XtParent(w), w,
+	"%s:_XmDestroyParentCallback(%d)\n",
+	__FILE__, __LINE__));
     XtDestroyWidget(XtParent(w));
 }
 
@@ -1696,7 +1682,7 @@ _XmClearShadowType(Widget w,
 	if (XtWidth(w) >= old_width)
 	{
 	    XClearArea(XtDisplay(w), XtWindow(w),
-		    old_width - old_shadow_thickness - old_highlight_thickness,
+		       old_width - old_shadow_thickness - old_highlight_thickness,
 		       0, old_shadow_thickness,
 		       old_height - old_highlight_thickness, False);
 	}
@@ -1704,7 +1690,7 @@ _XmClearShadowType(Widget w,
 	{
 	    XClearArea(XtDisplay(w), XtWindow(w),
 		       0,
-		   old_height - old_shadow_thickness - old_highlight_thickness,
+		       old_height - old_shadow_thickness - old_highlight_thickness,
 		       old_width - old_highlight_thickness,
 		       old_shadow_thickness, False);
 	}
@@ -1747,12 +1733,7 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
     XtActionProc act = NULL;
     Widget comp = (Widget)client_data;
 
-    DEBUGOUT(_LtDebug(__FILE__, w,
-		      "Got Accelerator key: type %d code %04x "
-		      "state %08x data %08x\n",
-		      event->type, event->xkey.keycode, event->xkey.state,
-		      client_data));
-    DEBUGOUT(_LtDebug("NMEM", w,
+    DEBUGOUT(XdbDebug(__FILE__, w,
 		      "Got Accelerator key: type %d code %04x "
 		      "state %08x data %08x\n",
 		      event->type, event->xkey.keycode, event->xkey.state,
@@ -1761,24 +1742,20 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
     if (!XmIsManager(w) ||
 	(event->type != KeyPress && event->type != KeyRelease))
     {
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 			  "Bad match for event.  Not manager or bad event.\n"));
 	return;
     }
 
-    DEBUGOUT(_LtDebug(__FILE__, w,
-		    "Got Accelerator key: code: %08x state: %08x cd %08x %s\n",
-		      event->xkey.keycode, event->xkey.state, comp,
-		      XtName(comp)));
-    DEBUGOUT(_LtDebug("NMEM", w,
-		    "Got Accelerator key: code: %08x state: %08x cd %08x %s\n",
-		      event->xkey.keycode, event->xkey.state, comp,
-		      XtName(comp)));
+    DEBUGOUT(XdbDebug(__FILE__, w,
+		      "Got Accelerator key: code: %08x state: %08x cd %08x %s\n",
+		      event->xkey.keycode, event->xkey.state, client_data,
+		      XtName(client_data)));
 
     /* JAC added this test.  Occasionally in nedit the accelerators cause
        segfaults.  The comp value passed has 0 for all fields in the
        Widget.  e.g.:
-
+     
        (gdb) p *comp
 
        $10 = {core = {self = 0x0, widget_class = 0x0, parent = 0x0,
@@ -1796,16 +1773,15 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
        I suspect that "comp" may be the address of a widget that's been
        destroyed, and for some reason we're still getting the callback,
        but that's a WAG.
-     */
-    if (!comp->core.widget_class)
-    {
-	_XmWarning(NULL, "XmManager _XmAcceleratorHandler: bad news!!!\n");
-	DEBUGOUT(_LtDebug(__FILE__, w,
-			  "_XmAcceleratorHandler: called for w=%s"
-			  " with invalid comp, ignoring\n",
-			  XtName(w)));
-	return;
-
+    */
+   if (!comp->core.widget_class) {
+    _XmWarning(NULL, "XmManager _XmAcceleratorHandler: bad news!!!\n");
+      DEBUGOUT(XdbDebug(__FILE__, w,
+			"_XmAcceleratorHandler: called for w=%s"
+			" with invalid comp, ignoring\n",
+			XtName(w)));
+      return;
+      
     }
 
     /*
@@ -1817,115 +1793,64 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
      * no point in searching when we know that we can't do anything with
      * what we find.
      * --mu@trends.net, 1998.09.06 */
-    if (!XtIsSensitive(comp))
+    if(!XtIsSensitive(comp))
     {
-	DEBUGOUT(_LtDebug(__FILE__, w,
-			"_XmAcceleratorHandler: %s is insensitive, ignoring\n",
-			  XtName(comp)));
-	return;
+       DEBUGOUT(XdbDebug(__FILE__, w,
+                         "_XmAcceleratorHandler: %s is insensitive, ignoring\n",
+                         XtName(comp)));
+       return;
     }
 
     for (i = 0; i < MGR_NumKeyboardEntries(w); i++)
     {
-	if (/*MGR_KeyboardList(w)[i].eventType == event->type && */
+	if (/*MGR_KeyboardList(w)[i].eventType == event->type &&*/
 	    MGR_KeyboardList(w)[i].key == event->xkey.keycode &&
 	    MGR_KeyboardList(w)[i].modifiers == event->xkey.state &&
-	    MGR_KeyboardList(w)[i].component == comp &&
-	    XtIsManaged(comp))
+	    MGR_KeyboardList(w)[i].component == client_data)
 	{
 	    Cardinal num_params = 0;
 
-	    DEBUGOUT(_LtDebug(__FILE__, w,
+	    DEBUGOUT(XdbDebug(__FILE__, w,
 			      "MATCH!!!! "
 			      "code %08x state %08x name: %s:%s mnem: %d\n",
 			      event->xkey.keycode, event->xkey.state,
 			      comp
-			      ? comp->core.widget_class->core_class.class_name
-			      : "(nil)",
-			      comp ? XtName(comp) : "(nil)",
-			      MGR_KeyboardList(w)[i].isMnemonic));
-	    DEBUGOUT(_LtDebug("NMEM", w,
-			      "MATCH!!!! "
-			      "code %08x state %08x name: %s:%s mnem: %d\n",
-			      event->xkey.keycode, event->xkey.state,
-			      comp
-			      ? comp->core.widget_class->core_class.class_name
-			      : "(nil)",
+				? comp->core.widget_class->core_class.class_name
+				: "(nil)",
 			      comp ? XtName(comp) : "(nil)",
 			      MGR_KeyboardList(w)[i].isMnemonic));
 
 	    /* Make sure XmGetPostedFromWidget works: ? */
 
-   /* amai: The following "if (act==NULL)" catches are just dumb
-            attempts to prevent some rare crashes, e.g. as seen with
-   	    NEdit. They really should be replaced by something better.
-   	    Actually the only confirmed crash location is the
-   	    first one, however I just decided to add a "full set"
-	    of checks here ...
-	    The _XmWarning()s should help us to get additional feedback
-	    on that issue!
-	    FIX ME ! */
-
-	    if (!MGR_KeyboardList(w)[i].isMnemonic || RC_Type(XtParent(comp)) == XmMENU_BAR ||
-		(MGR_KeyboardList(w)[i].isMnemonic && XtParent(comp) == RC_PopupPosted(w))
-		)
+	    if (XmIsPrimitive(MGR_KeyboardList(w)[i].component))
 	    {
-		DEBUGOUT(_LtDebug2(__FILE__, w, MGR_KeyboardList(w)[i].component,
-				   "menu showing\n"));
-		DEBUGOUT(_LtDebug2("NMEM", w, MGR_KeyboardList(w)[i].component,
-				   "menu showing\n"));
-		if (XmIsPrimitive(MGR_KeyboardList(w)[i].component))
-		{
-		    act = PrimC_ArmAndActivate(XtClass(comp));
-		    if (act==NULL) {
-                       _XmWarning(w, "%s:_XmAcceleratorHandler(%d) - act==NULL for %s", 
-		               __FILE__, __LINE__, comp->core.widget_class->core_class.class_name);
-		    } else {
-                       (*act) (comp, event, NULL, &num_params);
-		    }
-		}
-		else if (XmIsGadget(MGR_KeyboardList(w)[i].component))
-		{
-		    act = GC_ArmAndActivate(XtClass(comp));
-		    if (act==NULL) {
-                       _XmWarning(w, "%s:_XmAcceleratorHandler(%d) - act==NULL for gadget", 
-		               __FILE__, __LINE__);
-	            } else {
-                       (*act) (comp, event, NULL, &num_params);
-		    }
-		}
-		else if (XmIsRowColumn(w))
-		{
-		    act = RCClass_ArmAndActivate(XtClass(comp));
-		    if (act==NULL) {
-                       _XmWarning(w, "%s:_XmAcceleratorHandler(%d) - act==NULL for RowColumn", 
-		               __FILE__, __LINE__);
-		    } else {
-                       (*act) (comp, event, NULL, &num_params);
-		    }
-		}
-		else
-		{
-		    DEBUGOUT(_LtDebug(__FILE__, MGR_KeyboardList(w)[i].component,
-				      "Not a widget/gadget\n"));
+		act = PrimC_ArmAndActivate(XtClass(comp));
 
-		    XtCallActionProc(comp, "Activate", event, NULL, 0);
-		}
-		*cont = False;
-		break;
+		(*act)(comp, event, NULL, &num_params);
+	    }
+	    else if (XmIsGadget(MGR_KeyboardList(w)[i].component))
+	    {
+		act = GC_ArmAndActivate(XtClass(comp));
+
+		(*act)(comp, event, NULL, &num_params);
+	    }
+	    else if (XmIsRowColumn(w))
+	    {
+		act = RCClass_ArmAndActivate(XtClass(comp));
+
+		(*act)(comp, event, NULL, &num_params);
 	    }
 	    else
 	    {
-		DEBUGOUT(_LtDebug2(__FILE__, w, MGR_KeyboardList(w)[i].component,
-				   "menu is not showing\n"));
-		DEBUGOUT(_LtDebug2("NMEM", w, MGR_KeyboardList(w)[i].component,
-				   "menu is not showing\n"));
+		DEBUGOUT(XdbDebug(__FILE__, MGR_KeyboardList(w)[i].component,
+				  "Not a widget/gadget\n"));
+
+		XtCallActionProc(comp, "Activate", event, NULL, 0);
 	    }
 
-	    /*
 	    *cont = False;
+
 	    break;
-	    */
 	}
     }
 }
@@ -1952,14 +1877,14 @@ AddKeyboardEntry(Widget m, Widget w, XmKeyboardData *item)
 	{
 	    MGR_SizeKeyboardList(m) *= 2;
 	    MGR_KeyboardList(m) =
-		(XmKeyboardData *)XtRealloc((char *)MGR_KeyboardList(m),
+		(XmKeyboardData *)XtRealloc((XtPointer)MGR_KeyboardList(m),
 					    sizeof(XmKeyboardData) *
 					    MGR_SizeKeyboardList(m));
 	}
 
 	if (MGR_SizeKeyboardList(m) > i)
 	{
-	    memset(&MGR_KeyboardList(m)[i], 0,
+	    bzero(&MGR_KeyboardList(m)[i],
 		  (MGR_SizeKeyboardList(m) - i) * sizeof(XmKeyboardData));
 	}
     }
@@ -1973,22 +1898,15 @@ AddKeyboardEntry(Widget m, Widget w, XmKeyboardData *item)
 	_XmError(m, "This should not happen: %d\n", i);
     }
 
-    memcpy(&MGR_KeyboardList(m)[i], item, sizeof(XmKeyboardData));
+    bcopy(item, &MGR_KeyboardList(m)[i], sizeof(XmKeyboardData));
 
     MGR_NumKeyboardEntries(m)++;
 
-    DEBUGOUT(_LtDebug(__FILE__, m,
-		      "GrabKey: key %04x Sym: %04x modifiers %08x %s %s\n",
-		      item->key, item->keysym, item->modifiers,
-		      item->needGrab ? "Grabbing" : "Not Grabbing",
-		      item->isMnemonic ? "mnemonic" : "not mnemonic"));
-    DEBUGOUT(_LtDebug("NMEM", m,
-		      "GrabKey: key %04x Sym: %04x modifiers %08x %s %s\n",
-		      item->key, item->keysym, item->modifiers,
-		      item->needGrab ? "Grabbing" : "Not Grabbing",
-		      item->isMnemonic ? "mnemonic" : "not mnemonic"));
+    DEBUGOUT(XdbDebug(__FILE__, m,
+		      "GrabKey: key %04x Sym: %04x modifiers %08x\n",
+		      item->key, item->keysym, item->modifiers));
 
-    XtInsertEventHandler(m, item->eventType /*KeyPressMask|KeyReleaseMask */ ,
+    XtInsertEventHandler(m, item->eventType /*KeyPressMask|KeyReleaseMask*/,
 			 False, _XmAcceleratorHandler,
 			 (XtPointer)w, XtListHead);
 
@@ -2028,19 +1946,18 @@ DeleteKeyboardEntry(Widget m, Widget w, Boolean isMnemonic)
 
 	    if (i < MGR_NumKeyboardEntries(m) - 1)
 	    {
-		memcpy(&MGR_KeyboardList(m)[i],
-                       &MGR_KeyboardList(m)[i + 1],
-		       sizeof(XmKeyboardData) *
-		        (MGR_NumKeyboardEntries(m) - i - 1));
+		bcopy(&MGR_KeyboardList(m)[i + 1],
+		      &MGR_KeyboardList(m)[i],
+		      sizeof(XmKeyboardData) *
+			(MGR_NumKeyboardEntries(m) - i - 1));
 
-		memset(&MGR_KeyboardList(m)[MGR_NumKeyboardEntries(m) - 1], 0,
+		bzero(&MGR_KeyboardList(m)[MGR_NumKeyboardEntries(m) - 1],
 		      sizeof(XmKeyboardData));
 	    }
 	    /* end of list */
 	    else
 	    {
-		memset(&MGR_KeyboardList(m)[i], 0,
-		       sizeof(XmKeyboardData));
+		bzero(&MGR_KeyboardList(m)[i], sizeof(XmKeyboardData));
 	    }
 
 	    MGR_NumKeyboardEntries(m)--;
@@ -2058,9 +1975,7 @@ _XmManagerInstallAccelerator(Widget m, Widget w, String s)
     unsigned int modifiers = 0;
     XmKeyboardData data;
 
-    DEBUGOUT(_LtDebug2(__FILE__, m, w,
-		       "_XmManagerInstallAccelerator(%s)\n", s));
-    DEBUGOUT(_LtDebug2("NMEM", m, w,
+    DEBUGOUT(XdbDebug2(__FILE__, m, w,
 		       "_XmManagerInstallAccelerator(%s)\n", s));
 
     /* Do we really have an accelerator ? */
@@ -2086,20 +2001,13 @@ _XmManagerInstallAccelerator(Widget m, Widget w, String s)
 
 	if (XtIsSubclass(sh, applicationShellWidgetClass) ||
 	    XtIsSubclass(sh, xmDialogShellWidgetClass) ||
-	    XtIsSubclass(sh, transientShellWidgetClass) ||
 	    XtIsSubclass(sh, topLevelShellWidgetClass))
 	{
 	    break;
 	}
     }
 
-    if (!XmIsManager(mw))
-    {
-	return;
-    }
-
-
-    DEBUGOUT(_LtDebug(__FILE__, w,
+    DEBUGOUT(XdbDebug(__FILE__, w,
 		      "_XmManagerInstallAccelerator found manager %s\n",
 		      XtName(mw)));
 
@@ -2114,31 +2022,8 @@ _XmManagerInstallAccelerator(Widget m, Widget w, String s)
     data.key = XKeysymToKeycode(XtDisplay(w), data.keysym);
     data.modifiers = modifiers;
     data.needGrab = True;
-    if (data.key == 0)
-    {
-#if 1
-    KeySym real_sym;
-    Modifiers real_mod;
 
-	_XmVirtualToActualKeysym(XtDisplay(w), data.keysym, &real_sym, &real_mod);
-	if (real_sym == NoSymbol && real_mod == (Modifiers)0)
-	{
-	    _XmWarning(m, "%s:_XmManagerInstallAccelerator(%d) - Could not convert >%s< to a KeyCode\n    %s -> %08x -> %i", 
-		__FILE__, __LINE__, s,
-		s, data.keysym, data.key);
-	}
-	else
-	{
-	    data.key = XKeysymToKeycode(XtDisplay(w), real_sym);
-	    data.modifiers = real_mod;
-	    AddKeyboardEntry(mw, w, &data);
-	}
-#endif
-    }
-    else
-    {
-	AddKeyboardEntry(mw, w, &data);
-    }
+    AddKeyboardEntry(mw, w, &data);
 }
 
 void
@@ -2152,9 +2037,6 @@ _XmManagerUninstallAccelerator(Widget m, Widget w)
 	sh = XtParent(mw);
 	if (XtIsSubclass(sh, applicationShellWidgetClass) ||
 	    XtIsSubclass(sh, xmDialogShellWidgetClass) ||
-	    XtIsSubclass(sh, transientShellWidgetClass) ||
-		XtIsSubclass(sh, transientShellWidgetClass) ||
-		XtIsSubclass(sh, transientShellWidgetClass) ||
 	    XtIsSubclass(sh, topLevelShellWidgetClass))
 	{
 	    break;
@@ -2181,41 +2063,32 @@ _XmManagerInstallMnemonic(Widget m, Widget w, KeySym mn)
 	return;
     }
 
-    DEBUGOUT(_LtDebug2(__FILE__, m, w, "_XmManagerInstallMnemonic(%c)\n", mn));
-    DEBUGOUT(_LtDebug2("NMEM", m, w, "_XmManagerInstallMnemonic(%c)\n", mn));
+    DEBUGOUT(XdbDebug2(__FILE__, m, w, "_XmManagerInstallMnemonic(%c)\n", mn));
 
     /* If we're dealing with the menu bar, store the stuff in the highest
      * manager widget that you can find (with all the accelerators) */
     if (XmIsRowColumn(m) &&
-	(RC_Type(m) == XmMENU_PULLDOWN || RC_Type(m) == XmMENU_BAR || RC_Type(m) == XmMENU_OPTION))
+	(RC_Type(m) == XmMENU_BAR || RC_Type(m) == XmMENU_OPTION))
     {
 	Widget mw, sh;
 	XmModifierMaskSetReference mods =
-	_XmGetModifierMappingsForDisplay(XtDisplay(w));
+		_XmGetModifierMappingsForDisplay(XtDisplay(w));
 
-	if (RC_Type(m) == XmMENU_PULLDOWN)
-	{
-	}
-	else
-	{
-	    need_grab = True;
-	    modifiers |= mods[ALTModifier];
-	}
+	need_grab = True;
+	modifiers |= mods[ALTModifier];
 
 	for (mw = m; XtParent(mw); mw = sh)
 	{
 	    sh = XtParent(mw);
 	    if (XtIsSubclass(sh, applicationShellWidgetClass) ||
 		XtIsSubclass(sh, xmDialogShellWidgetClass) ||
-		XtIsSubclass(sh, topLevelShellWidgetClass) ||
-		(RC_Type(m) != XmMENU_BAR && XmIsRowColumn(mw) && RC_Type(mw) == XmMENU_BAR))
+		XtIsSubclass(sh, topLevelShellWidgetClass))
 	    {
 		break;
 	    }
 	}
 
-	DEBUGOUT(_LtDebug2(__FILE__, mw, w, "Store mnemonic info\n"));
-	DEBUGOUT(_LtDebug2("NMEM", mw, w, "Store mnemonic info\n"));
+	DEBUGOUT(XdbDebug2(__FILE__, mw, w, "Store mnemonic info\n"));
 	m = mw;
     }
 
@@ -2223,7 +2096,7 @@ _XmManagerInstallMnemonic(Widget m, Widget w, KeySym mn)
     {
 	/* Put the data in the entry */
 	data.component = w;
-	data.eventType = KeyPress;
+	data.eventType = KeyPressMask;
 	data.keysym = mn;
 	data.isMnemonic = True;
 	data.key = XKeysymToKeycode(XtDisplay(w), data.keysym);
@@ -2239,8 +2112,7 @@ _XmManagerUninstallMnemonic(Widget m, Widget w)
 {
     Widget mw, sh;
 
-    if (XmIsRowColumn(m) &&
-	(RC_Type(m) == XmMENU_PULLDOWN || RC_Type(m) == XmMENU_BAR || RC_Type(m) == XmMENU_OPTION))
+    if (XmIsRowColumn(m) && RC_Type(m) == XmMENU_BAR)
     {
 	/* Find the manager widget just underneath the shell */
 	for (mw = m; XtParent(mw); mw = sh)
@@ -2248,8 +2120,7 @@ _XmManagerUninstallMnemonic(Widget m, Widget w)
 	    sh = XtParent(mw);
 	    if (XtIsSubclass(sh, applicationShellWidgetClass) ||
 		XtIsSubclass(sh, xmDialogShellWidgetClass) ||
-		XtIsSubclass(sh, topLevelShellWidgetClass) ||
-		(RC_Type(m) != XmMENU_BAR && XmIsRowColumn(mw) && RC_Type(mw) == XmMENU_BAR))
+		XtIsSubclass(sh, topLevelShellWidgetClass))
 	    {
 		break;
 	    }
@@ -2277,18 +2148,18 @@ widget_navigable(Widget w)
 	    MGR_NavigationType(w) == XmEXCLUSIVE_TAB_GROUP ||
 	    (MGR_NavigationType(w) == XmTAB_GROUP && !_XmShellIsExclusive(w)))
 	{
-	    DEBUGOUT(_LtDebug(__FILE__, w,
+	    DEBUGOUT(XdbDebug(__FILE__, w,
 			  "WidgetNavigable => XmDESCENDANTS_TAB_NAVIGABLE\n"));
 
 	    return XmDESCENDANTS_TAB_NAVIGABLE;
 	}
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 			  "WidgetNavigable => XmDESCENDANTS_NAVIGABLE\n"));
 
 	return XmDESCENDANTS_NAVIGABLE;
     }
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "WidgetNavigable => XmNOT_NAVIGABLE\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "WidgetNavigable => XmNOT_NAVIGABLE\n"));
 
     return XmNOT_NAVIGABLE;
 }
@@ -2296,44 +2167,44 @@ widget_navigable(Widget w)
 void
 _XmManagerHighlightPixmapDefault(Widget w, int offset, XrmValue *value)
 {
-    static Pixmap pixmap;
+	static Pixmap pixmap;  
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "_XmManagerHighlightPixmapDefault\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "_XmManagerHighlightPixmapDefault\n"));
 
-    pixmap = XmUNSPECIFIED_PIXMAP;
+	pixmap = XmUNSPECIFIED_PIXMAP;
 
-    value->addr = (char *)&pixmap;
-    value->size = sizeof(Pixmap);
+	value->addr = (char *) &pixmap;
+	value->size = sizeof (Pixmap);
 
-    if (MGR_HighlightColor(w) == XtBackground(w))
-	pixmap = XmGetPixmapByDepth(XtScreen(w), "50_foreground",
-				    MGR_HighlightColor(w),
-				    MGR_Foreground(w),
-				    CoreDepth(w));
+	if (MGR_HighlightColor(w) == XtBackground(w))
+		pixmap = XmGetPixmapByDepth(XtScreen(w), "50_foreground",
+			MGR_HighlightColor(w),
+			MGR_Foreground(w),
+			CoreDepth(w));
 }
 
 void
 _XmManagerTopShadowPixmapDefault(Widget w, int offset, XrmValue *value)
 {
-    static Pixmap pixmap;
+	static Pixmap pixmap;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "_XmManagerTopShadowPixmapDefault\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "_XmManagerTopShadowPixmapDefault\n"));
 
-    pixmap = XmUNSPECIFIED_PIXMAP;
+	pixmap = XmUNSPECIFIED_PIXMAP;
 
-    value->addr = (char *)&pixmap;
-    value->size = sizeof(Pixmap);
+	value->addr = (char *) &pixmap;
+	value->size = sizeof (Pixmap);
 
-    if (MGR_TopShadowColor(w) == XtBackground(w))
-	pixmap = XmGetPixmapByDepth(XtScreen(w), "50_foreground",
-				    MGR_TopShadowColor(w),
-				    MGR_Foreground(w),
-				    CoreDepth(w));
-    else if (DefaultDepthOfScreen(XtScreen(w)) == 1)
-	pixmap = XmGetPixmapByDepth(XtScreen(w), "50_foreground",
-				    MGR_TopShadowColor(w),
-				    XtBackground(w),
-				    CoreDepth(w));
+	if (MGR_TopShadowColor(w) == XtBackground(w))
+		pixmap = XmGetPixmapByDepth(XtScreen(w), "50_foreground",
+			MGR_TopShadowColor(w),
+			MGR_Foreground(w),
+			CoreDepth(w));
+	else if (DefaultDepthOfScreen(XtScreen(w)) == 1)
+		pixmap = XmGetPixmapByDepth(XtScreen(w), "50_foreground",
+			MGR_TopShadowColor(w),
+			XtBackground(w),
+			CoreDepth(w));
 }
 
 static void
@@ -2344,7 +2215,7 @@ _XmManagerExportX(Widget widget, int offset, XtArgVal *value)
 
     if (XtIsManaged(widget) && XtParent(widget) && XmIsVendorShell(XtParent(widget)))
     {
-	*value = XtX(XtParent(widget));
+    	*value = XtX(XtParent(widget));
     }
     converted_value = XmConvertUnits(widget,
 				     XmHORIZONTAL,
@@ -2363,7 +2234,7 @@ _XmManagerExportY(Widget widget, int offset, XtArgVal *value)
 
     if (XtIsManaged(widget) && XtParent(widget) && XmIsVendorShell(XtParent(widget)))
     {
-	*value = XtY(XtParent(widget));
+    	*value = XtY(XtParent(widget));
     }
     converted_value = XmConvertUnits(widget,
 				     XmVERTICAL,
@@ -2375,16 +2246,16 @@ _XmManagerExportY(Widget widget, int offset, XtArgVal *value)
 }
 
 #if XmVERSION > 1
-static XmDirection 
-get_direction(Widget w)
+static XmDirection get_direction(Widget w)
 {
     /* 
-       This macro obtains the layout direction resource even
-       though it looks like the string direction resource. 
-       In 2.0 layout direction replaced string direction
-       but the identifier in the internal data structure stayed
-       the same.  Everyone still with me. 8)
-     */
+      This macro obtains the layout direction resource even
+      though it looks like the string direction resource. 
+      In 2.0 layout direction replaced string direction
+      but the identifier in the internal data structure stayed
+      the same.  Everyone still with me. 8)
+    */
     return MGR_StringDirection(w);
 }
 #endif
+
