@@ -1,9 +1,8 @@
 /**
  *
- * $Id: MapEvent.c,v 1.19 2001/07/27 18:51:56 dannybackx Exp $
+ * $Id: MapEvent.c,v 1.13 1999/02/02 18:23:17 gritton Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: MapEvent.c,v 1.19 2001/07/27 18:51:56 dannybackx Exp $";
+static const char rcsid[] = "$Id: MapEvent.c,v 1.13 1999/02/02 18:23:17 gritton Exp $";
 
 /*
  * this code borrows heavily from TMparse.c.  The copyright there is as follows:
@@ -50,20 +49,23 @@ static const char rcsid[] = "$Id: MapEvent.c,v 1.19 2001/07/27 18:51:56 dannybac
  * SOFTWARE.
  */
 #include <LTconfig.h>
-
-#include <ctype.h>
-#include <stdlib.h>
-#include <string.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 
+#include <XmI/DebugUtil.h>
+
 #define XK_MISCELLANY
 #define XK_LATIN1
 #include <X11/keysymdef.h>
+#include <X11/Xfuncs.h>
 
-#include <XmI/DebugUtil.h>
+#include <ctype.h>
+#include <stdlib.h>
 
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
 
 #define COLON	':'
 
@@ -707,7 +709,7 @@ FetchModifierToken(String str, XrmQuark *token_return)
     if (start != str)
     {
 	char modStr[100];
-	memcpy(modStr, start, str-start);
+	bcopy(start, modStr, str-start);
 	modStr[str-start] = '\0';
 	*token_return = XrmStringToQuark(modStr);
 
@@ -843,7 +845,7 @@ ParseXtEventType(String str, EventPtr event, Cardinal *tmEventP, Boolean *error)
     char eventTypeStr[100];
 
     ScanAlphanumeric(str);
-    memcpy(eventTypeStr, start, str-start);
+    bcopy(start, eventTypeStr, str-start);
     eventTypeStr[str-start] = '\0';
     *tmEventP = LookupTMEventType(eventTypeStr,error);
     if (*error) 
@@ -1072,7 +1074,7 @@ ParseKeySym(String str, XP closure, EventPtr event, Boolean *error)
 	    str++;
 	}
 
-	memcpy(keySymName, start, str-start);
+	bcopy(start, keySymName, str-start);
 
 	keySymName[str-start] = '\0';
 
@@ -1115,7 +1117,7 @@ ParseTable(String str, XP closure, EventPtr event, Boolean *error)
 	return str;
     }
 
-    memcpy(tableSymName, start, str-start);
+    bcopy(start, tableSymName, str-start);
     tableSymName[str-start] = '\0';
 
     if (!_XtLookupTableSym((NameValueTable)closure, tableSymName, 
@@ -1172,7 +1174,7 @@ ParseAtom(String str, XP closure, EventPtr event, Boolean *error)
 	    return str;
 	}
 
-	memcpy(atomName, start, str-start);
+	bcopy(start, atomName, str-start);
 	atomName[str-start] = '\0';
 	event->event.eventCode = XrmStringToQuark(atomName);
     }
@@ -1608,13 +1610,13 @@ ParseRepeat(String str, int *reps, Boolean *plus, Boolean *error)
     {
 	String start = str;
 	char repStr[7];
-	size_t len;
+	int len;
 
 	ScanNumeric(str);
 	len = (str - start);
-	if (len < sizeof(repStr))
+	if (len < sizeof repStr)
 	{
-	    memcpy(repStr, start, len);
+	    bcopy(start, repStr, len);
 	    repStr[len] = '\0';
 	    *reps = StrToNum(repStr);
 	}
@@ -1769,7 +1771,7 @@ ParseEventSeq(String str, EventSeqPtr *eventSeqP, Boolean *error)
 static void
 PrintLateBindings(LateBindingsPtr late)
 {
-    DEBUGOUT(_LtDebug(__FILE__, NULL,
+    DEBUGOUT(XdbDebug(__FILE__, NULL,
 		      "LateBindings: knot: %d pair: %d, ref: %d KeySym %04x\n",
 		      late->knot, late->pair, late->ref_count, late->keysym));
 }
@@ -1777,15 +1779,15 @@ PrintLateBindings(LateBindingsPtr late)
 static void
 PrintEvent(Event *event)
 {
-    DEBUGOUT(_LtDebug(__FILE__, NULL,
+    DEBUGOUT(XdbDebug(__FILE__, NULL,
 		      "Event: modifiers: %08x modMask: %08x late: %p\n",
 		      event->modifiers, event->modifierMask,
 		      event->lateModifiers));
-    DEBUGOUT(_LtDebug(__FILE__, NULL,
+    DEBUGOUT(XdbDebug(__FILE__, NULL,
 		      "       eventType: %08x eventCode: %08x codeMask: %08x\n",
 		      event->eventType, event->eventCode,
 		      event->eventCodeMask));
-    DEBUGOUT(_LtDebug(__FILE__, NULL, "       standard: %d\n",
+    DEBUGOUT(XdbDebug(__FILE__, NULL, "       standard: %d\n",
 		      event->standard));
 
     if (event->lateModifiers)
@@ -1799,7 +1801,7 @@ PrintEventSeq(EventSeqPtr evs)
 {
     EventSeqPtr tmp;
 
-    DEBUGOUT(_LtDebug(__FILE__, NULL, "EventSequence:\n"));
+    DEBUGOUT(XdbDebug(__FILE__, NULL, "EventSequence:\n"));
     for (tmp = evs; tmp != NULL; tmp = tmp->next)
     {
 	PrintEvent(&evs->event);
@@ -1910,7 +1912,7 @@ _XmMapBtnEvent(String str, int *eventType,
 
     _XmTransParseInit();
 
-    DEBUGOUT(_LtDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
+    DEBUGOUT(XdbDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
 
     ParseEventSeq(str, &evs, &err);
 
@@ -1963,13 +1965,13 @@ _XmMapKeyEvent(String str, int *eventType,
 
     _XmTransParseInit();
 
-    DEBUGOUT(_LtDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
+    DEBUGOUT(XdbDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
 
     ParseEventSeq(str, &evs, &err);
 
     if (evs == NULL)
     {
-    	DEBUGOUT(_LtDebug(__FILE__, NULL, "MapKey got NULL sequence:\n"));
+    	DEBUGOUT(XdbDebug(__FILE__, NULL, "MapKey got NULL sequence:\n"));
 	FreeEventSeq(evs);
 
 	return False;
@@ -1983,7 +1985,7 @@ _XmMapKeyEvent(String str, int *eventType,
     err = SetLateModifier(_XmGetDefaultDisplay(), evs);
     if (err)
     {
-    	DEBUGOUT(_LtDebug(__FILE__, NULL, "MapKey got err sequence:\n"));
+    	DEBUGOUT(XdbDebug(__FILE__, NULL, "MapKey got err sequence:\n"));
 	FreeEventSeq(evs);
 
 	return False;
