@@ -1,9 +1,8 @@
 /**
  *
- * $Id: MessageB.c,v 1.42 2000/09/23 15:05:24 amai Exp $
+ * $Id: MessageB.c,v 1.37 1999/08/14 12:17:13 danny Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
- * Copyright (C) 1996-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,11 +22,12 @@
  *
  **/
 
-static const char rcsid[] = "$Id: MessageB.c,v 1.42 2000/09/23 15:05:24 amai Exp $";
+static const char rcsid[] = "$Id: MessageB.c,v 1.37 1999/08/14 12:17:13 danny Exp $";
 
 #include <LTconfig.h>
-
 #include <XmI/XmI.h>
+
+#include <X11/Xfuncs.h>
 #include <Xm/XmP.h>
 #include <Xm/MessageBP.h>
 #ifdef USE_WIDGETS
@@ -418,10 +418,6 @@ initialize(Widget request, Widget new_w,
     {
 	MB_OKButton(new_w) = NULL;
     }
-    if (MB_OKLabelString(new_w) != NULL)
-    {
-        MB_OKLabelString(new_w) = XmStringCopy(MB_OKLabelString(new_w));
-    }
 
     if (MB_DialogType(new_w) != XmDIALOG_TEMPLATE ||
 	MB_CancelLabelString(new_w) != NULL ||
@@ -436,10 +432,6 @@ initialize(Widget request, Widget new_w,
     {
 	BB_CancelButton(new_w) = NULL;
     }
-    if (MB_CancelLabelString(new_w) != NULL)
-    {
-        MB_CancelLabelString(new_w) = XmStringCopy(MB_CancelLabelString(new_w));
-    }
 
     if (MB_DialogType(new_w) != XmDIALOG_TEMPLATE ||
 	MB_HelpLabelString(new_w) != NULL ||
@@ -453,10 +445,6 @@ initialize(Widget request, Widget new_w,
     {
 	MB_HelpButton(new_w) = NULL;
     }
-    if (MB_HelpLabelString(new_w) != NULL)
-    {
-        MB_HelpLabelString(new_w) = XmStringCopy(MB_HelpLabelString(new_w));
-    }
 
     /* Remove auto_unmanage */
     if (MB_HelpButton(new_w))
@@ -543,18 +531,6 @@ destroy(Widget w)
     {
 	XmStringFree(MB_MessageString(w));
     }
-    if (MB_HelpLabelString(w))
-    {
-        XmStringFree(MB_HelpLabelString(w));
-    }
-    if (MB_CancelLabelString(w))
-    {
-        XmStringFree(MB_CancelLabelString(w));
-    }
-    if (MB_OKLabelString(w))
-    {
-        XmStringFree(MB_OKLabelString(w));
-    }
 }
 
 static void
@@ -874,55 +850,43 @@ XmMbSetSubresources(Widget new_w, Widget old, ArgList args, Cardinal *nargs)
     }
 
     if (MB_HelpButton(new_w) &&
-	MB_HelpLabelString(new_w) != MB_HelpLabelString(old))
+	MB_HelpLabelString(new_w) != MB_HelpLabelString(old) &&	/* Fast */
+	!XmStringCompare(MB_HelpLabelString(new_w), MB_HelpLabelString(old)))
     {
-        if (!XmStringCompare(MB_HelpLabelString(new_w), MB_HelpLabelString(old)))
-        {
-            Arg al[2];
+	Arg al[2];
 
-            XtSetArg(al[0], XmNlabelString, MB_HelpLabelString(new_w));
-            XtSetArg(al[1], XmNlabelType, XmSTRING);
-            XtSetValues(MB_HelpButton(new_w), al, 2);
+	XtSetArg(al[0], XmNlabelString, MB_HelpLabelString(new_w));
+	XtSetArg(al[1], XmNlabelType, XmSTRING);
+	XtSetValues(MB_HelpButton(new_w), al, 2);
 
-            refresh_needed = True;
-        }
-        MB_HelpLabelString(new_w) = XmStringCopy(MB_HelpLabelString(new_w));
-        XmStringFree(MB_HelpLabelString(old));
+	refresh_needed = True;
     }
 
     if (BB_CancelButton(new_w) &&
-	MB_CancelLabelString(new_w) != MB_CancelLabelString(old))
+	MB_CancelLabelString(new_w) != MB_CancelLabelString(old) && /* Fast */
+	!XmStringCompare(MB_CancelLabelString(new_w),
+			 MB_CancelLabelString(old)))
     {
-	if (!XmStringCompare(MB_CancelLabelString(new_w),
-                             MB_CancelLabelString(old)))
-        {
-            Arg al[2];
+	Arg al[2];
 
-            XtSetArg(al[0], XmNlabelString, MB_CancelLabelString(new_w));
-            XtSetArg(al[1], XmNlabelType, XmSTRING);
-            XtSetValues(BB_CancelButton(new_w), al, 2);
+	XtSetArg(al[0], XmNlabelString, MB_CancelLabelString(new_w));
+	XtSetArg(al[1], XmNlabelType, XmSTRING);
+	XtSetValues(BB_CancelButton(new_w), al, 2);
 
-            refresh_needed = True;
-        }
-        MB_CancelLabelString(new_w) = XmStringCopy(MB_CancelLabelString(new_w));
-        XmStringFree(MB_CancelLabelString(old));
+	refresh_needed = True;
     }
 
     if (MB_OKButton(new_w) &&
-	MB_OKLabelString(new_w) != MB_OKLabelString(old))
+	MB_OKLabelString(new_w) != MB_OKLabelString(old) && /* Fast */
+	!XmStringCompare(MB_OKLabelString(new_w), MB_OKLabelString(old)))
     {
-        if (!XmStringCompare(MB_OKLabelString(new_w), MB_OKLabelString(old)))
-        {
-            Arg al[2];
+	Arg al[2];
 
-            XtSetArg(al[0], XmNlabelString, MB_OKLabelString(new_w));
-            XtSetArg(al[1], XmNlabelType, XmSTRING);
-            XtSetValues(MB_OKButton(new_w), al, 2);
+	XtSetArg(al[0], XmNlabelString, MB_OKLabelString(new_w));
+	XtSetArg(al[1], XmNlabelType, XmSTRING);
+	XtSetValues(MB_OKButton(new_w), al, 2);
 
-            refresh_needed = True;
-        }
-        MB_OKLabelString(new_w) = XmStringCopy(MB_OKLabelString(new_w));
-        XmStringFree(MB_OKLabelString(old));
+	refresh_needed = True;
     }
 
     return refresh_needed;
@@ -1669,24 +1633,31 @@ XmMessageBoxGetChild(Widget parent,
     {
     case XmDIALOG_CANCEL_BUTTON:
 	return BB_CancelButton(mb);
+	break;
 
     case XmDIALOG_DEFAULT_BUTTON:
 	return BB_DefaultButton(mb);
+	break;
 
     case XmDIALOG_HELP_BUTTON:
 	return MB_HelpButton(mb);
+	break;
 
     case XmDIALOG_MESSAGE_LABEL:
 	return MB_Message(mb);
+	break;
 
     case XmDIALOG_OK_BUTTON:
 	return MB_OKButton(mb);
+	break;
 
     case XmDIALOG_SEPARATOR:
 	return MB_Separator(mb);
+	break;
 
     case XmDIALOG_SYMBOL_LABEL:
 	return MB_Symbol(mb);
+	break;
 
     default:
 	/* invalid child */
