@@ -1,9 +1,8 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/PanedW.c,v 1.52 2001/07/27 18:51:56 dannybackx Exp $
+ * $Id: PanedW.c,v 1.44 1998/11/16 02:00:11 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,14 +22,9 @@
  *
  **/
 
-static const char rcsid[] = "$Id: PanedW.c,v 1.52 2001/07/27 18:51:56 dannybackx Exp $";
+static const char rcsid[] = "$Id: PanedW.c,v 1.44 1998/11/16 02:00:11 rwscott Exp $";
 
 #include <LTconfig.h>
-
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -38,6 +32,9 @@ static const char rcsid[] = "$Id: PanedW.c,v 1.52 2001/07/27 18:51:56 dannybackx
 #include <Xm/PanedWP.h>
 #include <Xm/SashP.h>
 #include <Xm/SeparatorP.h>
+#include <X11/Xfuncs.h>
+#include <stdlib.h>
+#include <stdio.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -255,7 +252,7 @@ static Boolean constraint_set_values(Widget current,
 				     ArgList args,
 				     Cardinal *num_args);
 
-static Cardinal panedw_insert_position(Widget w);
+Cardinal panedw_insert_position(Widget w);
 
 /* helpers */
 static void _XmPanedWPreferredSize(Widget w, Widget child,
@@ -416,6 +413,7 @@ static XmSyntheticResource constraint_syn_resources[] =
 
 static void SashAction(Widget w, XtPointer client_data, XtPointer call_data);
 
+/* *INDENT-OFF* */
 #if 0
 static CompositeClassExtensionRec panedWCompositeExt = {
     /* next_extension */  NULL,
@@ -532,6 +530,7 @@ XmPanedWindowClassRec xmPanedWindowClassRec = {
 	/* extension */ NULL,
     },
 };
+/* *INDENT-ON* */
 
 
 WidgetClass xmPanedWindowWidgetClass = (WidgetClass)&xmPanedWindowClassRec;
@@ -572,7 +571,6 @@ ValidatePaneMin(Widget w)
     }
 }
 
-
 static void
 ValidatePaneMax(Widget w)
 {
@@ -592,7 +590,6 @@ ValidatePaneMax(Widget w)
     }
 }
 
-
 static Boolean
 AllPanesRealized(Widget w)
 {
@@ -623,7 +620,6 @@ class_initialize()
 }
 #endif
 
-
 static void
 class_part_initialize(WidgetClass widget_class)
 {
@@ -652,7 +648,6 @@ class_part_initialize(WidgetClass widget_class)
     _XmFastSubclassInit(widget_class, XmPANED_WINDOW_BIT);
 }
 
-
 static void
 CreateFlipGC(Widget w)
 {
@@ -668,12 +663,11 @@ CreateFlipGC(Widget w)
     PW_FlipGC(w) = XtGetGC(w, careabout, &gcv);
 }
 
-
 static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "%s:initialize(%d) - %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -683,7 +677,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     PW_StartY(new_w) = 0;
     PW_PaneCount(new_w) = 0;
@@ -700,12 +694,11 @@ initialize(Widget request, Widget new_w,
 						     PW_NumSlots(new_w));
 }
 
-
 static void
 constraint_initialize(Widget request, Widget new_w,
 		      ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebug2(__FILE__, XtParent(new_w), new_w,
+    DEBUGOUT(XdbDebug2(__FILE__, XtParent(new_w), new_w,
 		       "%s:constraint_initialize(%d) - %i args\n"
 		       "\trequest X %5i Y %5i W %5i H %5i\n"
 		       "\t  new_w X %5i Y %5i W %5i H %5i\n"
@@ -717,7 +710,7 @@ constraint_initialize(Widget request, Widget new_w,
 		       XtX(new_w), XtY(new_w),
 		       XtWidth(new_w), XtHeight(new_w),
 		       XtWidth(XtParent(new_w)), XtHeight(XtParent(new_w))));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     ValidatePaneMin(new_w);
     ValidatePaneMax(new_w);
@@ -743,7 +736,6 @@ destroy(Widget w)
     XtReleaseGC(w, PW_FlipGC(w));
 }
 
-
 static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
@@ -752,7 +744,7 @@ set_values(Widget old, Widget request, Widget new_w,
     Boolean redisplay = False;
     Arg argl[3];
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "PanedWindow set_values****************\n"));
 
     if (PW_SeparatorOn(new_w) != PW_SeparatorOn(old))
@@ -833,7 +825,6 @@ set_values(Widget old, Widget request, Widget new_w,
     return redisplay;
 }
 
-
 static void
 expose(Widget w, XEvent *event, Region region)
 {
@@ -859,7 +850,6 @@ expose(Widget w, XEvent *event, Region region)
     _XmRedisplayGadgets(w, event, region);
 }
 
-
 static Boolean
 constraint_set_values(Widget current, Widget request, Widget new_w,
 		      ArgList args, Cardinal *num_args)
@@ -868,7 +858,7 @@ constraint_set_values(Widget current, Widget request, Widget new_w,
     Boolean redisplay = False;
     int i;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w, "PanedWindow constraint_set_values\n"));
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "PanedWindow constraint_set_values\n"));
 
     if (!PWC_IsPane(current))
     {
@@ -933,18 +923,17 @@ constraint_set_values(Widget current, Widget request, Widget new_w,
 	redisplay = True;
     }
 
-    DEBUGOUT(_LtDebug(__FILE__, pw,
+    DEBUGOUT(XdbDebug(__FILE__, pw,
 		      "constraint_set_values: after PreferredSize\n"));
     return redisplay;
 }
 
-
 static void
 resize(Widget w)
 {
     XtWidgetGeometry geo;
 
-    DEBUGOUT(_LtDebug(__FILE__, w,
+    DEBUGOUT(XdbDebug(__FILE__, w,
 		      "PanedWindow Resize (%d %d)\n",
 		      XtWidth(w), XtHeight(w)));
 
@@ -955,7 +944,6 @@ resize(Widget w)
     _XmPanedWLayout(w, NULL, NULL, &geo, NULL, NULL, NULL);
 }
 
-
 static void
 realize(Widget w,
 	XtValueMask *value_mask,
@@ -965,7 +953,7 @@ realize(Widget w,
     XtWidgetGeometry geo;
     */
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
     	__FILE__, __LINE__,
     	XtWidth(w), XtHeight(w)));
 
@@ -996,7 +984,7 @@ realize(Widget w,
 /*
  * Insert panes before sashes and separators.
  */
-static Cardinal
+Cardinal
 panedw_insert_position(Widget w)
 {
     XmPanedWindowWidget pw = (XmPanedWindowWidget)XtParent(w);
@@ -1017,14 +1005,13 @@ panedw_insert_position(Widget w)
     return PWC_PositionIndex(w);
 }
 
-
 static void
 insert_child(Widget w)
 {
     XmPanedWindowWidget pw = (XmPanedWindowWidget)XtParent(w);
     int i;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:insert_child(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:insert_child(%d)\n",
 		      __FILE__, __LINE__));
 
     if (PW_RecursivelyCalled(pw))
@@ -1086,7 +1073,6 @@ insert_child(Widget w)
     PW_RecursivelyCalled(pw) = False;
 }
 
-
 static void
 delete_child(Widget w)
 {
@@ -1103,15 +1089,14 @@ delete_child(Widget w)
 #undef superclass
 }
 
-
 #if 0
 static XtGeometryResult
 query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *desired)
 {
     /* Motif does not have this method! */
-    DEBUGOUT(_LtDebug(__FILE__, w,
+    DEBUGOUT(XdbDebug(__FILE__, w,
 		      "QueryGeometry (request %s)\n",
-		      _LtDebugWidgetGeometry2String(proposed)));
+		      XdbWidgetGeometry2String(proposed)));
 
     _XmPanedWPreferredSize(w, NULL, NULL, desired);
 
@@ -1144,7 +1129,6 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *desired)
 }
 #endif
 
-
 static XtGeometryResult
 geometry_manager(Widget w,
 		 XtWidgetGeometry *request,
@@ -1155,17 +1139,17 @@ geometry_manager(Widget w,
     Widget pw = XtParent(w);
     XmKidGeometry boxes = NULL, sashes = NULL, seps = NULL;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "PanedW: geometry manager\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "PanedW: geometry manager\n"));
 
     if (AllPanesRealized(pw))
     {
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 			  "All panes realized in geom_manager\n"));
     }
 
     if (AllPanesRealized(pw) && !PWC_AllowResize(w) && XtIsManaged(pw))
     {
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 			  "Not allowing resize from geom_manager\n"));
 
 	return XtGeometryNo;
@@ -1180,7 +1164,7 @@ geometry_manager(Widget w,
 
     want = *request;
 
-    DEBUGOUT(_LtDebug(__FILE__, w,
+    DEBUGOUT(XdbDebug(__FILE__, w,
 		      "geom_mgr: child %s wants %d %d\n", XtName(w),
 		      request->width, request->height));
 
@@ -1188,7 +1172,7 @@ geometry_manager(Widget w,
 
     if (_XmMakeGeometryRequest(pw, &geo) == XtGeometryYes)
     {
-	DEBUGOUT(_LtDebug(__FILE__, pw,
+	DEBUGOUT(XdbDebug(__FILE__, pw,
 			  "We wanted %d %d and we got it\n",
 			  geo.width, geo.height));
     }
@@ -1196,7 +1180,7 @@ geometry_manager(Widget w,
     {
 	geo.width = XtWidth(pw);
 	geo.height = XtHeight(pw);
-	DEBUGOUT(_LtDebug(__FILE__, pw,
+	DEBUGOUT(XdbDebug(__FILE__, pw,
 			  "We didn't get our request, but %d %d\n",
 			  geo.width, geo.height));
     }
@@ -1232,7 +1216,7 @@ geometry_manager(Widget w,
 	    PWC_DHeight(w) = want.height;
 	}
 
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 			  "Child wanted %d and that's ok\n", want.height));
 
 	_XmSetKidGeo(boxes, w);
@@ -1252,20 +1236,19 @@ geometry_manager(Widget w,
 
     if (good == 0)
     {
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 			  "Child wanted %d (NO)\n", want.height));
 	return XtGeometryNo;
     }
     else
     {
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 			  "Child wanted %d (ALMOST)\n", want.height));
 	return XtGeometryAlmost;
     }
 #undef Wants
 }
 
-
 static int
 pi_sort(const void *a, const void *b)
 {
@@ -1275,18 +1258,17 @@ pi_sort(const void *a, const void *b)
     return PWC_PositionIndex(wa) - PWC_PositionIndex(wb);
 }
 
-
 static void
 change_managed(Widget w)
 {
     int i, j;
     XtWidgetGeometry geo;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "PanedWindow change_managed\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "PanedWindow change_managed\n"));
 
     if (PW_RecursivelyCalled(w))
     {
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 			  "ChangeManaged was recursively called\n"));
 	return;
     }
@@ -1313,7 +1295,7 @@ change_managed(Widget w)
 
 	    if ((PW_NumManagedChildren(w) - i) > 0)
 	    {
-		memcpy(&PW_ManagedChildren(w)[i], &PW_ManagedChildren(w)[i + 1],
+		bcopy(&PW_ManagedChildren(w)[i + 1], &PW_ManagedChildren(w)[i],
 		      sizeof(Widget) * (PW_NumManagedChildren(w) - i));
 	    }
 	}
@@ -1347,7 +1329,7 @@ change_managed(Widget w)
 
 		PW_PaneCount(w)++;
 
-		DEBUGOUT(_LtDebug(__FILE__, MGR_Children(w)[i],
+		DEBUGOUT(XdbDebug(__FILE__, MGR_Children(w)[i],
 				  "Setting DHeight in change_managed to %d:"
 				  " was %d\n",
 				  XtHeight(MGR_Children(w)[i]),
@@ -1358,7 +1340,7 @@ change_managed(Widget w)
 		{
 		    PW_NumSlots(w) *= 2;
 		    PW_ManagedChildren(w) =
-			(WidgetList)XtRealloc((char *)PW_ManagedChildren(w),
+			(WidgetList)XtRealloc((void *)PW_ManagedChildren(w),
 					      sizeof(Widget) * PW_NumSlots(w));
 		}
 
@@ -1432,7 +1414,7 @@ change_managed(Widget w)
 	    CoreConstraints(PW_ManagedChildren(w)[PW_NumManagedChildren(w) - 1]);
     }
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "Compute size in change_managed\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "Compute size in change_managed\n"));
 
     _XmPanedWPreferredSize(w, NULL, NULL, &geo);
 
@@ -1450,7 +1432,6 @@ change_managed(Widget w)
     _XmNavigChangeManaged(w);
 }
 
-
 #if 0
 static Boolean
 traversal_children(Widget mw, Widget **children, Cardinal *num_children)
@@ -1486,8 +1467,7 @@ traversal_children(Widget mw, Widget **children, Cardinal *num_children)
 
     return True;
 }
-#endif /* #if 0*/
-
+#endif
 
 static void
 _XmPanedWPreferredSize(Widget w, Widget rchild,
@@ -1497,7 +1477,7 @@ _XmPanedWPreferredSize(Widget w, Widget rchild,
     int i;
     Dimension curw, curh;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "_XmPanedWPreferredSize\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "_XmPanedWPreferredSize\n"));
 
     /* Find widest child and compute total height of PanedWindow */
     curw = curh = 0;
@@ -1506,7 +1486,7 @@ _XmPanedWPreferredSize(Widget w, Widget rchild,
 
 	child = PW_ManagedChildren(w)[i];
 
-	DEBUGOUT(_LtDebug2(__FILE__, w, child,
+	DEBUGOUT(XdbDebug2(__FILE__, w, child,
 			   "_XmPanedWPreferredSize: child wid %d ht %d "
 			   "pref.ht. %d panemin %d panemax %d\n",
 			   XtWidth(child), XtHeight(child),
@@ -1516,7 +1496,7 @@ _XmPanedWPreferredSize(Widget w, Widget rchild,
 	if (rchild != NULL && child == rchild && childgeom != NULL &&
 	    childgeom->request_mode & CWWidth)
 	{
-	    DEBUGOUT(_LtDebug(__FILE__, w, "Using childgeom width: %d\n",
+	    DEBUGOUT(XdbDebug(__FILE__, w, "Using childgeom width: %d\n",
 			      childgeom->width));
 	    curw = curw >= childgeom->width ? curw : childgeom->width;
 	}
@@ -1533,7 +1513,7 @@ _XmPanedWPreferredSize(Widget w, Widget rchild,
 	if (rchild != NULL && child == rchild && childgeom != NULL &&
 	    childgeom->request_mode & CWHeight)
 	{
-	    DEBUGOUT(_LtDebug(__FILE__, w, "Using childgeom height: %d\n",
+	    DEBUGOUT(XdbDebug(__FILE__, w, "Using childgeom height: %d\n",
 			      childgeom->height));
 	    curh += _XmMax(childgeom->height, PWC_PaneMinimum(child));
 	}
@@ -1546,7 +1526,7 @@ _XmPanedWPreferredSize(Widget w, Widget rchild,
     curh += 2 * PW_MarginHeight(w);
     curw += 2 * PW_MarginWidth(w);
 
-    DEBUGOUT(_LtDebug(__FILE__, w,
+    DEBUGOUT(XdbDebug(__FILE__, w,
 		      "_XmPanedWPreferredSize: computed %d %d\n",
 		      curw, curh));
 
@@ -1555,7 +1535,6 @@ _XmPanedWPreferredSize(Widget w, Widget rchild,
     pwg->request_mode = CWWidth | CWHeight;
 }
 
-
 static void
 _XmPanedWLayout(Widget w, Widget rchild,
 		XtWidgetGeometry *childgeom, XtWidgetGeometry *pwg,
@@ -1763,7 +1742,6 @@ _XmPanedWLayout(Widget w, Widget rchild,
     }
 }
 
-
 static void
 MoveBorder(Widget pw, Widget sash, int dy)
 {
@@ -1788,14 +1766,14 @@ MoveBorder(Widget pw, Widget sash, int dy)
 	/* Move up? */
 	if (dy < 0)
 	{
-	    DEBUGOUT(_LtDebug(__FILE__, pw,
+	    DEBUGOUT(XdbDebug(__FILE__, pw,
 			      "Move up: %d %d %d %d %d\n",
 			      PWC_DHeight(panea), dy, PWC_PaneMaximum(panea),
 			      PWC_DHeight(paneb), PWC_PaneMinimum(paneb)));
 
 	    if ((XtHeight(paneb) - dy) < PWC_PaneMaximum(paneb))
 	    {
-		DEBUGOUT(_LtDebug(__FILE__, paneb, "Widget can grow\n"));
+		DEBUGOUT(XdbDebug(__FILE__, paneb, "Widget can grow\n"));
 
 		/*
 		 * can panea absorb the change?  If so, then adjust paneb's
@@ -1803,7 +1781,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		 */
 		if ((XtHeight(panea) + dy) > PWC_PaneMinimum(panea))
 		{
-		    DEBUGOUT(_LtDebug(__FILE__, panea,
+		    DEBUGOUT(XdbDebug(__FILE__, panea,
 				      "Widget can shrink to compensate\n"));
 
 		    cons = PW_BottomPane(pw);
@@ -1831,7 +1809,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		 */
 		else if (XtHeight(panea) > PWC_PaneMinimum(panea))
 		{
-		    DEBUGOUT(_LtDebug(__FILE__, panea,
+		    DEBUGOUT(XdbDebug(__FILE__, panea,
 				      "Widget can partially compensate\n"));
 
 		    dy += XtHeight(panea) - PWC_PaneMinimum(panea);
@@ -1859,7 +1837,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		    sash = PWC_Sash(PW_ManagedChildren(pw)[PWC_Position(panea) - 1]);
 		    panea = PWC_Sash(sash);
 
-		    DEBUGOUT(_LtDebug(__FILE__, paneb,
+		    DEBUGOUT(XdbDebug(__FILE__, paneb,
 				      "And we'll try to pass it off\n"));
 
 		    PW_TopPane(pw) = (XmPanedWindowConstraintPtr)
@@ -1870,7 +1848,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		 */
 		else
 		{
-		    DEBUGOUT(_LtDebug(__FILE__, pw,
+		    DEBUGOUT(XdbDebug(__FILE__, pw,
 				      "No more panes above\n"));
 		    return;
 		}
@@ -1887,7 +1865,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		    sash = PWC_Sash(paneb);
 		    paneb = PW_ManagedChildren(pw)[PWC_Position(PWC_Sash(sash)) + 1];
 
-		    DEBUGOUT(_LtDebug(__FILE__, paneb,
+		    DEBUGOUT(XdbDebug(__FILE__, paneb,
 				      "And we'll try to pass it off\n"));
 
 		    PW_BottomPane(pw) = (XmPanedWindowConstraintPtr)
@@ -1895,7 +1873,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		}
 		else
 		{
-		    DEBUGOUT(_LtDebug(__FILE__, paneb, "Can't grow\n"));
+		    DEBUGOUT(XdbDebug(__FILE__, paneb, "Can't grow\n"));
 		    return;
 		}
 	    }
@@ -1903,7 +1881,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 	/* move down? */
 	else if (dy > 0)
 	{
-	    DEBUGOUT(_LtDebug(__FILE__, pw,
+	    DEBUGOUT(XdbDebug(__FILE__, pw,
 			      "Move down: %d %d %d %d %d\n",
 			      PWC_DHeight(panea), dy, PWC_PaneMaximum(panea),
 			      PWC_DHeight(paneb), PWC_PaneMinimum(paneb)));
@@ -1911,7 +1889,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 	    /* can panea grow? */
 	    if ((XtHeight(panea) + dy) < PWC_PaneMaximum(panea))
 	    {
-		DEBUGOUT(_LtDebug(__FILE__, panea, "Pane can grow\n"));
+		DEBUGOUT(XdbDebug(__FILE__, panea, "Pane can grow\n"));
 
 		/*
 		 * can paneb absorb the change?  If so, increate panea's
@@ -1919,7 +1897,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		 */
 		if ((XtHeight(paneb) - dy) > PWC_PaneMinimum(paneb))
 		{
-		    DEBUGOUT(_LtDebug(__FILE__, paneb,
+		    DEBUGOUT(XdbDebug(__FILE__, paneb,
 				  "And this pane can shrink to compensate\n"));
 
 		    XtHeight(paneb) -= dy;
@@ -1947,7 +1925,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		 */
 		else if (XtHeight(paneb) > PWC_PaneMinimum(paneb))
 		{
-		    DEBUGOUT(_LtDebug(__FILE__, paneb,
+		    DEBUGOUT(XdbDebug(__FILE__, paneb,
 				  "And this pane can partially compensate\n"));
 
 		    dy -= XtHeight(paneb) - PWC_PaneMinimum(paneb);
@@ -1976,7 +1954,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		    sash = PWC_Sash(paneb);
 		    paneb = PW_ManagedChildren(pw)[PWC_Position(PWC_Sash(sash)) + 1];
 
-		    DEBUGOUT(_LtDebug(__FILE__, paneb,
+		    DEBUGOUT(XdbDebug(__FILE__, paneb,
 				      "And we'll try to pass it off\n"));
 
 		    PW_BottomPane(pw) = (XmPanedWindowConstraintPtr)
@@ -1987,7 +1965,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		 */
 		else
 		{
-		    DEBUGOUT(_LtDebug(__FILE__, pw, "No more panes below\n"));
+		    DEBUGOUT(XdbDebug(__FILE__, pw, "No more panes below\n"));
 		    return;
 		}
 	    }
@@ -2003,7 +1981,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		    sash = PWC_Sash(PW_ManagedChildren(pw)[PWC_Position(panea) - 1]);
 		    panea = PWC_Sash(sash);
 
-		    DEBUGOUT(_LtDebug(__FILE__, paneb,
+		    DEBUGOUT(XdbDebug(__FILE__, paneb,
 				      "And we'll try to pass it off\n"));
 
 		    PW_TopPane(pw) = (XmPanedWindowConstraintPtr)
@@ -2011,7 +1989,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		}
 		else
 		{
-		    DEBUGOUT(_LtDebug(__FILE__, panea, "Pane can't grow\n"));
+		    DEBUGOUT(XdbDebug(__FILE__, panea, "Pane can't grow\n"));
 
 		    return;
 		}
@@ -2020,14 +1998,13 @@ MoveBorder(Widget pw, Widget sash, int dy)
 	/* no motion, bail out */
 	else
 	{
-	    DEBUGOUT(_LtDebug(__FILE__, pw, "No motion\n"));
+	    DEBUGOUT(XdbDebug(__FILE__, pw, "No motion\n"));
 
 	    return;
 	}
     }
 }
 
-
 static void
 SashAction(Widget w, XtPointer client_data, XtPointer call_data)
 {
@@ -2063,7 +2040,7 @@ SashAction(Widget w, XtPointer client_data, XtPointer call_data)
 
 	    }
 
-	    DEBUGOUT(_LtDebug(__FILE__, child,
+	    DEBUGOUT(XdbDebug(__FILE__, child,
 			      "SashAction places child %dx%d, size %d/%d\n",
 			      XtX(child), PWC_DY(child),
 			      XtWidth(child), XtHeight(child)));
@@ -2103,7 +2080,7 @@ SashAction(Widget w, XtPointer client_data, XtPointer call_data)
 		sash = PWC_Sash(child);
 		if (sash)
 		{
-		    DEBUGOUT(_LtDebug(__FILE__, pw,
+		    DEBUGOUT(XdbDebug(__FILE__, pw,
 				      "moving sash to : %d %d w = %d h = %d\n",
 				      XtWidth(pw) - PW_MarginWidth(pw) +
 				      PW_SashIndent(pw) - PW_SashWidth(pw),
