@@ -1,9 +1,8 @@
 /**
  *
- * $Id: Primitive.c,v 1.44 2000/09/29 22:51:55 amai Exp $
+ * $Id: Primitive.c,v 1.42 1999/08/15 17:17:10 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,10 +22,9 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Primitive.c,v 1.44 2000/09/29 22:51:55 amai Exp $";
+static const char rcsid[] = "$Id: Primitive.c,v 1.42 1999/08/15 17:17:10 rwscott Exp $";
 
 #include <LTconfig.h>
-
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -36,14 +34,14 @@ static const char rcsid[] = "$Id: Primitive.c,v 1.44 2000/09/29 22:51:55 amai Ex
 #include <Xm/ManagerP.h>
 #include <Xm/TransltnsP.h>
 #include <Xm/VirtKeysP.h>
+
+#include <XmI/DebugUtil.h>
+
 #if XmVERSION > 1
 /* Includes for 2.0 features */
 #include <XmI/DirectionI.h>
 #endif
 
-#include <XmI/DebugUtil.h>
-
-
 /* Forward Declarations */
 
 static void class_initialize(void);
@@ -190,6 +188,8 @@ static XtResource resources[] =
 	XmRImmediate, (XtPointer)NULL
     }
 
+#if LESSTIF_BACK_COMPAT
+#else
 #if XmVERSION > 1
     ,{
 	XmNconvertCallback, XmCCallback, XmRCallback,
@@ -207,6 +207,7 @@ static XtResource resources[] =
 	XmRCallProc, (XtPointer)_XmDirectionDefault
     }
 #endif
+#endif
 
 };
 
