@@ -1,9 +1,8 @@
 /**
  *
- * $Id: PushB.c,v 1.81 2001/07/27 18:51:56 dannybackx Exp $
+ * $Id: PushB.c,v 1.72 1999/08/14 09:59:25 danny Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,13 +22,11 @@
  *
  **/
 
-static const char rcsid[] = "$Id: PushB.c,v 1.81 2001/07/27 18:51:56 dannybackx Exp $";
+static const char rcsid[] = "$Id: PushB.c,v 1.72 1999/08/14 09:59:25 danny Exp $";
 
 #include <LTconfig.h>
-
-#include <stdarg.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/PushBP.h>
 #include <Xm/RepType.h>
@@ -39,15 +36,19 @@ static const char rcsid[] = "$Id: PushB.c,v 1.81 2001/07/27 18:51:56 dannybackx
 #include <Xm/MenuShell.h>
 #include <Xm/CascadeB.h>
 #include <Xm/CascadeBG.h>
-#if XmVERSION > 1
-#include <Xm/TraitP.h>
-#include <Xm/ActivatableT.h>
+
+#ifndef __STDC__
+#include <varargs.h>
+#else
+#include <stdarg.h>
 #endif
 
 #include <XmI/DebugUtil.h>
 
-
 #if XmVERSION > 1
+#include <Xm/TraitP.h>
+#include <Xm/ActivatableT.h>
+
 void _XmPushB_TraitAddCallback(Widget, XtCallbackProc, XtPointer, Boolean);
 
 static XmActivatableTraitRec _XmPushBTraitRec = {
@@ -352,8 +353,8 @@ class_initialize(void)
     _XmPushBCoreClassExtRec.record_type = XmQmotif;
 
 #if XmVERSION > 1
-	if (! XmeTraitSet((XtPointer)xmPushButtonWidgetClass, XmQTactivatable,
-			(XtPointer)&_XmPushBTraitRec)) {
+	if (! XmeTraitSet(xmPushButtonWidgetClass, XmQTactivatable,
+			&_XmPushBTraitRec)) {
 		_XmWarning(NULL,
 			"XmPushButton ClassInitialize: XmeTraitSet failed\n");
 	}
@@ -450,7 +451,7 @@ initialize(Widget request, Widget new_w,
 {
     Dimension margin, width, height;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "initialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -459,7 +460,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     /* check the RepType resources */
     if (PB_MultiClick(new_w) == (unsigned char)XmUNSPECIFIED ||
@@ -552,10 +553,8 @@ initialize(Widget request, Widget new_w,
 
 	    Lab_TextRect_x(new_w) += margin;
 	    Lab_TextRect_y(new_w) += margin;
-	    if (Lab_AcceleratorText(new_w)) {
-		Lab_AccTextRect(new_w).x += margin;
-		Lab_AccTextRect(new_w).y += margin;
-	    }
+	    Lab_AccTextRect(new_w).x += margin;
+	    Lab_AccTextRect(new_w).y += margin;
 
 	    /* rws 19 Aug 1997
 	     * This does not seem to make sense! Without this the width and
@@ -572,7 +571,7 @@ initialize(Widget request, Widget new_w,
 	    XtWidth(request) = XtWidth(new_w);
 #endif
 
-	    DEBUGOUT(_LtDebug(__FILE__, new_w,
+	    DEBUGOUT(XdbDebug(__FILE__, new_w,
 			      "adjust margins for default button\n"
 			      "\trequest X %5i Y %5i W %5i H %5i\n"
 			      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -592,7 +591,6 @@ destroy(Widget w)
     if (PB_Timer(w) != 0)
     {
 	XtRemoveTimeOut(PB_Timer(w));
-	PB_Timer(w) = 0;
     }
 
     XtReleaseGC(w, PB_FillGC(w));
@@ -606,7 +604,7 @@ set_values(Widget old, Widget request, Widget new_w,
     Boolean refresh_needed = False;
     Dimension margin, width, height;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -618,7 +616,7 @@ set_values(Widget old, Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     /* check the RepType resources */
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRMultiClick),
@@ -704,10 +702,8 @@ set_values(Widget old, Widget request, Widget new_w,
 
 	    Lab_TextRect_x(new_w) += margin;
 	    Lab_TextRect_y(new_w) += margin;
-	    if (Lab_AcceleratorText(new_w) != NULL) {
-		Lab_AccTextRect(new_w).x += margin;
-		Lab_AccTextRect(new_w).y += margin;
-	    }
+	    Lab_AccTextRect(new_w).x += margin;
+	    Lab_AccTextRect(new_w).y += margin;
 #endif
 	    refresh_needed = True;
 	}
@@ -834,7 +830,7 @@ expose(Widget w, XEvent *event, Region region)
 	return;
     }
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "PB expose\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "PB expose\n"));
 
     if (!IN_MENU(w))
     {
@@ -843,7 +839,7 @@ expose(Widget w, XEvent *event, Region region)
 	    inset += Xm3D_ENHANCE_PIXEL + Lab_Shadow(w)
 		  + (PB_DefaultButtonShadow(w) << 1);
 
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 			  "x %d y %d w %d h %d b %d\n",
 			  inset, inset,
 			  (XtWidth(w) - (inset << 1)),
@@ -1019,8 +1015,8 @@ Activate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XmPushButtonCallbackStruct cbs;
     XButtonEvent *ev = (XButtonEvent *)event;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "Activate()\n"));
-    DEBUGOUT(_LtDebug("ENTRY", w, "Activate()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "Activate()\n"));
+    DEBUGOUT(XdbDebug("ENTRY", w, "Activate()\n"));
 
     /*
      * This test also broke Accelerators. Refined as well.
@@ -1108,7 +1104,7 @@ ArmTimeout(XtPointer data, XtIntervalId *id)
 {
     Widget w = (Widget)data;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "ArmTimeout\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "ArmTimeout\n"));
 
     PB_Timer(w) = 0;
 
@@ -1125,8 +1121,8 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XmPushButtonCallbackStruct cbs;
     Boolean poppedUp;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "ArmAndActivate\n"));
-    DEBUGOUT(_LtDebug("MENU", w, "%s:ArmAndActivate(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "ArmAndActivate\n"));
+    DEBUGOUT(XdbDebug("MENU", w, "%s:ArmAndActivate(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -1172,7 +1168,6 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 	if (PB_Timer(w) != 0)
 	{
 	    XtRemoveTimeOut(PB_Timer(w));
-	    PB_Timer(w) = 0;
 	}
 
 	PB_Timer(w) = XtAppAddTimeOut(XtWidgetToApplicationContext(w),
@@ -1196,8 +1191,8 @@ EnterWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "PushB Enter\n"));
-    DEBUGOUT(_LtDebug("MENU", w, "%s:EnterWindow(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "PushB Enter\n"));
+    DEBUGOUT(XdbDebug("MENU", w, "%s:EnterWindow(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -1245,8 +1240,8 @@ LeaveWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "LeaveWindow()\n"));
-    DEBUGOUT(_LtDebug("MENU", w, "%s:LeaveWindow(%d) - %s %s %s\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "LeaveWindow()\n"));
+    DEBUGOUT(XdbDebug("MENU", w, "%s:LeaveWindow(%d) - %s %s %s\n",
     	__FILE__, __LINE__,
     	IN_MENU(w) ? "menu" : "no-menu",
     	IN_MENU(w) && _XmGetInDragMode(w) ? "dragging" : "not-dragging",
@@ -1300,9 +1295,9 @@ ButtonUp(Widget w,
     Boolean validButton, poppedUp;
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s(%d) - ButtonUp()\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s(%d) - ButtonUp()\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(_LtDebug("MENU", w, "%s:ButtonUp(%d)\n",
+    DEBUGOUT(XdbDebug("MENU", w, "%s:ButtonUp(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -1317,9 +1312,9 @@ ButtonUp(Widget w,
     {
 	validButton = False;
     }
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s(%d):ButtonUp() - valid %s %ix%i\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s(%d):ButtonUp() - valid %s %ix%i\n",
     	__FILE__, __LINE__,
-    	_LtDebugBoolean2String(validButton),
+    	XdbBoolean2String(validButton),
     	event->xbutton.x, event->xbutton.y));
 
     if (!validButton)
@@ -1385,8 +1380,8 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XmPushButtonCallbackStruct cbs;
     Boolean poppedUp;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "ButtonDown()\n"));
-    DEBUGOUT(_LtDebug("MENU", w, "%s:ButtonDown(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "ButtonDown()\n"));
+    DEBUGOUT(XdbDebug("MENU", w, "%s:ButtonDown(%d)\n",
     	__FILE__, __LINE__
     	));
     /* queue events until the next button event */
@@ -1398,7 +1393,7 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
 
 	if (!validButton)
 	{
-	    DEBUGOUT(_LtDebug(__FILE__, w, "ButtonDown() - Invalid button\n"));
+	    DEBUGOUT(XdbDebug(__FILE__, w, "ButtonDown() - Invalid button\n"));
 	    return;
 	}
     }
@@ -1407,7 +1402,7 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
 
     RC_MenuShellPopdown(w, event, &poppedUp);
     {
-    Cardinal i;
+    int i;
     Widget menu = XtParent(w);
 
 	for (i = 0; i < MGR_NumChildren(menu); i++)
@@ -1453,7 +1448,7 @@ MultiActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XButtonEvent *ev = (XButtonEvent *)event;
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "PushB: MultiClick\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "PushB: MultiClick\n"));
 
     if (PB_MultiClick(w) == XmMULTICLICK_KEEP)
     {
@@ -1503,7 +1498,7 @@ MultiActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 MultiArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "PushB: MultiArm\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "PushB: MultiArm\n"));
 
     if (PB_MultiClick(w) == XmMULTICLICK_KEEP)
 	Arm(w, event, NULL, NULL);
@@ -1512,7 +1507,7 @@ MultiArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 KeySelect(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "KeySelect\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "KeySelect\n"));
 
     /* FIX ME */
 }
@@ -1525,6 +1520,7 @@ _XmClearBCompatibility(Widget w)
     _XmObjectUnlock(w);
 }
 
+#ifdef __STDC__
 static void
 MenuProcEntry(int proc, Widget w,...)
 {
@@ -1532,6 +1528,17 @@ MenuProcEntry(int proc, Widget w,...)
     Cardinal num_params = 0;
 
     va_start(arg_list, w);
+#else
+MenuProcEntry(proc, w, va_alist)
+     int proc;
+     Widget w;
+     va_dcl
+{
+    va_list arglist;
+    Cardinal num_params = 0;
+
+    va_start(arglist);
+#endif
 
     switch (proc)
     {
