@@ -1,9 +1,8 @@
 /**
  *
- * $Id: RCUtils.c,v 1.108 2000/09/23 15:05:25 amai Exp $
+ * $Id: RCUtils.c,v 1.106 1999/10/27 02:13:25 rwscott Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
- * Copyright (C) 1996-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,15 +22,12 @@
  *
  **/
 
-static const char rcsid[] = "$Id: RCUtils.c,v 1.108 2000/09/23 15:05:25 amai Exp $";
+static const char rcsid[] = "$Id: RCUtils.c,v 1.106 1999/10/27 02:13:25 rwscott Exp $";
 
 #include <LTconfig.h>
-
-#include <stdio.h>
-#include <string.h>
-#include <stdarg.h>
-
 #include <XmI/XmI.h>
+
+#include <X11/Xfuncs.h>
 #include <Xm/XmP.h>
 #include <Xm/BaseClassP.h>
 #include <Xm/CascadeBP.h>
@@ -54,6 +50,11 @@ static const char rcsid[] = "$Id: RCUtils.c,v 1.108 2000/09/23 15:05:25 amai Exp
 #include <Xm/ToggleBGP.h>
 #include <Xm/TransltnsP.h>
 
+#include <stdio.h>
+#include <string.h>
+#include <stdarg.h>
+#include <assert.h>
+
 #include <XmI/DebugUtil.h>
 
 /*
