@@ -1,9 +1,8 @@
 /**
  *
- * $Id: Region.c,v 1.7 2000/09/23 15:05:25 amai Exp $
+ * $Id: Region.c,v 1.5 1999/02/02 18:23:23 gritton Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,12 +21,12 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  **/
-static const char rcsid[] = "$Id: Region.c,v 1.7 2000/09/23 15:05:25 amai Exp $";
-
-#include <LTconfig.h>
+static const char rcsid[] = "$Id: Region.c,v 1.5 1999/02/02 18:23:23 gritton Exp $";
 
+#include <stdio.h>
 #include <stdlib.h>
 
+#include <LTconfig.h>
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
 
@@ -282,7 +281,7 @@ _XmRegionIntersectRectWithRegion(XRectangle *rect,
 	    continue;
 	}
 
-/*	printf("Rectangle %d intersects\n", i); */
+	printf("Rectangle %d intersects\n", i);
 
 	/* if we're here the rectangles intersect */
 
