@@ -1,9 +1,8 @@
 /**
  *
- * $Id: RepType.c,v 1.14 2000/11/06 09:40:17 amai Exp $
+ * $Id: RepType.c,v 1.10 1999/02/02 18:23:24 gritton Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,18 +21,23 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  **/
-static const char rcsid[] = "$Id: RepType.c,v 1.14 2000/11/06 09:40:17 amai Exp $";
+static const char rcsid[] = "$Id: RepType.c,v 1.10 1999/02/02 18:23:24 gritton Exp $";
 
 #include <LTconfig.h>
-
-#include <stdio.h>
-#include <string.h>
-#include <ctype.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/RepType.h>
 
+#include <stdio.h>
+#ifdef HAVE_STRING_H
+#define ANSI_STRING
+#include <string.h>
+#else
+#include <strings.h>
+#endif
+#include <ctype.h>
+
 #include <XmI/DebugUtil.h>
 
 static XmRepTypeList rep_types = NULL;
@@ -553,7 +557,7 @@ XmRepTypeRegister(String rep_type,
     /* now install the forward converter */
 
     Args[0].address_mode = XtImmediate;
-    Args[0].address_id = (XtPointer)(long)number_of_types;
+    Args[0].address_id = (XtPointer)number_of_types;
     Args[0].size = sizeof(XmRepTypeId);
 
     XtSetTypeConverter(XmRString, rep_type,
