@@ -1,9 +1,8 @@
 /**
  *
- * $Id: ResConvert.c,v 1.77 2001/08/05 09:25:56 dannybackx Exp $
+ * $Id: ResConvert.c,v 1.53 1999/10/26 09:25:10 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,15 +22,22 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ResConvert.c,v 1.77 2001/08/05 09:25:56 dannybackx Exp $";
+static const char rcsid[] = "$Id: ResConvert.c,v 1.53 1999/10/26 09:25:10 amai Exp $";
 
 #include <LTconfig.h>
 
 #include <stdio.h>
 #include <stdlib.h>
+#ifdef __STDC__
 #include <stdarg.h>
+#else
+#include <varargs.h>
+#endif
 #include <ctype.h>
+
+#ifdef HAVE_STRING_H
 #include <string.h>
+#endif
 
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
@@ -42,11 +48,15 @@ static const char rcsid[] = "$Id: ResConvert.c,v 1.77 2001/08/05 09:25:56 dannyb
 #include <Xm/VendorSEP.h>
 #include <Xm/ExtObjectP.h>
 #include <Xm/XmosP.h>
-
-#include "LTmisc.h"
+#include <X11/Xfuncs.h>
 
 #include <XmI/DebugUtil.h>
 
+#include "LTmisc.h"
+
+#ifndef XmUNSPECIFIED
+#define XmUNSPECIFIED (~0)
+#endif
 
 enum
 {
@@ -106,8 +116,7 @@ static Boolean _XmCvtStringToRenderTable(Display *display, XrmValue *args,
 		       XtPointer *converter_data);
 #endif
 
-
-int xmUseVersion = 0;
+int	xmUseVersion = 0;
 
 /* please be careful if you're editting these arrays, as
  * the strings have to be in the _same_ order as the
@@ -276,11 +285,6 @@ static char *unit_types[] =
     "100th_font_units"
 };
 
-/*
- * These are the values of XmNdialogType for XmMessageBox
- *	This is the value type XmRDialogType.
- *	The class of this resource is XmCDialogType.
- */
 static char *dialog_types[] =
 {
     "dialog_template",
@@ -292,19 +296,6 @@ static char *dialog_types[] =
     "dialog_working"
 };
 
-/*
- * These are the values of XmNdialogType for XmSelectionBox
- *	This is the value type XmRSelectionType.
- *	The class of this resource is (also) XmCDialogType
- */
-static char *selection_dialog_types[] = {
-	"dialog_work_area",
-	"dialog_prompt",
-	"dialog_selection",
-	"dialog_command",
-	"dialog_file_selection",
-};
-
 static char *dialog_styles[] =
 {
     "dialog_modeless",
@@ -541,13 +532,12 @@ static char *spb_arrow_layouts[] =
 
 static unsigned char spb_arrow_layout_values[] =
 {
-    XmARROWS_END,
     XmARROWS_BEGINNING,
-    XmARROWS_SPLIT,
-    XmARROWS_FLAT_END,
-    XmARROWS_FLAT_BEGINNING
+    XmARROWS_END,
+    XmARROWS_SPLIT
 };
 
+#if XmVERSION > 1
 /* Notebook */
 static char *nb_child_types[] =
 {
@@ -568,6 +558,7 @@ static unsigned char nb_child_type_values[] =
     XmSTATUS_AREA, 
     XmPAGE_SCROLLER
 };
+#endif
 
 static char *indicator_on[] =
 {
@@ -605,10 +596,9 @@ static unsigned char indicator_on_values[] =
     XmINDICATOR_FILL,		/* yes */
 };
 
-#endif /* XmVERSION > 1 */
+#endif
 
-
-extern void
+void
 XmRegisterConverters(void)
 {
     /* don't really know the difference between the two, so
@@ -617,8 +607,7 @@ XmRegisterConverters(void)
     _XmRegisterConverters();
 }
 
-
-extern void
+void
 _XmRegisterConverters(void)
 {
     static Boolean first = True;
@@ -656,6 +645,10 @@ _XmRegisterConverters(void)
 	    0
 	}};
 
+#ifdef NONSTANDARD_CONVERTERS
+    extern void _XmRegisterNSEConverters(void);
+#endif
+
     if (first)
     {
 	first = False;
@@ -703,7 +696,7 @@ _XmRegisterConverters(void)
     REPTYPE_REGISTER(XmRDragReceiverProtocolStyle, protocol_styles);
     REPTYPE_REGISTER(XmRUnitType, unit_types);
     REPTYPE_REGISTER(XmRDialogType, dialog_types);
-    REPTYPE_REGISTER(XmRSelectionType, selection_dialog_types);
+    REPTYPE_REGISTER(XmRSelectionType, dialog_types);
     REPTYPE_REGISTER(XmRDialogStyle, dialog_styles);
     REPTYPE_REGISTER(XmRSeparatorType, separator_types);
     REPTYPE_REGISTER(XmRResizePolicy, resize_policies);
@@ -998,182 +991,132 @@ _XmRegisterConverters(void)
 #endif
 }
 
-
 /*
  * error convenience
  */
 void
-_XmError(Widget w, const char *fmt, ...)
+#ifdef __STDC__
+_XmError(Widget w, char *fmt,...)
 {
     va_list arg_list;
-    char buf[1024];
-    int charsleft=sizeof(buf);
+    char buf[256];
 
     va_start(arg_list, fmt);
-#ifdef HAVE_VSNPRINTF
-    charsleft -= vsnprintf(buf, sizeof(buf),
-                           fmt, arg_list);
 #else
-    charsleft -= vsprintf(buf,
-                          fmt, arg_list);
-    /* one might add a catch here ... */
+_XmError(w, fmt, va_alist)
+     Widget w;
+     char *fmt;
+     va_dcl
+{
+    char buf[256];
+    va_list arg_list;
+
+    va_start(arg_list);
 #endif
-    va_end(arg_list);
     if (w)
     {
+	vsprintf(buf, fmt, arg_list);
+	va_end(arg_list);
+
 	XtAppError(XtWidgetToApplicationContext(w), buf);
     }
     else
     {
+	vsprintf(buf, fmt, arg_list);
+	va_end(arg_list);
+
 	XtError(buf);
     }
 }
 
-
 /*
  * Warning convenience
  *
- * Added _LtDebug stuff here to be able to avoid infinite loops in applications
+ * Added XdbDebug stuff here to be able to avoid infinite loops in applications
  * that redirect stderr to a scrolledText. ML suffers from this, due to LessTif
  * bugs of cource :-(
  */
-static void
-_LtWarning(Widget w, const char *fmt, va_list arg_list)
+void
+#ifdef __STDC__
+_XmWarning(Widget w, char *fmt,...)
 {
- /* Somewhere it's pointed out that we shouldn't exceed 1024 characters here.
-    Let's reserve two chars for \n\000
-    If we don't have (v)snprintf() we have a vulnerable piece of
-    code here ...  */
-#define BUFLEN 1026
-    char buf[BUFLEN]="";
-    int charsleft=BUFLEN;
-    static Boolean redirect=False;
-#ifndef	LESSTIF_PRODUCTION
-    static Boolean init=False;
+    va_list arg_list;
+    char buf[256];
 
+    va_start(arg_list, fmt);
+#else
+_XmWarning(Widget w, fmt, va_list)
+     Widget w;
+     char *fmt;
+     va_dcl
+{
+    char buf[256];
 
-    if (!init) {
-    	if (getenv("DEBUG_REDIRECT_XMWARNING"))
-	   redirect = True;
-	init=True;
-    }
-#endif /* !LESSTIF_PRODUCTION */
-
+    va_start(arg_list);
+#endif
     if (w)
     {
-#ifdef HAVE_SNPRINTF
-	charsleft -= snprintf(buf, charsleft,
-    	                      "\n    Name: %s\n    Class: %s\n    ",
-		              XtName(w), XtClass(w)->core_class.class_name);
-#else
-	charsleft -= sprintf(buf,
-	                     "\n    Name: %s\n    Class: %s\n    ",
-		             XtName(w), XtClass(w)->core_class.class_name);
-        /* one might add a catch here ... */
-#endif
+	sprintf(buf, "\n    Name: %s\n    Class: %s\n    ",
+		XtName(w), XtClass(w)->core_class.class_name);
 
-#ifdef HAVE_VSNPRINTF
-	charsleft -= vsnprintf(buf + strlen(buf), charsleft,
-	                       fmt, arg_list);
-#else
-	charsleft -= vsprintf(buf + strlen(buf),
-	                      fmt, arg_list);
-        /* one might add a catch here ... */
-#endif
+	vsprintf(buf + strlen(buf), fmt, arg_list);
+	va_end(arg_list);
 
 	strcat(buf, "\n");
 
-	if (redirect)
+#ifdef	LESSTIF_PRODUCTION
+	XtAppWarning(XtWidgetToApplicationContext(w), buf);
+#else
+	if (getenv("DEBUG_REDIRECT_XMWARNING"))
 	{
-	    _LtDebugPrintString(buf);
+	    XdbPrintString(buf);
 	}
 	else
 	{
 	    XtAppWarning(XtWidgetToApplicationContext(w), buf);
 	}
+#endif
     }
     else
     {
-#ifdef HAVE_VSNPRINTF
-	charsleft -= vsnprintf(buf + strlen(buf), charsleft,
-	          fmt, arg_list);
-#else
-	charsleft -= vsprintf(buf + strlen(buf),
-	         fmt, arg_list);
-#endif
+	buf[0] = '\0';
+	vsprintf(buf + strlen(buf), fmt, arg_list);
+	va_end(arg_list);
 
-	if (redirect)
+#ifdef	LESSTIF_PRODUCTION
+	XtWarning(buf);
+#else
+	if (getenv("DEBUG_REDIRECT_XMWARNING"))
 	{
-	    _LtDebugPrintString(buf);
+	    XdbPrintString(buf);
 	}
 	else
 	{
 	    XtWarning(buf);
 	}
-    } /* if(w) */
+#endif
+    }
 }
 
-/*
- * Warning convenience
- *
- * Added _LtDebug stuff here to be able to avoid infinite loops in applications
- * that redirect stderr to a scrolledText. ML suffers from this, due to LessTif
- * bugs of course :-(
- */
-
-/* unshadow for the Motif 2.x build */
-#if XmVERSION >= 2
-#ifdef _XmWarning
-#undef _XmWarning
-#endif
-#endif
-
-extern void
-_XmWarning(Widget w, const char *fmt, ...)
-{
-    va_list arg_list;
-
-    va_start(arg_list, fmt);
-    _LtWarning(w, fmt, arg_list);
-    va_end(arg_list);
-}
-
-
-#if XmVERSION >= 2
-extern void
-XmeWarning(Widget w, const char *fmt, ...)
-{
-    va_list arg_list;
-
-    va_start(arg_list, fmt);
-    _LtWarning(w, fmt, arg_list);
-    va_end(arg_list);
-}
-#endif
-
-
-extern char *
+char *
 XmRegisterSegmentEncoding(char *fontlist_tag, char *ct_encoding)
 {
     return NULL;
 }
 
-
-extern char *
+char *
 XmMapSegmentEncoding(char *fontlist_tag)
 {
     return NULL;
 }
 
-
-extern XmString
+XmString
 XmCvtCTToXmString(char *text)
 {
     return XmStringCreate(text, XmFONTLIST_DEFAULT_TAG);
 }
 
-
-extern Boolean
+Boolean
 XmCvtTextToXmString(Display *display, XrmValuePtr args,
 		    Cardinal *num_args, XrmValue *from_val, XrmValue *to_val,
 		    XtPointer *converter_data)
@@ -1181,8 +1124,7 @@ XmCvtTextToXmString(Display *display, XrmValuePtr args,
     return False;
 }
 
-
-extern char *
+char *
 XmCvtXmStringToCT(XmString string)
 {
     char *text = (char *)NULL;
@@ -1192,7 +1134,7 @@ XmCvtXmStringToCT(XmString string)
     XmStringDirection direction;
     Boolean separator;
 
-    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmCvtXmStringToCT\n"));
+    DEBUGOUT(XdbDebug(__FILE__, NULL, "XmCvtXmStringToCT\n"));
 
     if (XmStringInitContext(&context, string) == True)
     {
@@ -1233,7 +1175,7 @@ XmCvtXmStringToCT(XmString string)
     return text;
 }
 
-extern Boolean
+Boolean
 XmCvtXmStringToText(Display *display, XrmValuePtr args,
 		    Cardinal *num_args, XrmValue *from_val, XrmValue *to_val,
 		    XtPointer *converter_data)
@@ -1296,21 +1238,20 @@ XmCvtXmStringToText(Display *display, XrmValuePtr args,
     to_val->addr = value;
     to_val->size = strlen(value);  /* FIXME: should this be sizeof(value)? */
 
-    DEBUGOUT(_LtDebug(__FILE__, NULL,
+    DEBUGOUT(XdbDebug(__FILE__, NULL,
 		      "XmCvtXmStringToText(%p) => %s\n",
 		      from_val->addr, to_val->addr));
 
     return True;
 }
 
-
 /*
  * Compare two strings to see if they're equivalent. This one is used
  * whenever comparing motif constants with resource string values. The
  * motif constants must have the Xm prefix stripped off and must be
  * in lower case.
  */
-extern Boolean
+Boolean
 _XmStringsAreEqual(char *in_str,
 		   char *text_str)
 {
@@ -1331,24 +1272,17 @@ _XmStringsAreEqual(char *in_str,
     return *text_str ? False : True;
 }
 
-
 /*
  * Fixed this thing to make a COPY of the fontlist it returns.
  * Danny 16/4/1996
  */
-extern XmFontList
+XmFontList
 _XmGetDefaultFontList(Widget w,
 		      unsigned char fontListType)
 {
-#if 1
-    XmFontList labelFontList = NULL;
-    XmFontList buttonFontList = NULL;
-    XmFontList textFontList = NULL;
-#else
     static XmFontList labelFontList = NULL;
     static XmFontList buttonFontList = NULL;
     static XmFontList textFontList = NULL;
-#endif
     Widget par = w;
     XmFontList fontlist;
     XmVendorShellExtObject ve = NULL;
@@ -1392,7 +1326,6 @@ _XmGetDefaultFontList(Widget w,
 							   XmFONT_IS_FONT,
 						       XmFONTLIST_DEFAULT_TAG);
 	    textFontList = XmFontListAppendEntry(NULL, newEntry);
-            XmFontListEntryFree(&newEntry);
 	}
 
 	if (textFontList == NULL) {
@@ -1400,6 +1333,7 @@ _XmGetDefaultFontList(Widget w,
 	}
 
 	return XmFontListCopy(textFontList);
+	break;
 
     case XmBUTTON_FONTLIST:
 	while ((par = XtParent(par)) != NULL)
@@ -1424,9 +1358,8 @@ _XmGetDefaultFontList(Widget w,
 		}
 	    }
 	}
-	if (fontlist) {
-		return XmFontListCopy(fontlist);
-	}
+	if (fontlist)
+	    return XmFontListCopy(fontlist);
 
 	if (!buttonFontList)
 	{
@@ -1435,7 +1368,6 @@ _XmGetDefaultFontList(Widget w,
 							   XmFONT_IS_FONT,
 						       XmFONTLIST_DEFAULT_TAG);
 	    buttonFontList = XmFontListAppendEntry(NULL, newEntry);
-            XmFontListEntryFree(&newEntry);
 	}
 
 	if (buttonFontList == NULL) {
@@ -1443,6 +1375,7 @@ _XmGetDefaultFontList(Widget w,
 	}
 
 	return XmFontListCopy(buttonFontList);
+	break;
 
     default:
     case XmLABEL_FONTLIST:
@@ -1481,7 +1414,6 @@ _XmGetDefaultFontList(Widget w,
 							   XmFONT_IS_FONT,
 						       XmFONTLIST_DEFAULT_TAG);
 	    labelFontList = XmFontListAppendEntry(NULL, newEntry);
-            XmFontListEntryFree(&newEntry);
 	}
 
 	if (labelFontList == NULL) {
@@ -1490,19 +1422,19 @@ _XmGetDefaultFontList(Widget w,
 
 	return XmFontListCopy(labelFontList);
 
+	break;
     }
 }
 
 /* resource converters, of various types */
 
-extern char *
+char *
 _XmConvertCSToString(XmString cs)
 {
     return NULL;
 }
 
-
-extern Boolean
+Boolean
 _XmCvtXmStringToCT(XrmValue *from,
 		   XrmValue *to)
 {
@@ -1535,7 +1467,7 @@ _XmCvtStringToXmString(Display *display,
     {
 	if (to->addr == NULL)
 	{
-	    to->addr = (XPointer)&newString;
+	    to->addr = (XtPointer)&newString;
 	    to->size = sizeof(XmString);
 	}
 	else
@@ -1558,7 +1490,7 @@ _XmCvtStringToXmString(Display *display,
 					 XmRXmString);
     }
 
-    DEBUGOUT(_LtDebug(__FILE__, NULL,
+    DEBUGOUT(XdbDebug(__FILE__, NULL,
 		      "_XmCvtStringToXmString(%s) => %p\n",
 		      from->addr, to->addr));
 
@@ -1583,10 +1515,9 @@ __XmFontListResourceAddEntry(Display *display,
 			     XmFontList oldFontList)
 {
     XmFontList newFontList;
-    XmFontListEntry newEntry;
     char *eq, *end, *fn, *ft, *tag, *font, *semi, *colon;
 
-    DEBUGOUT(_LtDebug(__FILE__, NULL,
+    DEBUGOUT(XdbDebug(__FILE__, NULL,
 		      "__XmFontListResourceAddEntry(%s)\n", full_entry));
 
     eq = strchr(full_entry, (int)'=');
@@ -1635,9 +1566,11 @@ __XmFontListResourceAddEntry(Display *display,
 	    *end = 0;
 	}
 
-        newEntry = XmFontListEntryLoad(display,
-                                       font, XmFONT_IS_FONT, tag);
-	newFontList = XmFontListAppendEntry(oldFontList, newEntry);
+	newFontList = XmFontListAppendEntry(oldFontList,
+					    XmFontListEntryLoad(display,
+								font,
+								XmFONT_IS_FONT,
+								tag));
 
 	XtFree(ft);
 	XtFree(fn);
@@ -1684,9 +1617,11 @@ __XmFontListResourceAddEntry(Display *display,
 	{
 	    *colon = '\0';
 	}
-	newEntry = XmFontListEntryLoad(display,
-                                       fn, XmFONT_IS_FONTSET, tag);
-	newFontList = XmFontListAppendEntry(oldFontList, newEntry);
+	newFontList = XmFontListAppendEntry(oldFontList,
+					    XmFontListEntryLoad(display,
+								fn,
+							      XmFONT_IS_FONTSET,
+								tag));
 
 	XtFree(fn);
 
@@ -1712,9 +1647,10 @@ __XmFontListResourceAddEntry(Display *display,
 	end++;
 	*end = 0;
     }
-    newEntry = XmFontListEntryLoad(display,
-                                   full_entry, XmFONT_IS_FONT, XmFONTLIST_DEFAULT_TAG);
-    newFontList = XmFontListAppendEntry(oldFontList, newEntry);
+    newFontList = XmFontListAppendEntry(oldFontList,
+					XmFontListEntryLoad(display, full_entry,
+							    XmFONT_IS_FONT,
+						      XmFONTLIST_DEFAULT_TAG));
     XtFree(fn);
     return newFontList;
 }
@@ -1822,7 +1758,7 @@ _XmCvtStringToXmFontList(Display *display,
     {
 	if (to->addr == NULL)
 	{
-	    to->addr = (XPointer)&newFontList;
+	    to->addr = (XtPointer)&newFontList;
 	    to->size = sizeof(XmFontList);
 	}
 	else
@@ -1938,13 +1874,17 @@ _XmCvtStringToCardinal(Display *display,
 		    (String *)NULL, (Cardinal *)NULL);
 	}
 
+#ifdef	HAVE_STRTOUL
 	value = strtoul((char *)from->addr, &end, 10);
+#else
+	value = (Cardinal)strtol((char *)from->addr, &end, 10);
+#endif
 
 	if (*end == '\0')
 	{
 		if (to->addr == NULL)
 		{
-			to->addr = (XPointer)&value;
+			to->addr = (XtPointer)&value;
 			to->size = sizeof(Cardinal);
 		}
 		else
@@ -1984,7 +1924,7 @@ _XmCvtStringToKeySym(Display *d, XrmValue *args, Cardinal *nargs,
     {
 	if (to->addr == NULL)
 	{
-	    to->addr = (XPointer)&k;
+	    to->addr = (XtPointer)&k;
 	    to->size = sizeof(k);
 	    return True;
 	}
@@ -2000,7 +1940,7 @@ _XmCvtStringToKeySym(Display *d, XrmValue *args, Cardinal *nargs,
 	    {
 		XtDisplayStringConversionWarning(d, (char *)from->addr,
 						 XmRKeySym);
-		DEBUGOUT(_LtDebug(__FILE__, NULL,
+		DEBUGOUT(XdbDebug(__FILE__, NULL,
 				  "_XmCvtStringToKeySym fail at line %d\n",
 				  __LINE__));
 		return False;
@@ -2010,12 +1950,11 @@ _XmCvtStringToKeySym(Display *d, XrmValue *args, Cardinal *nargs,
 
     XtDisplayStringConversionWarning(d, (char *)from->addr, XmRKeySym);
 
-    DEBUGOUT(_LtDebug(__FILE__, NULL,
+    DEBUGOUT(XdbDebug(__FILE__, NULL,
 		      "_XmCvtStringToKeySym fail at line %d\n", __LINE__));
     return False;
 }
 
-
 static Boolean
 _XmCvtStringToResIndPosition(Display *display,
 			     XrmValue *args,
@@ -2033,14 +1972,14 @@ _XmCvtStringToResIndPosition(Display *display,
 		     (String *)NULL, (Cardinal *)NULL);
 
     pos = (Position)_XmConvertUnits(*(Screen **)args[0].addr,
-				    (int)(long)*(XtPointer *)args[1].addr,
+				    (int)*(XtPointer *)args[1].addr,
 				    *(unsigned char *)args[2].addr,
 				    atoi(from->addr),
 				    XmPIXELS);
 
     if (to->addr == NULL)
     {
-	to->addr = (XPointer)&pos;
+	to->addr = (XtPointer)&pos;
 	to->size = sizeof pos;
     }
     else
@@ -2048,7 +1987,7 @@ _XmCvtStringToResIndPosition(Display *display,
 	if (to->size < sizeof pos)
 	{
 	    XtDisplayStringConversionWarning(display, (char *)from->addr,
-		(int)(long)*(XtPointer *)args[1].addr == XmHORIZONTAL
+		(int)*(XtPointer *)args[1].addr == XmHORIZONTAL
 		? XmRHorizontalPosition : XmRVerticalPosition);
 	    return False;
 	}
@@ -2059,7 +1998,6 @@ _XmCvtStringToResIndPosition(Display *display,
     return True;
 }
 
-
 static Boolean
 _XmCvtStringToResIndDimension(Display *display,
 			      XrmValue *args,
@@ -2077,14 +2015,14 @@ _XmCvtStringToResIndDimension(Display *display,
 		     (String *)NULL, (Cardinal *)NULL);
 
     dim = (Dimension)_XmConvertUnits(*(Screen **)args[0].addr,
-				     (int)(long)*(XtPointer *)args[1].addr,
+				     (int)*(XtPointer *)args[1].addr,
 				     *(unsigned char *)args[2].addr,
 				     atoi(from->addr),
 				     XmPIXELS);
 
     if (to->addr == NULL)
     {
-	to->addr = (XPointer)&dim;
+	to->addr = (XtPointer)&dim;
 	to->size = sizeof dim;
     }
     else
@@ -2092,7 +2030,7 @@ _XmCvtStringToResIndDimension(Display *display,
 	if (to->size < sizeof dim)
 	{
 	    XtDisplayStringConversionWarning(display, (char *)from->addr,
-		(int)(long)*(XtPointer *)args[1].addr == XmHORIZONTAL
+		(int)*(XtPointer *)args[1].addr == XmHORIZONTAL
 		? XmRHorizontalDimension : XmRVerticalDimension);
 	    return False;
 	}
@@ -2103,7 +2041,6 @@ _XmCvtStringToResIndDimension(Display *display,
     return True;
 }
 
-
 static Boolean
 _XmCvtStringToResIndInt(Display *display,
 			XrmValue *args,
@@ -2121,14 +2058,14 @@ _XmCvtStringToResIndInt(Display *display,
 		     (String *)NULL, (Cardinal *)NULL);
 
     pos = _XmConvertUnits(*(Screen **)args[0].addr,
-			  (int)(long)*(XtPointer *)args[1].addr,
+			  (int)*(XtPointer *)args[1].addr,
 			  *(unsigned char *)args[2].addr,
 			  atoi(from->addr),
 			  XmPIXELS);
 
     if (to->addr == NULL)
     {
-	to->addr = (XPointer)&pos;
+	to->addr = (XtPointer)&pos;
 	to->size = sizeof pos;
     }
     else
@@ -2136,7 +2073,7 @@ _XmCvtStringToResIndInt(Display *display,
 	if (to->size < sizeof pos)
 	{
 	    XtDisplayStringConversionWarning(display, (char *)from->addr,
-		(int)(long)*(XtPointer *)args[1].addr == XmHORIZONTAL
+		(int)*(XtPointer *)args[1].addr == XmHORIZONTAL
 		? XmRHorizontalInt : XmRVerticalInt);
 	    return False;
 	}
@@ -2147,7 +2084,6 @@ _XmCvtStringToResIndInt(Display *display,
     return True;
 }
 
-
 static Boolean
 _XmCvtStringToWidget(	Display *display,
 			XrmValue *args,
@@ -2176,7 +2112,7 @@ _XmCvtStringToWidget(	Display *display,
 
 	if (to->addr == NULL)
 	{
-	    to->addr = (XPointer)&child;
+	    to->addr = (XtPointer)&child;
 	    to->size = sizeof(Widget);
 	}
 	else
@@ -2202,7 +2138,6 @@ _XmCvtStringToWidget(	Display *display,
     return True;
 }
 
-
 static Boolean
 _XmCvtStringToWindow(Display *display,
 		     XrmValue *args,
@@ -2229,7 +2164,6 @@ _XmCvtStringToWindow(Display *display,
     return True;
 }
 
-
 static Boolean
 _XmCvtStringToBooleanDimension( Display *display,
 				XrmValue *args,
@@ -2255,7 +2189,7 @@ _XmCvtStringToBooleanDimension( Display *display,
 	if (isdigit(str[0])) {
 	    preval = atoi(from->addr);
 	    value = (Dimension)_XmConvertUnits(*(Screen **)args[0].addr,
-					       (int)(long)*(XtPointer *)args[1].addr,
+					       (int)*(XtPointer *)args[1].addr,
 					       *(unsigned char *)args[2].addr,
 					       preval,
 					       XmPIXELS);
@@ -2277,7 +2211,7 @@ _XmCvtStringToBooleanDimension( Display *display,
 	}
 
 	if (to->addr == NULL) {
-	    to->addr = (XPointer)&value;
+	    to->addr = (XtPointer)&value;
 	    to->size = sizeof(value);
 	} else {
 	    if (to->size >= sizeof(value)) {
@@ -2297,7 +2231,6 @@ _XmCvtStringToBooleanDimension( Display *display,
     return True;
 }
 
-
 static Boolean
 _XmCvtStringToChar( Display *display,
 		    XrmValue *args,
@@ -2324,7 +2257,6 @@ _XmCvtStringToChar( Display *display,
     return True;
 }
 
-
 static Boolean
 _XmCvtStringToTextPosition( Display *display,
 			    XrmValue *args,
@@ -2337,7 +2269,7 @@ _XmCvtStringToTextPosition( Display *display,
 
     tp = atol( from->addr);
     if (to->addr == NULL) {
-	to->addr = (XPointer)&tp;
+	to->addr = (XtPointer)&tp;
 	to->size = sizeof tp;
     } else {
 	if (to->size < sizeof tp) {
@@ -2352,7 +2284,6 @@ _XmCvtStringToTextPosition( Display *display,
     return True;
 }
 
-
 static Boolean
 _XmCvtStringToTopItemPosition( Display *display,
 			       XrmValue *args,
@@ -2365,7 +2296,7 @@ _XmCvtStringToTopItemPosition( Display *display,
 
     tip = atoi( from->addr);
     if (to->addr == NULL) {
-	to->addr = (XPointer)&tip;
+	to->addr = (XtPointer)&tip;
 	to->size = sizeof tip;
     } else {
 	if (to->size < sizeof tip) {
@@ -2380,7 +2311,6 @@ _XmCvtStringToTopItemPosition( Display *display,
     return True;
 }
 
-
 /* Converter for various tables of comma-separated strings,
  * with those strings converted each in their own way.
  */
@@ -2406,7 +2336,7 @@ _XmCvtStringToSomeTable( Display *display,
     nitems = 0;
     item = NULL;
     escaped = anyescaped = False;
-    tabtype = (int)(long)*(XtPointer *)args[0].addr;
+    tabtype = (int)*(XtPointer *)args[0].addr;
     for (p = from->addr;; p++)
     {
 	if (escaped)
@@ -2498,7 +2428,7 @@ _XmCvtStringToSomeTable( Display *display,
 
 	    case ST_XM_STRING_TABLE:
 		table[nitems] =
-		    (XtPointer)XmStringCreateLtoR(str, XmFONTLIST_DEFAULT_TAG);
+		    XmStringCreateLtoR(str, XmFONTLIST_DEFAULT_TAG);
 		XtFree(str);
 	    }
 
@@ -2567,7 +2497,7 @@ _XmCvtStringToSomeTable( Display *display,
     }
 
     if (to->addr == NULL) {
-	to->addr = (XPointer)&table;
+	to->addr = (XtPointer)&table;
 	to->size = sizeof table;
     } else {
 	if (to->size < sizeof table) {
@@ -2585,7 +2515,6 @@ _XmCvtStringToSomeTable( Display *display,
     return True;
 }
 
-
 static void
 destroy_font_list(XtAppContext app, XrmValue *to,
 		  XtPointer converer_data, XrmValue *args,
@@ -2594,7 +2523,6 @@ destroy_font_list(XtAppContext app, XrmValue *to,
     XmFontListFree(*(XmFontList *)to->addr);
 }
 
-
 static void
 destroy_table(XtAppContext app, XrmValue *to,
 	      XtPointer converer_data, XrmValue *args,
@@ -2603,7 +2531,6 @@ destroy_table(XtAppContext app, XrmValue *to,
     XtFree(*(char **)to->addr);
 }
 
-
 static void
 destroy_string_table(XtAppContext app, XrmValue *to,
 		     XtPointer converer_data, XrmValue *args,
@@ -2617,7 +2544,6 @@ destroy_string_table(XtAppContext app, XrmValue *to,
     XtFree((char *)table);
 }
 
-
 static void
 destroy_xm_string_table(XtAppContext app, XrmValue *to,
 		     XtPointer converer_data, XrmValue *args,
@@ -2631,7 +2557,6 @@ destroy_xm_string_table(XtAppContext app, XrmValue *to,
     XtFree((char *)table);
 }
 
-
 static void
 get_unit_type(Widget w, Cardinal *size, XrmValue *val)
 {
@@ -2642,19 +2567,18 @@ get_unit_type(Widget w, Cardinal *size, XrmValue *val)
     ut = _XmGetUnitType(w);
 }
 
-#if XmVERSION > 1
+#if	XmVERSION > 1
 /*
  * XmConvertStringToUnits converts a string specification value and returns
  * the converted value as the return value from the function. This function
  * uses the specified screen's resolution to compute the number of units for
  * the string specification.
  */
-extern int
+int
 XmConvertStringToUnits(Screen *screen, String spec, int orientation,
 	int to_type, XtEnum *parse_error)
 {
 	/* FIX ME not implemented yet */
-        _XmWarning(NULL, "XmConvertStringToUnits() is not implemented yet!\n");
 
 	if (screen == NULL)
 		return 0;
@@ -2680,7 +2604,6 @@ XmConvertStringToUnits(Screen *screen, String spec, int orientation,
     return 0;
 }
 
-
 static Boolean
 _XmCvtStringToTabList(Display *display,
 		       XrmValue *args,
@@ -2692,46 +2615,14 @@ _XmCvtStringToTabList(Display *display,
 	return False;
 }
 
-
 static Boolean
 _XmCvtStringToRenderTable(Display *display,
-                          XrmValue *args,
-                          Cardinal *num_args,
-                          XrmValue *from,
-                          XrmValue *to,
-                          XtPointer *converter_data)
+		       XrmValue *args,
+		       Cardinal *num_args,
+		       XrmValue *from,
+		       XrmValue *to,
+		       XtPointer *converter_data)
 {
-
 	return False;
 }
-
-
-extern unsigned int
-XmCvtXmStringToByteStream(XmString string,
-                          unsigned char **prop_return)
-{
-        _XmWarning(NULL, "XmConvertStringToUnits() is not implemented yet!\n");
-	return 0;
-}
-
-
-
-extern XmString 
-XmCvtByteStreamToXmString(unsigned char *property)
-{
-      _XmWarning(NULL, "XmCvtByteStreamToXmString() is not implemented yet!\n");
-      return NULL;
-}
-
-
-extern int
-XmCvtXmStringTableToTextProperty (Display *display,
-                                  XmStringTable string_table,
-                                  int count,
-                                  XmICCEncodingStyle style,
-                                  XTextProperty *text_prop_return)
-{
-        _XmWarning(NULL, "XmCvtXmStringTableToTextProperty() is not implemented yet!\n");
-	return 0;
-}				      
-#endif /* XmVERSION > 1 */
+#endif
