@@ -1,9 +1,8 @@
 /**
  *
- * $Id: Scale.c,v 1.48 2001/07/27 18:51:57 dannybackx Exp $
+ * $Id: Scale.c,v 1.36 1999/05/11 14:07:40 strauman Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,16 +22,11 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Scale.c,v 1.48 2001/07/27 18:51:57 dannybackx Exp $";
+static const char rcsid[] = "$Id: Scale.c,v 1.36 1999/05/11 14:07:40 strauman Exp $";
 
 #include <LTconfig.h>
-
-#include <stdlib.h>
-#include <stdio.h>
-#include <limits.h>
-#include <math.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/ScaleP.h>
 #include <Xm/LabelGP.h>
@@ -42,6 +36,9 @@ static const char rcsid[] = "$Id: Scale.c,v 1.48 2001/07/27 18:51:57 dannybackx
 #include <Xm/VendorSP.h>
 #include <Xm/VendorSEP.h>
 
+#include <stdio.h>
+#include <limits.h>
+
 #include <XmI/DebugUtil.h>
 
 /* Forward Declarations */
@@ -52,7 +49,7 @@ static const char rcsid[] = "$Id: Scale.c,v 1.48 2001/07/27 18:51:57 dannybackx
 #define CHILD_SB	1
 
 /* FIX ME/BUGS
- *   - highlight
+ *   - higlight
  */
 
 /*
@@ -79,22 +76,32 @@ static const char rcsid[] = "$Id: Scale.c,v 1.48 2001/07/27 18:51:57 dannybackx
 #define Scale_ShadowThickness(x) MGR_ShadowThickness(x)
 
 static void class_initialize(void);
+
 static void class_part_initialize(WidgetClass w_class);
+
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
+
 static void destroy(Widget w);
+
 static void realize(Widget w, XtValueMask *value_mask,
 		    XSetWindowAttributes *attributes);
+
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
+
 static XtGeometryResult query_geometry(Widget w,
 				       XtWidgetGeometry *request,
 				       XtWidgetGeometry *reply);
+
 static XtGeometryResult geometry_manager(Widget w,
 					 XtWidgetGeometry *request,
 					 XtWidgetGeometry *reply);
+
 static void expose(Widget w, XEvent *event, Region region);
+
 static void resize(Widget w);
+
 static void change_managed(Widget w);
 
 #if 0
@@ -104,25 +111,36 @@ static void insert_child(Widget w);
 static XmKidGeometry _XmScalePreferredSize(Widget scale, Widget child,
 					   XtWidgetGeometry *childgeom,
 					   Dimension *w, Dimension *ht);
+
 static XtGeometryResult _XmScaleGeomRequest(Widget scale,
 					    Dimension *wd, Dimension *ht);
+
 static void _XmScaleLayout(Widget scale, XmKidGeometry boxes,
 			   Widget child, XtWidgetGeometry *childgeom,
 			   Dimension curw, Dimension curh);
+
 static void _XmScaleConfigureChildren(Widget scale,
 				      Widget child,
 				      XmKidGeometry boxes);
+
 static int _XmScaleConvertWidthToSliderSize(Widget w);
+
 static int _XmScaleConvertSCBValueToScaleValue(Widget w, int value);
+
 static int _XmScaleConvertScaleValueToSCBValue(Widget w);
+
 static void _ScaleValueChanged(Widget sb, XtPointer cd, XtPointer data);
+
 static void _ScaleDrag(Widget sb, XtPointer cd, XtPointer data);
+
 static void computeValueSize(Widget w);
+
 static void showValue(Widget w, int scb_value, int scale_value);
 
 #if 0
 static void GetFocus(Widget w, XEvent *event,
 		     String *params, Cardinal *num_params);
+
 static void LoseFocus(Widget w, XEvent *event,
 		      String *params, Cardinal *num_params);
 #endif
@@ -185,7 +203,7 @@ static XtResource resources[] =
     {
 	XmNdecimalPoints, XmCDecimalPoints, XmRShort,
 	sizeof(short), Offset(decimal_points),
-	XmRImmediate, (XtPointer)(short)0
+	XmRImmediate, (XtPointer)0
     },
     {
 	XmNscaleWidth, XmCScaleWidth, XmRHorizontalDimension,
@@ -220,7 +238,7 @@ static XtResource resources[] =
 #if XmVERSION > 1
     {
 	XmNeditable, XmCEditable, XmRBoolean,
-	sizeof(Boolean), Offset(editable),
+	sizeof(int), Offset(editable),
 	XmRImmediate, (XtPointer)True
     },
 #endif
@@ -261,7 +279,7 @@ static XtActionsRec actions[] =
     {"FocusOut", LoseFocus}
 };
 #endif
-
+/* *INDENT-OFF* */
 static XmBaseClassExtRec _XmScaleCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -368,19 +386,17 @@ XmScaleClassRec xmScaleClassRec =
 	/* extension */ NULL,
     },
 };
-
+/* *INDENT-ON* */
 
 
 WidgetClass xmScaleWidgetClass = (WidgetClass)&xmScaleClassRec;
 
-
 static void
 class_initialize(void)
 {
     _XmScaleCoreClassExtRec.record_type = XmQmotif;
 }
 
-
 static void
 class_part_initialize(WidgetClass widget_class)
 {
@@ -411,7 +427,6 @@ class_part_initialize(WidgetClass widget_class)
     _XmFastSubclassInit(widget_class, XmSCALE_BIT);
 }
 
-
 static void
 CreateForegroundGC(Widget w)
 {
@@ -445,7 +460,7 @@ initialize(Widget request, Widget new_w,
     Dimension wd, ht;
     */
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "%s:initialize(%d) - %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -455,22 +470,8 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
 
-    if (Scale_ScaleWidth(new_w) == 0)
-    {
-    	/* rws 22 Dec 1999
-    	   scale/test18 scale/test16
-    	 */
-	if (Scale_Orientation(new_w) == XmHORIZONTAL)
-	{
-	    Scale_ScaleWidth(new_w) = XtWidth(request);
-    	}
-    	else
-	{
-	    Scale_ScaleWidth(new_w) = XtHeight(request);
-    	}
-    }
     if (Scale_Value(new_w) == INT_MAX)
     {
 	if (Scale_Minimum(new_w) >= 0)
@@ -579,20 +580,13 @@ initialize(Widget request, Widget new_w,
 #endif
 }
 
-
 static void
 destroy(Widget w)
 {
-
-    if (Scale_Title(w))
-     {
-         XmStringFree(Scale_Title(w));
-     }
     XmFontListFree(Scale_FontList(w));
     XtDestroyGC(Scale_ForegroundGC(w));
 }
 
-
 /*
  * called when the user changes a resource
  */
@@ -609,7 +603,7 @@ set_values(Widget old, Widget request, Widget new_w,
     Widget sb, lab;
     int resize = False;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w, "XmScale set_values()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "XmScale set_values()\n"));
 
     sb = ((XmScaleWidget)new_w)->composite.children[CHILD_SB];
     lab = ((XmScaleWidget)new_w)->composite.children[CHILD_LAB];
@@ -713,12 +707,8 @@ set_values(Widget old, Widget request, Widget new_w,
 	Scale_ScaleHeight(new_w) != Scale_ScaleHeight(old))
     {
 	argc = 0;
-	if (Scale_ScaleWidth(new_w) != Scale_ScaleWidth(old) ) {
-	    XtSetArg(argl[argc], XmNwidth, Scale_ScaleWidth(new_w)); argc++;
-	}
-	if ( Scale_ScaleHeight(new_w) != Scale_ScaleHeight(old) ) {
-	    XtSetArg(argl[argc], XmNheight, Scale_ScaleHeight(new_w)); argc++;
-	}
+	XtSetArg(argl[argc], XmNwidth, Scale_ScaleWidth(new_w)); argc++;
+	XtSetArg(argl[argc], XmNheight, Scale_ScaleHeight(new_w)); argc++;
 
 	XtSetValues(sb, argl, argc);
        
@@ -787,13 +777,12 @@ set_values(Widget old, Widget request, Widget new_w,
     return refresh;
 }
 
-
 static void
 expose(Widget w,
        XEvent *event,
        Region region)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale expose()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale expose()\n"));
 
     _XmRedisplayGadgets(w, event, region);
 
@@ -805,7 +794,6 @@ expose(Widget w,
     }
 }
 
-
 /*
  * called when our parent wants to find out how we would like to look.  It
  * doesn't have to honor our preference, though.
@@ -820,7 +808,7 @@ query_geometry(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 
 #define Wants(x)	((wants.request_mode & x) == x)
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale %s QueryGeometry\n", XtName(w)));
+    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale %s QueryGeometry\n", XtName(w)));
 
     wants = *request;
 
@@ -870,7 +858,7 @@ query_geometry(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
     XtWidgetGeometry wants;
     Dimension wd, ht;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale %s QueryGeometry\n", XtName(w)));
+    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale %s QueryGeometry\n", XtName(w)));
 
     wants = *request;
 
@@ -883,7 +871,6 @@ query_geometry(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 #endif
 }
 
-
 /*
  * called when our parent is resizing us.  We have no choice but to obey.
  */
@@ -893,7 +880,7 @@ resize(Widget w)
     XmKidGeometry boxes;
     Dimension wd, ht;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "Scale %s Resize: x %d y %d w %d h %d\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "Scale %s Resize: x %d y %d w %d h %d\n",
 		      XtName(w), XtX(w), XtY(w), XtWidth(w), XtHeight(w)));
 
     Scale_SliderSize(w) = _XmScaleConvertWidthToSliderSize(w);
@@ -909,7 +896,6 @@ resize(Widget w)
     XtFree((char *)boxes);
 }
 
-
 /*
  * called when one of our children wants to change.  We control whether
  * the child can, or not
@@ -923,7 +909,7 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
     XmKidGeometry boxes;
     XtWidgetGeometry wants;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale geometry_manager()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale geometry_manager()\n"));
 
     wants = *request;
 
@@ -947,7 +933,7 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 
     *reply = *request;
 
-    reply->request_mode &= CWWidth|CWHeight;
+    reply->request_mode = CWWidth|CWHeight;
 
     if (Wants(CWWidth) && Wants(CWHeight) &&
 	wants.width == reply->width && wants.height == reply->height)
@@ -971,19 +957,10 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 	return XtGeometryYes;
     }
 
-    if (Wants(CWWidth) && wants.width == reply->width)
-    {
-    	reply->request_mode &= ~CWWidth;
-    }
-    if (Wants(CWHeight) && wants.height == reply->height)
-    {
-    	reply->request_mode &= ~CWHeight;
-    }
     return XtGeometryAlmost;
 #undef Wants
 }
 
-
 /*
  * called when our Window is allocated.  We may want to change our layout,
  * and we can ask our parent to allow this
@@ -997,7 +974,7 @@ realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
     XmKidGeometry boxes;
     */
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale realize()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale realize()\n"));
 
 #define superclass (&xmManagerClassRec)
     (*superclass->core_class.realize) (w, value_mask, attributes);
@@ -1019,7 +996,6 @@ realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
 #endif
 }
 
-
 /*
  * one of our children has become managed or unmanaged.  We need to relayout
  */
@@ -1029,7 +1005,7 @@ change_managed(Widget w)
     Dimension wd, ht;
     XmKidGeometry boxes;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale change_managed()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale change_managed()\n"));
 
     wd = ht = 0;
     boxes = _XmScalePreferredSize(w, NULL, NULL, &wd, &ht);
@@ -1045,7 +1021,6 @@ change_managed(Widget w)
     _XmNavigChangeManaged(w);
 }
 
-
 #if 0
 /*
  * a child has been added
@@ -1057,14 +1032,13 @@ insert_child(Widget w)
     (*superclass->composite_class.insert_child) (w);
 #undef  superclass
 
-    DEBUGOUT(_LtDebug(__FILE__, w,
+    DEBUGOUT(XdbDebug(__FILE__, w,
 		      "Scale %s: insert child %s\n",
 		      XtName(XtParent(w)), XtName(w)));
 }
 #endif
 
-
-extern Widget
+Widget
 XmCreateScale(Widget parent,
 	      char *name,
 	      Arg *arglist,
@@ -1077,16 +1051,14 @@ XmCreateScale(Widget parent,
 			  argcount);
 }
 
-
-extern void
+void
 XmScaleGetValue(Widget widget,
 		int *value_return)
 {
     *value_return = Scale_Value(widget);
 }
 
-
-extern void
+void
 XmScaleSetValue(Widget widget,
 		int value)
 {
@@ -1113,7 +1085,6 @@ XmScaleSetValue(Widget widget,
     }
 }
 
-
 static void
 valueToString(Widget w, char *buf)
 {
@@ -1671,7 +1642,6 @@ printf("COMPUTED %d %d : %d %d\n", curw, cury, incw, inch);
     return boxes;
 }
 
-
 /*
  * if we can, change our size to match
  */
@@ -1685,7 +1655,7 @@ _XmScaleGeomRequest(Widget scale, Dimension *wd, Dimension *ht)
     request.width = *wd;
     request.height = *ht;
 
-    DEBUGOUT(_LtDebug(__FILE__, scale, "_XmScaleGeomRequest(ing) (%d %d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, scale, "_XmScaleGeomRequest(ing) (%d %d)\n",
 		      *wd, *ht));
 
     result = _XmMakeGeometryRequest(scale, &request);
@@ -1701,13 +1671,12 @@ _XmScaleGeomRequest(Widget scale, Dimension *wd, Dimension *ht)
 	*ht = XtHeight(scale);
     }
 
-    DEBUGOUT(_LtDebug(__FILE__, scale, "_XmScaleLayout (%d %d) => %s\n",
-		      *wd, *ht, _LtDebugGeometryResult2String(result)));
+    DEBUGOUT(XdbDebug(__FILE__, scale, "_XmScaleLayout (%d %d) => %s\n",
+		      *wd, *ht, XdbGeometryResult2String(result)));
 
     return result;
 }
 
-
 static void
 _XmScaleLayout(Widget scale, XmKidGeometry boxes,
 	       Widget child, XtWidgetGeometry *childgeom,
@@ -1756,9 +1725,9 @@ _XmScaleLayout(Widget scale, XmKidGeometry boxes,
 	{
 	    for (i = 2; i < num_children; i++)
 	    {
-		boxes[i].box.width = (Dimension)((double)boxes[i].box.width /
-						 (double)curw *
-						 (double)XtWidth(scale));
+		boxes[i].box.width = (Dimension)((float)boxes[i].box.width /
+						 (float)curw *
+						 (float)XtWidth(scale));
 	    }
 	}
 #endif
@@ -1849,9 +1818,9 @@ _XmScaleLayout(Widget scale, XmKidGeometry boxes,
 	if (XtWidth(scale) > curw)
 	{
 	    for (i = 2; i < num_children; i++)
-		boxes[i].box.height = (Dimension)((double)boxes[i].box.height /
-						  (double)curw *
-						  (double)XtWidth(scale));
+		boxes[i].box.height = (Dimension)((float)boxes[i].box.height /
+						  (float)curw *
+						  (float)XtWidth(scale));
 	}
 #endif
 
@@ -1918,8 +1887,8 @@ _XmScaleConfigureChildren(Widget scale, Widget child, XmKidGeometry boxes)
     _XmSetKidGeo(boxes, child);
 
     Scale_SliderSize(scale) = _XmScaleConvertWidthToSliderSize(scale);
-    inc = (int)((double)(SCB_MAX - SCB_MIN - Scale_SliderSize(scale)) /
-		(double)(Scale_Maximum(scale) - Scale_Minimum(scale)) +
+    inc = (int)((float)(SCB_MAX - SCB_MIN - Scale_SliderSize(scale)) /
+		(float)(Scale_Maximum(scale) - Scale_Minimum(scale)) +
 		0.5);
     inc = _XmMax(inc, 1);	/* FIX ME */
     p_inc = inc * Scale_ScaleMultiple(scale);
@@ -1930,7 +1899,6 @@ _XmScaleConfigureChildren(Widget scale, Widget child, XmKidGeometry boxes)
 			 inc, p_inc, False);
 }
 
-
 static void
 computeValueSize(Widget w)
 {
@@ -1970,7 +1938,6 @@ computeValueSize(Widget w)
         Scale_FontStruct(w)->max_bounds.descent;
 }
 
-
 static void
 showValue(Widget w, int scb_value, int scale_value)
 {
@@ -2045,7 +2012,6 @@ showValue(Widget w, int scb_value, int scale_value)
     }
 }
 
-
 static void
 _ScaleValueChanged(Widget sb, XtPointer cd, XtPointer data)
 {
@@ -2073,7 +2039,6 @@ _ScaleValueChanged(Widget sb, XtPointer cd, XtPointer data)
     }
 }
 
-
 static void
 _ScaleDrag(Widget sb, XtPointer cd, XtPointer data)
 {
@@ -2082,7 +2047,7 @@ _ScaleDrag(Widget sb, XtPointer cd, XtPointer data)
     int scale_value;
 
 #if XmVERSION > 1
-    if (! Scale_Editable(XtParent(sb)))
+    if (! Scale_Editable(sb))
 	return;
 #endif
 
@@ -2105,14 +2070,13 @@ _ScaleDrag(Widget sb, XtPointer cd, XtPointer data)
     }
 }
 
-
 #if 0
 static void
 GetFocus(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmScrollBarWidget sb;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "GetFocus\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "GetFocus\n"));
 
     sb = (XmScrollBarWidget)(((XmScaleWidget)w)->composite.children[CHILD_SB]);
 
@@ -2120,13 +2084,12 @@ GetFocus(Widget w, XEvent *event, String *params, Cardinal *num_params)
 		     params, *num_params);
 }
 
-
 static void
 LoseFocus(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmScrollBarWidget sb;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "LoseFocus\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "LoseFocus\n"));
 
     sb = (XmScrollBarWidget)(((XmScaleWidget)w)->composite.children[CHILD_SB]);
 
@@ -2135,7 +2098,6 @@ LoseFocus(Widget w, XEvent *event, String *params, Cardinal *num_params)
 }
 #endif
 
-
 static int
 _XmScaleConvertWidthToSliderSize(Widget w)
 {
@@ -2165,9 +2127,9 @@ _XmScaleConvertWidthToSliderSize(Widget w)
 	    if (XtWidth(sb) == 2 * (ht + st))
 	    {
 		/* Note: M*tif 1.2.2 SIGFPE's on this -- PvH */
-		ret = (int)((double)(SCB_MAX - SCB_MIN) /
-			    (double)(Scale_Maximum(w) - Scale_Minimum(w)) *
-			    (double)HSLIDERSIZE);
+		ret = (int)((float)(SCB_MAX - SCB_MIN) /
+			    (float)(Scale_Maximum(w) - Scale_Minimum(w)) *
+			    (float)HSLIDERSIZE);
 	    }
 	    else if (XtWidth(sb) < HSLIDERSIZE)
 	    {
@@ -2207,49 +2169,29 @@ _XmScaleConvertWidthToSliderSize(Widget w)
     return ret;
 }
 
-
 static int
 _XmScaleConvertSCBValueToScaleValue(Widget w, int value)
 {
-    double roundarg;
-    int result;
-
-    DEBUGOUT(_LtDebug(__FILE__, w, "_XmScaleConvertSCBValueToScaleValue(,%i)\n",
-                       value));
     if ((SCB_MAX - SCB_MIN - Scale_SliderSize(w)) == 0)
     {
 	return Scale_Minimum(w);
     }
 
-    roundarg = (double)(Scale_Maximum(w) - Scale_Minimum(w)) 
-	     * (double)value 
-	     / (double)(SCB_MAX - SCB_MIN - Scale_SliderSize(w))
-	     + (double)Scale_Minimum(w);
-
-    result = (int)(roundarg + 0.5);
-
-    return result;
+    return (int)((float)(Scale_Maximum(w) - Scale_Minimum(w)) 
+		* (float)value 
+		/ (float)(SCB_MAX - SCB_MIN - Scale_SliderSize(w))
+		+ (float)Scale_Minimum(w) );
 }
 
-
 static int
 _XmScaleConvertScaleValueToSCBValue(Widget w)
 {
-
-    double roundarg;
-    int result;
-
-    DEBUGOUT(_LtDebug(__FILE__, w, "_XmScaleConvertScaleValueToSCBValue()\n"));
-    roundarg = (double)(Scale_Value(w) - Scale_Minimum(w)) 
-	     * (double)(SCB_MAX - SCB_MIN - Scale_SliderSize(w))
-	     / (double)(Scale_Maximum(w) - Scale_Minimum(w));
-    /* amai: is this the correct formula? 
-             looks like the old one in _XmScaleConvertSCBValueToScaleValue() */
-    result = (int)(roundarg);
-    return result;
+    return (int)((float)(Scale_Value(w) - Scale_Minimum(w)) 
+		* (float)(SCB_MAX - SCB_MIN - Scale_SliderSize(w))
+		/ (float)(Scale_Maximum(w) - Scale_Minimum(w)) 
+		);
 }
 
-
 static void
 _XmScaleProcessingDirectionDefault(Widget w, int offset, XrmValue *val)
 {
@@ -2265,5 +2207,6 @@ _XmScaleProcessingDirectionDefault(Widget w, int offset, XrmValue *val)
 	direction = XmMAX_ON_RIGHT;	/* FIX ME */
     }
 
-    val->addr = (XPointer)&direction;
+    val->addr = (XtPointer)&direction;
 }
+
