@@ -1,9 +1,8 @@
 /**
  *
- * $Id: Screen.c,v 1.26 2001/07/27 18:51:57 dannybackx Exp $
+ * $Id: Screen.c,v 1.17 1999/02/02 18:23:28 gritton Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,14 +22,13 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Screen.c,v 1.26 2001/07/27 18:51:57 dannybackx Exp $";
+static const char rcsid[] = "$Id: Screen.c,v 1.17 1999/02/02 18:23:28 gritton Exp $";
 
 #include <LTconfig.h>
+#include <XmI/XmI.h>
 
 #include <stdio.h>
 
-#include <XmI/XmI.h>
-
 #include <Xm/XmP.h>
 #include <Xm/AtomMgr.h>
 #include <Xm/MwmUtil.h>
@@ -43,29 +41,39 @@ static const char rcsid[] = "$Id: Screen.c,v 1.26 2001/07/27 18:51:57 dannybackx
 
 #include <XmI/DebugUtil.h>
 
+#ifndef XmUNSPECIFIED
+#define XmUNSPECIFIED (~0)
+#endif
 
-/* Some global variables */
-XrmQuark _XmInvalidCursorIconQuark=0;
-XrmQuark _XmValidCursorIconQuark=0;
-XrmQuark _XmNoneCursorIconQuark=0;
-XrmQuark _XmDefaultDragIconQuark=0;
-XrmQuark _XmMoveCursorIconQuark=0;
-XrmQuark _XmCopyCursorIconQuark=0;
-XrmQuark _XmLinkCursorIconQuark=0;
+XrmQuark _XmInvalidCursorIconQuark;
+XrmQuark _XmValidCursorIconQuark;
+XrmQuark _XmNoneCursorIconQuark;
+XrmQuark _XmDefaultDragIconQuark;
+XrmQuark _XmMoveCursorIconQuark;
+XrmQuark _XmCopyCursorIconQuark;
+XrmQuark _XmLinkCursorIconQuark;
 
 /* Forward Declarations */
 
 static void class_initialize(void);
+
 static void class_part_initialize(WidgetClass w_class);
+
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
+
 static void realize(Widget w, XtValueMask *value_mask,
 		    XSetWindowAttributes *attributes);
+
 static void destroy(Widget w);
+
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
+
+
 static void insert_child(Widget w);
 static void delete_child(Widget w);
+
 static void default_horizontal_font_unit(Widget w, int offset, XrmValue *val);
 static void default_vertical_font_unit(Widget w, int offset, XrmValue *val);
 
@@ -157,7 +165,7 @@ static XtResource resources[] =
     },
 };
 
-
+/* *INDENT-OFF* */
 static XmBaseClassExtRec _XmScreenCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -232,6 +240,7 @@ XmScreenClassRec xmScreenClassRec = {
         /* extension             */ NULL
     }
 };
+/* *INDENT-ON* */
 
 
 WidgetClass xmScreenClass = (WidgetClass)&xmScreenClassRec;
@@ -244,36 +253,33 @@ WidgetClass xmScreenClass = (WidgetClass)&xmScreenClassRec;
 #define PSWC_None               ((XContext) 0)
 static XContext PerScreenWidgetContext = PSWC_None;
 
-
 static void
 class_initialize(void)
 {
     _XmScreenCoreClassExtRec.record_type = XmQmotif;
 
     _XmInvalidCursorIconQuark = XrmStringToQuark(XmNdefaultInvalidCursorIcon);
-    _XmValidCursorIconQuark   = XrmStringToQuark(XmNdefaultValidCursorIcon);
-    _XmNoneCursorIconQuark    = XrmStringToQuark(XmNdefaultNoneCursorIcon);
-    _XmDefaultDragIconQuark   = XrmStringToQuark(XmNdefaultSourceCursorIcon);
-    _XmMoveCursorIconQuark    = XrmStringToQuark(XmNdefaultMoveCursorIcon);
-    _XmCopyCursorIconQuark    = XrmStringToQuark(XmNdefaultCopyCursorIcon);
-    _XmLinkCursorIconQuark    = XrmStringToQuark(XmNdefaultLinkCursorIcon);
+    _XmValidCursorIconQuark = XrmStringToQuark(XmNdefaultValidCursorIcon);
+    _XmNoneCursorIconQuark = XrmStringToQuark(XmNdefaultNoneCursorIcon);
+    _XmDefaultDragIconQuark = XrmStringToQuark(XmNdefaultSourceCursorIcon);
+    _XmMoveCursorIconQuark = XrmStringToQuark(XmNdefaultMoveCursorIcon);
+    _XmCopyCursorIconQuark = XrmStringToQuark(XmNdefaultCopyCursorIcon);
+    _XmLinkCursorIconQuark = XrmStringToQuark(XmNdefaultLinkCursorIcon);
 }
 
-
 static void
 class_part_initialize(WidgetClass widget_class)
 {
     _XmFastSubclassInit(widget_class, XmSCREEN_BIT);
 }
 
-
 static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
     XtPointer FirstScreenWidget;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w, "%s:initialize(%d)\n", 
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "%s:initialize(%d)\n", 
     			__FILE__, __LINE__));
 
     /*
@@ -300,7 +306,7 @@ initialize(Widget request, Widget new_w,
      * appropiate screen.
      */
     if (XFindContext(XtDisplay(new_w), RootWindowOfScreen(XtScreen(new_w)),
-		     PerScreenWidgetContext, (XPointer *)&FirstScreenWidget)
+		     PerScreenWidgetContext, (XtPointer)&FirstScreenWidget)
 	== XCSUCCESS)
     {
 	_XmError(new_w, "Attempt to create a second XmScreen widget.");
@@ -308,7 +314,7 @@ initialize(Widget request, Widget new_w,
     else
     {
 	XSaveContext(XtDisplay(new_w), RootWindowOfScreen(XtScreen(new_w)),
-		     PerScreenWidgetContext, (XPointer)new_w);
+		     PerScreenWidgetContext, (_Xconst char *)new_w);
     }
 
     Screen_MwmPresent(new_w) = XmIsMotifWMRunning(new_w);
@@ -332,7 +338,6 @@ initialize(Widget request, Widget new_w,
     Screen_NullCursor(new_w) = None;
 }
 
-
 static void
 destroy(Widget w)
 {
@@ -356,7 +361,6 @@ destroy(Widget w)
     _XmInvalidateColorCache(False);
 }
 
-
 static void
 insert_child(Widget w)
 {
@@ -384,7 +388,6 @@ insert_child(Widget w)
 
 }
 
-
 static void
 delete_child(Widget w)
 {
@@ -414,18 +417,16 @@ delete_child(Widget w)
     }
 }
 
-
 static void
 realize(Widget w,
 	XtValueMask *value_mask,
 	XSetWindowAttributes *attributes)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:realize(%d)\n", 
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:realize(%d)\n", 
     			__FILE__, __LINE__));
 
 }
 
-
 static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
@@ -462,7 +463,6 @@ set_values(Widget old, Widget request, Widget new_w,
     return need_refresh;
 }
 
-
 static void
 default_horizontal_font_unit(Widget w, int offset, XrmValue *val)
 {
@@ -489,7 +489,6 @@ default_horizontal_font_unit(Widget w, int offset, XrmValue *val)
 	: ((font->min_bounds.width + font->max_bounds.width) * 10 + 11) / 23;
 }
 
-
 static void
 default_vertical_font_unit(Widget w, int offset, XrmValue *val)
 {
@@ -517,8 +516,7 @@ default_vertical_font_unit(Widget w, int offset, XrmValue *val)
 	: ((font->ascent + font->descent) * 10 + 11) / 22;
 }
 
-
-extern XmDragIconObject
+XmDragIconObject
 _XmScreenGetOperationIcon(Widget w, unsigned char operation)
 {
     XmScreen scr;
@@ -569,8 +567,7 @@ _XmScreenGetOperationIcon(Widget w, unsigned char operation)
     return *d;
 }
 
-
-extern XmDragIconObject
+XmDragIconObject
 _XmScreenGetStateIcon(Widget w, unsigned char state)
 {
     XmScreen scr;
@@ -631,8 +628,7 @@ _XmScreenGetStateIcon(Widget w, unsigned char state)
     return Screen_StateCursorIcon(scr);
 }
 
-
-extern XmDragIconObject
+XmDragIconObject
 _XmScreenGetSourceIcon(Widget w)
 {
     XmScreen scr;
@@ -661,8 +657,7 @@ _XmScreenGetSourceIcon(Widget w)
     return Screen_DefaultSourceCursorIcon(scr);
 }
 
-
-extern Pixmap
+Pixmap
 _XmAllocScratchPixmap(XmScreen xmScreen,
 		      Cardinal depth,
 		      Dimension width,
@@ -670,7 +665,7 @@ _XmAllocScratchPixmap(XmScreen xmScreen,
 {
     XmScratchPixmap pix = NULL;
 
-    DEBUGOUT(_LtDebug(__FILE__, (Widget)xmScreen, "%s:_XmAllocScratchPixmap(%d) - %dx%dx%d\n", 
+    DEBUGOUT(XdbDebug(__FILE__, (Widget)xmScreen, "%s:_XmAllocScratchPixmap(%d) - %dx%dx%d\n", 
     			__FILE__, __LINE__,
     			width, height, depth));
 
@@ -680,7 +675,7 @@ _XmAllocScratchPixmap(XmScreen xmScreen,
 	    pix->width == width && pix->height == height)
 	{
 	    pix->inUse = True;
-	    DEBUGOUT(_LtDebug(__FILE__, (Widget)xmScreen, "\tfrom cache %p\n", 
+	    DEBUGOUT(XdbDebug(__FILE__, (Widget)xmScreen, "\tfrom cache %p\n", 
     			pix->pixmap));
 	    break;
 	}
@@ -699,19 +694,18 @@ _XmAllocScratchPixmap(XmScreen xmScreen,
 	pix->next = Screen_ScratchPixmaps(xmScreen);
 	Screen_ScratchPixmaps(xmScreen) = pix;
 
-	DEBUGOUT(_LtDebug(__FILE__, (Widget)xmScreen, "\tnew %p\n", 
+	DEBUGOUT(XdbDebug(__FILE__, (Widget)xmScreen, "\tnew %p\n", 
 			    pix->pixmap));
     }
     return pix->pixmap;
 }
 
-
-extern void
+void
 _XmFreeScratchPixmap(XmScreen xmScreen, Pixmap pixmap)
 {
     XmScratchPixmap pix;
 
-    DEBUGOUT(_LtDebug(__FILE__, (Widget)xmScreen, "%s:_XmFreeScratchPixmap(%d) - %p\n", 
+    DEBUGOUT(XdbDebug(__FILE__, (Widget)xmScreen, "%s:_XmFreeScratchPixmap(%d) - %p\n", 
     			__FILE__, __LINE__,
     			pixmap));
     for (pix = Screen_ScratchPixmaps(xmScreen); pix != NULL; pix = pix->next)
@@ -729,15 +723,13 @@ _XmFreeScratchPixmap(XmScreen xmScreen, Pixmap pixmap)
     }
 }
 
-
-extern XmDragCursorCache *
+XmDragCursorCache *
 _XmGetDragCursorCachePtr(XmScreen xmScreen)
 {
     return &Screen_CursorCache(xmScreen);
 }
 
-
-extern void
+void
 _XmGetMaxCursorSize(Widget w,
 		    Dimension *width,
 		    Dimension *height)
@@ -749,8 +741,7 @@ _XmGetMaxCursorSize(Widget w,
     *height = Screen_MaxCursorHeight(scr);
 }
 
-
-extern Cursor
+Cursor
 _XmGetNullCursor(Widget w)
 {
     XmScreen scr;
@@ -781,8 +772,7 @@ _XmGetNullCursor(Widget w)
     return Screen_NullCursor(scr);
 }
 
-
-extern Cursor
+Cursor
 _XmGetMenuCursorByScreen(Screen *screen)
 {
     XmScreen scr;
@@ -791,8 +781,7 @@ _XmGetMenuCursorByScreen(Screen *screen)
     return Screen_MenuCursor(scr);
 }
 
-
-extern Boolean
+Boolean
 _XmGetMoveOpaqueByScreen(Screen *screen)
 {
     XmScreen scr;
@@ -801,8 +790,7 @@ _XmGetMoveOpaqueByScreen(Screen *screen)
     return Screen_MoveOpaque(scr);
 }
 
-
-extern unsigned char
+unsigned char
 _XmGetUnpostBehavior(Widget wid)
 {
     XmScreen scr;
@@ -811,8 +799,7 @@ _XmGetUnpostBehavior(Widget wid)
     return Screen_UnpostBehavior(scr);
 }
 
-
-extern int
+int
 _XmGetFontUnit(Screen *screen, int dimension)
 {
     XmScreen scr;
@@ -827,8 +814,7 @@ _XmGetFontUnit(Screen *screen, int dimension)
     return Screen_HorizUnit(scr);
 }
 
-
-extern void
+void
 _XmScreenRemoveFromCursorCache(XmDragIconObject icon)
 {
     XmScreen scr;
@@ -886,8 +872,7 @@ _XmScreenRemoveFromCursorCache(XmDragIconObject icon)
     }
 }
 
-
-extern XmScreenInfo *
+XmScreenInfo *
 _XmGetScreenInfo(Widget scr)
 {
     if (!Screen_ScreenInfo(scr))
@@ -897,9 +882,6 @@ _XmGetScreenInfo(Widget scr)
 
 	state->MU_InDragMode = False;
 	state->MU_InPMMode = False;
-	state->RC_menuFocus.oldWidget = NULL;
-	state->RC_menuFocus.oldFocus = None;
-	state->RC_menuFocus.oldRevert = RevertToNone;
 
 	info->menu_state = (XtPointer)state;
 	info->destroyCallbackAdded = False;
@@ -910,18 +892,17 @@ _XmGetScreenInfo(Widget scr)
     return (XmScreenInfo *)Screen_ScreenInfo(scr);
 }
 
-
-extern Widget
+Widget
 XmGetXmScreen(Screen *scr)
 {
     Widget disp;
     Widget screen;
     int argc;
-    Arg args[4];
+    Arg args[5];
     char name[128];
     int screen_no, max_screens;
 
-    DEBUGOUT(_LtDebug0(__FILE__, (Widget)NULL, "%s:XmGetXmScreen(%d)\n", 
+    DEBUGOUT(XdbDebug0(__FILE__, (Widget)NULL, "%s:XmGetXmScreen(%d)\n", 
     			__FILE__, __LINE__));
 
     disp = XmGetXmDisplay(DisplayOfScreen(scr));
@@ -936,19 +917,19 @@ XmGetXmScreen(Screen *scr)
 	XtSetArg(args[argc], XmNwidth, 1); argc++;
 	XtSetArg(args[argc], XmNheight, 1); argc++;
 	XtSetArg(args[argc], XmNmappedWhenManaged, False); argc++;
-	XtSetArg(args[argc], XmNscreen, scr); argc++;
 
 	max_screens = ScreenCount(DisplayOfScreen(scr));
 	for (screen_no = 0; screen_no < max_screens; screen_no++)
 	{
-	    if (ScreenOfDisplay(DisplayOfScreen(scr), screen_no) ==	scr)
+	    if (ScreenOfDisplay(DisplayOfScreen(scr), screen_no) ==
+		scr)
 	    {
 		break;
 	    }
 	}
 	sprintf(name, "screen%d", screen_no);
 
-	screen = XtCreateWidget(name, xmScreenClass, disp,
+	screen = XtCreateManagedWidget(name, xmScreenClass, disp,
 				       args, argc);
     }
 
