@@ -1,9 +1,8 @@
 /**
  *
- * $Id: ScrollBar.c,v 1.58 2000/09/22 20:35:13 amai Exp $
+ * $Id: ScrollBar.c,v 1.56 1999/10/26 09:25:12 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,22 +22,21 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ScrollBar.c,v 1.58 2000/09/22 20:35:13 amai Exp $";
+static const char rcsid[] = "$Id: ScrollBar.c,v 1.56 1999/10/26 09:25:12 amai Exp $";
 
 #include <LTconfig.h>
-
-#include <stdlib.h>
-#include <limits.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/ScrollBarP.h>
 #include <Xm/ScaleP.h>
+#include <limits.h>
 #include <Xm/ScreenP.h>
 #include <Xm/TransltnsP.h>
 #include <Xm/ScrolledWP.h>
 #include <Xm/RepType.h>
 #include <Xm/VirtKeys.h>
+#include <stdlib.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -829,10 +827,8 @@ destroy(Widget w)
 			     SCB_Pixmap(w));
     }
 
-    if (SCB_Timer(w)) {
+    if (SCB_Timer(w))
 	XtRemoveTimeOut(SCB_Timer(w));
-	SCB_Timer(w) = 0;
-    }
 
     XtReleaseGC(w, SCB_UnavailableGC(w));
     XtReleaseGC(w, SCB_ForegroundGC(w));
@@ -1698,10 +1694,8 @@ Select(Widget sw,
     /* handle non-slider movement */
     if (change_type)
     {
-	if (SCB_Timer(sw)) {
+	if (SCB_Timer(sw))
 	    XtRemoveTimeOut(SCB_Timer(sw));
-	    SCB_Timer(sw) = 0;
-	}
 	XSync(XtDisplay(sw), False);
 	SCB_Timer(sw) = XtAppAddTimeOut(XtWidgetToApplicationContext(sw),
 					SCB_InitialDelay(sw),
