@@ -1,9 +1,8 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/SelectionBox.c,v 1.55 2001/07/31 14:41:59 sholson Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm/SelectionBox.c,v 1.45 1999/10/07 18:18:22 danny Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,14 +22,12 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/SelectionBox.c,v 1.55 2001/07/31 14:41:59 sholson Exp $";
+static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm/SelectionBox.c,v 1.45 1999/10/07 18:18:22 danny Exp $";
 
 #include <LTconfig.h>
-
-#include <stdlib.h>
-
 #include <XmI/XmI.h>
 #include <XmI/MacrosI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/SelectioBP.h>
 #include <Xm/CommandP.h>
@@ -48,7 +45,8 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/SelectionB
 #include <Xm/TextF.h>
 
 #include <XmI/DebugUtil.h>
-
+#include <stdio.h>
+#include <stdlib.h>
 
 /* Forward Declarations */
 
@@ -119,7 +117,7 @@ static XtResource resources[] =
     {
 	XmNtextString, XmCTextString, XmRXmString,
 	sizeof(XmString), Offset(text_string),
-	XmRImmediate, (XtPointer)XmUNSPECIFIED
+	XmRImmediate, (XtPointer)XmUNSPECIFIED /*NULL*/	/* Used to be -1 (XmUNSPECIFIED) */
     },
     {
 	XmNlistItems, XmCItems, XmRXmStringTable,
@@ -265,6 +263,7 @@ static XtActionsRec actions[] =
 	{"SelectionBoxRestore", _XmSelectionBoxRestore},
 };
 
+/* *INDENT-OFF* */
 #if 0
 static XmBaseClassExtRec _XmSelectionBCoreClassExtRec = {
     /* next_extension            */ NULL,
@@ -375,10 +374,10 @@ XmSelectionBoxClassRec xmSelectionBoxClassRec = {
     },
     /* XmSelectionBox part */
     {
-	/* list_callback                */ NULL,
-	/* extension                    */ NULL,
+	/* extension */ NULL,
     }
 };
+/* *INDENT-ON* */
 
 
 
@@ -400,17 +399,9 @@ class_initialize(void)
 static void
 class_part_initialize(WidgetClass widget_class)
 {
-    XmSelectionBoxWidgetClass sbwc = (XmSelectionBoxWidgetClass)widget_class;
-    XmSelectionBoxWidgetClass swc = (XmSelectionBoxWidgetClass)widget_class->core_class.superclass;
-
-    if (sbwc->selection_box_class.list_callback == XmInheritCallbackProc)
-    {
-    	sbwc->selection_box_class.list_callback = swc->selection_box_class.list_callback;
-    }
     _XmFastSubclassInit(widget_class, XmSELECTION_BOX_BIT);
 }
 
-
 /*
  * Determine if the selection is a match with one of the
  * items in the list
@@ -440,7 +431,6 @@ _XmSelectionBoxMatch(XmSelectionBoxWidget w)
     return r;
 }
 
-
 /*
  * When the user clicks on an item in the list, copy its value to the
  * text field.
@@ -459,26 +449,26 @@ ListSingleSelect(Widget w, XtPointer client, XtPointer call)
 
     if (SB_Text(sb) == NULL)
     {
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 			  "ListSingleSelect (No TextField)\n"));
 	return;
     }
 
     if (lp == NULL || lp->item == NULL)
     {
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 			  "ListSingleSelect (NULL)\n"));
 	return;
     }
 
     if (!XmStringGetLtoR(lp->item, XmFONTLIST_DEFAULT_TAG, &s))
     {
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(XdbDebug(__FILE__, w,
 			  "ListSingleSelect (Couldn't convert to string)\n"));
 	return;
     }
 
-    DEBUGOUT(_LtDebug(__FILE__, w,
+    DEBUGOUT(XdbDebug(__FILE__, w,
 		      "ListSingleSelect '%s'\n", s));
 
     XmTextFieldSetString(SB_Text(sb), s);
@@ -487,7 +477,6 @@ ListSingleSelect(Widget w, XtPointer client, XtPointer call)
     XtFree(s);
 }
 
-
 /*
  * This routine is called for any button child of selectionbox for the
  * XmNactivateCallback. Make mapping to XmNokCallback etc.
@@ -501,7 +490,7 @@ _XmSbButton(Widget w, XtPointer client, XtPointer call)
     XmSelectionBoxCallbackStruct cbs;
     int au = 0;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "_XmSbButton\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "_XmSbButton\n"));
 
     if (XmIsList(w))
     {
@@ -599,7 +588,7 @@ _XmSbButton(Widget w, XtPointer client, XtPointer call)
 	{
 	    XtUnmanageChild((Widget)sb);
 
-	    DEBUGOUT(_LtDebug2(__FILE__, (Widget)sb, w, "AutoUnmanage\n"));
+	    DEBUGOUT(XdbDebug2(__FILE__, (Widget)sb, w, "AutoUnmanage\n"));
 
 	    /* XtNpopdownCallback */
 	    XtCallCallbackList(s, Shell_PopdownCallback(s), NULL);
@@ -626,7 +615,7 @@ initialize(Widget request,
 {
     XmSelectionBoxWidget sb = (XmSelectionBoxWidget)new_w;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "initialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -635,7 +624,7 @@ initialize(Widget request,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
 
 
     SB_List(sb) = NULL;
@@ -647,10 +636,6 @@ initialize(Widget request,
 	_XmSelectionBoxCreateList(sb);
     }
 
-    if (SB_SelectionLabelString(sb) != NULL) {
-	SB_SelectionLabelString(sb) = XmStringCopy(SB_SelectionLabelString(sb));
-    }
-
     _XmSelectionBoxCreateSelectionLabel(sb);
     _XmSelectionBoxCreateText(sb);
 
@@ -663,19 +648,6 @@ initialize(Widget request,
     SB_Separator(sb) = NULL;
     if (SB_DialogType(sb) != XmDIALOG_COMMAND)
     {
-	if (SB_OkLabelString(sb) != NULL) {
-	    SB_OkLabelString(sb) = XmStringCopy(SB_OkLabelString(sb));
-	}
-
-	/* ApplyLabelString is handled in FileSB - should it be here? */
-
-	if (SB_CancelLabelString(sb) != NULL) {
-	    SB_CancelLabelString(sb) = XmStringCopy(SB_CancelLabelString(sb));
-	}
-
-	if (SB_HelpLabelString(sb) != NULL) {
-	    SB_HelpLabelString(sb) = XmStringCopy(SB_HelpLabelString(sb));
-	}
 
 	_XmSelectionBoxCreateSeparator(sb);
 	_XmSelectionBoxCreateOkButton(sb);
@@ -743,26 +715,23 @@ initialize(Widget request,
 		/* T. Straumann: List made a copy of the item list;
 		 *				 we have to adjust SB_ListItems
 		 */
-		XtVaGetValues(SB_List(sb), XmNitems, &SB_ListItems(sb), NULL);
+		XtVaGetValues(SB_List(sb), XmNitems, &SB_ListItems(sb), 0);
     }
 }
 
 static void
 destroy(Widget w)
 {
-    DEBUGOUT(_LtDebug("RWS", w,"%s:destroy(%d)\n",
+    DEBUGOUT(XdbDebug("RWS", w,"%s:destroy(%d)\n",
     	__FILE__, __LINE__
     	));
     /* rws 14 Apr 1998
-       Motif does not have this method.  Thats because the strings are
-       shared with the child buttons and the buttons manage the storage.
+       Motif does not have this method.  Then again we all know Motif has
+       memory leaks.
      */
-    if (SB_SelectionLabelString(w)) XmStringFree(SB_SelectionLabelString(w));
     XmStringFree(SB_TextString(w));
-    if (SB_OkLabelString(w))        XmStringFree(SB_OkLabelString(w));
-    if (SB_ApplyLabelString(w))     XmStringFree(SB_ApplyLabelString(w));
-    if (SB_CancelLabelString(w))    XmStringFree(SB_CancelLabelString(w));
-    if (SB_HelpLabelString(w))      XmStringFree(SB_HelpLabelString(w));
+	/* T. Straumann: fixed memory leak */
+	XmStringFree(SB_ApplyLabelString(w));
 }
 
 /*
@@ -782,7 +751,7 @@ set_values(Widget old,
     Arg al[10];
     int ac;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -794,7 +763,7 @@ set_values(Widget old,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     /* this is required for every BB subclass */
     BB_InSetValues(new_w) = True;
@@ -824,7 +793,6 @@ set_values(Widget old,
 	String text;
 
 	SB_TextString(sb) = XmStringCopy(SB_TextString(sb));
-	XmStringFree(SB_TextString(o));
 	if (XmStringGetLtoR(SB_TextString(sb), XmSTRING_DEFAULT_CHARSET, &text))
 	{
 	    XmTextFieldSetString(SB_Text(sb), text);
@@ -837,8 +805,6 @@ set_values(Widget old,
     ac = 0;
     if (NE(SB_SelectionLabelString))
     {
-	SB_SelectionLabelString(sb) = XmStringCopy(SB_SelectionLabelString(sb));
-	XmStringFree(SB_SelectionLabelString(o));
 	XtSetArg(al[ac], XmNlabelString, SB_SelectionLabelString(sb)); ac++;
 	r = True;
     }
@@ -851,8 +817,6 @@ set_values(Widget old,
     ac = 0;
     if (NE(SB_ListLabelString))
     {
-	SB_ListLabelString(sb) = XmStringCopy(SB_ListLabelString(sb));
-	XmStringFree(SB_ListLabelString(o));
 	XtSetArg(al[ac], XmNlabelString, SB_ListLabelString(sb)); ac++;
 	r = True;
     }
@@ -865,8 +829,6 @@ set_values(Widget old,
     ac = 0;
     if (NE(SB_OkLabelString))
     {
-	SB_OkLabelString(sb) = XmStringCopy(SB_OkLabelString(sb));
-	XmStringFree(SB_OkLabelString(o));
 	XtSetArg(al[ac], XmNlabelString, SB_OkLabelString(sb)); ac++;
 	r = True;
     }
@@ -879,8 +841,6 @@ set_values(Widget old,
     ac = 0;
     if (NE(SB_CancelLabelString))
     {
-	SB_CancelLabelString(sb) = XmStringCopy(SB_CancelLabelString(sb));
-	XmStringFree(SB_CancelLabelString(o));
 	XtSetArg(al[ac], XmNlabelString, SB_CancelLabelString(sb)); ac++;
 	r = True;
     }
@@ -893,8 +853,6 @@ set_values(Widget old,
     ac = 0;
     if (NE(SB_ApplyLabelString))
     {
-	SB_ApplyLabelString(sb) = XmStringCopy(SB_ApplyLabelString(sb));
-	XmStringFree(SB_ApplyLabelString(o));
 	XtSetArg(al[ac], XmNlabelString, SB_ApplyLabelString(sb)); ac++;
 	r = True;
     }
@@ -907,8 +865,6 @@ set_values(Widget old,
     ac = 0;
     if (NE(SB_HelpLabelString))
     {
-	SB_HelpLabelString(sb) = XmStringCopy(SB_HelpLabelString(sb));
-	XmStringFree(SB_HelpLabelString(o));
 	XtSetArg(al[ac], XmNlabelString, SB_HelpLabelString(sb)); ac++;
 	r = True;
     }
@@ -1113,7 +1069,7 @@ _XmSelectionBoxGetTextColumns(Widget wid, int resource_offset,
     Arg a;
     int n;
 
-    DEBUGOUT(_LtDebug(__FILE__, wid, "XmSelectionBoxGettTextColumns\n"));
+    DEBUGOUT(XdbDebug(__FILE__, wid, "XmSelectionBoxGettTextColumns\n"));
 
     XtSetArg(a, XmNtextColumns, &n);
     n = -1;
@@ -1127,13 +1083,9 @@ void
 _XmSelectionBoxGetTextString(Widget wid, int resource_offset,
 			     XtArgVal *value)
 {
-    char *str;
+    DEBUGOUT(XdbDebug(__FILE__, wid, "_XmSelectionBoxGetTextString\n"));
 
-    DEBUGOUT(_LtDebug(__FILE__, wid, "_XmSelectionBoxGetTextString\n"));
-
-    str = XmTextFieldGetString(SB_Text(wid));
-    *value = (XtArgVal)XmStringCreateSimple(str);
-    XtFree(str);
+    *value = (XtArgVal)XmStringCreateSimple(XmTextFieldGetString(SB_Text(wid)));
 }
 
 void
@@ -1143,7 +1095,7 @@ _XmSelectionBoxGetListItems(Widget wid, int resource_offset,
     XmStringTable l;
     Arg a;
 
-    DEBUGOUT(_LtDebug(__FILE__, wid,
+    DEBUGOUT(XdbDebug(__FILE__, wid,
 		      "XmSelectionBoxGetListItems(_, %d, _)\n",
 		      resource_offset));
 
@@ -1170,7 +1122,7 @@ _XmSelectionBoxGetListItemCount(Widget wid, int resource_offset,
     Arg a;
     int n;
 
-    DEBUGOUT(_LtDebug(__FILE__, wid, "XmSelectionBoxGetListItemCount\n"));
+    DEBUGOUT(XdbDebug(__FILE__, wid, "XmSelectionBoxGetListItemCount\n"));
 
     XtSetArg(a, XmNitemCount, &n);
     n = -1;
@@ -1223,7 +1175,7 @@ _XmSelectionBoxUpOrDown(Widget wid, XEvent *event,
     int *position_list, position_count, new_position, old_position;
     /* char *selected_text; */
 
-    DEBUGOUT(_LtDebug(__FILE__, wid, "_XmSelectionBoxUpOrDown %s\n",
+    DEBUGOUT(XdbDebug(__FILE__, wid, "_XmSelectionBoxUpOrDown %s\n",
 		      argv ? *argv: "NULL"));
     if (list != NULL && text != NULL)
     {
@@ -1312,7 +1264,7 @@ _XmSelectionBoxRestore(Widget wid, XEvent *event,
     int item_count, *position_list, position_count;
     char *selected_text;
 
-    DEBUGOUT(_LtDebug(__FILE__, wid, "_XmSelectionBoxRestore\n"));
+    DEBUGOUT(XdbDebug(__FILE__, wid, "_XmSelectionBoxRestore\n"));
 
     if (text != NULL && list != NULL)
     {
@@ -1351,7 +1303,7 @@ _XmSelectionBoxGeoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
     register XmKidGeometry boxPtr;
     Cardinal numKids;
     Boolean newRow;
-    Cardinal nrows, i, nextras;
+    int nrows, i, nextras;
     Widget *extras;
 
     numKids = MGR_NumChildren(_w);
@@ -1741,7 +1693,7 @@ XmCreateSelectionDialog(Widget parent, char *name,
     Widget d, r;
     char *s;
     Arg *al = (Arg *)XtCalloc(argcount + 1, sizeof(Arg));
-    Cardinal ac, i;
+    int ac, i;
 
     s = _XmMakeDialogName(name);
 
@@ -1760,7 +1712,7 @@ XmCreateSelectionDialog(Widget parent, char *name,
     XtFree(s);
 
     r = XtCreateWidget(name, xmSelectionBoxWidgetClass, d, al, ac);
-    XtFree((XPointer)al);
+    XtFree((XtPointer)al);
     return r;
 }
 
@@ -1771,7 +1723,7 @@ XmCreatePromptDialog(Widget parent, char *name,
     Widget d, ret;
     char *s;
     Arg *al;
-    Cardinal i;
+    int i;
 
     s = _XmMakeDialogName(name);
 
@@ -1790,13 +1742,12 @@ XmCreatePromptDialog(Widget parent, char *name,
     XtSetArg(al[argcount - 1], XmNdialogType, XmDIALOG_PROMPT);
     ret = XtCreateWidget(name, xmSelectionBoxWidgetClass, d, al, argcount);
 
-    XtFree((XPointer)al);
+    XtFree((XtPointer)al);
 
     return ret;
 }
 
 
-/* This routine is marked as obsolete as of Motif 2.1 */
 Widget
 XmSelectionBoxGetChild(Widget w, unsigned char child)
 {
@@ -1804,15 +1755,17 @@ XmSelectionBoxGetChild(Widget w, unsigned char child)
 
     switch (child)
     {
-
     case XmDIALOG_APPLY_BUTTON:
 	return SB_ApplyButton(sb);
 
     case XmDIALOG_CANCEL_BUTTON:
 	return BB_CancelButton(sb);
 
-    case XmDIALOG_DEFAULT_BUTTON:
-	return BB_DefaultButton(sb);
+    case XmDIALOG_OK_BUTTON:
+	return SB_OkButton(sb);
+
+    case XmDIALOG_FILTER_TEXT:
+	return BB_CancelButton(sb);
 
     case XmDIALOG_HELP_BUTTON:
 	return SB_HelpButton(sb);
@@ -1820,32 +1773,43 @@ XmSelectionBoxGetChild(Widget w, unsigned char child)
     case XmDIALOG_LIST:
 	return SB_List(sb);
 
-    case XmDIALOG_LIST_LABEL:
-	return SB_ListLabel(sb);
-	
-    case XmDIALOG_OK_BUTTON:
-	return SB_OkButton(sb);
-
-    case XmDIALOG_SELECTION_LABEL:
-	return SB_SelectionLabel(sb);
-
     case XmDIALOG_SEPARATOR:
 	return SB_Separator(sb);
 
     case XmDIALOG_TEXT:
 	return SB_Text(sb);
 
-    case XmDIALOG_WORK_AREA:
-      /* TODO: implement this */
+    case XmDIALOG_LIST_LABEL:
+	return SB_ListLabel(sb);
+
+    case XmDIALOG_MESSAGE_LABEL:
 	return NULL;
 
-    /* These are illegal */
+    case XmDIALOG_SELECTION_LABEL:
+	return SB_SelectionLabel(sb);
+
+    case XmDIALOG_SYMBOL_LABEL:
+	return NULL;
+
+    case XmDIALOG_FILTER_LABEL:
+	return NULL;
+
+    case XmDIALOG_DIR_LIST:
+	return NULL;
+
+    case XmDIALOG_DIR_LIST_LABEL:
+	return NULL;
+
+    case XmDIALOG_DEFAULT_BUTTON:
+	return BB_DefaultButton(sb);
+
+	/* These are illegal */
+    case XmDIALOG_NONE:
     default:
 	return NULL;
     }
 }
 
-
 /*      
  * Keep track of button children
  */
@@ -1867,8 +1831,6 @@ insert_child(Widget w)
     }
 #endif
 }
-
-
 static void
 DeleteChild(Widget w)
 {
@@ -1898,13 +1860,12 @@ DeleteChild(Widget w)
 		SB_ListLabel(sb) = NULL;
 }
 
-
 static void
 _XmDialogTypeDefault(Widget w, int offset, XrmValue *value)
 {
     static unsigned char dialog_type;
     
-    DEBUGOUT(_LtDebug(__FILE__, w, "_XmDialogTypeDefault\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "_XmDialogTypeDefault\n"));
     
     dialog_type = XmDIALOG_WORK_AREA;
     
