@@ -1,9 +1,8 @@
 /**
  *
- * $Id: SeparatoG.c,v 1.20 2001/07/27 18:51:57 dannybackx Exp $
+ * $Id: SeparatoG.c,v 1.13 1999/02/02 18:23:37 gritton Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,13 +22,11 @@
  *
  **/
 
-static const char rcsid[] = "$Id: SeparatoG.c,v 1.20 2001/07/27 18:51:57 dannybackx Exp $";
+static const char rcsid[] = "$Id: SeparatoG.c,v 1.13 1999/02/02 18:23:37 gritton Exp $";
 
 #include <LTconfig.h>
-
-#include <string.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/ManagerP.h>
 #include <Xm/SeparatoGP.h>
@@ -37,10 +34,10 @@ static const char rcsid[] = "$Id: SeparatoG.c,v 1.20 2001/07/27 18:51:57 dannyba
 #include <Xm/CacheP.h>
 #include <Xm/RepType.h>
 #include <Xm/RowColumnP.h>
+#include <X11/Xfuncs.h>
 
 #include <XmI/DebugUtil.h>
 
-
 /* Forward Declarations */
 
 static void class_initialize(void);
@@ -301,9 +298,9 @@ secondary_object_create(Widget request,
     XmBaseClassExt *bce;
     XtPointer nsec, rsec;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "SeparatorGCacheRec %s being initialized.\n",
 		      XtName(new_w)));
 
@@ -333,7 +330,7 @@ secondary_object_create(Widget request,
     ed->widget = (Widget)nsec;
     ed->reqWidget = (Widget)rsec;
 
-    memcpy(rsec, nsec, size);
+    bcopy(nsec, rsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     _XmPushWidgetExtData(new_w, ed, XmCACHE_EXTENSION);
@@ -345,7 +342,7 @@ secondary_object_create(Widget request,
 int
 _XmSeparatorCacheCompare(XtPointer A, XtPointer B)
 {
-    return !memcmp(((XmSeparatorGCacheObjPart *)A),
+    return !bcmp(((XmSeparatorGCacheObjPart *)A),
 		 ((XmSeparatorGCacheObjPart *)B),
 		 sizeof(XmSeparatorGCacheObjPart));
 }
@@ -376,7 +373,7 @@ static void
 initialize_prehook(Widget request, Widget new_w,
 		   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebug(__FILE__, new_w, "SeparatoG InitializePrehook\n"));
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "SeparatoG InitializePrehook\n"));
 
     /*
      * We should allocate secondary object here, using _XmExtObjAlloc (to create
@@ -400,7 +397,7 @@ initialize_posthook(Widget request, Widget new_w,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w, "SeparatoG InitializePosthook\n"));
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "SeparatoG InitializePosthook\n"));
 
     /* don't let the null fool you */
     SEPG_Cache(new_w) = (XmSeparatorGCacheObjPart *)
@@ -537,7 +534,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
     XtPointer nsec, rsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -557,9 +554,9 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
     ExtObj_LogicalParent(nsec) = new_w;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    memcpy(&((XmSeparatorGCacheObject)nsec)->separator_cache,
-           SEPG_Cache(new_w),
-	   sizeof(XmSeparatorGCacheObjPart));
+    bcopy(SEPG_Cache(new_w),
+	  &((XmSeparatorGCacheObject)nsec)->separator_cache,
+	  sizeof(XmSeparatorGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -574,7 +571,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 		   (*bce)->secondaryObjectClass->core_class.num_resources,
 		   args, *num_args);
 
-    memcpy(rsec, nsec, size);
+    bcopy(nsec, rsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     SEPG_Cache(new_w) = &(((XmSeparatorGCacheObject)nsec)->separator_cache);
@@ -712,7 +709,7 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
     XtPointer nsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -731,9 +728,9 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
     ExtObj_LogicalParent(nsec) = new_w;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    memcpy(&((XmSeparatorGCacheObject)nsec)->separator_cache,
-           SEPG_Cache(new_w),
-	   sizeof(XmSeparatorGCacheObjPart));
+    bcopy(SEPG_Cache(new_w),
+	  &((XmSeparatorGCacheObject)nsec)->separator_cache,
+	  sizeof(XmSeparatorGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -763,7 +760,7 @@ get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args)
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w,
+    DEBUGOUT(XdbDebug(__FILE__, w,
 		      "XmSeparatorGadget %s Expose (shadowThickness %d)\n",
 		      XtName(w), G_ShadowThickness(w)));
 
