@@ -1,9 +1,8 @@
 /**
  *
- * $Id: Simple.c,v 1.25 2000/09/22 20:35:13 amai Exp $
+ * $Id: Simple.c,v 1.21 1999/08/14 12:17:14 danny Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,14 +22,14 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Simple.c,v 1.25 2000/09/22 20:35:13 amai Exp $";
-
-#include <LTconfig.h>
+static const char rcsid[] = "$Id: Simple.c,v 1.21 1999/08/14 12:17:14 danny Exp $";
 
 #include <stdio.h>
-#include <string.h>
 
+#include <LTconfig.h>
 #include <XmI/XmI.h>
+
+#include <X11/Xfuncs.h>
 #include <Xm/XmP.h>
 #include <Xm/RowColumnP.h>
 #include <Xm/CascadeBG.h>
@@ -42,7 +41,6 @@ static const char rcsid[] = "$Id: Simple.c,v 1.25 2000/09/22 20:35:13 amai Exp $
 
 #include <XmI/DebugUtil.h>
 
-
 /* For the prototype police */
 extern Widget _XmCreateSimpleGadget(char *name, Widget parent, int def_type,
 				    XmSimpleMenu data, int which,
@@ -257,7 +255,7 @@ XmCreateSimpleCheckBox(Widget parent,
     }
 #endif
 
-    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
+    bzero((void *)&data, sizeof(XmSimpleMenuRec));
 
     n = 0;
     XtSetArg(myArgList[n], XmNrowColumnType, XmWORK_AREA);
@@ -313,7 +311,7 @@ XmCreateSimpleMenuBar(Widget parent,
     }
 #endif
 
-    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
+    bzero((void *)&data, sizeof(XmSimpleMenuRec));
 
     n = 0;
     XtSetArg(myArgList[n], XmNrowColumnType, XmMENU_BAR);
@@ -371,7 +369,7 @@ XmCreateSimpleOptionMenu(Widget parent,
     }
 #endif
 
-    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
+    bzero((void *)&data, sizeof(XmSimpleMenuRec));
 
     XtGetSubresources(parent, (XtPointer)&data, name, XmCSimpleOptionMenu,
 		      simple_resources, XtNumber(simple_resources),
@@ -431,7 +429,7 @@ XmCreateSimpleOptionMenu(Widget parent,
 		tmp = _XmCreateSimpleGadget(buf, RC_OptionSubMenu(rc),
 				      data.button_type[i],
 				      &data, i, bcnt - 1, arglist, argcount);
-		if (data.button_type[i] == XmPUSHBUTTON && data.button_set == bcnt - 1)
+		if (data.button_set == bcnt)
 		{
 		    XtVaSetValues(rc,
 			    XmNmenuHistory, tmp,
@@ -499,7 +497,7 @@ XmCreateSimplePopupMenu(Widget parent,
     }
 #endif
 
-    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
+    bzero((void *)&data, sizeof(XmSimpleMenuRec));
 
     rc = XmCreatePopupMenu(parent, name, arglist, argcount);
 
@@ -572,7 +570,7 @@ XmCreateSimplePulldownMenu(Widget parent,
     }
 #endif
 
-    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
+    bzero((void *)&data, sizeof(XmSimpleMenuRec));
 
     rc = XmCreatePulldownMenu(parent, name, arglist, argcount);
 
@@ -711,7 +709,7 @@ XmCreateSimpleRadioBox(Widget parent,
     }
 #endif
 
-    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
+    bzero((void *)&data, sizeof(XmSimpleMenuRec));
 
     n = 0;
     XtSetArg(myArgList[n], XmNrowColumnType, XmWORK_AREA); n++;
