@@ -1,9 +1,8 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/TextStrSo.c,v 1.56 2001/07/27 18:51:57 dannybackx Exp $
+ * $Header: /cvsroot/hungry/lesstif/lib/Xm/TextStrSo.c,v 1.33 1999/08/07 15:32:55 rwscott Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: TextStrSo.c,v 1.56 2001/07/27 18:51:57 dannybackx Exp $";
+static const char rcsid[] = "$Id: TextStrSo.c,v 1.33 1999/08/07 15:32:55 rwscott Exp $";
 
 /*
  * Empirical evidence (fooling around with the structures found in Motif
@@ -40,22 +39,26 @@ static const char rcsid[] = "$Id: TextStrSo.c,v 1.56 2001/07/27 18:51:57 dannyba
 #define	DO_SANITY
 
 /* Defining this is a bit too verbose for my liking ... */
-#undef VERBOSE__LtDebug
+#undef VERBOSE_XdbDebug
 
 #include <LTconfig.h>
-
-#include <string.h>
-#include <stdlib.h>
-
 #include <Xm/XmP.h>
 #include <Xm/TextP.h>
-#include <Xm/VendorSEP.h>
-#include <Xm/AtomMgr.h>
+#include <X11/Xfuncs.h>
+#ifdef HAVE_STRING_H
+#include <string.h>
+#define ANSI_STRING
+#else
+#include <strings.h>
+#endif
+#include <stdlib.h>
 
 #include <XmI/DebugUtil.h>
 
 #define SOURCE_ALLOC_SIZE 256
 
+void _XmTextInvalidate(XmTextWidget w, XmTextPosition position,
+		       XmTextPosition topos, long delta);
 
 static char *
 StrPtr(XmSourceData d, XmTextPosition pos)
@@ -66,7 +69,6 @@ StrPtr(XmSourceData d, XmTextPosition pos)
     return ptr;
 }
 
-
 #if 0
 static char *
 StrNext(XmSourceData d, XmTextPosition pos)
@@ -74,7 +76,6 @@ StrNext(XmSourceData d, XmTextPosition pos)
     return d->ptr + pos + 1;
 }
 
-
 static char *
 StrPrev(XmSourceData d, XmTextPosition pos)
 {
@@ -118,13 +119,12 @@ AddWidget(XmTextSource source, XmTextWidget w)
 	else
 	{
 	    d->value = XtNewString(d->value);
-/*CP:wrong - the "old_length" is the lengh in chars of the longest line
 	    d->old_length = (d->value) ? strlen(d->value) : 0;
-*/
 	}
-	d->length = (d->value) ? strlen(d->value) : 0;
-	d->maxlength = d->length + SOURCE_ALLOC_SIZE;
+
+	d->maxlength = d->old_length + SOURCE_ALLOC_SIZE;
 	d->ptr = XtMalloc(d->maxlength + 1);
+	d->length = d->old_length;
 	strcpy(d->ptr, d->value);
 
 	d->gap_start = d->ptr;
@@ -242,13 +242,7 @@ ReadSource(XmTextSource source,
 
     block->ptr[len] = '\0';
 
-    if ( d->old_length < ( last - pos ) )
-    	{
-    	if ( ( pos == 0 || d->ptr[pos-1] == '\n' ) &&
-    		( last == d->length || d->ptr[last] == '\n' ) && len > d->old_length )
-	    d->old_length = len;
-	}
-    return last;
+    return pos;
 }
 
 /* Replace ------------------------------------------------------------------
@@ -273,7 +267,7 @@ CheckSize(XmSourceData d, int len)
 	d->maxlength += i + 1;
 	d->ptr = XtRealloc(d->ptr, d->maxlength);
 
-	DEBUGOUT(_LtDebug(__FILE__, NULL,
+	DEBUGOUT(XdbDebug(__FILE__, NULL,
 			  "*source->CheckSize: Alloced new space\n"));
     }
 }
@@ -322,134 +316,74 @@ Replace(XmTextWidget w,
 {
     XmSourceData d;
     int i;
-    XmTextPosition start, end, lastPos = 0;
+    XmTextPosition start, end;
     XmTextVerifyCallbackStruct cbs;
 
-    if (!call_callback || _XmTextModifyVerify(w, ev, startret, endret, &Text_CursorPos(w), block, NULL, False))
+    d = Text_Source(w)->data;
+
+    start = *startret;
+    end = *endret;
+
+    if (start > end)
     {
-	d = Text_Source(w)->data;
+	int swap;
 
-	start = *startret;
-	end = *endret;
+	swap = start;
+	start = end;
+	end = swap;
+    }
 
-	if (start > end)
+    if (end > d->length)
+    {
+	end = d->length;
+    }
+
+    if (start > d->length)
+    {
+	return EditError;
+    }
+
+    if ( ( start >= end ) &&
+               d->length + (end - start) + block->length > d->maxallowed)
+    {
+	return EditError;
+    }
+
+
+    for (i = 0; i < d->numwidgets; i++)
+    {
+	_XmTextDisableRedisplay(d->widgets[i], True);
+    }
+
+    if (end > start)
+    {				/* we need to delete some stuff */
+	char *dest, *source, *last;
+
+	dest = d->ptr + start;
+	source = d->ptr + end;
+	last = d->ptr + d->length;
+	while (source < last)
 	{
-	    int swap;
-
-	    swap = start;
-	    start = end;
-	    end = swap;
+	    *dest++ = *source++;
 	}
 
-	if (end > d->length)
-	{
-	    end = d->length;
-	}
+	d->length -= end - start;
+    }
 
-	if (start > d->length)
-	{
-	    return EditError;
-	}
+    if (block && block->length > 0)
+    {
+	CheckSize(d, block->length);
+	Insert(d, start, block->ptr, block->length);
+    }
 
-	if ( ( start >= end ) &&
-		   d->length + (end - start) + block->length > d->maxallowed)
-	{
-	    return EditError;
-	}
+    for (i = 0; i < d->numwidgets; i++)
+    {
+	Text_LastPos(d->widgets[i]) = d->length;
+    }
 
-	for (i = 0; i < d->numwidgets; i++)
-	{
-	    _XmTextDisableRedisplay(d->widgets[i], True);
-	}
-
-	if (end > start)
-	{				/* we need to delete some stuff */
-	    char *dest, *source, *last;
-
-	    dest = d->ptr + start;
-	    source = d->ptr + end;
-	    last = d->ptr + d->length;
-	    while (source < last)
-	    {
-		*dest++ = *source++;
-	    }
-
-	    d->length -= end - start;
-	}
-
-	if (block && block->length > 0)
-	{
-	    CheckSize(d, block->length);
-	    Insert(d, start, block->ptr, block->length);
-	}
-
-	for (i = 0; i < d->numwidgets; i++)
-	{
-	    XmTextPosition startPos = (*Text_Source(w)->Scan)(Text_Source(w), 0, XmSELECT_ALL, XmsdLeft, 1, False ) ;
-	    lastPos = (*Text_Source(w)->Scan)(Text_Source(w), startPos, XmSELECT_ALL, XmsdRight, 1, False ) ;
-	}
-
-       if ( d -> hasselection )
-	    {
-	    /* rws 15 Jan 2000
-	       What if only part of the selection is being replaced???
-	    if ( start == d->left && end == d-> right )
-	    */
-	    if ( start <= d->right && end >= d->left )
-		{
-		    /* CP:15 May 1999: If the text we are replacing is the
-		    ** selected text then unselect it. */
-		d->hasselection = False;
-		for (i = 0; i < d->numwidgets; i++)
-		  {
-#if 0
-		    _XmHighlightRecNode* p;
-		    p = Text_Highlight(d->widgets[i]).list;
-		    while (p) {
-		      _XmHighlightRecNode* k=p;
-		      p = p->next;
-		      XtFree((XtPointer)k);
-		    }
-		    Text_Highlight(d->widgets[i]).list = NULL;
-#else
-		    Text_Highlight(d->widgets[i]).number = 0;
-#endif
-		  }
-		}
-	    /*CP:15 May 1999:
-		    at this point we do not want to overwrite the selection
-		    but just to move its coordinates if we are inserting
-		    text before the selection. */
-
-	    else if ( start <  d-> left )
-		    {
-		    d-> left += block -> length;
-		    d-> right += block -> length;
-		    for (i = 0; i < d->numwidgets; i++)
-			    {
-			    XmTextSetHighlight((Widget)d->widgets[i],
-				    d-> left, d->right, XmHIGHLIGHT_SELECTED);
-			    }
-		    }
-	    }
-	/* End selection */
-
-	if (Text_CursorPos(w) == Text_LastPos(w))
-	{
-	    if (call_callback)
-	    {
-		Text_LastPos(w) = lastPos;
-	    }
-	    if (lastPos != Text_CursorPos(w))
-	    {
-		_XmTextSetCursorPosition((Widget)w, lastPos);
-	    }
-	}
-	Text_LastPos(w) = lastPos;
-	if (Text_CursorPos(w) > Text_LastPos(w))
-	{
-	    Text_CursorPos(w) = Text_LastPos(w);
-	}
+    /* Callback : only do this for the widget activating this ! */
+    if (call_callback)
+    {
 	if (Text_ValueChangedCallback(w))
 	{
 	    cbs.reason = XmCR_VALUE_CHANGED;
@@ -459,38 +393,68 @@ Replace(XmTextWidget w,
 
 	    XtCallCallbacks((Widget)w, XmNvalueChangedCallback, &cbs);
 	}
+    }
 
-	for (i = 0; i < d->numwidgets; i++)
+   if ( d -> hasselection )
 	{
-	    _XmTextUpdateLineTable((Widget)d->widgets[i], start, end, block, True);
-	}
+	if ( start == d->left && end == d-> right )
+	    {
+		/* CP:15 May 1999: If the text we are replacing is the
+		** selected text then unselect it. */
+	    d->hasselection = False;
+	    for (i = 0; i < d->numwidgets; i++)
+		{
+		Text_Highlight(d->widgets[i]).number = 0;
+	 	}
+	    }
+	/*CP:15 May 1999:
+		at this point we do not want to overwrite the selection
+		but just to move its coordinates if we are inserting
+		text before the selection. */
 
-	for (i = 0; i < d->numwidgets; i++)
-	{
-	    _XmTextInvalidate(d->widgets[i], start, end,
-			      block->length - end + start);
+	else if ( start <  d-> left )
+		{
+		d-> left += block -> length;
+		d-> right += block -> length;
+		for (i = 0; i < d->numwidgets; i++)
+			{
+			XmTextSetHighlight((Widget)d->widgets[i],
+				d-> left, d->right, XmHIGHLIGHT_SELECTED);
+			}
+		}
 	}
+    /* End selection */
+
+    for (i = 0; i < d->numwidgets; i++)
+    {
+	_XmTextUpdateLineTable((Widget)d->widgets[i], start, end, block, True);
+    }
+
+    for (i = 0; i < d->numwidgets; i++)
+    {
+	_XmTextInvalidate(d->widgets[i], start, end,
+			  block->length - end + start);
+    }
 
 #if 0
-	/* Update the insertion position */
-	for (i = 0; i < d->numwidgets; i++)
-	{
-	    XmTextPosition	p = Text_CursorPos(d->widgets[i]);
+    /* Update the insertion position */
+    for (i = 0; i < d->numwidgets; i++)
+    {
+	XmTextPosition	p = Text_CursorPos(d->widgets[i]);
 
-	    if (p < *startret) {
-		    /* no action */
-	    } else if (p < *endret) {
-		    _XmTextSetCursorPosition(d->widgets[i], *startret);
-	    } else {
-		    _XmTextSetCursorPosition(d->widgets[i], p + block->length);
-	    }
+	if (p < *startret) {
+		/* no action */
+	} else if (p < *endret) {
+		_XmTextSetCursorPosition(d->widgets[i], *startret);
+	} else {
+		_XmTextSetCursorPosition(d->widgets[i], p + block->length);
 	}
+    }
 #endif
 
-	for (i = 0; i < d->numwidgets; i++)
-	{
-	    _XmTextEnableRedisplay(d->widgets[i]);
-	}
+    for (i = 0; i < d->numwidgets; i++)
+    {
+	_XmTextEnableRedisplay(d->widgets[i]);
     }
 
     return EditDone;
@@ -517,17 +481,14 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
     XmSourceData d = source->data;
     Boolean found = False;
     char *ptr;
-#ifdef VERBOSE__LtDebug
+#ifdef VERBOSE_XdbDebug
     XmTextPosition ipos = pos;
 #endif
 
     if (pos > d->length)
     {
-#if 0
-	/* This is reported to be a bad idea. */
-	pos = d->length;
-#endif
 	return(pos);
+	pos = d->length;
     }
 
     if (count < 0)
@@ -548,6 +509,7 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
 	ptr = StrPtr(d, pos - 1);
 	while (count > 0 && pos > 0 && InWhiteSpace(*ptr))
 	{
+	    count--;
 	    pos--;
 	    ptr = StrPtr(d, pos - 1);
 	}
@@ -557,6 +519,7 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
 	ptr = StrPtr(d, pos);
 	while (count > 0 && pos < d->length && InWhiteSpace(*ptr))
 	{
+	    count--;
 	    pos++;
 	    ptr = StrPtr(d, pos);
 	}
@@ -599,12 +562,6 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
 		}
 		break;
 
-	    case XmSELECT_ALL:
-		/*CP: probably a bit too simple */
-		found = True;
-		pos = 0;
-		break;
-
 	    default:
 		found = True;
 		break;
@@ -612,17 +569,15 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
 
 	    if (found)
 	    {
-#ifdef VERBOSE__LtDebug
-		DEBUGOUT(_LtDebug(__FILE__, (Widget)d->widgets[0],
+#ifdef VERBOSE_XdbDebug
+		DEBUGOUT(XdbDebug(__FILE__, (Widget)d->widgets[0],
 				  "Scan(%d)=>%d\n", ipos, pos));
 #endif
-		count--;
-		if ( count == 0 )
-		    return ( inc ? pos - 1 : pos );
-		found = False;    
+		return pos;
 	    }
 
 	    pos--;
+	    count--;
 	}
     }
     else
@@ -660,13 +615,6 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
 		}
 		break;
 
-	    case XmSELECT_ALL:
-		if (! *ptr )
-		{
-		    found = True;
-		}
-		break;
-
 	    default:
 		found = True;
 		break;
@@ -674,38 +622,25 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
 
 	    if (found)
 	    {
-#ifdef VERBOSE__LtDebug
-		DEBUGOUT(_LtDebug(__FILE__, (Widget)d->widgets[0],
+#ifdef VERBOSE_XdbDebug
+		DEBUGOUT(XdbDebug(__FILE__, (Widget)d->widgets[0],
 				  "Scan(%d)=>%d\n", ipos, pos));
 #endif
-		count--;
-		if ( count == 0 )
-		    return ( inc ? pos+1 : pos );
-		found = False;    
-		if ( type == XmSELECT_WORD )
-		    while ( InWhiteSpace(*ptr ) )
-			{
-			pos++;
-			ptr = StrPtr(d, pos);
-			}
+		return pos;
 	    }
 
 	    pos++;
+	    count--;
 	}
     }
 
-#ifdef VERBOSE__LtDebug
-    DEBUGOUT(_LtDebug(__FILE__, (Widget)d->widgets[0],
+#ifdef VERBOSE_XdbDebug
+    DEBUGOUT(XdbDebug(__FILE__, (Widget)d->widgets[0],
 		      "Scan(%d)=>%d\n", ipos, pos));
 #endif
-    if ( dir == XmsdRight && pos != d->length )
-	return ( inc ? pos+1 : pos );
-    if ( dir == XmsdLeft && pos != 0 )
-	return ( inc ? pos - 1 : pos );
     return pos;
 }
 
-
 static Boolean
 GetSelection(XmTextSource source, XmTextPosition *left,
 	     XmTextPosition *right)
@@ -743,10 +678,11 @@ _XmTextConvertSelection(Widget w, Atom *selection, Atom *target, Atom *type,
 {
     XmSourceData d = Text_Source(w)->data;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextConvertSelection\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "_XmTextConvertSelection\n"));
 
-    if (d->hasselection)
+    if (*target == XA_STRING && d->hasselection)
     {
+	*length = (long)(d->right - d->left);
 #if 0
 	/* rws 12 Dec 1997
 	   I think we need to make a copy of the value here. In ml if you
@@ -755,49 +691,11 @@ _XmTextConvertSelection(Widget w, Atom *selection, Atom *target, Atom *type,
 	   the contents of value.
 	 */
 	*value = &d->ptr[d->left];
+#else
+	*value = XtMalloc(d->right - d->left + 1);
+	strncpy(*value, &d->ptr[d->left], d->right - d->left);
 #endif
-	Atom atom_comp_text;
-	Atom atom_text;
-
-	atom_comp_text =  XmInternAtom(XtDisplay(w), "COMPOUND_TEXT", False);
-	atom_text =  XmInternAtom(XtDisplay(w), "TEXT", False);
-	if (*target == XA_STRING){
-	    *length = (long)(d->right - d->left);
-	    *value = XtMalloc(d->right - d->left + 1);
-	    strncpy((char *)*value, &d->ptr[d->left], d->right - d->left);
-	    *type = XA_STRING;
-	}
-	else if (*target == atom_comp_text || *target == atom_text){
-
-	    XTextProperty prop;
-	    char *buf;
-	    int ret;
-
-	    buf = XtMalloc(d->right - d->left + 1);
-	    strncpy(buf, &d->ptr[d->left], d->right - d->left);
-	    buf[d->right - d->left] = '\0';
-
-	    ret = XmbTextListToTextProperty(XtDisplay(w), &buf, 1,
-	    			XCompoundTextStyle, &prop);
-
-	    XtFree(buf);
-	    if (ret != 0){
-	    	*length = 0;
-	    	*value  = NULL;
-	    }
-	    else{
-	    	buf = XtMalloc(prop.nitems + 1);
-		strncpy(buf, prop.value, prop.nitems);
-		buf[prop.nitems] = '\0';
-	    	*length = prop.nitems;
-	    	*value  = buf;
-	    }
-	    *type = atom_comp_text;
-
-	}
-	else
-	    return False;
-
+	*type = XA_STRING;
 	*format = 8;
 	return True;
     }
@@ -816,7 +714,7 @@ _XmTextLoseSelection(Widget w, Atom *selection)
 
     if (*selection == XA_PRIMARY)
     {
-	DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextLoseSelection(PRIMARY)\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "_XmTextLoseSelection(PRIMARY)\n"));
 
 	XmTextSetHighlight(w, 0, XmTextGetLastPosition(w),
 			   XmHIGHLIGHT_NORMAL);
@@ -833,7 +731,7 @@ _XmTextLoseSelection(Widget w, Atom *selection)
     }
     else
     {
-	DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextLoseSelection(?)\n"));
+	DEBUGOUT(XdbDebug(__FILE__, w, "_XmTextLoseSelection(???)\n"));
 	/* ??? */
     }
 }
@@ -855,7 +753,7 @@ SetSelection(XmTextSource source, XmTextPosition left,
     int i;
     Boolean gain = False;
 
-    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmTextStrSource SetSelection %d %d\n",
+    DEBUGOUT(XdbDebug(__FILE__, NULL, "XmTextStrSource SetSelection %d %d\n",
 		      left, right));
 
     if (left >= right)
@@ -892,7 +790,7 @@ SetSelection(XmTextSource source, XmTextPosition left,
     source->data->prim_time = time;
 
     /* Xt, callbacks */
-    DEBUGOUT(_LtDebug(__FILE__, (Widget)d->widgets[0],
+    DEBUGOUT(XdbDebug(__FILE__, (Widget)d->widgets[0],
 		      "XtOwnSelection(_, XA_PRIMARY, ...)\n"));
 
     if (!XtOwnSelection((Widget)d->widgets[0], XA_PRIMARY, time,
@@ -923,7 +821,7 @@ SetSelection(XmTextSource source, XmTextPosition left,
     }
 }
 
-static XmTextSourceRec sourceRec =
+XmTextSourceRec sourceRec =
 {
     /* _XmSourceDataRec      */ NULL,
     /* AddWidgetProc         */ AddWidget,
@@ -936,8 +834,7 @@ static XmTextSourceRec sourceRec =
     /* SetSelectionProc      */ SetSelection
 };
 
-
-extern XmTextSource
+XmTextSource
 _XmStringSourceCreate(char *value, Boolean is_wchar)
 {
     XmTextSource source;
@@ -945,7 +842,7 @@ _XmStringSourceCreate(char *value, Boolean is_wchar)
 
 
     source = (XmTextSource)XtMalloc(sizeof(XmTextSourceRec));
-    memcpy(source, &sourceRec, sizeof(XmTextSourceRec));
+    bcopy(&sourceRec, source, sizeof(XmTextSourceRec));
 
     d = (XmSourceData)XtMalloc(sizeof(XmSourceDataRec));
     d->source = source;
@@ -953,13 +850,9 @@ _XmStringSourceCreate(char *value, Boolean is_wchar)
     d->numwidgets = 0;
     d->value = value;
     d->ptr = d->gap_start = d->gap_end = NULL;
-    d->length = d->maxlength = d->maxallowed = 0;
-    d->old_length = 1;
-    d->right = d->left = 0;
+    d->length = d->old_length = d->maxlength = d->maxallowed = 0;
     d->hasselection = False;
-    d->prim_time = 0;
-	/*CP: How do I set the character used for new lines ?? : FIXME */
-    d->PSWC_NWLN= XtNewString("\n");
+
     source->data = d;
 
     return source;
@@ -972,7 +865,7 @@ _XmStringSourceCreate(char *value, Boolean is_wchar)
  */
 
 
-extern void
+void
 _XmStringSourceDestroy(XmTextSource source)
 {
     XmSourceData d = source->data;
@@ -995,13 +888,11 @@ _XmStringSourceDestroy(XmTextSource source)
     }
 	/* tills 12 apr 1999 free the widget list also (memleak) */
 	XtFree((char*)d->widgets);
-    XtFree(d->PSWC_NWLN);
     XtFree((char *)d);
     XtFree((char *)source);
 }
 
-
-extern char *
+char *
 _XmStringSourceGetValue(XmTextSource source, Boolean want_wchar)
 {
     XmSourceData d = source->data;
@@ -1009,13 +900,10 @@ _XmStringSourceGetValue(XmTextSource source, Boolean want_wchar)
 
     if (want_wchar)
     {
-	DEBUGOUT(_LtDebug(__FILE__, NULL,
+	DEBUGOUT(XdbDebug(__FILE__, NULL,
 	   "_XmStringSourceGetValue: wide characters not implemented yet.\n"));
 
-	/* Returning NULL seems to do strange things */
-	txt = XtMalloc(1);
-	txt[0] = '\0';
-	return txt;
+	return NULL;
     }
 
     txt = XtMalloc(d->length + 1);
@@ -1023,22 +911,20 @@ _XmStringSourceGetValue(XmTextSource source, Boolean want_wchar)
     strncpy(txt, d->ptr, d->length);
     txt[d->length] = '\0';
 
-    DEBUGOUT(_LtDebug(__FILE__, NULL,
+    DEBUGOUT(XdbDebug(__FILE__, NULL,
 		      "_XmStringSourceGetValue => %p '%s'\n", txt, txt));
 
     return txt;
 }
 
-
-extern void
+void
 _XmStringSourceSetValue(XmTextWidget w, char *value)
 {
     XmTextVerifyCallbackStruct cbs;
     XmTextBlockRec tb;
     int len;
 
-    (Text_Source(w)->SetSelection)(Text_Source(w),1,0,
-		XtLastTimestampProcessed ( XtDisplay ( w ) ));
+    SetSelection(Text_Source(w),-1,-1,CurrentTime);
 
     len = value ? strlen(value) : 0;
 
@@ -1046,9 +932,9 @@ _XmStringSourceSetValue(XmTextWidget w, char *value)
     cbs.doit = True;
     cbs.event = NULL;
     cbs.startPos = 0;
-    cbs.endPos = Text_LastPos(w);
+    cbs.endPos = Text_Source(w)->data->length;
     cbs.currInsert = Text_CursorPos(w);
-    cbs.newInsert = Text_CursorPos(w);
+    cbs.newInsert = len;
 
     if (value)
     {
@@ -1083,20 +969,7 @@ _XmStringSourceSetValue(XmTextWidget w, char *value)
 #endif
     if (cbs.doit)
     {
-	XmTextStatus status ;
-	Text_BottomPos(w) = 0; /*CP: probably not the right value or place for initialization !*/
-	status = (Text_Source(w)->Replace)(w, NULL, &cbs.startPos, &cbs.endPos, &tb, False);
-        /* rws 2 Apr 2000
-           Done in Replace
-        if ( (status == EditDone) && ( Text_ValueChangedCallback(w)) )
-        {
-            XmAnyCallbackStruct any;
-            any.reason = XmCR_VALUE_CHANGED;
-            any.event = NULL;
-
-            XtCallCallbacks((Widget)w, XmNvalueChangedCallback, &any );
-        }
-        */
+	Replace(w, NULL, &cbs.startPos, &cbs.endPos, &tb, True);
     }
 #if 0
     else {
@@ -1109,22 +982,19 @@ _XmStringSourceSetValue(XmTextWidget w, char *value)
     }
 }
 
-
-extern Boolean
+Boolean
 _XmStringSourceHasSelection(XmTextSource source)
 {
     return source->data->hasselection;
 }
 
-
-extern Boolean
+Boolean
 _XmStringSourceGetEditable(XmTextSource source)
 {
     return source->data->editable;
 }
 
-
-extern void
+void
 _XmStringSourceSetEditable(XmTextSource source, Boolean editable)
 {
     XmSourceData d;
@@ -1133,15 +1003,13 @@ _XmStringSourceSetEditable(XmTextSource source, Boolean editable)
     d->editable = editable;
 }
 
-
-extern int
+int
 _XmStringSourceGetMaxLength(XmTextSource source)
 {
     return source->data->maxlength;
 }
 
-
-extern void
+void
 _XmStringSourceSetMaxLength(XmTextSource source, int max)
 {
     XmSourceData d;
@@ -1162,8 +1030,7 @@ _XmStringSourceSetMaxLength(XmTextSource source, int max)
     d->maxallowed = max;
 }
 
-
-extern char *
+char *
 _XmStringSourceGetString(XmTextWidget w,
 			 XmTextPosition from,
 			 XmTextPosition to,
@@ -1176,7 +1043,7 @@ _XmStringSourceGetString(XmTextWidget w,
 #else
     if (want_wchar)
     {
-	DEBUGOUT(_LtDebug(__FILE__, NULL,
+	DEBUGOUT(XdbDebug(__FILE__, NULL,
 	  "_XmStringSourceGetString: wide characters not implemented yet.\n"));
 
 	return NULL;
@@ -1186,7 +1053,7 @@ _XmStringSourceGetString(XmTextWidget w,
 }
 
 
-extern Boolean
+Boolean
 _XmTextFindStringBackwards(Widget w,
 			   XmTextPosition start,
 			   char *search_string,
@@ -1197,8 +1064,7 @@ _XmTextFindStringBackwards(Widget w,
     return False;		/* FIX ME */
 }
 
-
-extern Boolean
+Boolean
 _XmTextFindStringForwards(Widget w,
 			  XmTextPosition start,
 			  char *search_string,
@@ -1207,8 +1073,7 @@ _XmTextFindStringForwards(Widget w,
     return False;		/* FIX ME */
 }
 
-
-extern Boolean
+Boolean
 _XmStringSourceFindString(Widget w,
 			  XmTextPosition start,
 			  char *string,
@@ -1219,8 +1084,7 @@ _XmStringSourceFindString(Widget w,
     return False;		/* FIX ME */
 }
 
-
-extern void
+void
 _XmStringSourceSetGappedBuffer(XmSourceData data, XmTextPosition position)
 {
     _XmWarning(NULL, "_XmStringSourceSetGappedBuffer is not implemented yet.");
@@ -1238,19 +1102,6 @@ _XmTextModifyVerify(XmTextWidget initiator,
 		    XmTextBlock newblock,
 		    Boolean *freeBlock)
 {
-XmTextVerifyCallbackStruct cbs;
-
-    cbs.reason = XmCR_MODIFYING_TEXT_VALUE;
-    cbs.event = event;
-    cbs.doit = True;
-    cbs.currInsert = *cursorPos;
-    cbs.newInsert = *cursorPos;
-    cbs.startPos = *start;
-    cbs.endPos = *end;
-    cbs.text = block;
-    if (Text_ModifyVerifyCallback(initiator))
-    {
-        XtCallCallbacks((Widget)initiator, XmNmodifyVerifyCallback, &cbs);
-    }
-    return(cbs.doit);
+    _XmWarning((Widget)initiator, "_XmTextModifyVerify is not implemented yet.");
+    return False;		/* FIX ME */
 }
