@@ -1,9 +1,8 @@
 /**
  *
- * $Id: ToggleB.c,v 1.79 2001/07/27 18:51:57 dannybackx Exp $
+ * $Id: ToggleB.c,v 1.69 1999/09/11 04:28:35 gritton Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,13 +22,11 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ToggleB.c,v 1.79 2001/07/27 18:51:57 dannybackx Exp $";
+static const char rcsid[] = "$Id: ToggleB.c,v 1.69 1999/09/11 04:28:35 gritton Exp $";
 
 #include <LTconfig.h>
-
-#include <stdarg.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/ToggleBP.h>
 #include <Xm/RowColumnP.h>
@@ -39,11 +36,17 @@ static const char rcsid[] = "$Id: ToggleB.c,v 1.79 2001/07/27 18:51:57 dannyback
 #include <Xm/CascadeBG.h>
 #include <Xm/RepType.h>
 #include <Xm/TransltnsP.h>
-#include <Xm/ToggleBGP.h>
 #include <X11/ShellP.h>
 
+#ifndef __STDC__
+#include <varargs.h>
+#else
+#include <stdarg.h>
+#endif
+
 #include <XmI/DebugUtil.h>
 
+#include <Xm/ToggleBGP.h>
 
 /* Some M*tif versions (e.g. 1.2.6 on Solaris 2.6) leave less room above and
  * below the indicator than others (e.g. 1.2.5 on HP-UX 10, my reference).
@@ -138,7 +141,7 @@ static XtResource resources[] =
 	sizeof(Boolean), Offset(set),
 	XmRImmediate, (XtPointer)False
     },
-#if XmVERSION == 1
+#if XmVERSION == 1 || LESSTIF_BACK_COMPAT
     {
 	XmNindicatorOn, XmCIndicatorOn, XmRBoolean,
 	sizeof(Boolean), Offset(ind_on),
@@ -484,7 +487,7 @@ static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "initialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -493,7 +496,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     TB_Armed(new_w) = False;
 
@@ -612,8 +615,7 @@ initialize(Widget request, Widget new_w,
 	    {
 		Lab_MarginLeft(new_w) += margin;
 		Lab_TextRect_x(new_w) += margin;
-		if (Lab_AcceleratorText(new_w) != NULL)
-		    Lab_AccTextRect(new_w).x += margin;
+		Lab_AccTextRect(new_w).x += margin;
 	    }
 	    else
 		Lab_MarginRight(new_w) += margin;
@@ -640,8 +642,7 @@ initialize(Widget request, Widget new_w,
 	    if (!XtHeight(request))
 	    {
 		Lab_TextRect_y(new_w) += margin >> 1;
-		if (Lab_AcceleratorText(new_w) != NULL)
-		    Lab_AccTextRect(new_w).y += margin >> 1;
+		Lab_AccTextRect(new_w).y += margin >> 1;
 		XtHeight(new_w) += margin;
 	    }
 	}
@@ -669,7 +670,7 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Boolean refresh_needed = False;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w, "ToggleB set_values()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "ToggleB set_values()\n"));
 
     if (TB_IndType(old) != TB_IndType(new_w) &&
 	!XmRepTypeValidValue(XmRepTypeGetId(XmRIndicatorType),
@@ -941,7 +942,7 @@ resize(Widget w)
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleB Expose\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "ToggleB Expose\n"));
     draw_toggle(w, event, region, True, 0);
 }
 
@@ -994,8 +995,6 @@ Select(Widget w, XEvent *event, String *params, Cardinal *num_params)
 	{
 	    RC_MenuMenuCallback(w, &cbs);
 	}
-	/* Menu callback might cancel the set (radioAlwaysOne). */
-	cbs.set = TB_Set(w);
 	if (!Lab_SkipCallback(w) && TB_ValueChangedCallback(w))
 	{
 	    XFlush(XtDisplay(w));
@@ -1029,7 +1028,7 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     Boolean poppedUp;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:ArmAndActivate(%d)\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "%s:ArmAndActivate(%d)\n",
     	__FILE__, __LINE__));
     Arm(w, event, params, num_params);
 
@@ -1048,7 +1047,7 @@ ButtonUp(Widget w, XEvent *event, String *params, Cardinal *num_params)
     Boolean validButton, poppedUp;
     XmToggleButtonCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleB ButtonUp()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "ToggleB ButtonUp()\n"));
 
     /* queue events until the next button event */
     XAllowEvents(XtDisplay(w), SyncPointer, CurrentTime);
@@ -1084,7 +1083,7 @@ ButtonUp(Widget w, XEvent *event, String *params, Cardinal *num_params)
     TB_Set(w) = NEXT_TOGGLE(w);
     draw_toggle(w, NULL, NULL, False, TB_Set(w));
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "ButtonUp: HERE\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "ButtonUp: HERE\n"));
 
     cbs.reason = XmCR_VALUE_CHANGED;
     cbs.event = event;
@@ -1121,7 +1120,7 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
     /* queue events until the next button event. */
     XAllowEvents(XtDisplay(w), SyncPointer, CurrentTime);
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleB ButtonDown()\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "ToggleB ButtonDown()\n"));
 
     if (event && (event->type == ButtonPress))
     {
@@ -1136,7 +1135,7 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
 
     RC_MenuShellPopdown(w, event, &poppedUp);
     {
-	Cardinal i;
+	int i;
 	Widget menu = XtParent(w);
 
 	for (i = 0; i < MGR_NumChildren(menu); i++)
@@ -1185,7 +1184,7 @@ EnterWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmToggleButtonCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleB Enter\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "ToggleB Enter\n"));
 
     if (!IN_MENU(w))
     {
@@ -1261,11 +1260,12 @@ LeaveWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 KeySelect(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "KeySelect\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "KeySelect\n"));
 
     /* FIX ME */
 }
 
+#ifdef __STDC__
 static void
 MenuProcEntry(int proc, Widget w,...)
 {
@@ -1275,6 +1275,19 @@ MenuProcEntry(int proc, Widget w,...)
     */
 
     va_start(arg_list, w);
+#else
+MenuProcEntry(proc, w, va_alist)
+     int proc;
+     Widget w;
+     va_dcl
+{
+    va_list arglist;
+    /*
+    Cardinal num_params = 0;
+    */
+
+    va_start(arglist);
+#endif
 
     switch (proc)
     {
@@ -1778,7 +1791,7 @@ XmToggleButtonSetState(Widget w, Boolean state, Boolean notify)
 {
     XmToggleButtonCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleB SetState: %d %d\n",
+    DEBUGOUT(XdbDebug(__FILE__, w, "ToggleB SetState: %d %d\n",
 		      state, notify));
 
     _XmObjectLock(w);
@@ -1802,8 +1815,6 @@ XmToggleButtonSetState(Widget w, Boolean state, Boolean notify)
 	    {
 		RC_MenuMenuCallback(w, &cbs);
 	    }
-	    /* Menu callback might cancel the set (radioAlwaysOne). */
-	    cbs.set = TB_Set(w);
 	    if (!Lab_SkipCallback(w) && TB_ValueChangedCallback(w))
 	    {
 		XFlush(XtDisplay(w));
