@@ -1,9 +1,8 @@
 /**
  *
- * $Id: ToggleBG.c,v 1.79 2001/07/27 18:51:58 dannybackx Exp $
+ * $Id: ToggleBG.c,v 1.68 1999/09/11 04:28:36 gritton Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,13 +22,9 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ToggleBG.c,v 1.79 2001/07/27 18:51:58 dannybackx Exp $";
+static const char rcsid[] = "$Id: ToggleBG.c,v 1.68 1999/09/11 04:28:36 gritton Exp $";
 
 #include <LTconfig.h>
-
-#include <stdarg.h>
-#include <string.h>
-
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -41,11 +36,17 @@ static const char rcsid[] = "$Id: ToggleBG.c,v 1.79 2001/07/27 18:51:58 dannybac
 #include <Xm/MenuShell.h>
 #include <Xm/MenuUtilP.h>
 #include <Xm/CacheP.h>
+#include <X11/Xfuncs.h>
 #include <X11/ShellP.h>
 #include <Xm/ToggleBP.h>
 
-#include <XmI/DebugUtil.h>
+#ifndef __STDC__
+#include <varargs.h>
+#else
+#include <stdarg.h>
+#endif
 
+#include <XmI/DebugUtil.h>
 
 /* Some M*tif versions (e.g. 1.2.6 on Solaris 2.6) leave less room above and
  * below the indicator than others (e.g. 1.2.5 on HP-UX 10, my reference).
@@ -178,7 +179,7 @@ static XtResource cache_resources[] =
 	sizeof(Pixmap), Offset(insen_pixmap),
 	XmRImmediate, (XtPointer)XmUNSPECIFIED_PIXMAP
     },
-#if XmVERSION == 1
+#if XmVERSION == 1 || LESSTIF_BACK_COMPAT
     {
 	XmNindicatorOn, XmCIndicatorOn, XmRBoolean,
 	sizeof(Boolean), Offset(ind_on),
@@ -470,9 +471,9 @@ secondary_object_create(Widget request,
     XmBaseClassExt *bce;
     XtPointer nsec, rsec;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
+    DEBUGOUT(XdbDebug(__FILE__, new_w,
 		      "ToggleButtonGCacheRec %s being initialized.\n",
 		      XtName(new_w)));
 
@@ -502,7 +503,7 @@ secondary_object_create(Widget request,
     ed->widget = (Widget)nsec;
     ed->reqWidget = (Widget)rsec;
 
-    memcpy(rsec, nsec, size);
+    bcopy(nsec, rsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     _XmPushWidgetExtData(new_w, ed, XmCACHE_EXTENSION);
@@ -517,7 +518,7 @@ secondary_object_create(Widget request,
 int
 _XmToggleBCacheCompare(XtPointer A, XtPointer B)
 {
-    return !memcmp(((XmToggleButtonGCacheObjPart *)A),
+    return !bcmp(((XmToggleButtonGCacheObjPart *)A),
 		 ((XmToggleButtonGCacheObjPart *)B),
 		 sizeof(XmToggleButtonGCacheObjPart));
 }
@@ -555,10 +556,10 @@ class_initialize(void)
 			     &labels, &nlabels);
 
     combined = (XtResourceList)XtMalloc(sizeof(XtResource) * ncom);
-    memcpy(combined, labels, nlabels * sizeof(XtResource));
-    memcpy(&combined[nlabels],
-           cache_resources,
-	   XtNumber(cache_resources) * sizeof(XtResource));
+    bcopy(labels, combined, nlabels * sizeof(XtResource));
+    bcopy(cache_resources,
+	  &combined[nlabels],
+	  XtNumber(cache_resources) * sizeof(XtResource));
     XtFree((char *)labels);
 
     xmToggleButtonGCacheObjClassRec.object_class.resources = combined;
@@ -630,7 +631,7 @@ initialize_posthook(Widget request, Widget new_w,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w, "ToggleBG InitializePosthook\n"));
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "ToggleBG InitializePosthook\n"));
 
     /* don't let the null fool you */
     LabG_Cache(new_w) = (XmLabelGCacheObjPart *)
@@ -835,7 +836,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
     XtPointer nsec, rsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -854,12 +855,12 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
     ExtObj_LogicalParent(nsec) = new_w;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
-           LabG_Cache(new_w),
-	   sizeof(XmLabelGCacheObjPart));
-    memcpy(&((XmToggleButtonGCacheObject)nsec)->toggle_cache,
-           TBG_Cache(new_w),
-	   sizeof(XmToggleButtonGCacheObjPart));
+    bcopy(LabG_Cache(new_w),
+	  &((XmLabelGCacheObject)nsec)->label_cache,
+	  sizeof(XmLabelGCacheObjPart));
+    bcopy(TBG_Cache(new_w),
+	  &((XmToggleButtonGCacheObject)nsec)->toggle_cache,
+	  sizeof(XmToggleButtonGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -874,7 +875,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 		   (*bce)->secondaryObjectClass->core_class.num_resources,
 		   args, *num_args);
 
-    memcpy(rsec, nsec, size);
+    bcopy(nsec, rsec, size);
 
     LabG_Cache(new_w) = &(((XmToggleButtonGCacheObject)nsec)->label_cache);
     LabG_Cache(request) = &(((XmToggleButtonGCacheObject)rsec)->label_cache);
@@ -940,7 +941,7 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Boolean refresh_needed = False;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w, "ToggleBG set_values\n"));
+    DEBUGOUT(XdbDebug(__FILE__, new_w, "ToggleBG set_values\n"));
 
     if (TBG_IndType(old) != TBG_IndType(new_w) &&
 	!XmRepTypeValidValue(XmRepTypeGetId(XmRIndicatorType),
@@ -1181,7 +1182,7 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    Cardinal size;
+    int size;
     XtPointer nsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -1189,12 +1190,12 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 
     nsec = _XmExtObjAlloc(size);
 
-    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
-           LabG_Cache(new_w),
-	   sizeof(XmLabelGCacheObjPart));
-    memcpy(&((XmToggleButtonGCacheObject)nsec)->toggle_cache,
-           TBG_Cache(new_w),
-	   sizeof(XmToggleButtonGCacheObjPart));
+    bcopy(LabG_Cache(new_w),
+	  &((XmLabelGCacheObject)nsec)->label_cache,
+	  sizeof(XmLabelGCacheObjPart));
+    bcopy(TBG_Cache(new_w),
+	  &((XmToggleButtonGCacheObject)nsec)->toggle_cache,
+	  sizeof(XmToggleButtonGCacheObjPart));
 
     /*
      * don't do this and ResInd will blow up.
@@ -1273,7 +1274,7 @@ resize(Widget w)
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleBG Expose\n"));
+    DEBUGOUT(XdbDebug(__FILE__, w, "ToggleBG Expose\n"));
     draw_toggle(w, event, region, True, 0);
 }
 
@@ -1334,8 +1335,6 @@ Select(Widget w, XEvent *event, String *params, Cardinal *num_params)
 	{
 	    RC_MenuMenuCallback(w, &cbs);
 	}
-	/* Menu callback might cancel the set (radioAlwaysOne). */
-	cbs.set = TBG_Set(w);
 	if (!LabG_SkipCallback(w) && TBG_ValueChangedCallback(w))
 	{
 	    XFlush(XtDisplay(w));
@@ -1479,7 +1478,7 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
 	RC_MenuShellPopdown(w, event, &poppedUp);
     }
     {
-	Cardinal i;
+	int i;
 	Widget menu = XtParent(w);
 
 	for (i = 0; i < MGR_NumChildren(menu); i++)
@@ -1622,7 +1621,7 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
     {
     case XmARM_EVENT:
     case XmMULTI_ARM_EVENT:
-	DEBUGOUT(_LtDebug(__FILE__, gadget,
+	DEBUGOUT(XdbDebug(__FILE__, gadget,
 			  "ToggleButtonGadget got arm event\n"));
 	if (IN_MENU(gadget))
 	{
@@ -1636,7 +1635,7 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 
     case XmACTIVATE_EVENT:
     case XmMULTI_ACTIVATE_EVENT:
-	DEBUGOUT(_LtDebug(__FILE__, gadget,
+	DEBUGOUT(XdbDebug(__FILE__, gadget,
 			  "ToggleButtonGadget got activate event\n"));
 	if (IN_MENU(gadget))
 	{
@@ -1650,19 +1649,19 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 	break;
 
     case XmENTER_EVENT:
-	DEBUGOUT(_LtDebug(__FILE__, gadget,
+	DEBUGOUT(XdbDebug(__FILE__, gadget,
 			  "ToggleButtonGadget enter window\n"));
 	EnterWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmLEAVE_EVENT:
-	DEBUGOUT(_LtDebug(__FILE__, gadget,
+	DEBUGOUT(XdbDebug(__FILE__, gadget,
 			  "ToggleButtonGadget leave window\n"));
 	LeaveWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmMOTION_EVENT:
-	DEBUGOUT(_LtDebug(__FILE__, gadget,
+	DEBUGOUT(XdbDebug(__FILE__, gadget,
 			  "ToggleButtonGadget motion event\n"));
 	break;
 
@@ -1687,6 +1686,7 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
     }
 }
 
+#ifdef __STDC__
 static void
 MenuProcEntry(int proc, Widget w,...)
 {
@@ -1696,6 +1696,19 @@ MenuProcEntry(int proc, Widget w,...)
     */
 
     va_start(arg_list, w);
+#else
+MenuProcEntry(proc, w, va_alist)
+     int proc;
+     Widget w;
+     va_dcl
+{
+    va_list arglist;
+    /*
+    Cardinal num_params = 0;
+    */
+
+    va_start(arglist);
+#endif
 
     switch (proc)
     {
@@ -2240,8 +2253,6 @@ XmToggleButtonGadgetSetState(Widget w, Boolean state, Boolean notify)
 	    {
 		RC_MenuMenuCallback(w, &cbs);
 	    }
-	    /* Menu callback might cancel the set (radioAlwaysOne). */
-	    cbs.set = TBG_Set(w);
 	    if (!LabG_SkipCallback(w) && TBG_ValueChangedCallback(w))
 	    {
 		XFlush(XtDisplay(w));
