@@ -1,9 +1,8 @@
 /**
  *
- * $Id: TravAct.c,v 1.13 2000/09/23 15:05:26 amai Exp $
+ * $Id: TravAct.c,v 1.11 1999/05/05 20:24:57 danny Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,12 +22,12 @@
  *
  **/
 
-static const char rcsid[] = "$Id: TravAct.c,v 1.13 2000/09/23 15:05:26 amai Exp $";
+static const char rcsid[] = "$Id: TravAct.c,v 1.11 1999/05/05 20:24:57 danny Exp $";
 
 #include <LTconfig.h>
-
 #include <XmI/XmI.h>
 #include <XmI/TraversalI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/BaseClassP.h>
 #include <Xm/ManagerP.h>
@@ -46,8 +45,8 @@ typedef struct _XmFocusFlag
 }
 XmFocusFlagRec, *XmFocusFlag;
 
-static XmFocusFlag flag_list = NULL;
-static int flag_list_size = 0;
+XmFocusFlag flag_list = NULL;
+int flag_list_size = 0;
 
 /* For the prototype police */
 extern void _XmSetFocusFlag(Widget w, unsigned mask, Boolean value);
