@@ -1,9 +1,8 @@
 /**
  *
- * $Id: VaSimple.c,v 1.10 2000/09/22 20:35:13 amai Exp $
+ * $Id: VaSimple.c,v 1.7 1999/08/14 12:17:14 danny Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -50,13 +49,11 @@
  *
  **/
 
-static const char rcsid[] = "$Id: VaSimple.c,v 1.10 2000/09/22 20:35:13 amai Exp $";
+static const char rcsid[] = "$Id: VaSimple.c,v 1.7 1999/08/14 12:17:14 danny Exp $";
 
 #include <LTconfig.h>
-
-#include <string.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/ToggleBGP.h>
 #include <Xm/PushBGP.h>
@@ -64,10 +61,10 @@ static const char rcsid[] = "$Id: VaSimple.c,v 1.10 2000/09/22 20:35:13 amai Exp
 #include <Xm/SeparatoGP.h>
 #include <Xm/RowColumnP.h>
 #include <Xm/VaSimpleP.h>
+#include <X11/Xfuncs.h>
 
 #include <XmI/DebugUtil.h>
 
-
 /* this seems realistic to me */
 #define MAX_EMBEDDED_BUTTONS	512
 static XmButtonType button_types[MAX_EMBEDDED_BUTTONS];
@@ -125,11 +122,11 @@ _XmCountVaList(va_list var, int *button_count, int *args_count,
     *typed_count = 0;
     *button_count = 0;
     *args_count = 0;
-    memset((void *)button_types, 0, MAX_EMBEDDED_BUTTONS * sizeof(unsigned char));
-    memset((void *)button_strings, 0, MAX_EMBEDDED_BUTTONS * sizeof(XmString));
-    memset((void *)button_mnemonics, 0, MAX_EMBEDDED_BUTTONS * sizeof(KeySym));
-    memset((void *)button_accel, 0, MAX_EMBEDDED_BUTTONS * sizeof(String));
-    memset((void *)button_acc_text, 0, MAX_EMBEDDED_BUTTONS * sizeof(XmString));
+    bzero((void *)button_types, MAX_EMBEDDED_BUTTONS * sizeof(unsigned char));
+    bzero((void *)button_strings, MAX_EMBEDDED_BUTTONS * sizeof(XmString));
+    bzero((void *)button_mnemonics, MAX_EMBEDDED_BUTTONS * sizeof(KeySym));
+    bzero((void *)button_accel, MAX_EMBEDDED_BUTTONS * sizeof(String));
+    bzero((void *)button_acc_text, MAX_EMBEDDED_BUTTONS * sizeof(XmString));
 
     for (attr = va_arg(var, String); attr != NULL;
 	 attr = va_arg(var, String))
@@ -317,7 +314,7 @@ _XmTypedArgToArg(Widget widget, XtTypedArgList typed_arg, ArgList arg_return,
 	{
 	    arg_return->value = (XtArgVal)XtMalloc(to_val.size);
 	    memory_return->value = (XtArgVal)arg_return->value;
-	    memcpy((void *)arg_return->value, to_val.addr, to_val.size);
+	    bcopy(to_val.addr, (void *)arg_return->value, to_val.size);
 	}
     }
 
@@ -699,7 +696,7 @@ XmVaCreateSimpleCheckBox(Widget parent,
      * (this also sets the button_strings, button_mnemonics, etc
      * arrays)
      */
-    va_start(var, callback);
+    Va_start(var, callback);
     _XmCountVaList(var, &button_count, &args_count, &typed_count, &total_count);
     va_end(var);
 
@@ -724,7 +721,7 @@ XmVaCreateSimpleCheckBox(Widget parent,
      * if it can be set afterward, but it is easier to set it
      * afterward
      */
-    va_start(var, callback);
+    Va_start(var, callback);
     _XmVaToArgList(rc, var, total_count, &arglist, &n);
     va_end(var);
 
@@ -771,7 +768,7 @@ XmVaCreateSimpleMenuBar(Widget parent,
      * (this also sets the button_strings, button_mnemonics, etc
      * arrays)
      */
-    va_start(var, name);
+    Va_start(var, name);
     _XmCountVaList(var, &button_count, &args_count, &typed_count, &total_count);
     va_end(var);
 
@@ -787,7 +784,7 @@ XmVaCreateSimpleMenuBar(Widget parent,
      * if it can be set afterward, but it is easier to set it
      * afterward
      */
-    va_start(var, name);
+    Va_start(var, name);
     _XmVaToArgList(rc, var, total_count, &arglist, &n);
     va_end(var);
 
@@ -836,11 +833,11 @@ XmVaCreateSimpleOptionMenu(Widget parent,
      * (this also sets the button_strings, button_mnemonics, etc
      * arrays)
      */
-    va_start(var, callback);
+    Va_start(var, callback);
     _XmCountVaList(var, &button_count, &args_count, &typed_count, &total_count);
     va_end(var);
 
-    va_start(var, callback);
+    Va_start(var, callback);
     _XmVaToArgList(rc, var, total_count, &arglist, &n);
     va_end(var);
 
@@ -908,7 +905,7 @@ XmVaCreateSimplePopupMenu(Widget parent,
      * (this also sets the button_strings, button_mnemonics, etc
      * arrays)
      */
-    va_start(var, callback);
+    Va_start(var, callback);
     _XmCountVaList(var, &button_count, &args_count, &typed_count, &total_count);
     va_end(var);
 
@@ -928,7 +925,7 @@ XmVaCreateSimplePopupMenu(Widget parent,
      * if it can be set afterward, but it is easier to set it
      * afterward
      */
-    va_start(var, callback);
+    Va_start(var, callback);
     _XmVaToArgList(rc, var, total_count, &arglist, &n);
     va_end(var);
 
@@ -979,7 +976,7 @@ XmVaCreateSimplePulldownMenu(Widget parent,
      * (this also sets the button_strings, button_mnemonics, etc
      * arrays)
      */
-    va_start(var, callback);
+    Va_start(var, callback);
     _XmCountVaList(var, &button_count, &args_count, &typed_count, &total_count);
     va_end(var);
 
@@ -1000,7 +997,7 @@ XmVaCreateSimplePulldownMenu(Widget parent,
      * if it can be set afterward, but it is easier to set it
      * afterward
      */
-    va_start(var, callback);
+    Va_start(var, callback);
     _XmVaToArgList(rc, var, total_count, &arglist, &n);
     va_end(var);
 
@@ -1047,7 +1044,7 @@ XmVaCreateSimpleRadioBox(Widget parent,
      * (this also sets the button_strings, button_mnemonics, etc
      * arrays)
      */
-    va_start(var, callback);
+    Va_start(var, callback);
     _XmCountVaList(var, &button_count, &args_count, &typed_count, &total_count);
     va_end(var);
 
@@ -1073,7 +1070,7 @@ XmVaCreateSimpleRadioBox(Widget parent,
      * if it can be set afterward, but it is easier to set it
      * afterward
      */
-    va_start(var, callback);
+    Va_start(var, callback);
     _XmVaToArgList(rc, var, total_count, &arglist, &n);
     va_end(var);
 
