@@ -1,9 +1,8 @@
 /**
  *
- * $Id: XmIm.c,v 1.15 2000/11/05 17:25:36 amai Exp $
+ * $Id: XmIm.c,v 1.13 1999/10/17 07:42:45 danny Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,27 +22,27 @@
  *
  **/
 
-static const char rcsid[] = "$Id: XmIm.c,v 1.15 2000/11/05 17:25:36 amai Exp $";
+static const char rcsid[] = "$Id: XmIm.c,v 1.13 1999/10/17 07:42:45 danny Exp $";
 
 #include <LTconfig.h>
-
-#include <stdarg.h>
-
-#include <X11/Intrinsic.h>
-#include <X11/Xos.h>
-
 #include <XmI/XmI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/VendorSEP.h>
-#if XmVERSION > 1
-#include <Xm/XmIm.h>
-#endif
-
+#include <X11/Intrinsic.h>
+#include <X11/Xos.h>
+#include <stdarg.h>
 
 #include <XmI/DebugUtil.h>
 
 #include "LTmisc.h"
 
+/* For the prototype police */
+extern XIC XmImGetXIC(Widget w, XmIMInputPolicy input_policy, ArgList args,
+		      Cardinal num_args);
+extern XIC XmImSetXIC(Widget w, XIC xic);
+extern void XmImCloseXIM(Widget w);
+extern void XmImFreeXIC(Widget w, XIC xic);
 
 /*
  * This file contains I18N (Internationalisation) Input Method handling.
@@ -100,8 +99,6 @@ _XmFindICStuff(Widget w)
     return NULL;
 }
 
-
-
 /*
  * XmImGetXIC creates and registers an XIC with the specified arguments for the
  * widget. If XmINHERIT_POLICY is specified for input_policy, then a new XIC
@@ -117,16 +114,8 @@ _XmFindICStuff(Widget w)
  *
  * Reusing the XIM is possible though.
  */
-
-#if XmVERSION > 1
-#define XmIMInputPolicy XmInputPolicy
-#endif
-
-extern XIC
-XmImGetXIC(Widget w,
-           XmIMInputPolicy input_policy,
-           ArgList args,
-           Cardinal num_args)
+XIC
+XmImGetXIC(Widget w, XmIMInputPolicy input_policy, ArgList args, Cardinal num_args)
 {
     XmVendorShellExtObject v = (XmVendorShellExtObject)_LtFindVendorExt(w);
 
@@ -388,28 +377,25 @@ XmImGetXIC(Widget w,
  * input processing. The application is responsible for unregistering a widget by
  * calling XmImUnregister.
  */
-extern void
-XmImRegister(Widget w,
-             unsigned int reserved)
+void
+XmImRegister(Widget w, unsigned int reserved)
 {
     XIC xic;
 
     xic = XmImGetXIC(w, IP_PER_SHELL, NULL, 0);
 }
 
-
 /*
  * XmImUnregister removes the specified widget from the list of widgets
  * registered for input by the input manager.
  */
-extern void
+void
 XmImUnregister(Widget w)
 {
     DEBUGOUT(XdbDebug(__FILE__, w,
 		      "XmImUnregister is not implemented yet.\n"));
 }
 
-
 /*
  * XmImSetFocusValues notifies the input manager that the specified widget
  * has received input focus. This function also updates the attributes of
@@ -418,7 +404,7 @@ XmImUnregister(Widget w)
  * registered IC to be reused, that IC will be unregistered, and a new one will
  * be created and registered with the widget.
  */
-extern void
+void
 XmImSetFocusValues(Widget w, ArgList args, Cardinal num_args)
 {
     XmICStuff *stuff = _XmFindICStuff(w);
@@ -442,10 +428,9 @@ XmImSetFocusValues(Widget w, ArgList args, Cardinal num_args)
     }
 }
 
-
 /* Varargs interface to the above. */
-extern void
-XmImVaSetFocusValues(Widget w, ...)
+void
+XmImVaSetFocusValues(Widget w,...)
 {
     va_list ap;
     Arg *a;
@@ -476,7 +461,6 @@ XmImVaSetFocusValues(Widget w, ...)
     XtFree((XtPointer)a);
 }
 
-
 /*
  * XmImSetValues updates attributes of the input context associated with the
  * specified widget.
@@ -484,10 +468,8 @@ XmImVaSetFocusValues(Widget w, ...)
  * registered IC to be reused, that IC will be unregistered, and a new one will
  * be created and registered with the widget.
  */
-extern void
-XmImSetValues(Widget w,
-              ArgList args,
-              Cardinal num_args)
+void
+XmImSetValues(Widget w, ArgList args, Cardinal num_args)
 {
     DEBUGOUT(XdbDebug(__FILE__, w, "XmImSetValues is not implemented yet\n"));
 
@@ -542,10 +524,9 @@ XmImSetValues(Widget w,
 #endif
 }
 
-
 /* Varargs interface to the above. */
-extern void
-XmImVaSetValues(Widget w, ...)
+void
+XmImVaSetValues(Widget w,...)
 {
     va_list ap;
     Arg *a;
@@ -573,12 +554,11 @@ XmImVaSetValues(Widget w, ...)
     XtFree((XtPointer)a);
 }
 
-
 /*
  * XmImUnsetFocus unsets a specified widget's focus, then notifies the input
  * manager that the specified widget has lost its input focus.
  */
-extern void
+void
 XmImUnsetFocus(Widget w)
 {
     XmICStuff *stuff;
@@ -606,7 +586,6 @@ XmImUnsetFocus(Widget w)
     }
 }
 
-
 /*
  * XmImGetXIM retrieves the XIM data structure representing the input method
  * that the input manager has opened for the specified widget.
@@ -614,7 +593,7 @@ XmImUnsetFocus(Widget w)
  * the first time this routine is called it opens an input method using the
  * XmNinputMethod resource for the VendorShell.
  */
-extern XIM
+XIM
 XmImGetXIM(Widget w)
 {
     XmICStuff *stuff = _XmFindICStuff(w);
@@ -628,19 +607,14 @@ XmImGetXIM(Widget w)
     return NULL;
 }
 
-
 /*
  * XmImMbLookupString returns a string composed in the locale associated with
  * the widget's input method and a KeySym that is currently mapped to the
  * keycode in the KeyPressedEvent.
  */
-extern int
-XmImMbLookupString(Widget w,
-                   XKeyPressedEvent *evp,
-                   char *buf,
-                   int nbytes,
-                   KeySym *keysym,
-                   int *status)
+int
+XmImMbLookupString(Widget w, XKeyPressedEvent *evp,
+		   char *buf, int nbytes, KeySym *keysym, int *status)
 {
     XmICStuff *stuff = _XmFindICStuff(w);
     XIC xic = NULL;
@@ -663,15 +637,13 @@ XmImMbLookupString(Widget w,
     return XLookupString(evp, buf, nbytes, keysym, NULL);
 }
 
-
 /*
  * XmImSetXIC registers the X Input Context (XIC) with the specified widget.
  * Any existing XIC registered for the widget is unregistered. The new XIC
  * registered for the widget is returned.
  */
-extern XIC
-XmImSetXIC(Widget w,
-           XIC xic)
+XIC
+XmImSetXIC(Widget w, XIC xic)
 {
     XmVendorShellExtObject v = (XmVendorShellExtObject)_LtFindVendorExt(w);
     XmICStuff *stuff;
@@ -706,7 +678,6 @@ XmImSetXIC(Widget w,
  * Display is closed.
  */
 
-
 /* FIX ME
  * Currently we only tackle stuff under our own shell widget.
  * This is not enough, as the above text (which reflects the Motif 2.0 spec) indicates
@@ -715,7 +686,7 @@ XmImSetXIC(Widget w,
  * This requires the XmDisplay to keep track of top level widgets, or of (Vendor)Shells.
  * FIX ME
  */
-extern void
+void
 XmImCloseXIM(Widget w)
 {
     XmICStuff *stuff;
@@ -738,59 +709,31 @@ XmImCloseXIM(Widget w)
     }
 }
 
-
 /*
  * XmImFreeXIC unregisters all widgets associated with the specified XIC. The
  * specified widget must be specified with the specified XIC.
  */
-extern void
+void
 XmImFreeXIC(Widget w, XIC xic)
 {
 }
 
-
-extern void
+void
 _XmImChangeManaged(Widget w)
 {
 }
 
-
-extern void
+void
 _XmImRealize(Widget w)
 {
 }
 
-
-extern void
+void
 _XmImResize(Widget w)
 {
 }
 
-
-extern void
+void
 _XmImRedisplay(Widget w)
 {
 }
-
-
-extern void
-XmImMbResetIC(Widget widget,
-              char **mb)
-{
-/*
-    XmICStuff *stuff;
-    XIM xim;
-
-    if (!widget)
-    {
-	return;
-    }
-    if ((stuff = _XmFindICStuff(widget)) == NULL)
-    {
-	return;
-    }
-
-    xim = stuff->xim;
-*/
-  _XmWarning(NULL, "XmImMbResetIC() is not yet implemented!");
-}
