@@ -1,4 +1,4 @@
-/* $Id: alloca.c,v 1.5 2000/06/14 08:09:09 amai Exp $
+/* $Id: alloca.c,v 1.3 1999/10/27 15:44:01 amai Exp $
 
   alloca.c -- allocate automatically reclaimed memory
    (Mostly) portable public-domain implementation -- D A Gwyn
@@ -26,7 +26,6 @@
 #include <LTconfig.h>
 
 #include <stdlib.h>
-#include <X11/Intrinsic.h>
 
 #ifdef emacs
 #include "blockinput.h"
@@ -63,7 +62,7 @@ long i00afunc();
 #define ADDRESS_FUNCTION(arg) &(arg)
 #endif
 
-#if STDC_HEADERS
+#if __STDC__
 typedef void *pointer;
 #else
 typedef char *pointer;
