@@ -3,14 +3,11 @@
    Based on the test38.c from Xm/form.
  */
 
-
-#include <stdlib.h>
 #include <unistd.h>
 #include <Xm/Xm.h>
 #include <Xm/ComboBox.h>
-#include <Xm/List.h>
 
-int
+void 
 main(int argc, char *argv[])
 {
     XtAppContext app;
