@@ -1,7 +1,6 @@
-/* $Id: test1.c,v 1.2 2000/08/29 21:59:22 dannybackx Exp $ */
-
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdarg.h>
 
 #include <X11/Intrinsic.h>
 #include <Xm/Xm.h>
@@ -52,7 +51,7 @@ main(int argc, char **argv)
 		&argc, argv, NULL, NULL);
 
 	bb = XmCreateContainer(toplevel, "bb", NULL, 0);
-/*	bb = XmCreateBulletinBoard(toplevel, "bb", NULL, 0); */
+//	bb = XmCreateBulletinBoard(toplevel, "bb", NULL, 0);
 	XtManageChild(bb);
 
 	dpy = XtDisplay(toplevel);
@@ -72,7 +71,7 @@ main(int argc, char **argv)
 
 	XtRealizeWidget(toplevel);
 
-/*	check_geometry(widget); */
+//	check_geometry(widget);
 
 	LessTifTestMainLoop(toplevel);
 
