@@ -12,7 +12,7 @@
 #include <Xm/BulletinB.h>
 #include <Xm/ArrowB.h>
 
-void 
+int
 main(int argc, char *argv[])
 {
     XtAppContext app;
