@@ -3,9 +3,11 @@
 #include <Xm/RowColumn.h>
 #include <Xm/PushB.h>
 #include <Xm/ArrowB.h>
+#include <Xm/ArrowBG.h>
 #include <Xm/CascadeB.h>
 #include <Xm/MenuShell.h>
 #include <Xm/RepType.h>
+#include <Xm/Form.h>
 #include <Xm/MainW.h>
 
 #include <Xm/XmP.h>
