@@ -12,7 +12,7 @@
 #include <Xm/RowColumn.h>
 #include <Xm/CascadeBG.h>
 
-void 
+int
 main(int argc, char *argv[])
 {
     XtAppContext app;
