@@ -5,7 +5,7 @@
 
 static void to_clipbd(), from_clipbd();
 
-void
+int
 main(int argc, char **argv)
 {
     Widget toplevel, rowcol, button;
@@ -45,6 +45,7 @@ main(int argc, char **argv)
     PrintDetails(    toplevel ,Expected);
 };
    LessTifTestMainLoop(    toplevel );
+   exit(0);
 }
 
 static void
