@@ -1,4 +1,3 @@
-/* $Id: test3.c,v 1.3 2000/08/25 13:38:31 amai Exp $ */
 #include <stdio.h>
 #include <stdlib.h>
 
@@ -32,7 +31,7 @@ Widget Menu;
 
 	Menu = XmCreatePulldownMenu(MenuBar, "FilePullDownMenu", NULL, 0);
 	Button = XmCreatePushButton(Menu, "Quit", NULL, 0);
-	XtAddCallback(Button, XmNactivateCallback, (XtCallbackProc)exit, NULL);
+	XtAddCallback(Button, XmNactivateCallback, (void *)exit, NULL);
 	XtManageChild(Button);
 	Cascade = XmCreateCascadeButton(MenuBar, "File", NULL, 0);
 	XtVaSetValues(Cascade,
@@ -55,7 +54,7 @@ unsigned char *prop = NULL;
 char buf[1024];
 XmString string;
 
-/*    printf("ReadMotifDragWindowId()\n"); */
+    printf("ReadMotifDragWindowId()\n");
     DragWindowAtom = XmInternAtom(XtDisplay(label), "_MOTIF_DRAG_WINDOW", False);
     if (XGetWindowProperty(XtDisplay(label), DefaultRootWindow(XtDisplay(label)), DragWindowAtom, 0L, 100000L, False, XA_WINDOW, &actual_type, &actual_format, &nitems, &bytes_after, &prop) == Success)
     {
@@ -95,7 +94,7 @@ char buf[1024];
 XmString string;
 int num_target_lists;
 
-/*    printf("ReadDragTargets(%s)\n", XtName(label)); */
+    printf("ReadDragTargets(%s)\n", XtName(label));
     MotifDragTargets = XmInternAtom(XtDisplay(label), "_MOTIF_DRAG_TARGETS", False);
     if (XGetWindowProperty(XtDisplay(label), MotifDragWindowId, MotifDragTargets, 0L, 100000L, False, MotifDragTargets, &actual_type, &actual_format, &nitems, &bytes_after, &prop) == Success)
     {
@@ -156,30 +155,10 @@ unsigned char *prop = NULL;
 char buf[1024];
 XmString string;
 int num_atoms;
-typedef struct {
-    Atom atom;
-    Time time;
-} AtomTime_t;
-struct {
-    unsigned char format;
-    unsigned char version;
-    unsigned char num[2];
-    AtomTime_t *AtomTime;
-} DragAtomTable;
 
-/*    printf("ReadDragAtoms(%s)\n", XtName(label)); */
+    printf("ReadDragAtoms(%s)\n", XtName(label));
     MotifDragAtoms = XmInternAtom(XtDisplay(label), "_MOTIF_DRAG_ATOMS", False);
-    if (XGetWindowProperty(XtDisplay(label), 
-                           MotifDragWindowId, 
-                           MotifDragAtoms, 
-                           0L, 100000L, 
-                           False, 
-                           MotifDragAtoms, 
-                           &actual_type, 
-                           &actual_format, 
-                           &nitems, 
-                           &bytes_after, 
-                           &prop) == Success)
+    if (XGetWindowProperty(XtDisplay(label), MotifDragWindowId, MotifDragAtoms, 0L, 100000L, False, MotifDragAtoms, &actual_type, &actual_format, &nitems, &bytes_after, &prop) == Success)
     {
     	if (nitems >= 8)
     	{
@@ -238,7 +217,7 @@ unsigned char *prop = NULL;
 char buf[1024];
 XmString string;
 
-/*    printf("ReadDragAtomPairss(%s)\n", XtName(label)); */
+    printf("ReadDragAtomPairss(%s)\n", XtName(label));
     MotifDragAtomPairs = XmInternAtom(XtDisplay(label), "_MOTIF_DRAG_ATOM_PAIRS", False);
     if (XGetWindowProperty(XtDisplay(label), MotifDragWindowId, MotifDragAtomPairs, 0L, 100000L, False, MotifDragAtomPairs, &actual_type, &actual_format, &nitems, &bytes_after, &prop) == Success)
     {
@@ -272,7 +251,7 @@ XmString string;
 static void
 ReadMotifDragWindowProperties(Widget label)
 {
-/*	printf("ReadMotifDragWindowProperties()\n"); */
+	printf("ReadMotifDragWindowProperties()\n");
 	ReadDragTargets(XtNameToWidget(label, "*DragTargetsFrame"));
 	ReadDragAtoms(XtNameToWidget(label, "*DragAtomsFrame"));
 	ReadDragAtomPairs(XtNameToWidget(label, "*DragAtomPairsFrame"));
@@ -281,9 +260,44 @@ ReadMotifDragWindowProperties(Widget label)
 	   _MOTIF_DRAG_ATOMS
 	   _MOTIF_DRAG_ATOM_PAIRS
 	 */
+/*
+Atom DragWindowAtom;
+Atom actual_type;
+int actual_format;
+unsigned long nitems;
+unsigned long bytes_after;
+unsigned char *prop = NULL;
+char buf[1024];
+XmString string;
+
+    printf("ReadMotifDragWindowId()\n");
+    DragWindowAtom = XmInternAtom(XtDisplay(label), "_MOTIF_DRAG_WINDOW", False);
+    if (XGetWindowProperty(XtDisplay(label), DefaultRootWindow(XtDisplay(label)), DragWindowAtom, 0L, 100000L, False, XA_WINDOW, &actual_type, &actual_format, &nitems, &bytes_after, &prop) == Success)
+    {
+    	if (actual_format == 32 && nitems == 1)
+    	{
+	    MotifDragWindowId = *((Window *)prop);
+    	}
+    	XFree(prop);
+    }
+    sprintf(buf, "_MOTIF_DRAG_WINDOW - ");
+    if (MotifDragWindowId == None)
+    {
+    	sprintf(&buf[strlen(buf)], "None");
+    }
+    else
+    {
+    	sprintf(&buf[strlen(buf)], "%p", MotifDragWindowId);
+    }
+    string = XmStringCreateSimple(buf);
+    XtVaSetValues(label,
+    	XmNlabelString, string,
+    	NULL);
+    XmStringFree(string);
+*/
 }
 
-static void
+static XtEventHandler
 RootWindowPropertyNotifyHandler(Widget w, Widget label, XEvent *event)
 {
 Atom DragWindowAtom;
@@ -315,26 +329,26 @@ Window DummyLabelWindow;
 	Label = XmCreateLabel(Frame, "MotifDragWindowId", NULL, 0);
 	ReadMotifDragWindowId(Label);
 	XtManageChild(Label);
-	XtRegisterDrawable(XtDisplay(Frame), DefaultRootWindow(XtDisplay(parent)), Frame);
-
-	XtAddEventHandler(Frame,
+	DummyLabel = XmCreateLabel(Frame, "RootWindowLabel", NULL, 0);
+	DummyLabelWindow = XtWindow(DummyLabel);
+	XtWindow(DummyLabel) = DefaultRootWindow(XtDisplay(parent));
+	XtAddEventHandler(DummyLabel,
 		PropertyChangeMask,
 		False,
 		(XtEventHandler)RootWindowPropertyNotifyHandler,
 		Label);
 
+	XtWindow(DummyLabel) = DummyLabelWindow;
+	XtDestroyWidget(DummyLabel);
+
 	return(Frame);
 }
 
-static void
+static XtEventHandler
 DragWindowPropertyNotifyHandler(Widget w, Widget label, XEvent *event)
 {
-String AtomName = XGetAtomName(XtDisplay(w), event->xproperty.atom);
-
-    printf("DragWindowPropertyNotifyHandler() - %s %s\n",
-	    event->xproperty.state == PropertyNewValue ? "PropertyNewValue" : "PropertyDelete",
-	    AtomName);
-    XtFree(AtomName);
+    printf("DragWindowPropertyNotifyHandler() - %s\n",
+	    event->xproperty.state == PropertyNewValue ? "PropertyNewValue" : "PropertyDelete");
     ReadMotifDragWindowProperties(label);
 }
 
@@ -519,15 +533,18 @@ Window DummyLabelWindow;
 	XtManageChild(Form);
 	ReadMotifDragWindowProperties(Form);
 
-	XSelectInput(XtDisplay(Frame), MotifDragWindowId, PropertyChangeMask);
-	XtRegisterDrawable(XtDisplay(Frame), MotifDragWindowId, Frame);
-
-	XtAddEventHandler(Frame,
+	DummyLabel = XmCreateLabel(Frame, "DragWindowLabel", NULL, 0);
+	DummyLabelWindow = XtWindow(DummyLabel);
+	XtWindow(DummyLabel) = DefaultRootWindow(XtDisplay(parent));
+	XtAddEventHandler(DummyLabel,
 		PropertyChangeMask,
 		False,
 		(XtEventHandler)DragWindowPropertyNotifyHandler,
 		Form);
 
+	XtWindow(DummyLabel) = DummyLabelWindow;
+	XtDestroyWidget(DummyLabel);
+
 	return(Frame);
 }
 
