@@ -11,7 +11,12 @@
 #include <Xm/Xm.h>
 #include <Xm/FileSB.h>
 
-void 
+static char *FallBack[] = {
+		"*.geometrySlop: 0",
+		NULL
+};
+
+int
 main(int argc, char *argv[])
 {
     XtAppContext app;
@@ -24,7 +29,7 @@ main(int argc, char *argv[])
 
   make_tmp_dir_tree();
     shell = XtAppInitialize(&app, "Test", NULL, 0,
-			    &argc, argv, NULL, NULL, 0);
+			    &argc, argv, FallBack, NULL, 0);
     while (iter < 100)
     {
 	before = sbrk((ptrdiff_t) 0);
