@@ -3,6 +3,11 @@
 #include <Xm/PushB.h>
 #include <stdio.h>
 
+static char *FallBack[] = {
+		"*.geometrySlop: 0",
+		NULL
+};
+
 void cb(Widget w, XtPointer client, XtPointer call)
 {
   XmString *st1, *st2, *st3, t1, t2, test;
@@ -82,7 +87,7 @@ main(int argc, char **argv)
 
 
   toplevel = XtVaAppInitialize(&app, "listTest", NULL, 0,
- 		               &argc, argv, NULL, NULL);
+ 		               &argc, argv, FallBack, NULL);
 
   push = XmCreatePushButton(toplevel, "push", NULL, 0);
   XtVaSetValues(push,
@@ -103,28 +108,29 @@ main(int argc, char **argv)
 
   
   
+    
 {
     static XtWidgetGeometry Expected[] = {
-   CWWidth | CWHeight            ,    6,   22,  294,  374, 0,0,0, /* Box */
-   CWWidth | CWHeight | CWX | CWY,  170,   69,  113,   17, 0,0,0, /* Items */
-   CWWidth | CWHeight | CWX | CWY,  170,   86,  113,  154, 0,0,0, /* ItemsListSW */
-   CWWidth | CWHeight | CWX | CWY,   98,    0,   15,  135, 0,0,0, /* VertScrollBar */
-   CWWidth | CWHeight | CWX | CWY,    0,  139,   94,   15, 0,0,0, /* HorScrollBar */
-   CWWidth | CWHeight | CWX | CWY,    0,    0,   94,  135, 0,0,0, /* ItemsList */
-   CWWidth | CWHeight | CWX | CWY,   11,  250,  272,   17, 0,0,0, /* Selection */
-   CWWidth | CWHeight | CWX | CWY,   11,  267,  272,   31, 0,0,0, /* Text */
-   CWWidth | CWHeight | CWX | CWY,    0,  308,  294,    2, 0,0,0, /* Separator */
+   CWWidth | CWHeight            ,    6,   22,  286,  374, 0,0,0, /* Box */
+   CWWidth | CWHeight | CWX | CWY,  191,   69,   83,   17, 0,0,0, /* Items */
+   CWWidth | CWHeight | CWX | CWY,  191,   86,   83,  154, 0,0,0, /* ItemsListSW */
+   CWWidth | CWHeight | CWX | CWY,   68,    0,   15,  135, 0,0,0, /* VertScrollBar */
+   CWWidth | CWHeight | CWX | CWY,    0,  139,   64,   15, 0,0,0, /* HorScrollBar */
+   CWWidth | CWHeight | CWX | CWY,    0,    0,   64,  135, 0,0,0, /* ItemsList */
+   CWWidth | CWHeight | CWX | CWY,   11,  250,  264,   17, 0,0,0, /* Selection */
+   CWWidth | CWHeight | CWX | CWY,   11,  267,  264,   31, 0,0,0, /* Text */
+   CWWidth | CWHeight | CWX | CWY,    0,  308,  286,    2, 0,0,0, /* Separator */
    CWWidth | CWHeight | CWX | CWY,   11,  320,   66,   43, 0,0,0, /* OK */
-   CWWidth | CWHeight | CWX | CWY,   79,  320,   66,   43, 0,0,0, /* Apply */
-   CWWidth | CWHeight | CWX | CWY,  147,  320,   66,   43, 0,0,0, /* Cancel */
-   CWWidth | CWHeight | CWX | CWY,  215,  320,   66,   43, 0,0,0, /* Help */
-   CWWidth | CWHeight | CWX | CWY,   11,   11,  272,   17, 0,0,0, /* FilterLabel */
-   CWWidth | CWHeight | CWX | CWY,   11,   69,  149,   17, 0,0,0, /* Dir */
-   CWWidth | CWHeight | CWX | CWY,   11,   28,  272,   31, 0,0,0, /* FilterText */
-   CWWidth | CWHeight | CWX | CWY,   11,   86,  149,  154, 0,0,0, /* DirListSW */
-   CWWidth | CWHeight | CWX | CWY,  134,    0,   15,  135, 0,0,0, /* VertScrollBar */
-   CWWidth | CWHeight | CWX | CWY,    0,  139,  130,   15, 0,0,0, /* HorScrollBar */
-   CWWidth | CWHeight | CWX | CWY,    0,    0,  130,  135, 0,0,0, /* DirList */ 
+   CWWidth | CWHeight | CWX | CWY,   77,  320,   66,   43, 0,0,0, /* Apply */
+   CWWidth | CWHeight | CWX | CWY,  143,  320,   66,   43, 0,0,0, /* Cancel */
+   CWWidth | CWHeight | CWX | CWY,  209,  320,   66,   43, 0,0,0, /* Help */
+   CWWidth | CWHeight | CWX | CWY,   11,   11,  264,   17, 0,0,0, /* FilterLabel */
+   CWWidth | CWHeight | CWX | CWY,   11,   69,  170,   17, 0,0,0, /* Dir */
+   CWWidth | CWHeight | CWX | CWY,   11,   28,  264,   31, 0,0,0, /* FilterText */
+   CWWidth | CWHeight | CWX | CWY,   11,   86,  170,  154, 0,0,0, /* DirListSW */
+   CWWidth | CWHeight | CWX | CWY,  155,    0,   15,  135, 0,0,0, /* VertScrollBar */
+   CWWidth | CWHeight | CWX | CWY,    0,  139,  151,   15, 0,0,0, /* HorScrollBar */
+   CWWidth | CWHeight | CWX | CWY,    0,    0,  151,  135, 0,0,0, /* DirList */ 
     };
     PrintDetails(box,Expected);
 };
