@@ -1,6 +1,11 @@
 #include <Xm/XmAll.h>
 Widget GXCreateFileBox(Widget parent);
 
+static char *FallBack[] = {
+		"*.geometrySlop: 0",
+		NULL
+};
+
 Widget GXTopWidget, GXClipBox;
 int main(int argc, char **argv)
 {
@@ -9,13 +14,14 @@ int main(int argc, char **argv)
 
   make_tmp_dir_tree();
   GXTopWidget= XtVaAppInitialize(&theApp, "test1", NULL, 0, &argc, argv,
-				 NULL, NULL); 
+				 FallBack, NULL); 
   label = XmCreateLabel(GXTopWidget, "Label", NULL, 0);
   XtManageChild(label);
   XtManageChild(GXCreateFileBox(GXTopWidget));
   XtRealizeWidget(GXTopWidget);
 
   
+    
 {
     static XtWidgetGeometry Expected[] = {
    CWWidth | CWHeight            ,   57,   73,   34,   17, 0,0,0, /* Label */ 
