@@ -13,8 +13,6 @@
 #include <Xm/Text.h>
 #include <stdio.h>
 
-#include "DumpLayout.h"
-
 extern int putenv();
 
 Widget          appshell = (Widget) NULL;
@@ -173,6 +171,7 @@ main(argc, argv)
   	CWWidth | CWHeight | CWX | CWY,	88,	98,	151,	31,	0,0,0,	/* two */
 };
 
+  LessTifTestSetSlop(appshell, 2);
   PrintDetails(appshell, Expected);
   }
 	    LessTifTestMainLoop(appshell);
