@@ -487,9 +487,9 @@ void GridDialog_DimensionCB(Widget    widget,
 	else
 	    XmToggleButtonSetState(dialog->leftbtn, True, False);
 
-	/* make the form widget recalc its height requirement.  In the 1dH case,
-	   the align_form widget is getting too tall.  Changing from 1dH to either
-	   2d or 1dV, then makes a mess on the screen.*/
+	// make the form widget recalc its height requirement.  In the 1dH case,
+	// the align_form widget is getting too tall.  Changing from 1dH to either
+	// 2d or 1dV, then makes a mess on the screen.
 	XtVaSetValues (dialog->align_form, XmNheight, 0, NULL);
     }
     else if(widget == dialog->twoDTButton)
