@@ -1,6 +1,8 @@
 #include <stdio.h>
 #include <Xm/Xm.h>
-#include <XmI/MacrosI.h>
+#ifdef LESSTIF_VERSION
+#include <XmI/MacrosI.h> 
+#endif
 #include <Xm/FrameP.h>
 #include <Xm/Label.h>
 #include <Xm/LabelG.h>
@@ -43,9 +45,21 @@ main(int argc, char **argv)
 				 NULL);
 
   XtRealizeWidget(toplevel);
-  printf("PC: %d\n", Frame_ProcessingConstraints(one));
-
-  XtAppMainLoop(app);
+#ifdef LESSTIF_VERSION
+  printf("(IGNORE_IN_DIFF) PC: %d\n", Frame_ProcessingConstraints(one));
+#endif  
+{
+static XtWidgetGeometry Expected[] = {
+   CWWidth | CWHeight            ,  506,  322,  144,   68, 0,0,0, /* frame */
+   CWWidth | CWHeight | CWX | CWY,   11,    0,   64,   17, 0,0,0, /* OuterLabel */
+   CWWidth | CWHeight | CWX | CWY,    1,   17,  142,   50, 0,0,0, /* frame */
+   CWWidth | CWHeight | CWX | CWY,    2,   17,  138,   31, 0,0,0, /* three */
+   CWWidth | CWHeight | CWX | CWY,   12,    0,   64,   17, 0,0,0, /* InnerLabel */
+};
+/* toplevel should be replaced with to correct applicationShell */
+PrintDetails(toplevel, Expected);
+}
+  LessTifTestMainLoop(toplevel);
 
   exit(0);
 }
