@@ -42,6 +42,11 @@ Widget              leds[MAX_LED];
 Pixel               red_color_pixel;
 Pixmap              led_off_pixmap,led_on_pixmap;
 
+static char *FallBack[] = {
+		"*.geometrySlop: 2",
+		NULL
+};
+
 int
 main(int argc, char **argv)
 {
@@ -71,7 +76,7 @@ main(int argc, char **argv)
   XtInputId         inputId;
    
   toplevel = XtVaAppInitialize(&theApp, "ICTP_examples", NULL, 0,
-			       &argc, argv, NULL, NULL);
+			       &argc, argv, FallBack, NULL);
   XtSetArg(args[0],XtNtitle,"Simulator for Prof. Ang\'s I/O board");  
   XtSetValues(toplevel,args,1);
   display     = XtDisplay(toplevel);
