@@ -80,7 +80,7 @@ void replace(Widget w, XtPointer client, XtPointer call)
 
 	l[0] = XmStringCreateSimple("Yow");
 
-	XmListReplaceItemsPos(list, &l, 1, 3);
+	XmListReplaceItemsPos(list, l, 1, 3);
 }
 
 void talk(Widget w, XtPointer client, XtPointer call)
