@@ -2,6 +2,7 @@
 
 #include <stdio.h>
 #include <Xm/List.h>
+#include "XdbPrintTree.c"
 
 int
 main(int argc, char **argv)
@@ -18,6 +19,16 @@ main(int argc, char **argv)
 
     XtRealizeWidget(toplevel);
 
-    XtAppMainLoop(app);
+    XdbPrintTree(toplevel);
+
+{
+static XtWidgetGeometry Expected[] = {
+   CWWidth | CWHeight            ,   57,   73,   18,   26, 0,0,0, /* test_of_list */
+};
+/* toplevel should be replaced with to correct applicationShell */
+PrintDetails(toplevel, Expected);
+}
+  LessTifTestMainLoop(toplevel);
+
     exit(0);
 }
