@@ -29,7 +29,7 @@ static String fallback_resources[] =
 };
 
     static XtWidgetGeometry Expected[] = {
-   CWWidth | CWHeight            ,    0,    0,  444,  412, 0,0,0, /* mainWindow */
+   CWWidth | CWHeight            ,  508,  524,  444,  426, 0,0,0, /* mainWindow */
    CWWidth | CWHeight | CWX | CWY,    0,    0,  444,   30, 0,0,0, /* menuBar */
    CWWidth | CWHeight | CWX | CWY,    5,    5,   61,   20, 0,0,0, /* fileButton */
    CWWidth | CWHeight | CWX | CWY,   66,    5,   70,   20, 0,0,0, /* Edit dummy */
@@ -37,19 +37,19 @@ static String fallback_resources[] =
    CWWidth | CWHeight | CWX | CWY,  224,    5,   94,   20, 0,0,0, /* Detonate dummy */
    CWWidth | CWHeight | CWX | CWY,  318,    5,   84,   20, 0,0,0, /* Launch dummy */
    CWWidth | CWHeight | CWX | CWY,  402,    5,   37,   20, 0,0,0, /* Help */
-   CWWidth | CWHeight | CWX | CWY,    0,   30,  444,  382, 0,0,0, /* GXPanedW */
+   CWWidth | CWHeight | CWX | CWY,    0,   30,  444,  396, 0,0,0, /* GXPanedW */
    CWWidth | CWHeight | CWX | CWY,    3,    3,  438,  200, 0,0,0, /* GLWidget */
-   CWWidth | CWHeight | CWX | CWY,    3,  213,  438,   86, 0,0,0, /* GXTextOutSW */
-   CWWidth | CWHeight | CWX | CWY,    0,    0,  438,   86, 0,0,0, /* GXTextOut */
-   CWWidth | CWHeight | CWX | CWY,    3,  309,  438,   30, 0,0,0, /* GXTextIN */
-   CWWidth | CWHeight | CWX | CWY,    3,  349,  438,   30, 0,0,0, /* GXStatus */
-   CWWidth | CWHeight | CWX | CWY,    0,  343,  444,    2, 0,0,0, /* Separator */
-   CWWidth | CWHeight | CWX | CWY,  424,  299,   10,   10, 0,0,0, /* Sash */
-   CWWidth | CWHeight | CWX | CWY,    0,  303,  444,    2, 0,0,0, /* Separator */
-   CWWidth | CWHeight | CWX | CWY,  424,  203,   10,   10, 0,0,0, /* Sash */
-   CWWidth | CWHeight | CWX | CWY,    0,  207,  444,    2, 0,0,0, /* Separator */
-
-   CWWidth | CWHeight            ,  248,  254,  400,  412, 0,0,0, /* mainWindow */
+   CWWidth | CWHeight | CWX | CWY,    3,  213,  438,  100, 0,0,0, /* GXTextOutSW */
+   CWWidth | CWHeight | CWX | CWY,  423,    0,   15,  100, 0,0,0, /* VertScrollBar */
+   CWWidth | CWHeight | CWX | CWY,    0,    0,  419,  100, 0,0,0, /* GXTextOut */
+   CWWidth | CWHeight | CWX | CWY,    3,  323,  438,   30, 0,0,0, /* GXTextIN */
+   CWWidth | CWHeight | CWX | CWY,    3,  363,  438,   30, 0,0,0, /* GXStatus */
+   CWWidth | CWHeight | CWX | CWY,    0,  357,  444,    2, 0,0,0, /* separator */
+   CWWidth | CWHeight | CWX | CWY,  424,  313,   10,   10, 0,0,0, /* sash */
+   CWWidth | CWHeight | CWX | CWY,    0,  317,  444,    2, 0,0,0, /* separator */
+   CWWidth | CWHeight | CWX | CWY,  424,  203,   10,   10, 0,0,0, /* sash */
+   CWWidth | CWHeight | CWX | CWY,    0,  207,  444,    2, 0,0,0, /* separator */
+   CWWidth | CWHeight            ,  508,  524,  400,  412, 0,0,0, /* mainWindow */
    CWWidth | CWHeight | CWX | CWY,    0,    0,  400,   55, 0,0,0, /* menuBar */
    CWWidth | CWHeight | CWX | CWY,    5,    5,   61,   20, 0,0,0, /* fileButton */
    CWWidth | CWHeight | CWX | CWY,   66,    5,   70,   20, 0,0,0, /* Edit dummy */
@@ -58,18 +58,18 @@ static String fallback_resources[] =
    CWWidth | CWHeight | CWX | CWY,    5,   30,   84,   20, 0,0,0, /* Launch dummy */
    CWWidth | CWHeight | CWX | CWY,  358,   30,   37,   20, 0,0,0, /* Help */
    CWWidth | CWHeight | CWX | CWY,    0,   55,  400,  357, 0,0,0, /* GXPanedW */
-   CWWidth | CWHeight | CWX | CWY,    3,    3,  394,  175, 0,0,0, /* GLWidget */
-   CWWidth | CWHeight | CWX | CWY,    3,  188,  394,   86, 0,0,0, /* GXTextOutSW */
-   CWWidth | CWHeight | CWX | CWY,    0,    0,  394,   86, 0,0,0, /* GXTextOut */
+   CWWidth | CWHeight | CWX | CWY,    3,    3,  394,  161, 0,0,0, /* GLWidget */
+   CWWidth | CWHeight | CWX | CWY,    3,  174,  394,  100, 0,0,0, /* GXTextOutSW */
+   CWWidth | CWHeight | CWX | CWY,  379,    0,   15,  100, 0,0,0, /* VertScrollBar */
+   CWWidth | CWHeight | CWX | CWY,    0,    0,  375,  100, 0,0,0, /* GXTextOut */
    CWWidth | CWHeight | CWX | CWY,    3,  284,  394,   30, 0,0,0, /* GXTextIN */
    CWWidth | CWHeight | CWX | CWY,    3,  324,  394,   30, 0,0,0, /* GXStatus */
-   CWWidth | CWHeight | CWX | CWY,    0,  318,  400,    2, 0,0,0, /* Separator */
-   CWWidth | CWHeight | CWX | CWY,  380,  274,   10,   10, 0,0,0, /* Sash */
-   CWWidth | CWHeight | CWX | CWY,    0,  278,  400,    2, 0,0,0, /* Separator */
-   CWWidth | CWHeight | CWX | CWY,  380,  178,   10,   10, 0,0,0, /* Sash */
-   CWWidth | CWHeight | CWX | CWY,    0,  182,  400,    2, 0,0,0, /* Separator */
+   CWWidth | CWHeight | CWX | CWY,    0,  318,  400,    2, 0,0,0, /* separator */
+   CWWidth | CWHeight | CWX | CWY,  380,  274,   10,   10, 0,0,0, /* sash */
+   CWWidth | CWHeight | CWX | CWY,    0,  278,  400,    2, 0,0,0, /* separator */
+   CWWidth | CWHeight | CWX | CWY,  380,  164,   10,   10, 0,0,0, /* sash */
+   CWWidth | CWHeight | CWX | CWY,    0,  168,  400,    2, 0,0,0, /* separator */ 
     };
-
 void ShowHelp(w, client_data, call_data)
 Widget w;
 XtPointer client_data;
