@@ -1,5 +1,5 @@
 /*
- * $Header: /cvsroot/hungry/lesstif/test/Xm/menushell/test7.c,v 1.1 1998/04/22 22:01:02 u27113 Exp $
+ * $Header: /cvsroot/hungry/lesstif/test/Xm/menushell/test7.c,v 1.4 1998/09/29 17:04:07 jon Exp $
  */
 #include <Xm/Xm.h>
 #include <Xm/RowColumn.h>
@@ -67,6 +67,15 @@ main(int argc,
 				    NULL);
 
   XtRealizeWidget(toplevel);
-  XtAppMainLoop(theApp);
+
+  {
+    static XtWidgetGeometry Expected[] = {
+      CWWidth | CWHeight            ,   57,   73,   34,   17, 0,0,0, /* label */
+    };
+    /* toplevel should be replaced with to correct applicationShell */
+    PrintDetails(toplevel, Expected);
+  }
+  LessTifTestMainLoop(toplevel);
+
   exit(0);
 }
