@@ -1,19 +1,4 @@
-/* $Header: /cvsroot/lesstif/lesstif/test/Xm/messagebox/test8.c,v 1.7 2001/06/18 08:50:43 amai Exp $ */
-
-#include <stdlib.h>
-#include <stdio.h>
-
-#include <Xm/Xm.h>
-#include <Xm/CascadeB.h>
-#include <Xm/Form.h>
-#include <Xm/Label.h>
-#include <Xm/MessageB.h>
-#include <Xm/RowColumn.h>
-#include <Xm/Scale.h>
-#include <Xm/ScrollBar.h>
-
-#include "../../common/Test.h"
-
+#include <Xm/XmAll.h>
 #define LOCAL_CLIP_FRONT 0
 #define LOCAL_CLIP_REAR 1
 #define GLOBAL_CLIP_FRONT 2
@@ -22,7 +7,6 @@
 void GXMakeClipBox(void);
 
 Widget GXTopWidget, GXClipBox;
-
 int main(int argc, char **argv)
 {
   XtAppContext theApp;
@@ -48,7 +32,6 @@ static XtWidgetGeometry Expected[] = {
    CWWidth | CWHeight | CWX | CWY,  275,    0,   31,  104, 0,0,0, /* RearGlobalClipScale */
    CWWidth | CWHeight | CWX | CWY,   12,    0,   19,  104, 0,0,0, /* Scrollbar */
 };
-
 /* toplevel should be replaced with to correct applicationShell */
 PrintDetails(GXClipBox, Expected);
 }
@@ -56,7 +39,6 @@ PrintDetails(GXClipBox, Expected);
 
   exit(0);
 }
-
 static void scaleCB(Widget w, int client, XtPointer call_data)
 /*-
  *  callback for clipping scales
@@ -92,7 +74,6 @@ GXGetColor(char *colorstr)
 	return ((XtArgVal) NULL);
 
 }
-
 void GXSetTroughColor(Widget w, Pixel selectColor)
 /*-
   provide an API for setting the trough color of an XmScale Widget
@@ -166,9 +147,9 @@ void GXMakeClipBox(void)
     GXSetTroughColor(scale, GXGetColor("white"));
 
     XtManageChild(scale);
-    XtAddCallback(scale, XmNvalueChangedCallback, (XtCallbackProc) scaleCB,
+    XtAddCallback(scale, XmNvalueChangedCallback, (XtPointer) scaleCB,
 		  (XtPointer) GLOBAL_CLIP_FRONT);
-    XtAddCallback(scale, XmNdragCallback, (XtCallbackProc) scaleCB,
+    XtAddCallback(scale, XmNdragCallback, (XtPointer) scaleCB,
 		  (XtPointer) GLOBAL_CLIP_FRONT);
 
     /* front local scale */
@@ -190,9 +171,9 @@ void GXMakeClipBox(void)
     GXSetTroughColor(scale, GXGetColor("red"));
 
     XtManageChild(scale);
-    XtAddCallback(scale, XmNvalueChangedCallback, (XtCallbackProc) scaleCB,
+    XtAddCallback(scale, XmNvalueChangedCallback, (XtPointer) scaleCB,
 		  (XtPointer) LOCAL_CLIP_FRONT);
-    XtAddCallback(scale, XmNdragCallback, (XtCallbackProc) scaleCB,
+    XtAddCallback(scale, XmNdragCallback, (XtPointer) scaleCB,
 		  (XtPointer) LOCAL_CLIP_FRONT);
 
 #ifdef USEGL
@@ -240,9 +221,9 @@ void GXMakeClipBox(void)
     GXSetTroughColor(scale, GXGetColor("green"));
 
     XtManageChild(scale);
-    XtAddCallback(scale, XmNvalueChangedCallback, (XtCallbackProc) scaleCB,
+    XtAddCallback(scale, XmNvalueChangedCallback, (XtPointer) scaleCB,
 		  (XtPointer) LOCAL_CLIP_REAR);
-    XtAddCallback(scale, XmNdragCallback, (XtCallbackProc) scaleCB,
+    XtAddCallback(scale, XmNdragCallback, (XtPointer) scaleCB,
 		  (XtPointer) LOCAL_CLIP_REAR);
 
     /* rear scale */
@@ -263,9 +244,9 @@ void GXMakeClipBox(void)
 		  NULL);
     GXSetTroughColor(scale, GXGetColor("blue"));
     XtManageChild(scale);
-    XtAddCallback(scale, XmNvalueChangedCallback, (XtCallbackProc) scaleCB,
+    XtAddCallback(scale, XmNvalueChangedCallback, (XtPointer) scaleCB,
 		  (XtPointer) GLOBAL_CLIP_REAR);
-    XtAddCallback(scale, XmNdragCallback, (XtCallbackProc) scaleCB,
+    XtAddCallback(scale, XmNdragCallback, (XtPointer) scaleCB,
 		  (XtPointer) GLOBAL_CLIP_REAR);
 
     /* install_icon(GXClipBox); */
