@@ -86,7 +86,7 @@ main(int argc, char **argv)
   Arg args[1];
 
   one = XtAppInitialize(&app, argv[0], NULL, 0, &argc, argv, NULL, NULL, 0);
-  toplevel = XtCreateWidget("top", (WidgetClass)&xmBulletinBoardClassRec, one, args, 1);
+  toplevel = XtCreateWidget("top", (WidgetClass)&xmBulletinBoardClassRec, one, NULL, 0);
   XtSetArg(args[0], XmNrowColumnType, XmMENU_BAR);
   two = XtCreateWidget("top", (WidgetClass)&xmRowColumnClassRec, one, args, 1);
 
