@@ -1,6 +1,3 @@
-/* $Id: test7.c,v 1.6 2000/09/14 02:33:04 rwscott Exp $ */
-
-#include <stdlib.h>
 #include <Xm/Xm.h>
 #include <Xm/PanedW.h>
 #include <Xm/PushB.h>
@@ -8,20 +5,14 @@
 #include <Xm/Form.h> 
 #include <Xm/DialogS.h> 
 
-static char *FallBack[] = {
-		"*.geometrySlop: 0",
-		NULL
-};
-
 Widget toplevel, field, pane, button;
 Widget dialog;
 static XtWidgetGeometry Expected[] = {
    CWWidth | CWHeight            ,  492,  361,  102,   25, 0,0,0, /* TopForm */
    CWWidth | CWHeight | CWX | CWY,   10,    0,   36,   25, 0,0,0, /* Bad */
    CWWidth | CWHeight | CWX | CWY,   56,    0,   36,   25, 0,0,0, /* Good */
-
    CWWidth | CWHeight            ,    8,   24,  366,   98, 0,0,0, /* FD */
-   CWWidth | CWHeight            ,    8,   24,  366,   98, 0,0,0, /* pane */
+   CWWidth | CWHeight | CWX | CWY,    8,   24,  366,   98, 0,0,0, /* pane */
    CWWidth | CWHeight | CWX | CWY,    3,    3,  360,   59, 0,0,0, /* DetailCheckBox */
    CWWidth | CWHeight | CWX | CWY,    3,    3,  354,   25, 0,0,0, /* button_0 */
    CWWidth | CWHeight | CWX | CWY,    3,   31,  354,   25, 0,0,0, /* button_1 */
@@ -136,7 +127,7 @@ main(int argc, char **argv)
 
   XtSetLanguageProc(NULL, NULL, NULL);
 
-  toplevel = XtVaAppInitialize(&app,"Label",NULL,0,&argc,argv,FallBack,NULL);
+  toplevel = XtVaAppInitialize(&app,"Label",NULL,0,&argc,argv,NULL,NULL);
 
   Form = XmCreateForm(toplevel,"TopForm",NULL,0);
 
@@ -149,7 +140,7 @@ main(int argc, char **argv)
   		XmNrightAttachment, XmATTACH_POSITION,
   		XmNrightPosition, 45,
   		NULL);
-  XtAddCallback(pb,XmNactivateCallback,(XtCallbackProc)callback,(XtPointer)1);
+  XtAddCallback(pb,XmNactivateCallback,(void *)callback,(XtPointer)1);
   XtManageChild(pb);
   pb1 = pb;
 
@@ -162,7 +153,7 @@ main(int argc, char **argv)
   		XmNrightAttachment, XmATTACH_POSITION,
   		XmNrightPosition, 90,
   		NULL);
-  XtAddCallback(pb,XmNactivateCallback,(XtCallbackProc)callback,(XtPointer)2);
+  XtAddCallback(pb,XmNactivateCallback,(void *)callback,(XtPointer)2);
   XtManageChild(pb);
 
   XtManageChild(Form);
