@@ -40,6 +40,19 @@ main(int argc, char **argv)
 	XtAddCallback(t3, XmNvalueChangedCallback, VC, NULL);
 
         XtRealizeWidget(top);
+  {
+  static XtWidgetGeometry Expected[] = {
+  	CWWidth | CWHeight,		0,	0,	145,	87,	0,0,0,
+  	CWWidth | CWHeight | CWX | CWY,	3,	3,	139,	25,	0,0,0,
+  	CWWidth | CWHeight | CWX | CWY,	3,	31,	139,	25,	0,0,0,
+  	CWWidth | CWHeight | CWX | CWY,	3,	59,	139,	25,	0,0,0,
+};
+
+  PrintDetails(top, Expected);
+  }
+    LessTifTestMainLoop(top);
+    /*
         XtAppMainLoop(appc);
+        */
 }
 
