@@ -60,7 +60,22 @@ main(int argc, char **argv)
 
     XtRealizeWidget(toplevel);
 
+  {
+  static XtWidgetGeometry Expected[] = {
+  	CWWidth | CWHeight,		0,	0,	288,	31,	0,0,0,
+  	CWWidth | CWHeight | CWX | CWY,	3,	3,	54,	25,	0,0,0,
+  	CWWidth | CWHeight | CWX | CWY,	60,	3,	54,	25,	0,0,0,
+  	CWWidth | CWHeight | CWX | CWY,	117,	3,	54,	25,	0,0,0,
+  	CWWidth | CWHeight | CWX | CWY,	174,	3,	54,	25,	0,0,0,
+  	CWWidth | CWHeight | CWX | CWY,	231,	3,	54,	25,	0,0,0,
+};
+
+  PrintDetails(toplevel, Expected);
+  }
+    LessTifTestMainLoop(toplevel);
+    /*
     XtAppMainLoop(theApp);    
+    */
     exit(0);
 }
 
