@@ -1,8 +1,5 @@
-/* $Id: test45.c,v 1.5 2000/08/29 21:59:21 dannybackx Exp $ */
-/** test45 -- a menu bar with two pulldown menu, all made of widgets
+/** test33 -- a menu bar with two pulldown menu, all made of widgets
 **/
-
-#include <stdlib.h>
 #include <stdio.h>
 #include <Xm/XmP.h>
 #include <Xm/RowColumnP.h>
@@ -260,20 +257,20 @@ main(int argc, char **argv)
 				 &argc, argv, NULL, NULL);
 
     rc = XmCreateMenuBar(toplevel, "menubar", NULL, 0);
-    XtAddCallback(rc, XmNmapCallback, (XtCallbackProc)MapCallback, NULL);
-    XtAddCallback(rc, XmNunmapCallback, (XtCallbackProc)UnmapCallback, NULL);
+    XtAddCallback(rc, XmNmapCallback, (void *)MapCallback, NULL);
+    XtAddCallback(rc, XmNunmapCallback, (void *)UnmapCallback, NULL);
 
     pane1 = XmCreatePulldownMenu(rc, "pane1", NULL, 0);
-    XtAddCallback(XtParent(pane1), XmNpopupCallback, (XtCallbackProc)PopupCallback, NULL);
-    XtAddCallback(XtParent(pane1), XmNpopdownCallback, (XtCallbackProc)PopdownCallback, NULL);
-    XtAddCallback(pane1, XmNmapCallback, (XtCallbackProc)MapCallback, NULL);
-    XtAddCallback(pane1, XmNunmapCallback, (XtCallbackProc)UnmapCallback, NULL);
+    XtAddCallback(XtParent(pane1), XmNpopupCallback, (void *)PopupCallback, NULL);
+    XtAddCallback(XtParent(pane1), XmNpopdownCallback, (void *)PopdownCallback, NULL);
+    XtAddCallback(pane1, XmNmapCallback, (void *)MapCallback, NULL);
+    XtAddCallback(pane1, XmNunmapCallback, (void *)UnmapCallback, NULL);
 
     pane2 = XmCreatePulldownMenu(rc, "pane2", NULL, 0);
-    XtAddCallback(XtParent(pane2), XmNpopupCallback, (XtCallbackProc)PopupCallback, NULL);
-    XtAddCallback(XtParent(pane2), XmNpopdownCallback, (XtCallbackProc)PopdownCallback, NULL);
-    XtAddCallback(pane2, XmNmapCallback, (XtCallbackProc)MapCallback, NULL);
-    XtAddCallback(pane2, XmNunmapCallback, (XtCallbackProc)UnmapCallback, NULL);
+    XtAddCallback(XtParent(pane2), XmNpopupCallback, (void *)PopupCallback, NULL);
+    XtAddCallback(XtParent(pane2), XmNpopdownCallback, (void *)PopdownCallback, NULL);
+    XtAddCallback(pane2, XmNmapCallback, (void *)MapCallback, NULL);
+    XtAddCallback(pane2, XmNunmapCallback, (void *)UnmapCallback, NULL);
 
     cascade1 = XtVaCreateManagedWidget("File",
 				       xmCascadeButtonWidgetClass,
@@ -281,7 +278,7 @@ main(int argc, char **argv)
 				       XmNsubMenuId, pane1,
 				       XmNmnemonic, 'F',
 				       NULL);
-    XtAddCallback(cascade1, XmNcascadingCallback, (XtCallbackProc)CascadingCallback, NULL);
+    XtAddCallback(cascade1, XmNcascadingCallback, (void *)CascadingCallback, NULL);
 
     cascade2 = XtVaCreateManagedWidget("Edit",
 				       xmCascadeButtonWidgetClass,
@@ -289,14 +286,14 @@ main(int argc, char **argv)
 				       XmNsubMenuId, pane2,
 				       XmNmnemonic, 'E',
 				       NULL);
-    XtAddCallback(cascade2, XmNcascadingCallback, (XtCallbackProc)CascadingCallback, NULL);
+    XtAddCallback(cascade2, XmNcascadingCallback, (void *)CascadingCallback, NULL);
 
     button1 = XtVaCreateManagedWidget("Quit",
 				      xmPushButtonWidgetClass,
 				      pane1,
 				      XmNmnemonic, 'Q',
 				      NULL);
-    XtAddCallback(button1, XmNactivateCallback, (XtCallbackProc)exit_cb, NULL);
+    XtAddCallback(button1, XmNactivateCallback, (void *)exit_cb, NULL);
 
     pane3 = XmCreatePulldownMenu(pane1,
 				 "pane3",
