@@ -11,7 +11,7 @@
 #include <Xm/Xm.h>
 #include <Xm/ScrollBar.h>
 
-void 
+int
 main(int argc, char *argv[])
 {
     XtAppContext app;
