@@ -1,5 +1,4 @@
-/* $Header: /cvsroot/lesstif/lesstif/test/Xm/text/test11.c,v 1.7 2001/05/22 11:19:05 amai Exp $
-
+/*
    From:        Yasushi Yamasaki <yamapu@osk3.3web.ne.jp>
    To:          lesstif@hungry.com
    Subject:     bug report
@@ -7,13 +6,11 @@
    Cc:          yamapu@osk3.3web.ne.jp
  */
 
-#include <stdlib.h>
-#include <stdio.h>
+/* test1.c */
 #include <unistd.h>
 #include <Xm/Xm.h>
 #include <Xm/Text.h>
 
-
 int
 main(int argc, char *argv[])
 {
@@ -22,26 +19,27 @@ main(int argc, char *argv[])
     void *before;
     void *after;
     int iter = 0;
-    long diff, total = 0;
+    int diff = 0;
+    int total = 0;
 
     shell = XtAppInitialize(&app, "Test", NULL, 0,
 			    &argc, argv, NULL, NULL, 0);
-    while (iter < 100)
+    while (iter < 10000)
     {
 	before = sbrk((ptrdiff_t) 0);
 	w = XtCreateWidget("name", xmTextWidgetClass, shell, NULL, 0);
 	XtDestroyWidget(w);
 	after = sbrk((ptrdiff_t) 0);
-	diff = (long)((char *)after-(char *)before);
-	if (diff > 0)
+	if ((int)after - (int)before > 0)
 	{
 	    if (iter != 0)
 	    {
 		/*
 		printf("%i %i %p %i\n", iter, iter - diff, after - before, (after - before) / (iter - diff));
 		*/
-		total += diff;
+		total += (int)after - (int)before;
 	    }
+	    diff = iter;
 	}
 	iter++;
     }
