@@ -11,6 +11,7 @@
 
 #include <Xm/Xm.h>
 #include <Xm/PushB.h>
+#include <Xm/RowColumn.h>
 #include <Xm/Text.h>
 
 char *fallback[] = {
@@ -62,7 +63,7 @@ int main (int argc, char* argv[])
   XtSetArg (options[ac], XmNfontList, fl); ac++  ;  
   t1 = XmCreateText (rc, "text1", options, ac) ;
   XtManageChild (t1) ;
-  XmTextSetString(t1,txt) ;
+  XmTextSetString(t1,(char*)txt) ;
 
 /* Text with font set with setvalues */
   t2 = XmCreateText (rc, "text2", NULL, 0);
@@ -74,7 +75,7 @@ int main (int argc, char* argv[])
   ac = 0;
   XtSetArg (options[ac], XmNfontList, fl); ac++  ;  
   XtSetValues(t2, options, ac);
-  XmTextSetString(t2 ,txt) ;
+  XmTextSetString(t2 ,(char*)txt) ;
 
 /* Text with font set with setvalues, except the font doesn't exist */
   t3 = XmCreateText (rc, "text3", NULL, 0);
@@ -86,8 +87,7 @@ int main (int argc, char* argv[])
   ac = 0;
   XtSetArg (options[ac], XmNfontList, fl); ac++  ;  
   XtSetValues(t3, options, ac);
-  XmTextSetString(t3 ,txt) ;
-
+  XmTextSetString(t3 ,(char*)txt) ;
 /* Even stranger things .. */
   t4 = XmCreateText (rc, "text4", NULL, 0);
   XtManageChild (t4) ;
@@ -98,11 +98,11 @@ int main (int argc, char* argv[])
   ac = 0;
   XtSetArg (options[ac], XmNfontList, fl); ac++  ;  
   XtSetValues(t4, options, ac);
-  XmTextSetString(t4 ,txt) ;
+  XmTextSetString(t4 ,(char*)txt) ;
 
   t5 = XmCreateText (rc, "text5", NULL, 0);
   XtManageChild (t5) ;
-  XmTextSetString(t5 ,txt) ;
+  XmTextSetString(t5 ,(char*)txt) ;
 
   XtAddCallback(t5, XmNhelpCallback, doit, "text widget");
   XtAddCallback(rc, XmNhelpCallback, doit, "global");
