@@ -1,5 +1,3 @@
-/* $Id: test4.c,v 1.4 2000/08/25 13:38:57 amai Exp $ */
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <Xm/Xm.h>
@@ -16,8 +14,8 @@ static String FallBack[] = {
 NULL};
 
 static XtResource resources[] = {
-	{"time","time",XtRInt,sizeof(int),XtOffset(AppResourcesPtr,time),XtRImmediate, (XtPointer)1000},
-	{"autoExit","autoExit",XtRBoolean,sizeof(Boolean),XtOffset(AppResourcesPtr,autoExit),XtRImmediate, (XtPointer)False},
+	{"time","time",XtRInt,sizeof(int),XtOffset(AppResourcesPtr,time),XtRImmediate, (void *)1000},
+	{"autoExit","autoExit",XtRBoolean,sizeof(Boolean),XtOffset(AppResourcesPtr,autoExit),XtRImmediate, (void *)False},
 };
 
 static XrmOptionDescRec opTable[] = {
@@ -150,10 +148,10 @@ char *string;
 	TestResults.modifyVerify = False;
 	TestResults.modifyVerifyW = False;
 	TestResults.motionVerify = False;
-	XtAddCallback(W, XmNvalueChangedCallback, (XtCallbackProc)valueChange, NULL);
-	XtAddCallback(W, XmNmodifyVerifyCallback, (XtCallbackProc)modifyVerify, NULL);
-	XtAddCallback(W, XmNmodifyVerifyCallbackWcs, (XtCallbackProc)modifyVerifyW, NULL);
-	XtAddCallback(W, XmNmotionVerifyCallback, (XtCallbackProc)motionVerify, NULL);
+	XtAddCallback(W, XmNvalueChangedCallback, (void *)valueChange, NULL);
+	XtAddCallback(W, XmNmodifyVerifyCallback, (void *)modifyVerify, NULL);
+	XtAddCallback(W, XmNmodifyVerifyCallbackWcs, (void *)modifyVerifyW, NULL);
+	XtAddCallback(W, XmNmotionVerifyCallback, (void *)motionVerify, NULL);
 	XmTextFieldSetString(W, TestString);
 
 	string = XmTextFieldGetString(W);
