@@ -1,9 +1,8 @@
 /**
  *
- * $Id: Test.c,v 1.31 2000/11/09 15:24:02 amai Exp $
+ * $Id: Test.c,v 1.22 1999/10/23 12:39:29 amai Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
- * Copyright (C) 1996-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -25,8 +24,6 @@
 
 #include <stdlib.h>
 #include <stdio.h>
-#include <string.h>
-
 #include <X11/X.h>
 #include <X11/IntrinsicP.h>
 #include <X11/StringDefs.h>
@@ -37,14 +34,9 @@
 
 int GlobalErrors = 0;
 
-/* local prototypes */
-static void Initialize(Widget w);
+static Time SynthTime = 0;
+
 static void Delay(Widget w);
-static void Exit(Widget w);
-static void Popup(Widget w, Boolean *mapped, XEvent *event);
-static void TimeOut(Boolean *mapped);
-static void LessTifTestPrintEvent(Widget w, XEvent *event);
-static void LessTifTestProcessEvent(Widget w);
 
 typedef struct
 {
@@ -53,7 +45,9 @@ typedef struct
     int geometrySlop;
     Boolean printEvents;
     String dumpOnFailureFile;
-} AppResources_t, *AppResourcesPtr;
+}
+AppResources_t, *AppResourcesPtr;
+
 static AppResources_t AppResources;
 
 static XtResource resources[] =
@@ -67,7 +61,7 @@ static XtResource resources[] =
 
 /* ************** */
 
-const char *
+char *
 XdbGeometryResult2String(XtGeometryResult r)
 {
     switch (r)
@@ -91,7 +85,7 @@ XdbGeometryResult2String(XtGeometryResult r)
 
 /* ************** */
 
-extern const char *
+char *
 XdbWidgetGeometry2String(XtWidgetGeometry *g)
 {
     static char o1[128], o2[128], b[20], *out = NULL;
@@ -177,7 +171,7 @@ Initialize(Widget w)
 
 /* ************** */
 
-extern int
+int
 LessTifTestGetSlop(Widget w)
 {
     Initialize(w);
@@ -186,7 +180,7 @@ LessTifTestGetSlop(Widget w)
 
 /* ************** */
 
-extern void
+void
 LessTifTestSetSlop(Widget w, int slop)
 {
     Initialize(w);
@@ -198,9 +192,9 @@ LessTifTestSetSlop(Widget w, int slop)
 static void
 Exit(Widget w)
 {
-/*    Display *display = 
+    Display *display = 
       XtIsSubclass(w,coreWidgetClass) ? XtDisplay(w) : XtDisplay(XtParent(w));
-    XtAppContext app_context=XtWidgetToApplicationContext(w); */
+    XtAppContext app_context=XtWidgetToApplicationContext(w);
 
     /* destroy application and reclaim memory */ 
 
@@ -414,7 +408,7 @@ TimeOut(Boolean *mapped)
 
 /* ************** */
 
-extern void
+void
 LessTifTestDelay(Widget w, unsigned long interval)
 {
     Boolean mapped = False;
@@ -438,7 +432,7 @@ Delay(Widget w)
 
 /* ************** */
 
-extern void
+void
 LessTifTestFlushEvents(Widget w)
 {
     Display *display = XtIsSubclass(w, coreWidgetClass) ? XtDisplay(w) : XtDisplay(XtParent(w));
@@ -454,8 +448,7 @@ LessTifTestFlushEvents(Widget w)
 
 /* ************** */
 
-extern void
-LessTifTestPrintEvents(Widget w, Boolean flag)
+void LessTifTestPrintEvents(Widget w, Boolean flag)
 {
 	LessTifTestFlushEvents(w);
 	AppResources.printEvents = flag;
@@ -463,7 +456,7 @@ LessTifTestPrintEvents(Widget w, Boolean flag)
 
 /* ************** */
 
-extern int
+int
 LessTifTestResizeWidget(Widget w, Dimension wt, Dimension ht)
 {
     Dimension bw;
@@ -479,7 +472,7 @@ LessTifTestResizeWidget(Widget w, Dimension wt, Dimension ht)
 
 /* ************** */
 
-extern int
+int
 LessTifTestWaitForIt(Widget w)
 {
     XWindowAttributes window_attributes;
@@ -507,7 +500,7 @@ LessTifTestWaitForIt(Widget w)
 
 /* ************** */
 
-extern int
+int
 LessTifTestMainLoop(Widget w)
 {
     Initialize(w);
@@ -536,7 +529,7 @@ LessTifTestMainLoop(Widget w)
 
 /* ************** */
 
-extern void
+void
 LessTifTestWarpPointerAbove(Widget w)
 {
     Dimension width, height;
@@ -561,7 +554,7 @@ LessTifTestWarpPointerAbove(Widget w)
 
 /* ************** */
 
-extern void
+void
 LessTifTestWarpPointer(Widget w)
 {
     Dimension width, height;
@@ -586,99 +579,7 @@ LessTifTestWarpPointer(Widget w)
 
 /* ************** */
 
-extern void
-LessTifTestKeyRelease(Widget w, KeySym keysym, unsigned int state)
-{
-    Display *display = XtIsSubclass(w, coreWidgetClass) ? XtDisplay(w) : XtDisplay(XtParent(w));
-    Window window = XtIsSubclass(w, coreWidgetClass) ? XtWindow(w) : XtWindow(XtParent(w));
-    XKeyEvent key_event =
-    {
-	KeyRelease,
-	0,
-	False,
-	NULL, /* display, */
-	None, /* window, */
-	None, /* root, */
-	None, /* subwindow, */
-	CurrentTime,
-	0, 0,
-	0, 0,
-	0,
-	0x09,
-	True
-    };
-    XEvent *event;
-    unsigned int keys_buttons;
-
-    key_event.keycode = XKeysymToKeycode(display, keysym);
-    key_event.display=display;
-    key_event.state=state;
-    key_event.window=key_event.root=key_event.subwindow=window;
-    LessTifTestWarpPointer(w);
-    XQueryPointer(display, window,
-		  &key_event.root,
-		  &key_event.subwindow,
-		  &key_event.x_root, &key_event.y_root,
-		  &key_event.x, &key_event.y,
-		  &keys_buttons);
-    event = (XEvent*)&key_event;
-    event->xany.serial = NextRequest(display);
-    event->xbutton.time = XtLastTimestampProcessed(display);
-    LessTifTestDelay(w, 200);
-    XSendEvent(display, key_event.window, True, KeyReleaseMask, event);
-    LessTifTestFlushEvents(w);
-    Delay(w);
-}
-
-/* ************** */
-
-extern void
-LessTifTestKeyPress(Widget w, KeySym keysym, unsigned int state)
-{
-    Display *display = XtIsSubclass(w, coreWidgetClass) ? XtDisplay(w) : XtDisplay(XtParent(w));
-    Window window = XtIsSubclass(w, coreWidgetClass) ? XtWindow(w) : XtWindow(XtParent(w));
-    XKeyEvent key_event =
-    {
-	KeyPress,
-	0,
-	False,
-	NULL, /* display, */
-	None, /* window, */
-	None, /* root, */
-	None, /* subwindow, */
-	CurrentTime,
-	0, 0,
-	0, 0,
-	0,
-	0x09,
-	True
-    };
-    XEvent *event;
-    unsigned int keys_buttons;
-
-    key_event.keycode = XKeysymToKeycode(display, keysym);
-    key_event.display=display;
-    key_event.state=state;
-    key_event.window=key_event.root=key_event.subwindow=window;
-    LessTifTestWarpPointer(w);
-    XQueryPointer(display, window,
-		  &key_event.root,
-		  &key_event.subwindow,
-		  &key_event.x_root, &key_event.y_root,
-		  &key_event.x, &key_event.y,
-		  &keys_buttons);
-    event = (XEvent*)&key_event;
-    event->xany.serial = NextRequest(display);
-    event->xbutton.time = XtLastTimestampProcessed(display);
-    LessTifTestDelay(w, 200);
-    XSendEvent(display, InputFocus, True, KeyPressMask, event);
-    LessTifTestFlushEvents(w);
-    Delay(w);
-}
-
-/* ************** */
-
-extern void
+void
 LessTifTestKeysym(Widget w, KeySym keysym)
 {
     Display *display = XtIsSubclass(w, coreWidgetClass) ? XtDisplay(w) : XtDisplay(XtParent(w));
@@ -714,19 +615,18 @@ LessTifTestKeysym(Widget w, KeySym keysym)
 		  &keys_buttons);
     event = (XEvent*)&key_event;
     event->xany.serial = NextRequest(display);
-    event->xbutton.time = XtLastTimestampProcessed(display);
-    LessTifTestDelay(w, 200);
-    XSendEvent(display, InputFocus, True, KeyPressMask, event);
+    event->xbutton.time = SynthTime;
+    SynthTime += 200;
+    XSendEvent(display, PointerWindow, True, KeyPressMask, event);
     key_event.type = KeyRelease;
-    key_event.window = XtWindow(XtParent(w));
-    XSendEvent(display, key_event.window, True, KeyReleaseMask, event);
+    XSendEvent(display, PointerWindow, True, KeyReleaseMask, event);
     LessTifTestFlushEvents(w);
     Delay(w);
 }
 
 /* ************** */
 
-extern void
+void
 LessTifTestEsc(Widget w)
 {
     LessTifTestKeysym(w, XK_Escape);
@@ -734,8 +634,8 @@ LessTifTestEsc(Widget w)
 
 /* ************** */
 
-extern void
-LessTifTestBtnDown(Widget w, int button)
+void
+LessTifTestBtn1Down(Widget w)
 {
     Display *display = XtIsSubclass(w, coreWidgetClass) ? XtDisplay(w) : XtDisplay(XtParent(w));
     Window window = XtIsSubclass(w, coreWidgetClass) ? XtWindow(w) : XtWindow(XtParent(w));
@@ -758,7 +658,6 @@ LessTifTestBtnDown(Widget w, int button)
     XEvent *event;
     unsigned int keys_buttons;
 
-    button_event.button = button;
     button_event.display=display;
     button_event.window=button_event.root=button_event.subwindow=window;
     LessTifTestWarpPointer(w);
@@ -770,8 +669,8 @@ LessTifTestBtnDown(Widget w, int button)
 		  &keys_buttons);
     event = (XEvent*)&button_event;
     event->xany.serial = NextRequest(display);
-    event->xbutton.time = XtLastTimestampProcessed(display);
-    LessTifTestDelay(w, 200);
+    event->xbutton.time = SynthTime;
+    SynthTime += 200;
     XSendEvent(display, PointerWindow, True, ButtonPressMask, event);
     LessTifTestFlushEvents(w);
     Delay(w);
@@ -779,8 +678,8 @@ LessTifTestBtnDown(Widget w, int button)
 
 /* ************** */
 
-extern void
-LessTifTestBtnUp(Widget w, int button)
+void
+LessTifTestBtn1Up(Widget w)
 {
     Display *display = XtIsSubclass(w, coreWidgetClass) ? XtDisplay(w) : XtDisplay(XtParent(w));
     Window window = XtIsSubclass(w, coreWidgetClass) ? XtWindow(w) : XtWindow(XtParent(w));
@@ -803,22 +702,6 @@ LessTifTestBtnUp(Widget w, int button)
     XEvent *event;
     unsigned int keys_buttons;
 
-    switch (button)
-    {
-    case 1:
-	button_event.state = Button1Mask;
-	break;
-    case 2:
-	button_event.state = Button2Mask;
-	break;
-    case 3:
-	button_event.state = Button3Mask;
-	break;
-    default:
-	button_event.state = 0;
-    	break;
-    }
-    button_event.button = button;
     button_event.display=display;
     button_event.window=button_event.root=button_event.subwindow=window;
     LessTifTestWarpPointer(w);
@@ -830,8 +713,8 @@ LessTifTestBtnUp(Widget w, int button)
 		  &keys_buttons);
     event = (XEvent*)&button_event;
     event->xany.serial = NextRequest(display);
-    event->xbutton.time = XtLastTimestampProcessed(display);
-    LessTifTestDelay(w, 200);
+    event->xbutton.time = SynthTime;
+    SynthTime += 200;
     XSendEvent(display, PointerWindow, True, ButtonReleaseMask, event);
     LessTifTestFlushEvents(w);
     Delay(w);
@@ -839,55 +722,7 @@ LessTifTestBtnUp(Widget w, int button)
 
 /* ************** */
 
-extern void
-LessTifTestBtn1Down(Widget w)
-{
-    LessTifTestBtnDown(w, 1);
-}
-
-/* ************** */
-
-extern void
-LessTifTestBtn1Up(Widget w)
-{
-    LessTifTestBtnUp(w, 1);
-}
-
-/* ************** */
-
-extern void
-LessTifTestBtn2Down(Widget w)
-{
-    LessTifTestBtnDown(w, 2);
-}
-
-/* ************** */
-
-extern void
-LessTifTestBtn2Up(Widget w)
-{
-    LessTifTestBtnUp(w, 2);
-}
-
-/* ************** */
-
-extern void
-LessTifTestBtn3Down(Widget w)
-{
-    LessTifTestBtnDown(w, 3);
-}
-
-/* ************** */
-
-extern void
-LessTifTestBtn3Up(Widget w)
-{
-    LessTifTestBtnUp(w, 3);
-}
-
-/* ************** */
-
-extern int
+int
 LessTifTestPushButton(Widget w)
 {
     Initialize(w);
